@@ -1,11 +1,12 @@
 /*
  * Copyright (C) 2009-2011, Pino Toscano <pino@kde.org>
  * Copyright (C) 2016 Jakub Alba <jakubalba@gmail.com>
- * Copyright (C) 2017, 2022, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2017, 2022, 2025, Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2018, 2020, Adam Reichold <adam.reichold@t-online.de>
  * Copyright (C) 2019, Masamichi Hosoda <trueroad@trueroad.jp>
  * Copyright (C) 2019, 2020, Oliver Sander <oliver.sander@tu-dresden.de>
- * Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+ * Copyright (C) 2025, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+ * Copyright (C) 2025 Nathanael d. Noblet <nathanael@noblet.ca>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -53,22 +54,22 @@ using namespace poppler;
 
 document_private::document_private(std::unique_ptr<GooString> &&file_path, const std::string &owner_password, const std::string &user_password) : document_private()
 {
-    doc = new PDFDoc(std::move(file_path), GooString(owner_password.c_str()), GooString(user_password.c_str()));
+    doc = std::make_unique<PDFDoc>(std::move(file_path), GooString(owner_password.c_str()), GooString(user_password.c_str()));
 }
 
 document_private::document_private(byte_array *file_data, const std::string &owner_password, const std::string &user_password) : document_private()
 {
     file_data->swap(doc_data);
-    MemStream *memstr = new MemStream(&doc_data[0], 0, doc_data.size(), Object(objNull));
-    doc = new PDFDoc(memstr, GooString(owner_password.c_str()), GooString(user_password.c_str()));
+    auto memstr = std::make_unique<MemStream>(doc_data.data(), 0, doc_data.size(), Object::null());
+    doc = std::make_unique<PDFDoc>(std::move(memstr), GooString(owner_password.c_str()), GooString(user_password.c_str()));
 }
 
 document_private::document_private(const char *file_data, int file_data_length, const std::string &owner_password, const std::string &user_password) : document_private()
 {
     raw_doc_data = file_data;
     raw_doc_data_length = file_data_length;
-    MemStream *memstr = new MemStream(raw_doc_data, 0, raw_doc_data_length, Object(objNull));
-    doc = new PDFDoc(memstr, GooString(owner_password.c_str()), GooString(user_password.c_str()));
+    auto memstr = std::make_unique<MemStream>(raw_doc_data, 0, raw_doc_data_length, Object::null());
+    doc = std::make_unique<PDFDoc>(std::move(memstr), GooString(owner_password.c_str()), GooString(user_password.c_str()));
 }
 
 document_private::document_private() : GlobalParamsIniter(detail::error_function), doc(nullptr), raw_doc_data(nullptr), raw_doc_data_length(0), is_locked(false) { }
@@ -76,8 +77,6 @@ document_private::document_private() : GlobalParamsIniter(detail::error_function
 document_private::~document_private()
 {
     delete_all(embedded_files);
-
-    delete doc;
 }
 
 document *document_private::check_document(document_private *doc, byte_array *file_data)
@@ -87,13 +86,13 @@ document *document_private::check_document(document_private *doc, byte_array *fi
             doc->is_locked = true;
         }
         return new document(*doc);
-    } else {
-        // put back the document data where it was before
-        if (file_data) {
-            file_data->swap(doc->doc_data);
-        }
-        delete doc;
     }
+    // put back the document data where it was before
+    if (file_data) {
+        file_data->swap(doc->doc_data);
+    }
+    delete doc;
+
     return nullptr;
 }
 
@@ -171,7 +170,7 @@ bool document::unlock(const std::string &owner_password, const std::string &user
         } else if (d->raw_doc_data) {
             newdoc = new document_private(d->raw_doc_data, d->raw_doc_data_length, owner_password, user_password);
         } else {
-            newdoc = new document_private(std::make_unique<GooString>(d->doc->getFileName()), owner_password, user_password);
+            newdoc = new document_private(d->doc->getFileName()->copy(), owner_password, user_password);
         }
         if (!newdoc->doc->isOk()) {
             d->doc_data.swap(newdoc->doc_data);
@@ -325,27 +324,6 @@ bool document::set_info_key(const std::string &key, const ustring &val)
     return true;
 }
 
-/**
- Gets the time_type value of the specified \p key of the document
- information.
-
- \returns the time_t value for the \p key
- \see info_keys, info_date
- */
-time_type document::info_date(const std::string &key) const
-{
-    if (d->is_locked) {
-        return time_type(-1);
-    }
-
-    std::unique_ptr<GooString> goo_date(d->doc->getDocInfoStringEntry(key.c_str()));
-    if (!goo_date) {
-        return time_type(-1);
-    }
-
-    return static_cast<time_type>(dateStringToTime(goo_date.get()));
-}
-
 /**
  Gets the time_t value of the specified \p key of the document
  information.
@@ -367,30 +345,6 @@ time_t document::info_date_t(const std::string &key) const
     return dateStringToTime(goo_date.get());
 }
 
-/**
- Sets the time_type value of the specified \p key of the %document information
- to \p val.
- If \p val == time_type(-1), the entry specified by \p key is removed.
-
- \returns true on success, false on failure
- */
-bool document::set_info_date(const std::string &key, time_type val)
-{
-    if (d->is_locked) {
-        return false;
-    }
-
-    std::unique_ptr<GooString> goo_date;
-
-    if (val != time_type(-1)) {
-        time_t t = static_cast<time_t>(val);
-        goo_date = timeToDateString(&t);
-    }
-
-    d->doc->setDocInfoStringEntry(key.c_str(), std::move(goo_date));
-    return true;
-}
-
 /**
  Sets the time_t value of the specified \p key of the %document information
  to \p val.
@@ -666,26 +620,6 @@ bool document::set_producer(const ustring &producer)
     return true;
 }
 
-/**
- Gets the document's creation date as a time_type value.
-
- \returns the document's creation date as a time_type value
- \see set_creation_date, info_date
- */
-time_type document::get_creation_date() const
-{
-    if (d->is_locked) {
-        return time_type(-1);
-    }
-
-    std::unique_ptr<GooString> goo_creation_date(d->doc->getDocInfoCreatDate());
-    if (!goo_creation_date) {
-        return time_type(-1);
-    }
-
-    return static_cast<time_type>(dateStringToTime(goo_creation_date.get()));
-}
-
 /**
  Gets the document's creation date as a time_t value.
 
@@ -706,29 +640,6 @@ time_t document::get_creation_date_t() const
     return dateStringToTime(goo_creation_date.get());
 }
 
-/**
- Sets the %document's creation date to \p creation_date.
- If \p creation_date == time_type(-1), the %document's creation date is removed.
-
- \returns true on success, false on failure
- */
-bool document::set_creation_date(time_type creation_date)
-{
-    if (d->is_locked) {
-        return false;
-    }
-
-    std::unique_ptr<GooString> goo_creation_date;
-
-    if (creation_date != time_type(-1)) {
-        time_t t = static_cast<time_t>(creation_date);
-        goo_creation_date = timeToDateString(&t);
-    }
-
-    d->doc->setDocInfoCreatDate(std::move(goo_creation_date));
-    return true;
-}
-
 /**
  Sets the %document's creation date to \p creation_date.
  If \p creation_date == time_t(-1), the %document's creation date is removed.
@@ -751,26 +662,6 @@ bool document::set_creation_date_t(time_t creation_date)
     return true;
 }
 
-/**
- Gets the document's modification date as a time_type value.
-
- \returns the document's modification date as a time_type value
- \see set_modification_date, info_date
- */
-time_type document::get_modification_date() const
-{
-    if (d->is_locked) {
-        return time_type(-1);
-    }
-
-    std::unique_ptr<GooString> goo_modification_date(d->doc->getDocInfoModDate());
-    if (!goo_modification_date) {
-        return time_type(-1);
-    }
-
-    return static_cast<time_type>(dateStringToTime(goo_modification_date.get()));
-}
-
 /**
  Gets the document's modification date as a time_t value.
 
@@ -791,29 +682,6 @@ time_t document::get_modification_date_t() const
     return dateStringToTime(goo_modification_date.get());
 }
 
-/**
- Sets the %document's modification date to \p mod_date.
- If \p mod_date == time_type(-1), the %document's modification date is removed.
-
- \returns true on success, false on failure
- */
-bool document::set_modification_date(time_type mod_date)
-{
-    if (d->is_locked) {
-        return false;
-    }
-
-    std::unique_ptr<GooString> goo_mod_date;
-
-    if (mod_date != time_type(-1)) {
-        time_t t = static_cast<time_t>(mod_date);
-        goo_mod_date = timeToDateString(&t);
-    }
-
-    d->doc->setDocInfoModDate(std::move(goo_mod_date));
-    return true;
-}
-
 /**
  Sets the %document's modification date to \p mod_date.
  If \p mod_date == time_t(-1), the %document's modification date is removed.
@@ -867,6 +735,32 @@ bool document::is_linearized() const
     return d->doc->isLinearized();
 }
 
+/**
+ \returns the form type within the document
+ \since 25.04
+ */
+enum document::form_type document::form_type() const
+{
+    switch (d->doc->getCatalog()->getFormType()) {
+    case Catalog::AcroForm:
+        return form_type::acro;
+    case Catalog::XfaForm:
+        return form_type::xfa;
+    case Catalog::NoForm:
+    default:
+        return form_type::none;
+    }
+}
+
+/**
+ \returns true if the document contains javascript
+ \since 25.04
+ */
+bool document::has_javascript() const
+{
+    return d->doc->getCatalog()->numJS() > 0;
+}
+
 /**
  Check for available "document permission".
 
@@ -961,7 +855,7 @@ page *document::create_page(const ustring &label) const
     std::unique_ptr<GooString> goolabel(detail::ustring_to_unicode_GooString(label));
     int index = 0;
 
-    if (!d->doc->getCatalog()->labelToIndex(goolabel.get(), &index)) {
+    if (!d->doc->getCatalog()->labelToIndex(*goolabel, &index)) {
         return nullptr;
     }
     return create_page(index);
@@ -981,13 +875,11 @@ page *document::create_page(int index) const
         page *p = new page(d, index);
         if (p->d->page) {
             return p;
-        } else {
-            delete p;
-            return nullptr;
         }
-    } else {
+        delete p;
         return nullptr;
     }
+    return nullptr;
 }
 
 /**
@@ -1095,7 +987,7 @@ std::map<std::string, destination> document::create_destination_map() const
         std::unique_ptr<LinkDest> link_dest = catalog->getDestsDest(i);
 
         if (link_dest) {
-            destination dest(new destination_private(link_dest.get(), d->doc));
+            destination dest(new destination_private(link_dest.get(), d->doc.get()));
 
             m.emplace(std::move(key), std::move(dest));
         }
@@ -1104,11 +996,11 @@ std::map<std::string, destination> document::create_destination_map() const
     // Iterate from name-tree
     const int nDestsNameTree = catalog->numDestNameTree();
     for (int i = 0; i < nDestsNameTree; ++i) {
-        std::string key(catalog->getDestNameTreeName(i)->c_str(), catalog->getDestNameTreeName(i)->getLength());
+        std::string key(catalog->getDestNameTreeName(i)->toStr());
         std::unique_ptr<LinkDest> link_dest = catalog->getDestNameTreeDest(i);
 
         if (link_dest) {
-            destination dest(new destination_private(link_dest.get(), d->doc));
+            destination dest(new destination_private(link_dest.get(), d->doc.get()));
 
             m.emplace(std::move(key), std::move(dest));
         }
@@ -1128,8 +1020,7 @@ bool document::save(const std::string &file_name) const
         return false;
     }
 
-    GooString fname(file_name.c_str());
-    return d->doc->saveAs(fname) == errNone;
+    return d->doc->saveAs(file_name) == errNone;
 }
 
 /**
@@ -1143,8 +1034,7 @@ bool document::save_a_copy(const std::string &file_name) const
         return false;
     }
 
-    GooString fname(file_name.c_str());
-    return d->doc->saveWithoutChangesAs(fname) == errNone;
+    return d->doc->saveWithoutChangesAs(file_name) == errNone;
 }
 
 /**
@@ -1156,7 +1046,7 @@ bool document::save_a_copy(const std::string &file_name) const
  */
 document *document::load_from_file(const std::string &file_name, const std::string &owner_password, const std::string &user_password)
 {
-    document_private *doc = new document_private(std::make_unique<GooString>(file_name.c_str()), owner_password, user_password);
+    auto *doc = new document_private(std::make_unique<GooString>(file_name.c_str()), owner_password, user_password);
     return document_private::check_document(doc, nullptr);
 }
 
@@ -1176,7 +1066,7 @@ document *document::load_from_data(byte_array *file_data, const std::string &own
         return nullptr;
     }
 
-    document_private *doc = new document_private(file_data, owner_password, user_password);
+    auto *doc = new document_private(file_data, owner_password, user_password);
     return document_private::check_document(doc, file_data);
 }
 
@@ -1200,6 +1090,6 @@ document *document::load_from_raw_data(const char *file_data, int file_data_leng
         return nullptr;
     }
 
-    document_private *doc = new document_private(file_data, file_data_length, owner_password, user_password);
+    auto *doc = new document_private(file_data, file_data_length, owner_password, user_password);
     return document_private::check_document(doc, nullptr);
 }
