@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010, Pino Toscano <pino@kde.org>
- * Copyright (C) 2018, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2018, 2022, Albert Astals Cid <aacid@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,14 +36,14 @@ public:
     static image_private *create_data(int width, int height, image::format_enum format);
     static image_private *create_data(char *data, int width, int height, image::format_enum format);
 
-    int ref;
-    char *data;
+    int ref = 1;
+    char *data = nullptr;
     int width;
     int height;
-    int bytes_per_row;
-    int bytes_num;
-    image::format_enum format : 3;
-    bool own_data : 1;
+    int bytes_per_row = 0;
+    int bytes_num = 0;
+    image::format_enum format;
+    bool own_data : 1 = true;
 };
 
 }
