@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2010-2011, Pino Toscano <pino@kde.org>
  * Copyright (C) 2013 Adrian Johnson <ajohnson@redneon.com>
- * Copyright (C) 2017-2019, 2021, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2017-2019, 2021, 2024, 2025, Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2017, Jeroen Ooms <jeroenooms@gmail.com>
  * Copyright (C) 2018, Zsombor Hollay-Horvath <hollay.horvath@gmail.com>
  * Copyright (C) 2018, Adam Reichold <adam.reichold@t-online.de>
@@ -31,13 +31,13 @@
 
 #include <config.h>
 #include "goo/ImgWriter.h"
-#if defined(ENABLE_LIBPNG)
+#if ENABLE_LIBPNG
 #    include "goo/PNGWriter.h"
 #endif
-#if defined(ENABLE_LIBJPEG)
+#if ENABLE_LIBJPEG
 #    include "goo/JpegWriter.h"
 #endif
-#if defined(ENABLE_LIBTIFF)
+#if ENABLE_LIBTIFF
 #    include "goo/TiffWriter.h"
 #endif
 #include "goo/NetPBMWriter.h"
@@ -52,11 +52,11 @@ namespace {
 
 struct FileCloser
 {
-    inline explicit FileCloser(FILE *ff) : f(ff) { }
-    inline ~FileCloser() { (void)close(); }
+    explicit FileCloser(FILE *ff) : f(ff) { }
+    ~FileCloser() { (void)close(); }
     FileCloser(const FileCloser &) = delete;
     FileCloser &operator=(const FileCloser &) = delete;
-    inline bool close()
+    bool close()
     {
         if (f) {
             const int c = fclose(f);
@@ -106,7 +106,7 @@ NetPBMWriter::Format pnm_format(poppler::image::format_enum format)
 
 using namespace poppler;
 
-image_private::image_private(int iwidth, int iheight, image::format_enum iformat) : ref(1), data(nullptr), width(iwidth), height(iheight), bytes_per_row(0), bytes_num(0), format(iformat), own_data(true) { }
+image_private::image_private(int iwidth, int iheight, image::format_enum iformat) : width(iwidth), height(iheight), format(iformat) { }
 
 image_private::~image_private()
 {
@@ -149,7 +149,7 @@ image_private *image_private::create_data(char *data, int width, int height, ima
         return nullptr;
     }
 
-    image_private *d = new image_private(width, height, format);
+    auto *d = new image_private(width, height, format);
     d->bytes_num = bpr * height;
     d->data = data;
     d->own_data = false;
@@ -301,23 +301,15 @@ const char *image::const_data() const
 }
 
 /**
- Copy of a slice of the image.
+ Copies the image (i.e. \em detaches)
 
- \param r the sub-area of this image to copy; if empty, the whole image is
-          copied
-
- \returns a new image representing the specified part of the current image
+ \returns a new image copied from the current image
  */
-image image::copy(const rect &r) const
+image image::copy() const
 {
-    if (r.is_empty()) {
-        image img(*this);
-        img.detach();
-        return img;
-    }
-
-    // ### FIXME
-    return *this;
+    image img(*this);
+    img.detach();
+    return img;
 }
 
 /**
@@ -345,31 +337,26 @@ bool image::save(const std::string &file_name, const std::string &out_format, in
     }
 
     std::string fmt = out_format;
-    std::transform(fmt.begin(), fmt.end(), fmt.begin(), tolower);
+    std::ranges::transform(fmt, fmt.begin(), tolower);
 
     std::unique_ptr<ImgWriter> w;
     const int actual_dpi = dpi == -1 ? 75 : dpi;
-    if (false) {
-    }
-#if defined(ENABLE_LIBPNG)
-    else if (fmt == "png") {
+    if (fmt == "png") {
+#if ENABLE_LIBPNG
         w = std::make_unique<PNGWriter>();
-    }
 #endif
-#if defined(ENABLE_LIBJPEG)
-    else if (fmt == "jpeg" || fmt == "jpg") {
+    } else if (fmt == "jpeg" || fmt == "jpg") {
+#if ENABLE_LIBJPEG
         w = std::make_unique<JpegWriter>();
-    }
 #endif
-#if defined(ENABLE_LIBTIFF)
-    else if (fmt == "tiff") {
+    } else if (fmt == "tiff") {
+#if ENABLE_LIBTIFF
         w = std::make_unique<TiffWriter>();
-    }
 #endif
-    else if (fmt == "pnm") {
+    } else if (fmt == "pnm") {
         w = std::make_unique<NetPBMWriter>(pnm_format(d->format));
     }
-    if (!w.get()) {
+    if (!w) {
         return false;
     }
     FILE *f = fopen(file_name.c_str(), "wb");
@@ -389,13 +376,13 @@ bool image::save(const std::string &file_name, const std::string &out_format, in
         std::vector<unsigned char> row(3 * d->width);
         char *hptr = d->data;
         for (int y = 0; y < d->height; ++y) {
-            unsigned char *rowptr = &row[0];
+            unsigned char *rowptr = row.data();
             for (int x = 0; x < d->width; ++x, rowptr += 3) {
                 rowptr[0] = *reinterpret_cast<unsigned char *>(hptr + x);
                 rowptr[1] = *reinterpret_cast<unsigned char *>(hptr + x);
                 rowptr[2] = *reinterpret_cast<unsigned char *>(hptr + x);
             }
-            rowptr = &row[0];
+            rowptr = row.data();
             if (!w->writeRow(&rowptr)) {
                 return false;
             }
@@ -407,13 +394,13 @@ bool image::save(const std::string &file_name, const std::string &out_format, in
         std::vector<unsigned char> row(3 * d->width);
         char *hptr = d->data;
         for (int y = 0; y < d->height; ++y) {
-            unsigned char *rowptr = &row[0];
+            unsigned char *rowptr = row.data();
             for (int x = 0; x < d->width; ++x, rowptr += 3) {
                 rowptr[0] = *reinterpret_cast<unsigned char *>(hptr + x * 3 + 2);
                 rowptr[1] = *reinterpret_cast<unsigned char *>(hptr + x * 3 + 1);
                 rowptr[2] = *reinterpret_cast<unsigned char *>(hptr + x * 3);
             }
-            rowptr = &row[0];
+            rowptr = row.data();
             if (!w->writeRow(&rowptr)) {
                 return false;
             }
@@ -435,14 +422,14 @@ bool image::save(const std::string &file_name, const std::string &out_format, in
         std::vector<unsigned char> row(3 * d->width);
         char *hptr = d->data;
         for (int y = 0; y < d->height; ++y) {
-            unsigned char *rowptr = &row[0];
+            unsigned char *rowptr = row.data();
             for (int x = 0; x < d->width; ++x, rowptr += 3) {
                 const unsigned int pixel = *reinterpret_cast<unsigned int *>(hptr + x * 4);
                 rowptr[0] = (pixel >> 16) & 0xff;
                 rowptr[1] = (pixel >> 8) & 0xff;
                 rowptr[2] = pixel & 0xff;
             }
-            rowptr = &row[0];
+            rowptr = row.data();
             if (!w->writeRow(&rowptr)) {
                 return false;
             }
@@ -452,11 +439,7 @@ bool image::save(const std::string &file_name, const std::string &out_format, in
     }
     }
 
-    if (!w->close()) {
-        return false;
-    }
-
-    return true;
+    return w->close();
 }
 
 /**
@@ -465,14 +448,14 @@ bool image::save(const std::string &file_name, const std::string &out_format, in
 std::vector<std::string> image::supported_image_formats()
 {
     std::vector<std::string> formats;
-#if defined(ENABLE_LIBPNG)
+#if ENABLE_LIBPNG
     formats.emplace_back("png");
 #endif
-#if defined(ENABLE_LIBJPEG)
+#if ENABLE_LIBJPEG
     formats.emplace_back("jpeg");
     formats.emplace_back("jpg");
 #endif
-#if defined(ENABLE_LIBTIFF)
+#if ENABLE_LIBTIFF
     formats.emplace_back("tiff");
 #endif
     formats.emplace_back("pnm");
