@@ -1,6 +1,7 @@
 #include <cstdint>
 #include <poppler-document.h>
 #include <poppler-global.h>
+#include "fuzzer_init.h"
 #include <poppler-page.h>
 #include <poppler-page-renderer.h>
 
@@ -12,6 +13,7 @@ static void dummy_error_function(const std::string &, void *) { }
 
 extern "C" int LLVMFuzzerTestOneInput(const uint8_t *data, size_t size)
 {
+    initialize_poppler_data_dir();
     if (size < input_size) {
         return 0;
     }
