@@ -5,6 +5,8 @@
  * Copyright (C) 2018, 2020, Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
  * Copyright (C) 2019, Masamichi Hosoda <trueroad@trueroad.jp>
  * Copyright (C) 2020, Jiri Jakes <freedesktop@jirijakes.eu>
+ * Copyright (C) 2025, Zsombor Hollay-Horvath <hollay.horvath@gmail.com>
+ * Copyright (C) 2026, Adam Sampson <ats@offog.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -127,7 +129,7 @@ static char charToHex(int x)
 static std::string out_hex_string(const poppler::byte_array &str)
 {
     std::string ret(str.size() * 2, '\0');
-    const char *str_p = &str[0];
+    const char *str_p = str.data();
     for (unsigned int i = 0; i < str.size(); ++i, ++str_p) {
         ret[i * 2] = charToHex((*str_p & 0xf0) >> 4);
         ret[i * 2 + 1] = charToHex(*str_p & 0xf);
@@ -188,10 +190,8 @@ static void print_info(poppler::document *doc)
         std::cout << std::setw(out_width) << "PDF IDs"
                   << ": <none>" << std::endl;
     }
-    const std::vector<std::string> keys = doc->info_keys();
-    std::vector<std::string>::const_iterator key_it = keys.begin(), key_end = keys.end();
-    for (; key_it != key_end; ++key_it) {
-        std::cout << std::setw(out_width) << *key_it << ": " << doc->info_key(*key_it) << std::endl;
+    for (const auto &key : doc->info_keys()) {
+        std::cout << std::setw(out_width) << key << ": " << doc->info_key(key) << std::endl;
     }
     std::cout << std::setw(out_width) << "Date (creation)"
               << ": " << out_date(doc->info_date_t("CreationDate")) << std::endl;
@@ -234,9 +234,8 @@ static void print_toc_item(poppler::toc_item *item, int indent)
 {
     std::cout << std::setw(indent * 2) << " "
               << "+ " << item->title() << " (" << item->is_open() << ")" << std::endl;
-    poppler::toc_item::iterator it = item->children_begin(), it_end = item->children_end();
-    for (; it != it_end; ++it) {
-        print_toc_item(*it, indent + 1);
+    for (const auto &child : item->children()) {
+        print_toc_item(child, indent + 1);
     }
 }
 
@@ -256,12 +255,11 @@ static void print_fonts(poppler::document *doc)
     std::cout << "Document fonts:" << std::endl;
     std::vector<poppler::font_info> fl = doc->fonts();
     if (!fl.empty()) {
-        std::vector<poppler::font_info>::const_iterator it = fl.begin(), it_end = fl.end();
         const std::ios_base::fmtflags f = std::cout.flags();
         std::left(std::cout);
-        for (; it != it_end; ++it) {
-            std::cout << " " << std::setw(out_width + 10) << it->name() << " " << std::setw(15) << out_font_info_type(it->type()) << " " << std::setw(5) << it->is_embedded() << " " << std::setw(5) << it->is_subset() << " " << it->file()
-                      << std::endl;
+        for (const auto &font : fl) {
+            std::cout << " " << std::setw(out_width + 10) << font.name() << " " << std::setw(15) << out_font_info_type(font.type()) << " " << std::setw(5) << font.is_embedded() << " " << std::setw(5) << font.is_subset() << " "
+                      << font.file() << std::endl;
         }
         std::cout.flags(f);
     } else {
@@ -275,13 +273,11 @@ static void print_embedded_files(poppler::document *doc)
     std::cout << "Document embedded files:" << std::endl;
     std::vector<poppler::embedded_file *> ef = doc->embedded_files();
     if (!ef.empty()) {
-        std::vector<poppler::embedded_file *>::const_iterator it = ef.begin(), it_end = ef.end();
         const std::ios_base::fmtflags flags = std::cout.flags();
         std::left(std::cout);
-        for (; it != it_end; ++it) {
-            poppler::embedded_file *f = *it;
-            std::cout << " " << std::setw(out_width + 10) << f->name() << " " << std::setw(10) << out_size(f->size()) << " " << std::setw(20) << out_date(f->creation_date_t()) << " " << std::setw(20) << out_date(f->modification_date_t())
-                      << std::endl
+        for (const auto *f : ef) {
+            std::cout << " " << std::setw(out_width + 10) << f->unicodeName() << " " << std::setw(10) << out_size(f->size()) << " " << std::setw(20) << out_date(f->creation_date_t()) << " " << std::setw(20)
+                      << out_date(f->modification_date_t()) << std::endl
                       << "     ";
             if (f->description().empty()) {
                 std::cout << "<no description>";
@@ -452,7 +448,7 @@ int main(int argc, char *argv[])
     std::string file_name(argv[1]);
 
     std::unique_ptr<poppler::document> doc(poppler::document::load_from_file(file_name));
-    if (!doc.get()) {
+    if (!doc) {
         error("loading error");
     }
     if (doc->is_locked()) {
