@@ -15,9 +15,11 @@
 //
 // Copyright (C) 2008 Ed Avis <eda@waniasset.com>
 // Copyright (C) 2011 Jim Meyering <jim@meyering.net>
-// Copyright (C) 2016, 2018, 2020 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2016, 2018, 2020, 2026 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2019 Christian Persch <chpe@src.gnome.org>
 // Copyright (C) 2019 LE GARREC Vincent <legarrec.vincent@gmail.com>
+// Copyright (C) 2022 Oliver Sander <oliver.sander@tu-dresden.de>
+// Copyright (C) 2025, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -29,7 +31,6 @@
 #include <cstdio>
 #include <climits>
 #include "goo/gfile.h"
-#include "goo/gmem.h"
 #include "poppler/Error.h"
 #include "FoFiBase.h"
 
@@ -37,54 +38,44 @@
 // FoFiBase
 //------------------------------------------------------------------------
 
-FoFiBase::FoFiBase(const char *fileA, int lenA, bool freeFileDataA)
-{
-    file = (const unsigned char *)fileA;
-    len = lenA;
-    freeFileData = freeFileDataA;
-}
+FoFiBase::FoFiBase(std::vector<unsigned char> &&fileA) : fileOwner(std::move(fileA)), file(fileOwner) { }
 
-FoFiBase::~FoFiBase()
-{
-    if (freeFileData) {
-        gfree((char *)file);
-    }
-}
+FoFiBase::FoFiBase(std::span<const unsigned char> fileA) : file(fileA) { }
 
-char *FoFiBase::readFile(const char *fileName, int *fileLen)
+FoFiBase::~FoFiBase() = default;
+
+std::optional<std::vector<unsigned char>> FoFiBase::readFile(const char *fileName)
 {
     FILE *f;
-    char *buf;
-    int n;
 
     if (!(f = openFile(fileName, "rb"))) {
         error(errIO, -1, "Cannot open '{0:s}'", fileName);
-        return nullptr;
+        return std::nullopt;
     }
     if (fseek(f, 0, SEEK_END) != 0) {
         error(errIO, -1, "Cannot seek to end of '{0:s}'", fileName);
         fclose(f);
-        return nullptr;
+        return std::nullopt;
     }
-    n = (int)ftell(f);
+    const int n = (int)ftell(f);
     if (n < 0) {
         error(errIO, -1, "Cannot determine length of '{0:s}'", fileName);
         fclose(f);
-        return nullptr;
+        return std::nullopt;
     }
     if (fseek(f, 0, SEEK_SET) != 0) {
         error(errIO, -1, "Cannot seek to start of '{0:s}'", fileName);
         fclose(f);
-        return nullptr;
+        return std::nullopt;
     }
-    buf = (char *)gmalloc(n);
-    if ((int)fread(buf, 1, n, f) != n) {
-        gfree(buf);
+    const size_t nToRead = n;
+    std::vector<unsigned char> buf;
+    buf.resize(nToRead);
+    if (fread(buf.data(), 1, nToRead, f) != nToRead) {
         fclose(f);
-        return nullptr;
+        return std::nullopt;
     }
     fclose(f);
-    *fileLen = n;
     return buf;
 }
 
@@ -92,7 +83,7 @@ int FoFiBase::getS8(int pos, bool *ok) const
 {
     int x;
 
-    if (pos < 0 || pos >= len) {
+    if (pos < 0 || static_cast<size_t>(pos) >= file.size()) {
         *ok = false;
         return 0;
     }
@@ -105,7 +96,7 @@ int FoFiBase::getS8(int pos, bool *ok) const
 
 int FoFiBase::getU8(int pos, bool *ok) const
 {
-    if (pos < 0 || pos >= len) {
+    if (pos < 0 || static_cast<size_t>(pos) >= file.size()) {
         *ok = false;
         return 0;
     }
@@ -116,7 +107,7 @@ int FoFiBase::getS16BE(int pos, bool *ok) const
 {
     int x;
 
-    if (pos < 0 || pos > INT_MAX - 1 || pos + 1 >= len) {
+    if (pos < 0 || pos > INT_MAX - 1 || pos + 1 >= int(file.size())) {
         *ok = false;
         return 0;
     }
@@ -132,7 +123,7 @@ int FoFiBase::getU16BE(int pos, bool *ok) const
 {
     int x;
 
-    if (pos < 0 || pos > INT_MAX - 1 || pos + 1 >= len) {
+    if (pos < 0 || pos > INT_MAX - 1 || pos + 1 >= int(file.size())) {
         *ok = false;
         return 0;
     }
@@ -145,7 +136,7 @@ int FoFiBase::getS32BE(int pos, bool *ok) const
 {
     int x;
 
-    if (pos < 0 || pos > INT_MAX - 3 || pos + 3 >= len) {
+    if (pos < 0 || pos > INT_MAX - 3 || pos + 3 >= int(file.size())) {
         *ok = false;
         return 0;
     }
@@ -163,7 +154,7 @@ unsigned int FoFiBase::getU32BE(int pos, bool *ok) const
 {
     unsigned int x;
 
-    if (pos < 0 || pos > INT_MAX - 3 || pos + 3 >= len) {
+    if (pos < 0 || pos > INT_MAX - 3 || pos + 3 >= int(file.size())) {
         *ok = false;
         return 0;
     }
@@ -178,7 +169,7 @@ unsigned int FoFiBase::getU32LE(int pos, bool *ok) const
 {
     unsigned int x;
 
-    if (pos < 0 || pos > INT_MAX - 3 || pos + 3 >= len) {
+    if (pos < 0 || pos > INT_MAX - 3 || pos + 3 >= int(file.size())) {
         *ok = false;
         return 0;
     }
@@ -194,7 +185,7 @@ unsigned int FoFiBase::getUVarBE(int pos, int size, bool *ok) const
     unsigned int x;
     int i;
 
-    if (pos < 0 || pos > INT_MAX - size || pos + size > len) {
+    if (pos < 0 || pos > INT_MAX - size || pos + size > int(file.size())) {
         *ok = false;
         return 0;
     }
@@ -207,5 +198,5 @@ unsigned int FoFiBase::getUVarBE(int pos, int size, bool *ok) const
 
 bool FoFiBase::checkRegion(int pos, int size) const
 {
-    return pos >= 0 && size >= 0 && pos < INT_MAX - size && size < INT_MAX - pos && pos + size >= pos && pos + size <= len;
+    return pos >= 0 && size >= 0 && pos < INT_MAX - size && size < INT_MAX - pos && pos + size >= pos && pos + size <= int(file.size());
 }
