@@ -13,9 +13,9 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2018, 2022, 2024 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2018, 2022, 2024, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2022 Oliver Sander <oliver.sander@tu-dresden.de>
-// Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2025, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -52,7 +52,7 @@ protected:
     // takes ownership over data
     explicit FoFiBase(std::vector<unsigned char> &&fileA);
     // callers responsibility to keep the data alive as long as this object exists
-    explicit FoFiBase(std::span<unsigned char> fileA);
+    explicit FoFiBase(std::span<const unsigned char> fileA);
     static std::optional<std::vector<unsigned char>> readFile(const char *fileName);
 
     // S = signed / U = unsigned
@@ -70,7 +70,7 @@ protected:
     bool checkRegion(int pos, int size) const;
 
     std::vector<unsigned char> fileOwner;
-    std::span<unsigned char> file;
+    std::span<const unsigned char> file;
 };
 
 #endif
