@@ -20,7 +20,7 @@
 // Copyright (C) 2016 William Bader <williambader@hotmail.com>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 // Copyright (C) 2022 Oliver Sander <oliver.sander@tu-dresden.de>
-// Copyright (C) 2024, 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2024-2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -30,7 +30,6 @@
 #ifndef FOFITRUETYPE_H
 #define FOFITRUETYPE_H
 
-#include <cstddef>
 #include <memory>
 #include <vector>
 #include <unordered_map>
@@ -57,7 +56,7 @@ public:
     // Create a FoFiTrueType object from a memory buffer.
     // Note it is the responsibility of the caller to ensure the data is alive
     // during the lifetime of this object
-    static std::unique_ptr<FoFiTrueType> make(std::span<unsigned char> data, int faceIndexA);
+    static std::unique_ptr<FoFiTrueType> make(std::span<const unsigned char> data, int faceIndexA);
 
     // Create a FoFiTrueType object from a file on disk.
     static std::unique_ptr<FoFiTrueType> load(const char *fileName, int faceIndexA);
@@ -107,10 +106,6 @@ public:
     // * 0: restricted license embedding
     int getEmbeddingRights() const;
 
-    // Return the font matrix as an array of six numbers.  (Only useful
-    // for OpenType CFF fonts.)
-    void getFontMatrix(double *mat) const;
-
     // Convert to a Type 42 font, suitable for embedding in a PostScript
     // file.  <psName> will be used as the PostScript font name (so we
     // don't need to depend on the 'name' table in the font).  The
@@ -139,41 +134,41 @@ public:
     // Convert to a Type 0 CIDFont, suitable for embedding in a
     // PostScript file.  <psName> will be used as the PostScript font
     // name.  (Only useful for OpenType CFF fonts.)
-    void convertToCIDType0(const char *psName, const std::vector<int> &cidMap, FoFiOutputFunc outputFunc, void *outputStream) const;
+    void convertToCIDType0(const std::string &psName, const std::vector<int> &cidMap, FoFiOutputFunc outputFunc, void *outputStream) const;
 
     // Convert to a Type 0 (but non-CID) composite font, suitable for
     // embedding in a PostScript file.  <psName> will be used as the
     // PostScript font name (so we don't need to depend on the 'name'
     // table in the font).  The <cidMap> array maps CIDs to GIDs; it has
     // <nCIDs> entries.  (Not useful for OpenType CFF fonts.)
-    void convertToType0(const char *psName, const std::vector<int> &cidMap, bool needVerticalMetrics, int *maxValidGlyph, FoFiOutputFunc outputFunc, void *outputStream) const;
+    void convertToType0(const std::string &psName, const std::vector<int> &cidMap, bool needVerticalMetrics, int *maxValidGlyph, FoFiOutputFunc outputFunc, void *outputStream) const;
 
     // Convert to a Type 0 (but non-CID) composite font, suitable for
     // embedding in a PostScript file.  <psName> will be used as the
     // PostScript font name.  (Only useful for OpenType CFF fonts.)
-    void convertToType0(const char *psName, const std::vector<int> &cidMap, FoFiOutputFunc outputFunc, void *outputStream) const;
+    void convertToType0(const std::string &psName, const std::vector<int> &cidMap, FoFiOutputFunc outputFunc, void *outputStream) const;
 
     // Returns a pointer to the CFF font embedded in this OpenType font.
     // If successful, sets *<start> and *<length>, and returns true.
     // Otherwise returns false.  (Only useful for OpenType CFF fonts).
-    std::optional<std::span<unsigned char>> getCFFBlock() const;
+    std::optional<std::span<const unsigned char>> getCFFBlock() const;
 
     // setup vert/vrt2 GSUB for specified lang
     int setupGSUB(const std::string &scriptName, const std::string &languageName);
 
-    FoFiTrueType(std::vector<unsigned char> &&fileA, int faceIndexA, PrivateTag = {});
-    FoFiTrueType(std::span<unsigned char> data, int faceIndexA, PrivateTag = {});
+    FoFiTrueType(std::vector<unsigned char> &&fileA, int faceIndexA, PrivateTag /*unused*/ = {});
+    FoFiTrueType(std::span<const unsigned char> data, int faceIndexA, PrivateTag /*unused*/ = {});
 
 private:
-    void cvtEncoding(char **encoding, FoFiOutputFunc outputFunc, void *outputStream) const;
+    static void cvtEncoding(char **encoding, FoFiOutputFunc outputFunc, void *outputStream);
     void cvtCharStrings(char **encoding, const std::vector<int> &codeToGID, FoFiOutputFunc outputFunc, void *outputStream) const;
-    void cvtSfnts(FoFiOutputFunc outputFunc, void *outputStream, const GooString *name, bool needVerticalMetrics, int *maxUsedGlyph) const;
+    void cvtSfnts(FoFiOutputFunc outputFunc, void *outputStream, const std::optional<std::string> &name, bool needVerticalMetrics, int *maxUsedGlyph) const;
     static void dumpString(std::span<const unsigned char> s, FoFiOutputFunc outputFunc, void *outputStream);
     static unsigned int computeTableChecksum(std::span<const unsigned char> data);
     void parse();
     void readPostTable();
     int seekTable(const char *tag) const;
-    unsigned int charToTag(const std::string &tagName) const;
+    static unsigned int charToTag(const std::string &tagName);
     unsigned int doMapToVertGID(unsigned int orgGID);
     unsigned int scanLookupList(unsigned int listIndex, unsigned int orgGID);
     unsigned int scanLookupSubTable(unsigned int subTable, unsigned int orgGID);
