@@ -13,8 +13,9 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2018, 2022 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2018, 2022, 2023 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2022 Oliver Sander <oliver.sander@tu-dresden.de>
+// Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -26,41 +27,44 @@
 
 #include "FoFiBase.h"
 
+#include <string>
+#include <memory>
+
 //------------------------------------------------------------------------
 // FoFiType1
 //------------------------------------------------------------------------
 
 class FoFiType1 : public FoFiBase
 {
+    class PrivateTag
+    {
+    };
+
 public:
     // Create a FoFiType1 object from a memory buffer.
-    static FoFiType1 *make(const unsigned char *fileA, int lenA);
+    static std::unique_ptr<FoFiType1> make(std::vector<unsigned char> &&fileA);
 
     ~FoFiType1() override;
 
     // Return the font name.
-    const char *getName();
+    std::string getName();
 
     // Return the encoding, as an array of 256 names (any of which may
     // be NULL).
     char **getEncoding();
 
-    // Return the font matrix as an array of six numbers.
-    void getFontMatrix(double *mat);
-
     // Write a version of the Type 1 font file with a new encoding.
     void writeEncoded(const char **newEncoding, FoFiOutputFunc outputFunc, void *outputStream) const;
 
-private:
-    FoFiType1(const unsigned char *fileA, int lenA, bool freeFileDataA);
+    explicit FoFiType1(std::vector<unsigned char> &&fileA, PrivateTag /*unused*/ = {});
 
+private:
     char *getNextLine(char *line) const;
     void parse();
     void undoPFB();
 
-    char *name;
+    std::string name;
     char **encoding;
-    double fontMatrix[6];
     bool parsed;
 };
 
