@@ -15,9 +15,9 @@
 //
 // Copyright (C) 2006 Takashi Iwai <tiwai@suse.de>
 // Copyright (C) 2012 Thomas Freitag <Thomas.Freitag@alfa.de>
-// Copyright (C) 2018-2020, 2025 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2018-2020, 2025, 2026 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2022 Oliver Sander <oliver.sander@tu-dresden.de>
-// Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2025, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -31,6 +31,7 @@
 
 #include "poppler_private_export.h"
 
+#include <array>
 #include <memory>
 #include <set>
 #include <vector>
@@ -91,21 +92,17 @@ struct Type1CTopDict
     int fdSelectOffset;
 };
 
-#define type1CMaxBlueValues 14
-#define type1CMaxOtherBlues 10
-#define type1CMaxStemSnap 12
-
 struct Type1CPrivateDict
 {
     double fontMatrix[6];
     bool hasFontMatrix;
-    int blueValues[type1CMaxBlueValues];
+    std::array<int, 14> blueValues;
     int nBlueValues;
-    int otherBlues[type1CMaxOtherBlues];
+    std::array<int, 10> otherBlues;
     int nOtherBlues;
-    int familyBlues[type1CMaxBlueValues];
+    std::array<int, 14> familyBlues;
     int nFamilyBlues;
-    int familyOtherBlues[type1CMaxOtherBlues];
+    std::array<int, 10> familyOtherBlues;
     int nFamilyOtherBlues;
     double blueScale;
     int blueShift;
@@ -114,9 +111,9 @@ struct Type1CPrivateDict
     bool hasStdHW;
     double stdVW;
     bool hasStdVW;
-    double stemSnapH[type1CMaxStemSnap];
+    std::array<double, 12> stemSnapH;
     int nStemSnapH;
-    double stemSnapV[type1CMaxStemSnap];
+    std::array<double, 12> stemSnapV;
     int nStemSnapV;
     bool forceBold;
     bool hasForceBold;
@@ -163,7 +160,7 @@ class POPPLER_PRIVATE_EXPORT FoFiType1C : public FoFiBase
 public:
     // Create a FoFiType1C object from a memory buffer.
     static std::unique_ptr<FoFiType1C> make(std::vector<unsigned char> &&fileA);
-    static std::unique_ptr<FoFiType1C> make(std::span<unsigned char> data);
+    static std::unique_ptr<FoFiType1C> make(std::span<const unsigned char> data);
 
     // Create a FoFiType1C object from a file on disk.
     static std::unique_ptr<FoFiType1C> load(const char *fileName);
@@ -177,17 +174,10 @@ public:
     // be NULL).  This is only useful with 8-bit fonts.
     char **getEncoding() const;
 
-    // Get the glyph names.
-    int getNumGlyphs() const { return nGlyphs; }
-    GooString *getGlyphName(int gid) const;
-
     // Return the mapping from CIDs to GIDs, and return the number of
     // CIDs in *<nCIDs>.  This is only useful for CID fonts.
     std::vector<int> getCIDToGIDMap() const;
 
-    // Return the font matrix as an array of six numbers.
-    void getFontMatrix(double *mat) const;
-
     // Convert to a Type 1 font, suitable for embedding in a PostScript
     // file.  This is only useful with 8-bit fonts.  If <newEncoding> is
     // not NULL, it will be used in place of the encoding in the Type 1C
@@ -217,17 +207,17 @@ public:
     //     the identity CID-to-GID mapping is used
     void convertToType0(const std::string &psName, const std::vector<int> &codeMap, FoFiOutputFunc outputFunc, void *outputStream);
 
-    explicit FoFiType1C(std::vector<unsigned char> &&fileA, PrivateTag = {});
-    explicit FoFiType1C(std::span<unsigned char> data, PrivateTag = {});
+    explicit FoFiType1C(std::vector<unsigned char> &&fileA, PrivateTag /*unused*/ = {});
+    explicit FoFiType1C(std::span<const unsigned char> data, PrivateTag /*unused*/ = {});
 
 private:
     void eexecCvtGlyph(Type1CEexecBuf *eb, const char *glyphName, int offset, int nBytes, const Type1CIndex *subrIdx, const Type1CPrivateDict *pDict);
     void cvtGlyph(int offset, int nBytes, GooString *charBuf, const Type1CIndex *subrIdx, const Type1CPrivateDict *pDict, bool top, std::set<int> &offsetBeingParsed);
     void cvtGlyphWidth(bool useOp, GooString *charBuf, const Type1CPrivateDict *pDict);
-    void cvtNum(double x, bool isFP, GooString *charBuf) const;
-    void eexecWrite(Type1CEexecBuf *eb, const char *s) const;
-    void eexecWriteCharstring(Type1CEexecBuf *eb, const unsigned char *s, int n) const;
-    void writePSString(const char *s, FoFiOutputFunc outputFunc, void *outputStream) const;
+    static void cvtNum(double x, bool isFP, GooString *charBuf);
+    static void eexecWrite(Type1CEexecBuf *eb, const char *s);
+    static void eexecWriteCharstring(Type1CEexecBuf *eb, const unsigned char *s, int n);
+    static void writePSString(const char *s, FoFiOutputFunc outputFunc, void *outputStream);
     bool parse();
     void readTopDict();
     void readFD(int offset, int length, Type1CPrivateDict *pDict);
@@ -236,8 +226,8 @@ private:
     void buildEncoding();
     bool readCharset();
     int getOp(int pos, bool charstring, bool *ok);
-    int getDeltaIntArray(int *arr, int maxLen) const;
-    int getDeltaFPArray(double *arr, int maxLen) const;
+    int getDeltaIntArray(std::span<int> arr) const;
+    int getDeltaFPArray(std::span<double> arr) const;
     void getIndex(int pos, Type1CIndex *idx, bool *ok) const;
     void getIndexVal(const Type1CIndex &idx, int i, Type1CIndexVal *val, bool *ok) const;
     char *getString(int sid, char *buf, bool *ok) const;
