@@ -1,5 +1,6 @@
 /* poppler-action.cc: glib wrapper for poppler	      -*- c-basic-offset: 8 -*-
  * Copyright (C) 2005, Red Hat, Inc.
+ * Copyright (C) 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -224,7 +225,7 @@ PopplerAction *poppler_action_copy(PopplerAction *action)
             GList *new_list = nullptr;
 
             for (l = action->ocg_state.state_list; l; l = g_list_next(l)) {
-                PopplerActionLayer *alayer = (PopplerActionLayer *)l->data;
+                auto *alayer = (PopplerActionLayer *)l->data;
                 new_list = g_list_prepend(new_list, poppler_action_layer_copy(alayer));
             }
 
@@ -475,9 +476,8 @@ static AnnotMovie *find_annot_movie_for_action(PopplerDocument *document, const
                 }
                 if (found) {
                     break;
-                } else {
-                    annotObj.setToNull();
                 }
+                annotObj.setToNull();
             }
         }
     }
@@ -485,7 +485,7 @@ static AnnotMovie *find_annot_movie_for_action(PopplerDocument *document, const
     if (annotObj.isDict()) {
         Object tmp;
 
-        annot = new AnnotMovie(document->doc, std::move(annotObj), &tmp);
+        annot = new AnnotMovie(document->doc.get(), std::move(annotObj), &tmp);
         if (!annot->isOk()) {
             delete annot;
             annot = nullptr;
@@ -560,7 +560,7 @@ static PopplerLayer *get_layer_for_ref(PopplerDocument *document, GList *layers,
     GList *l;
 
     for (l = layers; l; l = g_list_next(l)) {
-        Layer *layer = (Layer *)l->data;
+        auto *layer = (Layer *)l->data;
 
         if (layer->oc) {
             const Ref ocgRef = layer->oc->getRef();
@@ -599,7 +599,7 @@ static void build_ocg_state(PopplerDocument *document, PopplerAction *action, co
     }
 
     for (const LinkOCGState::StateList &list : st_list) {
-        PopplerActionLayer *action_layer = g_slice_new0(PopplerActionLayer);
+        auto *action_layer = g_slice_new0(PopplerActionLayer);
 
         switch (list.st) {
         case LinkOCGState::On:
