@@ -1,6 +1,7 @@
 /* poppler-input-stream.cc: glib interface to poppler
  *
  * Copyright (C) 2012 Carlos Garcia Campos <carlosgc@gnome.org>
+ * Copyright (C) 2025, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,14 +36,14 @@ PopplerInputStream::~PopplerInputStream()
     }
 }
 
-BaseStream *PopplerInputStream::copy()
+std::unique_ptr<BaseStream> PopplerInputStream::copy()
 {
-    return new PopplerInputStream(inputStream, cancellable, start, limited, length, dict.copy());
+    return std::make_unique<PopplerInputStream>(inputStream, cancellable, start, limited, length, dict.copy());
 }
 
-Stream *PopplerInputStream::makeSubStream(Goffset startA, bool limitedA, Goffset lengthA, Object &&dictA)
+std::unique_ptr<Stream> PopplerInputStream::makeSubStream(Goffset startA, bool limitedA, Goffset lengthA, Object &&dictA)
 {
-    return new PopplerInputStream(inputStream, cancellable, startA, limitedA, lengthA, std::move(dictA));
+    return std::make_unique<PopplerInputStream>(inputStream, cancellable, startA, limitedA, lengthA, std::move(dictA));
 }
 
 Goffset PopplerInputStream::currentPos() const
