@@ -1,7 +1,9 @@
 /* poppler-page.cc: glib wrapper for poppler
  * Copyright (C) 2005, Red Hat, Inc.
  * Copyright (C) 2025 Lucas Baudin <lucas.baudin@ensae.fr>
- * Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+ * Copyright (C) 2025, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+ * Copyright (C) 2025 Nelson Benítez León <nbenitezl@gmail.com>
+ * Copyright (C) 2025, 2026 Albert Astals Cid <aacid@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,6 +32,7 @@
 #    include <GfxState.h>
 #    include <PageTransition.h>
 #    include <BBoxOutputDev.h>
+#    include <goo/gmem.h>
 #endif
 
 #include "poppler.h"
@@ -41,19 +44,21 @@
  * @title: PopplerPage
  */
 
+namespace {
 enum
 {
     PROP_0,
     PROP_LABEL
 };
+}
 
 static PopplerRectangleExtended *poppler_rectangle_extended_new();
 
-typedef struct _PopplerPageClass PopplerPageClass;
 struct _PopplerPageClass
 {
     GObjectClass parent_class;
 };
+using PopplerPageClass = _PopplerPageClass;
 
 G_DEFINE_TYPE(PopplerPage, poppler_page, G_TYPE_OBJECT)
 
@@ -77,10 +82,8 @@ static void poppler_page_finalize(GObject *object)
 
     g_object_unref(page->document);
     page->document = nullptr;
+    page->text.reset();
 
-    if (page->text != nullptr) {
-        page->text->decRefCnt();
-    }
     /* page->page is owned by the document */
 
     G_OBJECT_CLASS(poppler_page_parent_class)->finalize(object);
@@ -254,33 +257,27 @@ PopplerPageTransition *poppler_page_get_transition(PopplerPage *page)
 static TextPage *poppler_page_get_text_page(PopplerPage *page)
 {
     if (page->text == nullptr) {
-        TextOutputDev *text_dev;
 
-        text_dev = new TextOutputDev(nullptr, true, 0, false, false);
-        std::unique_ptr<Gfx> gfx = page->page->createGfx(text_dev, 72.0, 72.0, 0, false, /* useMediaBox */
+        auto text_dev = std::make_unique<TextOutputDev>(nullptr, true, 0, false, false);
+        std::unique_ptr<Gfx> gfx = page->page->createGfx(text_dev.get(), 72.0, 72.0, 0, false, /* useMediaBox */
                                                          true, /* Crop */
                                                          -1, -1, -1, -1, nullptr, nullptr);
         page->page->display(gfx.get());
         text_dev->endPage();
 
         page->text = text_dev->takeText();
-        gfx.reset(); // deletion order here is important, gfx before text_dev
-        delete text_dev;
     }
 
-    return page->text;
+    return page->text.get();
 }
 
 static bool annots_display_decide_cb(Annot *annot, void *user_data)
 {
-    PopplerRenderAnnotsFlags flags = (PopplerRenderAnnotsFlags)GPOINTER_TO_UINT(user_data);
+    auto flags = (PopplerRenderAnnotsFlags)GPOINTER_TO_UINT(user_data);
     Annot::AnnotSubtype type = annot->getType();
     int typeMask = 1 << MAX(0, (((int)type) - 1));
 
-    if (flags & typeMask) {
-        return true;
-    }
-    return false;
+    return (flags & typeMask) != 0;
 }
 
 /**
@@ -312,7 +309,7 @@ void poppler_page_render_full(PopplerPage *page, cairo_t *cairo, gboolean printi
     output_dev->setPrinting(printing);
 
     if (!printing && page->text == nullptr) {
-        page->text = new TextPage(false);
+        page->text = std::make_shared<TextPage>(false);
         output_dev->setTextPage(page->text);
     }
 
@@ -489,26 +486,7 @@ cairo_surface_t *poppler_page_get_thumbnail(PopplerPage *page)
     return surface;
 }
 
-/**
- * poppler_page_render_selection:
- * @page: the #PopplerPage for which to render selection
- * @cairo: cairo context to render to
- * @selection: start and end point of selection as a rectangle
- * @old_selection: previous selection
- * @style: a #PopplerSelectionStyle
- * @glyph_color: color to use for drawing glyphs
- * @background_color: color to use for the selection background
- *
- * Render the selection specified by @selection for @page to
- * the given cairo context.  The selection will be rendered, using
- * @glyph_color for the glyphs and @background_color for the selection
- * background.
- *
- * If non-NULL, @old_selection specifies the selection that is already
- * rendered to @cairo, in which case this function will (some day)
- * only render the changed part of the selection.
- **/
-void poppler_page_render_selection(PopplerPage *page, cairo_t *cairo, PopplerRectangle *selection, PopplerRectangle *old_selection, PopplerSelectionStyle style, PopplerColor *glyph_color, PopplerColor *background_color)
+static void render_selection(PopplerPage *page, cairo_t *cairo, PopplerRectangle *selection, PopplerSelectionStyle style, PopplerColor *glyph_color, PopplerColor *background_color, double background_opacity, bool draw_glyphs)
 {
     CairoOutputDev *output_dev;
     TextPage *text;
@@ -534,11 +512,63 @@ void poppler_page_render_selection(PopplerPage *page, cairo_t *cairo, PopplerRec
     output_dev->setCairo(cairo);
 
     text = poppler_page_get_text_page(page);
-    text->drawSelection(output_dev, 1.0, 0, &pdf_selection, selection_style, &gfx_glyph_color, &gfx_background_color);
+    text->drawSelection(output_dev, 1.0, 0, &pdf_selection, selection_style, &gfx_glyph_color, &gfx_background_color, background_opacity, draw_glyphs);
 
     output_dev->setCairo(nullptr);
 }
 
+/**
+ * poppler_page_render_selection:
+ * @page: the #PopplerPage for which to render selection
+ * @cairo: cairo context to render to
+ * @selection: start and end point of selection as a rectangle
+ * @old_selection: previous selection
+ * @style: a #PopplerSelectionStyle
+ * @glyph_color: color to use for drawing glyphs
+ * @background_color: color to use for the selection background
+ *
+ * Render the selection specified by @selection for @page to
+ * the given cairo context.  The selection will be rendered, using
+ * @glyph_color for the glyphs and @background_color for the selection
+ * background.
+ *
+ * If non-NULL, @old_selection specifies the selection that is already
+ * rendered to @cairo, in which case this function will (some day)
+ * only render the changed part of the selection.
+ **/
+void poppler_page_render_selection(PopplerPage *page, cairo_t *cairo, PopplerRectangle *selection, PopplerRectangle * /*old_selection*/, PopplerSelectionStyle style, PopplerColor *glyph_color, PopplerColor *background_color)
+{
+    render_selection(page, cairo, selection, style, glyph_color, background_color, 1, TRUE);
+}
+
+/**
+ * poppler_page_render_transparent_selection:
+ * @page: the #PopplerPage for which to render selection
+ * @cairo: cairo context to render to
+ * @selection: start and end point of selection as a rectangle
+ * @old_selection: previous selection
+ * @style: a #PopplerSelectionStyle
+ * @background_color: color to use for the selection background
+ * @background_opacity: opacity to use for the selection background
+ *
+ * Render the selection specified by @selection for @page to
+ * the given cairo context.  The selection will be rendered using
+ * @background_color and @background_opacity for the selection
+ * background. Glyphs will not be drawn.
+ *
+ * If non-NULL, @old_selection specifies the selection that is already
+ * rendered to @cairo, in which case this function will (some day)
+ * only render the changed part of the selection.
+ *
+ * Since: 25.08
+ **/
+void poppler_page_render_transparent_selection(PopplerPage *page, cairo_t *cairo, PopplerRectangle *selection, PopplerRectangle * /*old_selection*/, PopplerSelectionStyle style, PopplerColor *background_color, double background_opacity)
+{
+    PopplerColor glyph_color = { 0, 0, 0 };
+
+    render_selection(page, cairo, selection, style, &glyph_color, background_color, background_opacity, FALSE);
+}
+
 /**
  * poppler_page_get_thumbnail_size:
  * @page: A #PopplerPage
@@ -1060,10 +1090,10 @@ void poppler_page_render_to_ps(PopplerPage *page, PopplerPSFile *ps_file)
             pages.push_back(i);
         }
         if (ps_file->fd != -1) {
-            ps_file->out =
-                    new PSOutputDev(ps_file->fd, ps_file->document->doc, nullptr, pages, psModePS, (int)ps_file->paper_width, (int)ps_file->paper_height, false, ps_file->duplex, 0, 0, 0, 0, psRasterizeWhenNeeded, false, nullptr, nullptr);
+            ps_file->out = new PSOutputDev(ps_file->fd, ps_file->document->doc.get(), nullptr, pages, psModePS, (int)ps_file->paper_width, (int)ps_file->paper_height, false, ps_file->duplex, 0, 0, 0, 0, psRasterizeWhenNeeded, false,
+                                           nullptr, nullptr);
         } else {
-            ps_file->out = new PSOutputDev(ps_file->filename, ps_file->document->doc, nullptr, pages, psModePS, (int)ps_file->paper_width, (int)ps_file->paper_height, false, ps_file->duplex, 0, 0, 0, 0, psRasterizeWhenNeeded, false,
+            ps_file->out = new PSOutputDev(ps_file->filename, ps_file->document->doc.get(), nullptr, pages, psModePS, (int)ps_file->paper_width, (int)ps_file->paper_height, false, ps_file->duplex, 0, 0, 0, 0, psRasterizeWhenNeeded, false,
                                            nullptr, nullptr);
         }
     }
@@ -1099,7 +1129,7 @@ static void poppler_page_class_init(PopplerPageClass *klass)
     g_object_class_install_property(G_OBJECT_CLASS(klass), PROP_LABEL, g_param_spec_string("label", "Page Label", "The label of the page", nullptr, G_PARAM_READABLE));
 }
 
-static void poppler_page_init(PopplerPage *page) { }
+static void poppler_page_init(PopplerPage * /*page*/) { }
 
 /**
  * poppler_page_get_link_mapping:
@@ -1604,7 +1634,7 @@ void poppler_page_add_annot(PopplerPage *page, PopplerAnnot *annot)
 
     annot->annot->setRect(x1 + page_crop_box->x1, y1 + page_crop_box->y1, x2 + page_crop_box->x1, y2 + page_crop_box->y1);
 
-    AnnotTextMarkup *annot_markup = dynamic_cast<AnnotTextMarkup *>(annot->annot.get());
+    auto *annot_markup = dynamic_cast<AnnotTextMarkup *>(annot->annot.get());
     if (annot_markup) {
         crop_box = _poppler_annot_get_cropbox(annot);
         if (crop_box) {
@@ -1657,7 +1687,7 @@ static PopplerRectangleExtended *poppler_rectangle_extended_new()
 
 PopplerRectangle *poppler_rectangle_new_from_pdf_rectangle(const PDFRectangle *rect)
 {
-    auto r = poppler_rectangle_extended_new();
+    auto *r = poppler_rectangle_extended_new();
     r->x1 = rect->x1;
     r->y1 = rect->y1;
     r->x2 = rect->x2;
@@ -1693,7 +1723,7 @@ PopplerRectangle *poppler_rectangle_copy(PopplerRectangle *rectangle)
 {
     g_return_val_if_fail(rectangle != nullptr, NULL);
 
-    auto ext_rectangle = reinterpret_cast<PopplerRectangleExtended *>(rectangle);
+    auto *ext_rectangle = reinterpret_cast<PopplerRectangleExtended *>(rectangle);
     return reinterpret_cast<PopplerRectangle *>(g_slice_dup(PopplerRectangleExtended, ext_rectangle));
 }
 
@@ -1709,7 +1739,7 @@ PopplerRectangle *poppler_rectangle_copy(PopplerRectangle *rectangle)
  */
 void poppler_rectangle_free(PopplerRectangle *rectangle)
 {
-    auto ext_rectangle = reinterpret_cast<PopplerRectangleExtended *>(rectangle);
+    auto *ext_rectangle = reinterpret_cast<PopplerRectangleExtended *>(rectangle);
     g_slice_free(PopplerRectangleExtended, ext_rectangle);
 }
 
@@ -1735,7 +1765,7 @@ gboolean poppler_rectangle_find_get_match_continued(const PopplerRectangle *rect
 {
     g_return_val_if_fail(rectangle != nullptr, false);
 
-    auto ext_rectangle = reinterpret_cast<const PopplerRectangleExtended *>(rectangle);
+    const auto *ext_rectangle = reinterpret_cast<const PopplerRectangleExtended *>(rectangle);
     return ext_rectangle->match_continued;
 }
 
@@ -1762,7 +1792,7 @@ gboolean poppler_rectangle_find_get_ignored_hyphen(const PopplerRectangle *recta
 {
     g_return_val_if_fail(rectangle != nullptr, false);
 
-    auto ext_rectangle = reinterpret_cast<const PopplerRectangleExtended *>(rectangle);
+    const auto *ext_rectangle = reinterpret_cast<const PopplerRectangleExtended *>(rectangle);
     return ext_rectangle->ignored_hyphen;
 }
 
@@ -1884,19 +1914,19 @@ static gchar *get_font_name_from_word(const TextWord *word, gint word_i)
     const GooString *font_name = word->getFontName(word_i);
     const gchar *name;
     gboolean subset;
-    gint i;
+    size_t i;
 
-    if (!font_name || font_name->getLength() == 0) {
+    if (!font_name || font_name->empty()) {
         return g_strdup("Default");
     }
 
     // check for a font subset name: capital letters followed by a '+' sign
-    for (i = 0; i < font_name->getLength(); ++i) {
+    for (i = 0; i < font_name->size(); ++i) {
         if (font_name->getChar(i) < 'A' || font_name->getChar(i) > 'Z') {
             break;
         }
     }
-    subset = i > 0 && i < font_name->getLength() && font_name->getChar(i) == '+';
+    subset = i > 0 && i < font_name->size() && font_name->getChar(i) == '+';
     name = font_name->c_str();
     if (subset) {
         name += i + 1;
