@@ -15,19 +15,21 @@
 #ifndef GOO_GBASE64_H
 #define GOO_GBASE64_H
 
+#include "poppler_private_export.h"
+
 #include <string>
 #include <vector>
 
-std::string gbase64Encode(const void *input, size_t len);
+std::string POPPLER_PRIVATE_EXPORT gbase64Encode(const void *input, size_t len);
 
 inline std::string gbase64Encode(const std::vector<char> &input)
 {
-    return input.empty() ? std::string() : gbase64Encode(&input[0], input.size());
+    return input.empty() ? std::string() : gbase64Encode(input.data(), input.size());
 }
 
 inline std::string gbase64Encode(const std::vector<unsigned char> &input)
 {
-    return input.empty() ? std::string() : gbase64Encode(&input[0], input.size());
+    return input.empty() ? std::string() : gbase64Encode(input.data(), input.size());
 }
 
 #endif // ndef GOO_GBASE64_H
