@@ -28,7 +28,8 @@
 // Copyright (C) 2017 Christoph Cullmann <cullmann@kde.org>
 // Copyright (C) 2018 Mojca Miklavec <mojca@macports.org>
 // Copyright (C) 2019, 2021 Christian Persch <chpe@src.gnome.org>
-// Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2025, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2026 Kleis Auke Wolthuizen <github@kleisauke.nl>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -102,7 +103,7 @@ GooString *appendToPath(GooString *path, const char *fileName)
     char *fp;
 
     auto tmp = path->copy();
-    tmp->append('/');
+    tmp->push_back('/');
     tmp->append(fileName);
     GetFullPathNameA(tmp->c_str(), sizeof(buf), buf, &fp);
     path->clear();
@@ -140,7 +141,7 @@ GooString *appendToPath(GooString *path, const char *fileName)
 
     // otherwise, append "/" and new path component
     if (!path->empty() && path->getChar(path->size() - 1) != '/') {
-        path->append('/');
+        path->push_back('/');
     }
     path->append(fileName);
     return path;
@@ -187,8 +188,8 @@ FILE *openFile(const char *path, const char *mode)
 {
 #ifdef _WIN32
     OSVERSIONINFO version;
-    wchar_t wPath[_MAX_PATH + 1];
-    char nPath[_MAX_PATH + 1];
+    wchar_t wPath[MAX_PATH + 1];
+    char nPath[MAX_PATH + 1];
     wchar_t wMode[8];
     const char *p;
     size_t i;
@@ -197,7 +198,7 @@ FILE *openFile(const char *path, const char *mode)
     version.dwOSVersionInfoSize = sizeof(version);
     GetVersionEx(&version);
     if (version.dwPlatformId == VER_PLATFORM_WIN32_NT) {
-        for (p = path, i = 0; *p && i < _MAX_PATH; ++i) {
+        for (p = path, i = 0; *p && i < MAX_PATH; ++i) {
             if ((p[0] & 0xe0) == 0xc0 && p[1] && (p[1] & 0xc0) == 0x80) {
                 wPath[i] = (wchar_t)(((p[0] & 0x1f) << 6) | (p[1] & 0x3f));
                 p += 2;
@@ -216,7 +217,7 @@ FILE *openFile(const char *path, const char *mode)
         wMode[i] = (wchar_t)0;
         return _wfopen(wPath, wMode);
     } else {
-        for (p = path, i = 0; *p && i < _MAX_PATH; ++i) {
+        for (p = path, i = 0; *p && i < MAX_PATH; ++i) {
             if ((p[0] & 0xe0) == 0xc0 && p[1] && (p[1] & 0xc0) == 0x80) {
                 nPath[i] = (char)(((p[0] & 0x1f) << 6) | (p[1] & 0x3f));
                 p += 2;
