@@ -19,7 +19,7 @@
 // Copyright (C) 2013, 2017, 2019, 2022 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2018, 2019 Adam Reichold <adam.reichold@t-online.de>
-// Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2025, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -50,7 +50,7 @@ Array::~Array() = default;
 Array *Array::copy(XRef *xrefA) const
 {
     arrayLocker();
-    Array *a = new Array(xrefA);
+    auto *a = new Array(xrefA);
     a->elems.reserve(elems.size());
     for (const auto &elem : elems) {
         a->elems.push_back(elem.copy());
@@ -61,7 +61,7 @@ Array *Array::copy(XRef *xrefA) const
 Array *Array::deepCopy() const
 {
     arrayLocker();
-    Array *a = new Array(xref);
+    auto *a = new Array(xref);
     a->elems.reserve(elems.size());
     for (const auto &elem : elems) {
         a->elems.push_back(elem.deepCopy());
@@ -121,9 +121,8 @@ bool Array::getString(int i, GooString *string) const
     const Object &obj = getNF(i);
     if (obj.isString()) {
         string->clear();
-        string->append(obj.getString());
+        string->append(obj.getString()->toStr());
         return true;
-    } else {
-        return false;
     }
+    return false;
 }
