@@ -6,7 +6,7 @@
 //
 // Copyright 2020 sgerwk <sgerwk@aol.com>
 // Copyright 2022 Oliver Sander <oliver.sander@tu-dresden.de>
-// Copyright 2025 Albert Astals Cid <aacid@kde.org>
+// Copyright 2025, 2026 Albert Astals Cid <aacid@kde.org>
 //
 //========================================================================
 
@@ -14,9 +14,6 @@
 #include <BBoxOutputDev.h>
 #include <GfxFont.h>
 
-#define writingModeHorizontal 0
-#define writingModeVertical 1
-
 BBoxOutputDev::BBoxOutputDev() : BBoxOutputDev(true, true, true) { }
 
 BBoxOutputDev::BBoxOutputDev(bool textA, bool vectorA, bool rasterA) : BBoxOutputDev(textA, vectorA, rasterA, true) { }
@@ -72,28 +69,29 @@ void BBoxOutputDev::eoFill(GfxState *state)
     updatePath(&bb, state->getPath(), state);
 }
 
-void BBoxOutputDev::drawImageMask(GfxState *state, Object *ref, Stream *str, int width, int height, bool invert, bool interpolate, bool inlineImg)
+void BBoxOutputDev::drawImageMask(GfxState *state, Object * /*ref*/, Stream * /*str*/, int /*width*/, int /*height*/, bool /*invert*/, bool /*interpolate*/, bool /*inlineImg*/)
 {
     updateImage(&bb, state);
 }
 
-void BBoxOutputDev::drawImage(GfxState *state, Object *ref, Stream *str, int width, int height, GfxImageColorMap *colorMap, bool interpolate, const int *maskColors, bool inlineImg)
+void BBoxOutputDev::drawImage(GfxState *state, Object * /*ref*/, Stream * /*str*/, int /*width*/, int /*height*/, GfxImageColorMap * /*colorMap*/, bool /*interpolate*/, const int * /*maskColors*/, bool /*inlineImg*/)
 {
     updateImage(&bb, state);
 }
 
-void BBoxOutputDev::drawMaskedImage(GfxState *state, Object *ref, Stream *str, int width, int height, GfxImageColorMap *colorMap, bool interpolate, Stream *maskStr, int maskWidth, int maskHeight, bool maskInvert, bool maskInterpolate)
+void BBoxOutputDev::drawMaskedImage(GfxState *state, Object * /*ref*/, Stream * /*str*/, int /*width*/, int /*height*/, GfxImageColorMap * /*colorMap*/, bool /*interpolate*/, Stream * /*maskStr*/, int /*maskWidth*/, int /*maskHeight*/,
+                                    bool /*maskInvert*/, bool /*maskInterpolate*/)
 {
     updateImage(&bb, state);
 }
 
-void BBoxOutputDev::drawSoftMaskedImage(GfxState *state, Object *ref, Stream *str, int width, int height, GfxImageColorMap *colorMap, bool interpolate, Stream *maskStr, int maskWidth, int maskHeight, GfxImageColorMap *maskColorMap,
-                                        bool maskInterpolate)
+void BBoxOutputDev::drawSoftMaskedImage(GfxState *state, Object * /*ref*/, Stream * /*str*/, int /*width*/, int /*height*/, GfxImageColorMap * /*colorMap*/, bool /*interpolate*/, Stream * /*maskStr*/, int /*maskWidth*/, int /*maskHeight*/,
+                                        GfxImageColorMap * /*maskColorMap*/, bool /*maskInterpolate*/)
 {
     updateImage(&bb, state);
 }
 
-void BBoxOutputDev::drawChar(GfxState *state, double x, double y, double dx, double dy, double originX, double originY, CharCode code, int nBytes, const Unicode *u, int uLen)
+void BBoxOutputDev::drawChar(GfxState *state, double x, double y, double dx, double dy, double /*originX*/, double /*originY*/, CharCode code, int /*nBytes*/, const Unicode * /*u*/, int /*uLen*/)
 {
     double leftent, rightent, ascent, descent;
     double fontSize, w, adjust;
@@ -115,7 +113,7 @@ void BBoxOutputDev::drawChar(GfxState *state, double x, double y, double dx, dou
     fontSize = state->getFontSize();
 
     const std::array<double, 4> &fb = font->getFontBBox();
-    if (font->getWMode() == writingModeHorizontal) {
+    if (font->getWMode() == GfxFont::WritingMode::Horizontal) {
         leftent = 0;
         rightent = 0;
         ascent = font->getAscent();
