@@ -28,12 +28,11 @@
 #define CMAP_H
 
 #include <array>
-#include <atomic>
 #include <memory>
 
 #include "Object.h"
-#include "poppler-config.h"
 #include "CharTypes.h"
+#include "GfxFont.h"
 
 class GooString;
 class Object;
@@ -48,7 +47,7 @@ class CMap
 public:
     // Parse a CMap from <obj>, which can be a name or a stream.  Sets
     // the initial reference count to 1.  Returns NULL on failure.
-    static std::shared_ptr<CMap> parse(CMapCache *cache, const std::string &collectionA, Object *obj);
+    static std::shared_ptr<CMap> parse(const std::string &collectionA, Object *obj);
 
     // Create the CMap specified by <collection> and <cMapName>.  Sets
     // the initial reference count to 1.  Returns NULL on failure.
@@ -73,20 +72,20 @@ public:
     // *<nUsed> to the number of bytes used by the char code.
     CID getCID(const char *s, int len, CharCode *c, int *nUsed);
 
-    // Return the writing mode (0=horizontal, 1=vertical).
-    int getWMode() const { return wMode; }
+    // Return the writing mode
+    GfxFont::WritingMode getWMode() const { return wMode; }
 
     void setReverseMap(unsigned int *rmap, unsigned int rmapSize, unsigned int ncand);
 
 private:
-    static std::shared_ptr<CMap> parse(CMapCache *cache, const std::string &collectionA, Object *obj, RefRecursionChecker &recursion);
+    static std::shared_ptr<CMap> parse(const std::string &collectionA, Object *obj, RefRecursionChecker &recursion);
     static std::shared_ptr<CMap> parse(CMapCache *cache, const std::string &collectionA, Stream *str, RefRecursionChecker &recursion);
 
     void parse2(CMapCache *cache, int (*getCharFunc)(void *), void *data);
     CMap(std::unique_ptr<GooString> &&collectionA, std::unique_ptr<GooString> &&cMapNameA);
-    CMap(std::unique_ptr<GooString> &&collectionA, std::unique_ptr<GooString> &&cMapNameA, int wModeA);
+    CMap(std::unique_ptr<GooString> &&collectionA, std::unique_ptr<GooString> &&cMapNameA, GfxFont::WritingMode wModeA);
     void useCMap(CMapCache *cache, const char *useName);
-    void useCMap(CMapCache *cache, Object *obj, RefRecursionChecker &recursion);
+    void useCMap(Object *obj, RefRecursionChecker &recursion);
     void copyVector(CMapVectorEntry *dest, CMapVectorEntry *src);
     void addCIDs(unsigned int start, unsigned int end, unsigned int nBytes, CID firstCID);
     void freeCMapVector(CMapVectorEntry *vec);
@@ -96,7 +95,7 @@ private:
     const std::unique_ptr<GooString> cMapName;
     bool isIdent; // true if this CMap is an identity mapping,
                   //   or is based on one (via usecmap)
-    int wMode; // writing mode (0=horizontal, 1=vertical)
+    GfxFont::WritingMode wMode;
     CMapVectorEntry *vector; // vector for first byte (NULL for
                              //   identity CMap)
 };
