@@ -14,7 +14,7 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2005 Kristian Høgsberg <krh@redhat.com>
-// Copyright (C) 2005, 2007, 2009-2011, 2013, 2017-2024 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2007, 2009-2011, 2013, 2017-2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2005 Jonathan Blandford <jrb@redhat.com>
 // Copyright (C) 2005, 2006, 2008 Brad Hards <bradh@frogmouth.net>
 // Copyright (C) 2007 Julien Rebetez <julienr@svn.gnome.org>
@@ -34,6 +34,7 @@
 // Copyright (C) 2021 RM <rm+git@arcsin.org>
 // Copyright (C) 2024, 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 // Copyright (C) 2024 Hubert Figuière <hub@figuiere.net>
+// Copyright (C) 2025 Trystan Mata <trystan.mata@tytanium.xyz>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -47,6 +48,7 @@
 #include "poppler_private_export.h"
 #include "Object.h"
 #include "Link.h"
+#include "GfxState.h"
 
 #include <memory>
 #include <optional>
@@ -89,7 +91,7 @@ public:
 private:
     struct Entry
     {
-        Entry(Array *array, int index);
+        Entry(const Array &array, int index);
         ~Entry();
         GooString name;
         Object value;
@@ -118,7 +120,7 @@ public:
     Catalog &operator=(const Catalog &) = delete;
 
     // Is catalog valid?
-    bool isOk() { return ok; }
+    bool isOk() const { return ok; }
 
     // Get number of pages.
     int getNumPages();
@@ -151,7 +153,7 @@ public:
 
     // Find a page, given its object ID.  Returns page number, or 0 if
     // not found.
-    int findPage(const Ref pageRef);
+    int findPage(Ref pageRef);
 
     // Find a named destination.  Returns the link destination, or
     // NULL if <name> is not a destination.
@@ -199,7 +201,7 @@ public:
     std::string getJS(int i);
 
     // Convert between page indices and page labels.
-    bool labelToIndex(GooString *label, int *index);
+    bool labelToIndex(const GooString &label, int *index);
     bool indexToLabel(int index, GooString *label);
 
     Object *getOutline();
@@ -207,8 +209,8 @@ public:
     Object *getCreateOutline();
 
     Object *getAcroForm() { return &acroForm; }
-    void addFormToAcroForm(const Ref formRef);
-    void removeFormFromAcroForm(const Ref formRef);
+    void addFormToAcroForm(Ref formRef);
+    void removeFormFromAcroForm(Ref formRef);
     void setAcroFormModified();
 
     const OCGs *getOptContentConfig() { return optContent.get(); }
@@ -269,6 +271,11 @@ public:
 
     std::unique_ptr<LinkAction> getOpenAction() const;
 
+#if USE_CMS
+    GfxLCMSProfilePtr getDisplayProfile();
+    std::shared_ptr<GfxXYZ2DisplayTransforms> getXYZ2DisplayTransforms();
+#endif
+
 private:
     // Get page label info.
     PageLabelInfo *getPageLabelInfo();
@@ -306,19 +313,24 @@ private:
     bool initPageList(); // init the page list. called by cachePageTree.
     bool cacheSubTree(); // called by cachePageTree.
     bool cachePageTree(int page); // Cache first <page> pages.
-    std::size_t cachePageTreeForRef(const Ref pageRef); // Cache until <pageRef>.
+    std::size_t cachePageTreeForRef(Ref pageRef); // Cache until <pageRef>.
     Object *findDestInTree(Object *tree, GooString *name, Object *obj);
 
     Object *getNames();
     NameTree *getDestNameTree();
     NameTree *getEmbeddedFileNameTree();
     NameTree *getJSNameTree();
-    std::unique_ptr<LinkDest> createLinkDest(Object *obj);
+    static std::unique_ptr<LinkDest> createLinkDest(Object *obj);
 
     int catalogPdfMajorVersion = -1;
     int catalogPdfMinorVersion = -1;
 
     mutable std::recursive_mutex mutex;
+
+#if USE_CMS
+    GfxLCMSProfilePtr displayProfile;
+    std::shared_ptr<GfxXYZ2DisplayTransforms> XYZ2DisplayTransforms;
+#endif
 };
 
 #endif
