@@ -17,9 +17,11 @@
 // Copyright (C) 2009 David Benjamin <davidben@mit.edu>
 // Copyright (C) 2012 Fabio D'Urso <fabiodurso@hotmail.it>
 // Copyright (C) 2013 Adrian Johnson <ajohnson@redneon.com>
-// Copyright (C) 2013, 2018, 2019, 2021 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2013, 2018, 2019, 2021, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2013 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2025 Nelson Benítez León <nbenitezl@gmail.com>
+// Copyright (C) 2025, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2025 Arnav V <arnav0872@gmail.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -45,12 +47,11 @@ public:
     // and returns true if either is correct.  Sets <ownerPasswordOk> if
     // the owner password was correct.  Either or both of the passwords
     // may be NULL, which is treated as an empty string.
-    static bool makeFileKey(int encVersion, int encRevision, int keyLength, const GooString *ownerKey, const GooString *userKey, const GooString *ownerEnc, const GooString *userEnc, int permissions, const GooString *fileID,
-                            const GooString *ownerPassword, const GooString *userPassword, unsigned char *fileKey, bool encryptMetadata, bool *ownerPasswordOk);
+    static bool makeFileKey(int encRevision, int keyLength, const GooString *ownerKey, const GooString *userKey, const GooString *ownerEnc, const GooString *userEnc, int permissions, const GooString *fileID, const GooString *ownerPassword,
+                            const GooString *userPassword, unsigned char *fileKey, bool encryptMetadata, bool *ownerPasswordOk);
 
 private:
-    static bool makeFileKey2(int encVersion, int encRevision, int keyLength, const GooString *ownerKey, const GooString *userKey, int permissions, const GooString *fileID, const GooString *userPassword, unsigned char *fileKey,
-                             bool encryptMetadata);
+    static bool makeFileKey2(int encRevision, int keyLength, const GooString *ownerKey, const GooString *userKey, int permissions, const GooString *fileID, const GooString *userPassword, unsigned char *fileKey, bool encryptMetadata);
 };
 
 //------------------------------------------------------------------------
@@ -93,16 +94,16 @@ struct DecryptAES256State
 class BaseCryptStream : public FilterStream
 {
 public:
-    BaseCryptStream(Stream *strA, const unsigned char *fileKey, CryptAlgorithm algoA, int keyLength, Ref ref);
+    BaseCryptStream(std::unique_ptr<Stream> strA, const unsigned char *fileKey, CryptAlgorithm algoA, int keyLength, Ref ref);
+    BaseCryptStream(Stream &strA, const unsigned char *fileKey, CryptAlgorithm algoA, int keyLength, Ref ref);
     ~BaseCryptStream() override;
     StreamKind getKind() const override { return strCrypt; }
-    bool reset() override;
+    [[nodiscard]] bool rewind() override;
     int getChar() override;
     int lookChar() override = 0;
     Goffset getPos() override;
     bool isBinary(bool last) const override;
     Stream *getUndecodedStream() override { return this; }
-    void setAutoDelete(bool val);
 
 protected:
     CryptAlgorithm algo;
@@ -110,7 +111,7 @@ protected:
     unsigned char objKey[32];
     Goffset charactersRead; // so that getPos() can be correct
     int nextCharBuff; // EOF means not read yet
-    bool autoDelete;
+    std::unique_ptr<Stream> ownedStream;
 
     union {
         DecryptRC4State rc4;
@@ -126,18 +127,23 @@ protected:
 class EncryptStream : public BaseCryptStream
 {
 public:
-    EncryptStream(Stream *strA, const unsigned char *fileKey, CryptAlgorithm algoA, int keyLength, Ref ref);
+    EncryptStream(Stream &strA, const unsigned char *fileKey, CryptAlgorithm algoA, int keyLength, Ref ref);
+    EncryptStream(std::unique_ptr<Stream> strA, const unsigned char *fileKey, CryptAlgorithm algoA, int keyLength, Ref ref);
     ~EncryptStream() override;
-    bool reset() override;
+    [[nodiscard]] bool rewind() override;
     int lookChar() override;
+
+private:
+    void init();
 };
 
 class DecryptStream : public BaseCryptStream
 {
 public:
-    DecryptStream(Stream *strA, const unsigned char *fileKey, CryptAlgorithm algoA, int keyLength, Ref ref);
+    DecryptStream(std::unique_ptr<Stream> strA, const unsigned char *fileKey, CryptAlgorithm algoA, int keyLength, Ref ref);
+    DecryptStream(Stream &strA, const unsigned char *fileKey, CryptAlgorithm algoA, int keyLength, Ref ref);
     ~DecryptStream() override;
-    bool reset() override;
+    [[nodiscard]] bool rewind() override;
     int lookChar() override;
 };
 
