@@ -14,13 +14,14 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2005, 2007 Jeff Muizelaar <jeff@infidigm.net>
-// Copyright (C) 2005, 2018, 2022 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2018, 2022, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2007 Krzysztof Kowalczyk <kkowalczyk@gmail.com>
 // Copyright (C) 2012 Marek Kasik <mkasik@redhat.com>
 // Copyright (C) 2013, 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2020 Adam Reichold <adam.reichold@t-online.de>
 // Copyright (C) 2024 Oliver Sander <oliver.sander@tu-dresden.de>
 // Copyright (C) 2024 Vincent Lefevre <vincent@vinc17.net>
+// Copyright (C) 2024, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -31,9 +32,8 @@
 #include <poppler-config.h>
 
 #include <cstdio>
-#include <cstddef>
 #include <cstdarg>
-#include "GooString.h"
+#include "goo/GooString.h"
 #include "GlobalParams.h"
 #include "Error.h"
 
@@ -63,7 +63,7 @@ void CDECL error(ErrorCategory category, Goffset pos, const char *msg, ...)
         if (c < (char)0x20 || c >= (char)0x7f) {
             sanitized.appendf("<{0:02x}>", c & 0xff);
         } else {
-            sanitized.append(c);
+            sanitized.push_back(c);
         }
     }
 
