@@ -5,10 +5,10 @@
 // This file is licensed under the GPLv2 or later
 //
 // Copyright 2010 Hib Eris <hib@hiberis.nl>
-// Copyright 2010, 2017, 2021, 2022 Albert Astals Cid <aacid@kde.org>
+// Copyright 2010, 2017, 2021, 2022, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright 2021 Oliver Sander <oliver.sander@tu-dresden.de>
 // Copyright 2021 Christian Persch <chpe@src.gnome.org>
-// Copyright 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright 2025, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 //========================================================================
 
@@ -24,7 +24,7 @@
 // FileDescriptorPDFDocBuilder
 //------------------------------------------------------------------------
 
-int FileDescriptorPDFDocBuilder::parseFdFromUri(const GooString &uri)
+int FileDescriptorPDFDocBuilder::parseFdFromUri(const std::string &uri)
 {
     int fd = -1;
     char c;
@@ -37,7 +37,7 @@ int FileDescriptorPDFDocBuilder::parseFdFromUri(const GooString &uri)
 
 std::unique_ptr<PDFDoc> FileDescriptorPDFDocBuilder::buildPDFDoc(const GooString &uri, const std::optional<GooString> &ownerPassword, const std::optional<GooString> &userPassword)
 {
-    const auto fd = parseFdFromUri(uri);
+    const auto fd = parseFdFromUri(uri.toStr());
     if (fd == -1) {
         return {};
     }
@@ -53,10 +53,10 @@ std::unique_ptr<PDFDoc> FileDescriptorPDFDocBuilder::buildPDFDoc(const GooString
     }
 
     auto cachedFile = std::make_shared<CachedFile>(std::make_unique<FILECacheLoader>(file));
-    return std::make_unique<PDFDoc>(new CachedFileStream(cachedFile, 0, false, cachedFile->getLength(), Object::null()), ownerPassword, userPassword);
+    return std::make_unique<PDFDoc>(std::make_unique<CachedFileStream>(cachedFile, 0, false, cachedFile->getLength(), Object::null()), ownerPassword, userPassword);
 }
 
 bool FileDescriptorPDFDocBuilder::supports(const GooString &uri)
 {
-    return parseFdFromUri(uri) != -1;
+    return parseFdFromUri(uri.toStr()) != -1;
 }
