@@ -7,7 +7,7 @@
 //
 // Copyright (C) 2008-2009 Carlos Garcia Campos <carlosgc@gnome.org>
 // Copyright (C) 2009 Kovid Goyal <kovid@kovidgoyal.net>
-// Copyright (C) 2012, 2017-2021, 2024 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2012, 2017-2021, 2024, 2026 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2012 Hib Eris <hib@hiberis.nl>
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
@@ -288,7 +288,7 @@ Object getFileSpecNameForPlatform(const Object *fileSpec)
             }
             if (j < name->size()) {
                 name->setChar(0, '\\');
-                name->insert(0, 1, '\\');
+                name->insert(0, "\\");
                 i = 2;
             }
         }
