@@ -13,7 +13,7 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2005, 2006, 2008-2010, 2012, 2014, 2015, 2017-2025 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2006, 2008-2010, 2012, 2014, 2015, 2017-2026 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2005, 2006 Kristian Høgsberg <krh@redhat.com>
 // Copyright (C) 2006 Takashi Iwai <tiwai@suse.de>
 // Copyright (C) 2007 Julien Rebetez <julienr@svn.gnome.org>
@@ -38,7 +38,7 @@
 // Copyright (C) 2021, 2022, 2024 Oliver Sander <oliver.sander@tu-dresden.de>
 // Copyright (C) 2023 Khaled Hosny <khaled@aliftype.com>
 // Copyright (C) 2024 Nelson Benítez León <nbenitezl@gmail.com>
-// Copyright (C) 2024, 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2024-2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 // Copyright (C) 2024 Vincent Lefevre <vincent@vinc17.net>
 // Copyright (C) 2024 G B <glen.browman@veeva.com>
 // Copyright (C) 2025 Arnav V <arnav0872@gmail.com>
@@ -83,75 +83,75 @@ struct Base14FontMapEntry
     const char *base14Name;
 };
 
-static const Base14FontMapEntry base14FontMap[] = { { "Arial", "Helvetica" },
-                                                    { "Arial,Bold", "Helvetica-Bold" },
-                                                    { "Arial,BoldItalic", "Helvetica-BoldOblique" },
-                                                    { "Arial,Italic", "Helvetica-Oblique" },
-                                                    { "Arial-Bold", "Helvetica-Bold" },
-                                                    { "Arial-BoldItalic", "Helvetica-BoldOblique" },
-                                                    { "Arial-BoldItalicMT", "Helvetica-BoldOblique" },
-                                                    { "Arial-BoldMT", "Helvetica-Bold" },
-                                                    { "Arial-Italic", "Helvetica-Oblique" },
-                                                    { "Arial-ItalicMT", "Helvetica-Oblique" },
-                                                    { "ArialMT", "Helvetica" },
-                                                    { "Courier", "Courier" },
-                                                    { "Courier,Bold", "Courier-Bold" },
-                                                    { "Courier,BoldItalic", "Courier-BoldOblique" },
-                                                    { "Courier,Italic", "Courier-Oblique" },
-                                                    { "Courier-Bold", "Courier-Bold" },
-                                                    { "Courier-BoldOblique", "Courier-BoldOblique" },
-                                                    { "Courier-Oblique", "Courier-Oblique" },
-                                                    { "CourierNew", "Courier" },
-                                                    { "CourierNew,Bold", "Courier-Bold" },
-                                                    { "CourierNew,BoldItalic", "Courier-BoldOblique" },
-                                                    { "CourierNew,Italic", "Courier-Oblique" },
-                                                    { "CourierNew-Bold", "Courier-Bold" },
-                                                    { "CourierNew-BoldItalic", "Courier-BoldOblique" },
-                                                    { "CourierNew-Italic", "Courier-Oblique" },
-                                                    { "CourierNewPS-BoldItalicMT", "Courier-BoldOblique" },
-                                                    { "CourierNewPS-BoldMT", "Courier-Bold" },
-                                                    { "CourierNewPS-ItalicMT", "Courier-Oblique" },
-                                                    { "CourierNewPSMT", "Courier" },
-                                                    { "Helvetica", "Helvetica" },
-                                                    { "Helvetica,Bold", "Helvetica-Bold" },
-                                                    { "Helvetica,BoldItalic", "Helvetica-BoldOblique" },
-                                                    { "Helvetica,Italic", "Helvetica-Oblique" },
-                                                    { "Helvetica-Bold", "Helvetica-Bold" },
-                                                    { "Helvetica-BoldItalic", "Helvetica-BoldOblique" },
-                                                    { "Helvetica-BoldOblique", "Helvetica-BoldOblique" },
-                                                    { "Helvetica-Italic", "Helvetica-Oblique" },
-                                                    { "Helvetica-Oblique", "Helvetica-Oblique" },
-                                                    { "Symbol", "Symbol" },
-                                                    { "Symbol,Bold", "Symbol" },
-                                                    { "Symbol,BoldItalic", "Symbol" },
-                                                    { "Symbol,Italic", "Symbol" },
-                                                    { "SymbolMT", "Symbol" },
-                                                    { "SymbolMT,Bold", "Symbol" },
-                                                    { "SymbolMT,BoldItalic", "Symbol" },
-                                                    { "SymbolMT,Italic", "Symbol" },
-                                                    { "Times-Bold", "Times-Bold" },
-                                                    { "Times-BoldItalic", "Times-BoldItalic" },
-                                                    { "Times-Italic", "Times-Italic" },
-                                                    { "Times-Roman", "Times-Roman" },
-                                                    { "TimesNewRoman", "Times-Roman" },
-                                                    { "TimesNewRoman,Bold", "Times-Bold" },
-                                                    { "TimesNewRoman,BoldItalic", "Times-BoldItalic" },
-                                                    { "TimesNewRoman,Italic", "Times-Italic" },
-                                                    { "TimesNewRoman-Bold", "Times-Bold" },
-                                                    { "TimesNewRoman-BoldItalic", "Times-BoldItalic" },
-                                                    { "TimesNewRoman-Italic", "Times-Italic" },
-                                                    { "TimesNewRomanPS", "Times-Roman" },
-                                                    { "TimesNewRomanPS-Bold", "Times-Bold" },
-                                                    { "TimesNewRomanPS-BoldItalic", "Times-BoldItalic" },
-                                                    { "TimesNewRomanPS-BoldItalicMT", "Times-BoldItalic" },
-                                                    { "TimesNewRomanPS-BoldMT", "Times-Bold" },
-                                                    { "TimesNewRomanPS-Italic", "Times-Italic" },
-                                                    { "TimesNewRomanPS-ItalicMT", "Times-Italic" },
-                                                    { "TimesNewRomanPSMT", "Times-Roman" },
-                                                    { "TimesNewRomanPSMT,Bold", "Times-Bold" },
-                                                    { "TimesNewRomanPSMT,BoldItalic", "Times-BoldItalic" },
-                                                    { "TimesNewRomanPSMT,Italic", "Times-Italic" },
-                                                    { "ZapfDingbats", "ZapfDingbats" } };
+static const Base14FontMapEntry base14FontMap[] = { { .altName = "Arial", .base14Name = "Helvetica" },
+                                                    { .altName = "Arial,Bold", .base14Name = "Helvetica-Bold" },
+                                                    { .altName = "Arial,BoldItalic", .base14Name = "Helvetica-BoldOblique" },
+                                                    { .altName = "Arial,Italic", .base14Name = "Helvetica-Oblique" },
+                                                    { .altName = "Arial-Bold", .base14Name = "Helvetica-Bold" },
+                                                    { .altName = "Arial-BoldItalic", .base14Name = "Helvetica-BoldOblique" },
+                                                    { .altName = "Arial-BoldItalicMT", .base14Name = "Helvetica-BoldOblique" },
+                                                    { .altName = "Arial-BoldMT", .base14Name = "Helvetica-Bold" },
+                                                    { .altName = "Arial-Italic", .base14Name = "Helvetica-Oblique" },
+                                                    { .altName = "Arial-ItalicMT", .base14Name = "Helvetica-Oblique" },
+                                                    { .altName = "ArialMT", .base14Name = "Helvetica" },
+                                                    { .altName = "Courier", .base14Name = "Courier" },
+                                                    { .altName = "Courier,Bold", .base14Name = "Courier-Bold" },
+                                                    { .altName = "Courier,BoldItalic", .base14Name = "Courier-BoldOblique" },
+                                                    { .altName = "Courier,Italic", .base14Name = "Courier-Oblique" },
+                                                    { .altName = "Courier-Bold", .base14Name = "Courier-Bold" },
+                                                    { .altName = "Courier-BoldOblique", .base14Name = "Courier-BoldOblique" },
+                                                    { .altName = "Courier-Oblique", .base14Name = "Courier-Oblique" },
+                                                    { .altName = "CourierNew", .base14Name = "Courier" },
+                                                    { .altName = "CourierNew,Bold", .base14Name = "Courier-Bold" },
+                                                    { .altName = "CourierNew,BoldItalic", .base14Name = "Courier-BoldOblique" },
+                                                    { .altName = "CourierNew,Italic", .base14Name = "Courier-Oblique" },
+                                                    { .altName = "CourierNew-Bold", .base14Name = "Courier-Bold" },
+                                                    { .altName = "CourierNew-BoldItalic", .base14Name = "Courier-BoldOblique" },
+                                                    { .altName = "CourierNew-Italic", .base14Name = "Courier-Oblique" },
+                                                    { .altName = "CourierNewPS-BoldItalicMT", .base14Name = "Courier-BoldOblique" },
+                                                    { .altName = "CourierNewPS-BoldMT", .base14Name = "Courier-Bold" },
+                                                    { .altName = "CourierNewPS-ItalicMT", .base14Name = "Courier-Oblique" },
+                                                    { .altName = "CourierNewPSMT", .base14Name = "Courier" },
+                                                    { .altName = "Helvetica", .base14Name = "Helvetica" },
+                                                    { .altName = "Helvetica,Bold", .base14Name = "Helvetica-Bold" },
+                                                    { .altName = "Helvetica,BoldItalic", .base14Name = "Helvetica-BoldOblique" },
+                                                    { .altName = "Helvetica,Italic", .base14Name = "Helvetica-Oblique" },
+                                                    { .altName = "Helvetica-Bold", .base14Name = "Helvetica-Bold" },
+                                                    { .altName = "Helvetica-BoldItalic", .base14Name = "Helvetica-BoldOblique" },
+                                                    { .altName = "Helvetica-BoldOblique", .base14Name = "Helvetica-BoldOblique" },
+                                                    { .altName = "Helvetica-Italic", .base14Name = "Helvetica-Oblique" },
+                                                    { .altName = "Helvetica-Oblique", .base14Name = "Helvetica-Oblique" },
+                                                    { .altName = "Symbol", .base14Name = "Symbol" },
+                                                    { .altName = "Symbol,Bold", .base14Name = "Symbol" },
+                                                    { .altName = "Symbol,BoldItalic", .base14Name = "Symbol" },
+                                                    { .altName = "Symbol,Italic", .base14Name = "Symbol" },
+                                                    { .altName = "SymbolMT", .base14Name = "Symbol" },
+                                                    { .altName = "SymbolMT,Bold", .base14Name = "Symbol" },
+                                                    { .altName = "SymbolMT,BoldItalic", .base14Name = "Symbol" },
+                                                    { .altName = "SymbolMT,Italic", .base14Name = "Symbol" },
+                                                    { .altName = "Times-Bold", .base14Name = "Times-Bold" },
+                                                    { .altName = "Times-BoldItalic", .base14Name = "Times-BoldItalic" },
+                                                    { .altName = "Times-Italic", .base14Name = "Times-Italic" },
+                                                    { .altName = "Times-Roman", .base14Name = "Times-Roman" },
+                                                    { .altName = "TimesNewRoman", .base14Name = "Times-Roman" },
+                                                    { .altName = "TimesNewRoman,Bold", .base14Name = "Times-Bold" },
+                                                    { .altName = "TimesNewRoman,BoldItalic", .base14Name = "Times-BoldItalic" },
+                                                    { .altName = "TimesNewRoman,Italic", .base14Name = "Times-Italic" },
+                                                    { .altName = "TimesNewRoman-Bold", .base14Name = "Times-Bold" },
+                                                    { .altName = "TimesNewRoman-BoldItalic", .base14Name = "Times-BoldItalic" },
+                                                    { .altName = "TimesNewRoman-Italic", .base14Name = "Times-Italic" },
+                                                    { .altName = "TimesNewRomanPS", .base14Name = "Times-Roman" },
+                                                    { .altName = "TimesNewRomanPS-Bold", .base14Name = "Times-Bold" },
+                                                    { .altName = "TimesNewRomanPS-BoldItalic", .base14Name = "Times-BoldItalic" },
+                                                    { .altName = "TimesNewRomanPS-BoldItalicMT", .base14Name = "Times-BoldItalic" },
+                                                    { .altName = "TimesNewRomanPS-BoldMT", .base14Name = "Times-Bold" },
+                                                    { .altName = "TimesNewRomanPS-Italic", .base14Name = "Times-Italic" },
+                                                    { .altName = "TimesNewRomanPS-ItalicMT", .base14Name = "Times-Italic" },
+                                                    { .altName = "TimesNewRomanPSMT", .base14Name = "Times-Roman" },
+                                                    { .altName = "TimesNewRomanPSMT,Bold", .base14Name = "Times-Bold" },
+                                                    { .altName = "TimesNewRomanPSMT,BoldItalic", .base14Name = "Times-BoldItalic" },
+                                                    { .altName = "TimesNewRomanPSMT,Italic", .base14Name = "Times-Italic" },
+                                                    { .altName = "ZapfDingbats", .base14Name = "ZapfDingbats" } };
 
 //------------------------------------------------------------------------
 
@@ -229,9 +229,8 @@ std::unique_ptr<GfxFont> GfxFont::makeFont(XRef *xref, const char *tagA, Ref idA
     // create the font object
     if (typeA < fontCIDType0) {
         return std::make_unique<Gfx8BitFont>(xref, tagA, idA, std::move(name), typeA, embFontIDA, fontDict);
-    } else {
-        return std::make_unique<GfxCIDFont>(tagA, idA, std::move(name), typeA, embFontIDA, fontDict);
     }
+    return std::make_unique<GfxCIDFont>(tagA, idA, std::move(name), typeA, embFontIDA, fontDict);
 }
 
 GfxFont::GfxFont(const char *tagA, Ref idA, std::optional<std::string> &&nameA, GfxFontType typeA, Ref embFontIDA) : tag(tagA), id(idA), name(std::move(nameA)), type(typeA)
@@ -752,15 +751,14 @@ std::optional<GfxFontLoc> GfxFont::locateFont(XRef *xref, PSOutputDev *ps, GooSt
             fontLoc.path = substName;
             fontLoc.substIdx = substIdx;
             return fontLoc;
-        } else {
-            path = globalParams->findFontFile(substName);
-            if (path) {
-                if (std::optional<GfxFontLoc> fontLoc = getExternalFont(*path, false)) {
-                    error(errSyntaxWarning, -1, "Substituting font '{0:s}' for '{1:s}'", base14SubstFonts[substIdx], name ? name->c_str() : "");
-                    name = base14SubstFonts[substIdx];
-                    fontLoc->substIdx = substIdx;
-                    return fontLoc;
-                }
+        }
+        path = globalParams->findFontFile(substName);
+        if (path) {
+            if (std::optional<GfxFontLoc> fontLoc = getExternalFont(*path, false)) {
+                error(errSyntaxWarning, -1, "Substituting font '{0:s}' for '{1:s}'", base14SubstFonts[substIdx], name ? name->c_str() : "");
+                name = base14SubstFonts[substIdx];
+                fontLoc->substIdx = substIdx;
+                return fontLoc;
             }
         }
 
@@ -840,7 +838,8 @@ struct AlternateNameMap
     const char *alt;
 };
 
-static const AlternateNameMap alternateNameMap[] = { { "fi", "f_i" }, { "fl", "f_l" }, { "ff", "f_f" }, { "ffi", "f_f_i" }, { "ffl", "f_f_l" }, { nullptr, nullptr } };
+static const AlternateNameMap alternateNameMap[] = { { .name = "fi", .alt = "f_i" },    { .name = "fl", .alt = "f_l" },    { .name = "ff", .alt = "f_f" },
+                                                     { .name = "ffi", .alt = "f_f_i" }, { .name = "ffl", .alt = "f_f_l" }, { .name = nullptr, .alt = nullptr } };
 
 const char *GfxFont::getAlternateName(const char *name)
 {
@@ -1418,7 +1417,8 @@ static int parseCharName(char *charName, Unicode *uBuf, int uLen, bool names, bo
         char *var_part = strchr(charName, '.');
         if (var_part == charName) {
             return 0; // .notdef or similar
-        } else if (var_part != nullptr) {
+        }
+        if (var_part != nullptr) {
             // parse names of the form 7.oldstyle, P.swash, s.sc, etc.
             char *main_part = copyString(charName, var_part - charName);
             bool namesRecurse = true, variantsRecurse = false;
@@ -1662,18 +1662,16 @@ Object Gfx8BitFont::getCharProc(int code)
 {
     if (enc[code] && charProcs.isDict()) {
         return charProcs.dictLookup(enc[code]);
-    } else {
-        return Object::null();
     }
+    return Object::null();
 }
 
 Object Gfx8BitFont::getCharProcNF(int code)
 {
     if (enc[code] && charProcs.isDict()) {
         return charProcs.dictLookupNF(enc[code]).copy();
-    } else {
-        return Object::null();
     }
+    return Object::null();
 }
 
 Dict *Gfx8BitFont::getResources()
@@ -1741,8 +1739,8 @@ GfxCIDFont::GfxCIDFont(const char *tagA, Ref idA, std::optional<std::string> &&n
             obj3 = Object(std::make_unique<GooString>("Identity"));
         }
         collection = obj2.takeString();
-        collection->append('-');
-        collection->append(obj3.getString());
+        collection->push_back('-');
+        collection->append(obj3.getString()->toStr());
     } else {
         error(errSyntaxError, -1, "Missing CIDSystemInfo dictionary in Type 0 descendant font");
         error(errSyntaxError, -1, "Assuming Adobe-Identity for character collection");
@@ -1755,7 +1753,7 @@ GfxCIDFont::GfxCIDFont(const char *tagA, Ref idA, std::optional<std::string> &&n
 
         // use an identity mapping for the "Adobe-Identity" and
         // "Adobe-UCS" collections
-        if (!collection->cmp("Adobe-Identity") || !collection->cmp("Adobe-UCS")) {
+        if (!collection->compare("Adobe-Identity") || !collection->compare("Adobe-UCS")) {
             ctu = CharCodeToUnicode::makeIdentityMapping();
         } else {
             // look for a user-supplied .cidToUnicode file
@@ -1769,7 +1767,7 @@ GfxCIDFont::GfxCIDFont(const char *tagA, Ref idA, std::optional<std::string> &&n
                     "Adobe-CNS1", "Adobe-GB1", "Adobe-Japan1", "Adobe-Japan2", "Adobe-Korea1",
                 };
                 for (const char *knownCollection : knownCollections) {
-                    if (collection->cmp(knownCollection) == 0) {
+                    if (collection->compare(knownCollection) == 0) {
                         error(errSyntaxError, -1, "Missing language pack for '{0:t}' mapping", collection.get());
                         return;
                     }
@@ -1824,7 +1822,7 @@ GfxCIDFont::GfxCIDFont(const char *tagA, Ref idA, std::optional<std::string> &&n
             if (obj2.isInt() && obj3.isInt() && i + 2 < obj1.arrayGetLength()) {
                 obj4 = obj1.arrayGet(i + 2);
                 if (obj4.isNum()) {
-                    GfxFontCIDWidthExcep excep { static_cast<CID>(obj2.getInt()), static_cast<CID>(obj3.getInt()), obj4.getNum() * 0.001 };
+                    GfxFontCIDWidthExcep excep { .first = static_cast<CID>(obj2.getInt()), .last = static_cast<CID>(obj3.getInt()), .width = obj4.getNum() * 0.001 };
                     widths.exceps.push_back(excep);
                 } else {
                     error(errSyntaxError, -1, "Bad widths array in Type 0 font");
@@ -1836,7 +1834,7 @@ GfxCIDFont::GfxCIDFont(const char *tagA, Ref idA, std::optional<std::string> &&n
                     for (int k = 0; k < obj3.arrayGetLength(); ++k) {
                         obj4 = obj3.arrayGet(k);
                         if (obj4.isNum()) {
-                            GfxFontCIDWidthExcep excep { static_cast<CID>(j), static_cast<CID>(j), obj4.getNum() * 0.001 };
+                            GfxFontCIDWidthExcep excep { .first = static_cast<CID>(j), .last = static_cast<CID>(j), .width = obj4.getNum() * 0.001 };
                             widths.exceps.push_back(excep);
                             ++j;
                         } else {
@@ -1875,7 +1873,7 @@ GfxCIDFont::GfxCIDFont(const char *tagA, Ref idA, std::optional<std::string> &&n
             obj3 = obj1.arrayGet(i + 1);
             if (obj2.isInt() && obj3.isInt() && i + 4 < obj1.arrayGetLength()) {
                 if ((obj4 = obj1.arrayGet(i + 2), obj4.isNum()) && (obj5 = obj1.arrayGet(i + 3), obj5.isNum()) && (obj6 = obj1.arrayGet(i + 4), obj6.isNum())) {
-                    GfxFontCIDWidthExcepV excepV { static_cast<CID>(obj2.getInt()), static_cast<CID>(obj3.getInt()), obj4.getNum() * 0.001, obj5.getNum() * 0.001, obj6.getNum() * 0.001 };
+                    GfxFontCIDWidthExcepV excepV { .first = static_cast<CID>(obj2.getInt()), .last = static_cast<CID>(obj3.getInt()), .height = obj4.getNum() * 0.001, .vx = obj5.getNum() * 0.001, .vy = obj6.getNum() * 0.001 };
                     widths.excepsV.push_back(excepV);
                 } else {
                     error(errSyntaxError, -1, "Bad widths (W2) array in Type 0 font");
@@ -1885,8 +1883,12 @@ GfxCIDFont::GfxCIDFont(const char *tagA, Ref idA, std::optional<std::string> &&n
                 int j = obj2.getInt();
                 for (int k = 0; k < obj3.arrayGetLength(); k += 3) {
                     if ((obj4 = obj3.arrayGet(k), obj4.isNum()) && (obj5 = obj3.arrayGet(k + 1), obj5.isNum()) && (obj6 = obj3.arrayGet(k + 2), obj6.isNum())) {
-                        GfxFontCIDWidthExcepV excepV { static_cast<CID>(j), static_cast<CID>(j), obj4.getNum() * 0.001, obj5.getNum() * 0.001, obj6.getNum() * 0.001 };
+                        GfxFontCIDWidthExcepV excepV { .first = static_cast<CID>(j), .last = static_cast<CID>(j), .height = obj4.getNum() * 0.001, .vx = obj5.getNum() * 0.001, .vy = obj6.getNum() * 0.001 };
                         widths.excepsV.push_back(excepV);
+                        if (j == std::numeric_limits<int>::max()) {
+                            error(errSyntaxError, -1, "Reached limit for CID in W2 array in Type 0 font");
+                            break;
+                        }
                         ++j;
                     } else {
                         error(errSyntaxError, -1, "Bad widths (W2) array in Type 0 font");
@@ -1937,7 +1939,7 @@ int GfxCIDFont::getNextChar(const char *s, int len, CharCode *code, Unicode cons
     }
 
     // horizontal
-    if (cMap->getWMode() == 0) {
+    if (cMap->getWMode() == GfxFont::WritingMode::Horizontal) {
         w = getWidth(cid);
         h = vx = vy = 0;
 
@@ -1975,9 +1977,9 @@ int GfxCIDFont::getNextChar(const char *s, int len, CharCode *code, Unicode cons
     return n;
 }
 
-int GfxCIDFont::getWMode() const
+GfxFont::WritingMode GfxCIDFont::getWMode() const
 {
-    return cMap ? cMap->getWMode() : 0;
+    return cMap ? cMap->getWMode() : GfxFont::WritingMode::Horizontal;
 }
 
 const CharCodeToUnicode *GfxCIDFont::getToUnicode() const
@@ -1990,10 +1992,10 @@ const GooString *GfxCIDFont::getCollection() const
     return cMap ? cMap->getCollection() : nullptr;
 }
 
-int GfxCIDFont::mapCodeToGID(FoFiTrueType *ff, int cmapi, Unicode unicode, bool wmode)
+int GfxCIDFont::mapCodeToGID(FoFiTrueType *ff, int cmapi, Unicode unicode, GfxFont::WritingMode wmode)
 {
     unsigned short gid = ff->mapCodeToGID(cmapi, unicode);
-    if (wmode) {
+    if (wmode == GfxFont::WritingMode::Vertical) {
         const unsigned short vgid = ff->mapToVertGID(gid);
         if (vgid != 0) {
             gid = vgid;
@@ -2020,41 +2022,41 @@ std::vector<int> GfxCIDFont::getCodeToGIDMap(FoFiTrueType *ff)
         const std::string toUnicodeMap;
         const std::array<std::string, 4> *CMaps;
     } CMapList[] = { {
-                             "Adobe-CNS1",
-                             "hani",
-                             "CHN ",
-                             "Adobe-CNS1-UCS2",
-                             &adobe_cns1_cmaps,
+                             .collection = "Adobe-CNS1",
+                             .scriptTag = "hani",
+                             .languageTag = "CHN ",
+                             .toUnicodeMap = "Adobe-CNS1-UCS2",
+                             .CMaps = &adobe_cns1_cmaps,
                      },
                      {
-                             "Adobe-GB1",
-                             "hani",
-                             "CHN ",
-                             "Adobe-GB1-UCS2",
-                             &adobe_gb1_cmaps,
+                             .collection = "Adobe-GB1",
+                             .scriptTag = "hani",
+                             .languageTag = "CHN ",
+                             .toUnicodeMap = "Adobe-GB1-UCS2",
+                             .CMaps = &adobe_gb1_cmaps,
                      },
                      {
-                             "Adobe-Japan1",
-                             "kana",
-                             "JAN ",
-                             "Adobe-Japan1-UCS2",
-                             &adobe_japan1_cmaps,
+                             .collection = "Adobe-Japan1",
+                             .scriptTag = "kana",
+                             .languageTag = "JAN ",
+                             .toUnicodeMap = "Adobe-Japan1-UCS2",
+                             .CMaps = &adobe_japan1_cmaps,
                      },
                      {
-                             "Adobe-Japan2",
-                             "kana",
-                             "JAN ",
-                             "Adobe-Japan2-UCS2",
-                             &adobe_japan2_cmaps,
+                             .collection = "Adobe-Japan2",
+                             .scriptTag = "kana",
+                             .languageTag = "JAN ",
+                             .toUnicodeMap = "Adobe-Japan2-UCS2",
+                             .CMaps = &adobe_japan2_cmaps,
                      },
                      {
-                             "Adobe-Korea1",
-                             "hang",
-                             "KOR ",
-                             "Adobe-Korea1-UCS2",
-                             &adobe_korea1_cmaps,
+                             .collection = "Adobe-Korea1",
+                             .scriptTag = "hang",
+                             .languageTag = "KOR ",
+                             .toUnicodeMap = "Adobe-Korea1-UCS2",
+                             .CMaps = &adobe_korea1_cmaps,
                      },
-                     { nullptr, {}, {}, {}, nullptr } };
+                     { .collection = nullptr, .scriptTag = {}, .languageTag = {}, .toUnicodeMap = {}, .CMaps = nullptr } };
     Unicode *humap = nullptr;
     Unicode *vumap = nullptr;
     Unicode *tumap = nullptr;
@@ -2068,7 +2070,7 @@ std::vector<int> GfxCIDFont::getCodeToGIDMap(FoFiTrueType *ff)
     }
 
     if (getEmbeddedFontID(&embID)) {
-        if (getCollection()->cmp("Adobe-Identity") == 0) {
+        if (getCollection()->compare("Adobe-Identity") == 0) {
             return {};
         }
 
@@ -2089,7 +2091,8 @@ std::vector<int> GfxCIDFont::getCodeToGIDMap(FoFiTrueType *ff)
             cmap = i;
             /* use UCS-4 cmap */
             break;
-        } else if (cmapPlatform == 3 && cmapEncoding == 1) {
+        }
+        if (cmapPlatform == 3 && cmapEncoding == 1) {
             /* Unicode */
             cmap = i;
         } else if (cmapPlatform == 0 && cmap < 0) {
@@ -2100,7 +2103,7 @@ std::vector<int> GfxCIDFont::getCodeToGIDMap(FoFiTrueType *ff)
         return {};
     }
 
-    const int wmode = getWMode();
+    const GfxFont::WritingMode wmode = getWMode();
     for (lp = CMapList; lp->collection != nullptr; lp++) {
         if (strcmp(lp->collection, getCollection()->c_str()) == 0) {
             break;
@@ -2131,7 +2134,7 @@ std::vector<int> GfxCIDFont::getCodeToGIDMap(FoFiTrueType *ff)
         for (const std::string &cname : *lp->CMaps) {
             std::shared_ptr<CMap> cnameCMap;
             if ((cnameCMap = globalParams->getCMap(getCollection()->toStr(), cname)) != nullptr) {
-                if (cnameCMap->getWMode()) {
+                if (cnameCMap->getWMode() == GfxFont::WritingMode::Vertical) {
                     cnameCMap->setReverseMap(vumap, n, 1);
                 } else {
                     cnameCMap->setReverseMap(humap, n, N_UCS_CANDIDATES);
@@ -2140,7 +2143,7 @@ std::vector<int> GfxCIDFont::getCodeToGIDMap(FoFiTrueType *ff)
         }
         ff->setupGSUB(lp->scriptTag, lp->languageTag);
     } else {
-        if (getCollection()->cmp("Adobe-Identity") == 0) {
+        if (getCollection()->compare("Adobe-Identity") == 0) {
             error(errSyntaxError, -1, "non-embedded font using identity encoding: {0:s}", name ? name->c_str() : "(null)");
         } else {
             error(errSyntaxError, -1, "Unknown character collection {0:t}", getCollection());
@@ -2172,23 +2175,23 @@ std::vector<int> GfxCIDFont::getCodeToGIDMap(FoFiTrueType *ff)
         gid = 0;
         if (humap != nullptr) {
             for (i = 0; i < N_UCS_CANDIDATES && gid == 0 && (unicode = humap[code * N_UCS_CANDIDATES + i]) != 0; i++) {
-                gid = mapCodeToGID(ff, cmap, unicode, false);
+                gid = mapCodeToGID(ff, cmap, unicode, GfxFont::WritingMode::Horizontal);
             }
         }
         if (gid == 0 && vumap != nullptr) {
             unicode = vumap[code];
             if (unicode != 0) {
-                gid = mapCodeToGID(ff, cmap, unicode, true);
+                gid = mapCodeToGID(ff, cmap, unicode, GfxFont::WritingMode::Vertical);
                 if (gid == 0 && tumap != nullptr) {
                     if ((unicode = tumap[code]) != 0) {
-                        gid = mapCodeToGID(ff, cmap, unicode, true);
+                        gid = mapCodeToGID(ff, cmap, unicode, GfxFont::WritingMode::Vertical);
                     }
                 }
             }
         }
         if (gid == 0 && tumap != nullptr) {
             if ((unicode = tumap[code]) != 0) {
-                gid = mapCodeToGID(ff, cmap, unicode, false);
+                gid = mapCodeToGID(ff, cmap, unicode, GfxFont::WritingMode::Horizontal);
             }
         }
         if (gid == 0) {
@@ -2334,7 +2337,7 @@ public:
         }
     }
 
-    int get31() { return (h ^ (h >> 31)) & 0x7fffffff; }
+    int get31() const { return (h ^ (h >> 31)) & 0x7fffffff; }
 
 private:
     unsigned int h;
