@@ -13,7 +13,7 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2005, 2008, 2015, 2017-2022, 2024 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2008, 2015, 2017-2022, 2024-2026 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2006 Takashi Iwai <tiwai@suse.de>
 // Copyright (C) 2006 Kristian Høgsberg <krh@redhat.com>
 // Copyright (C) 2007 Julien Rebetez <julienr@svn.gnome.org>
@@ -36,6 +36,7 @@
 #define GFXFONT_H
 
 #include <memory>
+#include <array>
 #include <optional>
 
 #include "goo/GooString.h"
@@ -255,17 +256,23 @@ public:
     virtual const CharCodeToUnicode *getToUnicode() const = 0;
 
     // Return the font matrix.
-    const double *getFontMatrix() const { return fontMat; }
+    const std::array<double, 6> &getFontMatrix() const { return fontMat; }
 
     // Return the font bounding box.
-    const double *getFontBBox() const { return fontBBox; }
+    const std::array<double, 4> &getFontBBox() const { return fontBBox; }
 
     // Return the ascent and descent values.
     double getAscent() const { return ascent; }
     double getDescent() const { return descent; }
 
-    // Return the writing mode (0=horizontal, 1=vertical).
-    virtual int getWMode() const { return 0; }
+    enum class WritingMode
+    {
+        Horizontal,
+        Vertical
+    };
+
+    // Return the writing mode
+    virtual WritingMode getWMode() const { return WritingMode::Horizontal; }
 
     // Locate the font file for this font.  If <ps> is not null, includes PS
     // printer-resident fonts.  Returns std::optional without a value on failure.
@@ -294,11 +301,13 @@ public:
     // http://sourceforge.net/adobe/aglfn/wiki/AGL%20Specification/
     static const char *getAlternateName(const char *name);
 
+    static bool isBase14Font(std::string_view family, std::string_view style);
+
 protected:
     GfxFont(const char *tagA, Ref idA, std::optional<std::string> &&nameA, GfxFontType typeA, Ref embFontIDA);
 
     static GfxFontType getFontType(XRef *xref, Dict *fontDict, Ref *embID);
-    void readFontDescriptor(XRef *xref, Dict *fontDict);
+    void readFontDescriptor(Dict *fontDict);
     [[nodiscard]] std::unique_ptr<CharCodeToUnicode> readToUnicodeCMap(Dict *fontDict, int nBits, std::unique_ptr<CharCodeToUnicode> ctu);
     static std::optional<GfxFontLoc> getExternalFont(const std::string &path, bool cid);
 
@@ -312,8 +321,8 @@ protected:
     int flags; // font descriptor flags
     std::unique_ptr<GooString> embFontName; // name of embedded font
     Ref embFontID; // ref to embedded font file stream
-    double fontMat[6]; // font matrix (Type 3 only)
-    double fontBBox[4]; // font bounding box (Type 3 only)
+    std::array<double, 6> fontMat; // font matrix (Type 3 only)
+    std::array<double, 4> fontBBox; // font bounding box (Type 3 only)
     double missingWidth; // "default" width
     double ascent; // max height above baseline
     double descent; // max depth below baseline
@@ -389,14 +398,14 @@ private:
 class POPPLER_PRIVATE_EXPORT GfxCIDFont : public GfxFont
 {
 public:
-    GfxCIDFont(XRef *xref, const char *tagA, Ref idA, std::optional<std::string> &&nameA, GfxFontType typeA, Ref embFontIDA, Dict *fontDict);
+    GfxCIDFont(const char *tagA, Ref idA, std::optional<std::string> &&nameA, GfxFontType typeA, Ref embFontIDA, Dict *fontDict);
 
     bool isCIDFont() const override { return true; }
 
     int getNextChar(const char *s, int len, CharCode *code, Unicode const **u, int *uLen, double *dx, double *dy, double *ox, double *oy) const override;
 
     // Return the writing mode (0=horizontal, 1=vertical).
-    int getWMode() const override;
+    WritingMode getWMode() const override;
 
     // Return the Unicode map.
     const CharCodeToUnicode *getToUnicode() const override;
@@ -416,7 +425,7 @@ public:
     ~GfxCIDFont() override;
 
 private:
-    int mapCodeToGID(FoFiTrueType *ff, int cmapi, Unicode unicode, bool wmode);
+    static int mapCodeToGID(FoFiTrueType *ff, int cmapi, Unicode unicode, GfxFont::WritingMode wmode);
     double getWidth(CID cid) const; // Get width of a character.
 
     std::unique_ptr<GooString> collection; // collection name
@@ -437,7 +446,7 @@ class GfxFontDict
 {
 public:
     // Build the font dictionary, given the PDF font dictionary.
-    GfxFontDict(XRef *xref, const Ref fontDictRef, Dict *fontDict);
+    GfxFontDict(XRef *xref, Ref fontDictRef, Dict *fontDict);
 
     GfxFontDict(const GfxFontDict &) = delete;
     GfxFontDict &operator=(const GfxFontDict &) = delete;
