@@ -6,8 +6,9 @@
 // Hugo Mercier <hmercier31[at]gmail.com> (c) 2008
 // Pino Toscano <pino@kde.org> (c) 2008
 // Carlos Garcia Campos <carlosgc@gnome.org> (c) 2010
-// Albert Astals Cid <aacid@kde.org> (c) 2010, 2017-2019, 2022
+// Albert Astals Cid <aacid@kde.org> (c) 2010, 2017-2019, 2022, 2024
 // Evgeny Stambulchik <fnevgeny@gmail.com> (c) 2019
+// g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk> (c) 2025
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -45,8 +46,6 @@ MovieActivationParameters::MovieActivationParameters()
     zdenum = 1;
 }
 
-MovieActivationParameters::~MovieActivationParameters() { }
-
 void MovieActivationParameters::parseMovieActivation(const Object *aDict)
 {
     Object obj1 = aDict->dictLookup("Start");
@@ -172,7 +171,7 @@ void MovieActivationParameters::parseMovieActivation(const Object *aDict)
 
 void Movie::parseMovie(const Object *movieDict)
 {
-    fileName = nullptr;
+    fileName.reset();
     rotationAngle = 0;
     width = -1;
     height = -1;
@@ -181,7 +180,7 @@ void Movie::parseMovie(const Object *movieDict)
     Object obj1 = movieDict->dictLookup("F");
     Object obj2 = getFileSpecNameForPlatform(&obj1);
     if (obj2.isString()) {
-        fileName = obj2.getString()->copy();
+        fileName = obj2.takeString();
     } else {
         error(errSyntaxError, -1, "Invalid Movie");
         ok = false;
@@ -225,10 +224,7 @@ void Movie::parseMovie(const Object *movieDict)
     }
 }
 
-Movie::~Movie()
-{
-    delete fileName;
-}
+Movie::~Movie() = default;
 
 Movie::Movie(const Object *movieDict)
 {
@@ -268,12 +264,10 @@ Movie::Movie(const Movie &other)
 
     if (other.fileName) {
         fileName = other.fileName->copy();
-    } else {
-        fileName = nullptr;
     }
 }
 
-void Movie::getFloatingWindowSize(int *widthA, int *heightA)
+void Movie::getFloatingWindowSize(int *widthA, int *heightA) const
 {
     *widthA = int(width * double(MA.znum) / MA.zdenum);
     *heightA = int(height * double(MA.znum) / MA.zdenum);
