@@ -31,7 +31,6 @@
 
 #include <config.h>
 
-#include "goo/gmem.h"
 #include "goo/GooString.h"
 #include "PDFDoc.h"
 #include "XRef.h"
@@ -58,7 +57,7 @@ Outline::Outline(Object *outlineObjA, XRef *xrefA, PDFDoc *docA)
 Outline::~Outline()
 {
     if (items) {
-        for (auto entry : *items) {
+        for (auto *entry : *items) {
             delete entry;
         }
         delete items;
@@ -74,7 +73,7 @@ static void insertChildHelper(const std::string &itemTitle, int destPageNum, uns
         it = items.begin() + pos;
     }
 
-    Array *a = new Array(xref);
+    auto *a = new Array(xref);
     Ref *pageRef = doc->getCatalog()->getPageRef(destPageNum);
     if (pageRef != nullptr) {
         a->add(Object(*pageRef));
@@ -143,7 +142,7 @@ static void insertChildHelper(const std::string &itemTitle, int destPageNum, uns
         }
     }
 
-    OutlineItem *item = new OutlineItem(outlineItem.getDict(), outlineItemRef, nullptr, xref, doc);
+    auto *item = new OutlineItem(outlineItem.getDict(), outlineItemRef, nullptr, xref, doc);
 
     items.insert(it, item);
 }
@@ -191,15 +190,14 @@ static int recursiveRemoveList(Ref ref, XRef *xref)
     return count;
 }
 
-static void removeChildHelper(unsigned int pos, PDFDoc *doc, XRef *xref, std::vector<OutlineItem *> &items)
+static void removeChildHelper(unsigned int pos, XRef *xref, std::vector<OutlineItem *> &items)
 {
     std::vector<OutlineItem *>::const_iterator it;
     if (pos >= items.size()) {
         // position is out of range, do nothing
         return;
-    } else {
-        it = items.begin() + pos;
     }
+    it = items.begin() + pos;
 
     //  relink around this node
     Object itemObject = xref->fetch((*it)->getRef());
@@ -260,7 +258,7 @@ static void removeChildHelper(unsigned int pos, PDFDoc *doc, XRef *xref, std::ve
 
 void Outline::removeChild(unsigned int pos)
 {
-    removeChildHelper(pos, doc, xref, *items);
+    removeChildHelper(pos, xref, *items);
 }
 
 //------------------------------------------------------------------------
@@ -276,9 +274,9 @@ int Outline::addOutlineTreeNodeList(const std::vector<OutlineTreeNode> &nodeList
     int itemCount = 0;
     Ref prevNodeRef = Ref::INVALID();
 
-    for (auto &node : nodeList) {
+    for (const auto &node : nodeList) {
 
-        Array *a = new Array(doc->getXRef());
+        auto *a = new Array(doc->getXRef());
         Ref *pageRef = doc->getCatalog()->getPageRef(node.destPageNum);
         if (pageRef != nullptr) {
             a->add(Object(*pageRef));
@@ -381,7 +379,7 @@ void Outline::setOutline(const std::vector<OutlineTreeNode> &nodeList)
     // reload the outline object from the xrefs
 
     if (items) {
-        for (auto entry : *items) {
+        for (auto *entry : *items) {
             delete entry;
         }
         delete items;
@@ -446,7 +444,7 @@ OutlineItem::OutlineItem(const Dict *dict, Ref refA, OutlineItem *parentA, XRef
 OutlineItem::~OutlineItem()
 {
     if (kids) {
-        for (auto entry : *kids) {
+        for (auto *entry : *kids) {
             delete entry;
         }
         delete kids;
@@ -456,7 +454,7 @@ OutlineItem::~OutlineItem()
 
 std::vector<OutlineItem *> *OutlineItem::readItemList(OutlineItem *parent, const Object *firstItemRef, XRef *xrefA, PDFDoc *docA)
 {
-    auto items = new std::vector<OutlineItem *>();
+    auto *items = new std::vector<OutlineItem *>();
 
     RefRecursionChecker alreadyRead;
 
@@ -472,7 +470,7 @@ std::vector<OutlineItem *> *OutlineItem::readItemList(OutlineItem *parent, const
         if (!obj.isDict()) {
             break;
         }
-        OutlineItem *item = new OutlineItem(obj.getDict(), tempObj.getRef(), parent, xrefA, docA);
+        auto *item = new OutlineItem(obj.getDict(), tempObj.getRef(), parent, xrefA, docA);
         items->push_back(item);
         tempObj = obj.dictLookupNF("Next").copy();
     }
@@ -543,7 +541,7 @@ void OutlineItem::insertChild(const std::string &itemTitle, int destPageNum, uns
 void OutlineItem::removeChild(unsigned int pos)
 {
     open();
-    removeChildHelper(pos, doc, xref, *kids);
+    removeChildHelper(pos, xref, *kids);
 }
 
 void OutlineItem::setStartsOpen(bool value)
@@ -573,7 +571,6 @@ const std::vector<OutlineItem *> *OutlineItem::getKids()
 
     if (!kids || kids->empty()) {
         return nullptr;
-    } else {
-        return kids;
     }
+    return kids;
 }
