@@ -14,7 +14,7 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2005, 2006, 2008 Brad Hards <bradh@frogmouth.net>
-// Copyright (C) 2005, 2007-2009, 2011-2025 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2007-2009, 2011-2026 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2008 Julien Rebetez <julienr@svn.gnome.org>
 // Copyright (C) 2008, 2010 Pino Toscano <pino@kde.org>
 // Copyright (C) 2008, 2010, 2011 Carlos Garcia Campos <carlosgc@gnome.org>
@@ -54,10 +54,12 @@
 // Copyright (C) 2022 Felix Jung <fxjung@posteo.de>
 // Copyright (C) 2022 crt <chluo@cse.cuhk.edu.hk>
 // Copyright (C) 2022 Erich E. Hoover <erich.e.hoover@gmail.com>
-// Copyright (C) 2023-2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2023-2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 // Copyright (C) 2024 Vincent Lefevre <vincent@vinc17.net>
 // Copyright (C) 2024 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by Technische Universität Dresden
 // Copyright (C) 2025 Juraj Šarinay <juraj@sarinay.com>
+// Copyright (C) 2025 Jonathan Hähne <jonathan.haehne@hotmail.com>
+// Copyright (C) 2025 Arnav V <arnav0872@gmail.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -69,7 +71,6 @@
 
 #include <array>
 #include <cctype>
-#include <clocale>
 #include <cstdio>
 #include <cerrno>
 #include <climits>
@@ -82,10 +83,9 @@
 #include <sstream>
 #include <sys/stat.h>
 #include "CryptoSignBackend.h"
-#include "goo/glibc.h"
-#include "goo/gstrtod.h"
 #include "goo/GooString.h"
 #include "goo/gfile.h"
+#include "goo/glibc.h"
 #include "GlobalParams.h"
 #include "Page.h"
 #include "Catalog.h"
@@ -96,7 +96,6 @@
 #include "OutputDev.h"
 #include "Error.h"
 #include "Lexer.h"
-#include "Parser.h"
 #include "SecurityHandler.h"
 #include "Decrypt.h"
 #include "Outline.h"
@@ -116,19 +115,16 @@ struct FILECloser
 
 //------------------------------------------------------------------------
 
-#define headerSearchSize                                                                                                                                                                                                                       \
-    1024 // read this many bytes at beginning of
-         //   file to look for '%PDF'
-#define pdfIdLength 32 // PDF Document IDs (PermanentId, UpdateId) length
+constexpr int headerSearchSize = 1024; // read this many bytes at beginning of
+                                       //   file to look for '%PDF'
+constexpr int pdfIdLength = 32; // PDF Document IDs (PermanentId, UpdateId) length
 
-#define linearizationSearchSize                                                                                                                                                                                                                \
-    1024 // read this many bytes at beginning of
-         // file to look for linearization
-         // dictionary
+constexpr int linearizationSearchSize = 1024; // read this many bytes at beginning of
+                                              // file to look for linearization
+                                              // dictionary
 
-#define xrefSearchSize                                                                                                                                                                                                                         \
-    1024 // read this many bytes at end of file
-         //   to look for 'startxref'
+constexpr int xrefSearchSize = 1024; // read this many bytes at end of file
+                                     //   to look for 'startxref'
 
 //------------------------------------------------------------------------
 // PDFDoc
@@ -141,8 +137,8 @@ PDFDoc::PDFDoc() = default;
 PDFDoc::PDFDoc(std::unique_ptr<GooString> &&fileNameA, const std::optional<GooString> &ownerPassword, const std::optional<GooString> &userPassword, const std::function<void()> &xrefReconstructedCallback) : fileName(std::move(fileNameA))
 {
 #ifdef _WIN32
-    const int n = fileName->getLength();
-    for (int i = 0; i < n; ++i) {
+    const size_t n = fileName->size();
+    for (size_t i = 0; i < n; ++i) {
         fileNameU.push_back((wchar_t)(fileName->getChar(i) & 0xff));
     }
 
@@ -164,7 +160,7 @@ PDFDoc::PDFDoc(std::unique_ptr<GooString> &&fileNameA, const std::optional<GooSt
     }
 
     // create stream
-    str = new FileStream(file.get(), 0, false, file->size(), Object(objNull));
+    str = std::make_unique<FileStream>(file.get(), 0, false, file->size(), Object::null());
 
     ok = setup(ownerPassword, userPassword, xrefReconstructedCallback);
 }
@@ -177,7 +173,7 @@ PDFDoc::PDFDoc(wchar_t *fileNameA, int fileNameLen, const std::optional<GooStrin
     // save both Unicode and 8-bit copies of the file name
     std::unique_ptr<GooString> fileNameG = std::make_unique<GooString>();
     for (int i = 0; i < fileNameLen; ++i) {
-        fileNameG->append((char)fileNameA[i]);
+        fileNameG->push_back((char)fileNameA[i]);
         fileNameU.push_back(fileNameA[i]);
     }
     fileName = std::move(fileNameG);
@@ -198,24 +194,24 @@ PDFDoc::PDFDoc(wchar_t *fileNameA, int fileNameLen, const std::optional<GooStrin
     }
 
     // create stream
-    str = new FileStream(file.get(), 0, false, file->size(), Object(objNull));
+    str = std::make_unique<FileStream>(file.get(), 0, false, file->size(), Object::null());
 
     ok = setup(ownerPassword, userPassword, xrefReconstructedCallback);
 }
 #endif
 
-PDFDoc::PDFDoc(BaseStream *strA, const std::optional<GooString> &ownerPassword, const std::optional<GooString> &userPassword, const std::function<void()> &xrefReconstructedCallback)
+PDFDoc::PDFDoc(std::unique_ptr<BaseStream> strA, const std::optional<GooString> &ownerPassword, const std::optional<GooString> &userPassword, const std::function<void()> &xrefReconstructedCallback)
 {
     if (strA->getFileName()) {
         fileName = strA->getFileName()->copy();
 #ifdef _WIN32
-        const int n = fileName->getLength();
-        for (int i = 0; i < n; ++i) {
+        const size_t n = fileName->size();
+        for (size_t i = 0; i < n; ++i) {
             fileNameU.push_back((wchar_t)(fileName->getChar(i) & 0xff));
         }
 #endif
     }
-    str = strA;
+    str = std::move(strA);
     ok = setup(ownerPassword, userPassword, xrefReconstructedCallback);
 }
 
@@ -236,8 +232,8 @@ bool PDFDoc::setup(const std::optional<GooString> &ownerPassword, const std::opt
         return false;
     }
 
-    if (!str->reset()) {
-        error(errSyntaxError, -1, "Document base stream reset failure");
+    if (!str->rewind()) {
+        error(errSyntaxError, -1, "Document base stream rewind failure");
         errCode = errFileIO;
         return false;
     }
@@ -252,12 +248,12 @@ bool PDFDoc::setup(const std::optional<GooString> &ownerPassword, const std::opt
     bool wasReconstructed = false;
 
     // read xref table
-    xref = new XRef(str, getStartXRef(), getMainXRefEntriesOffset(), &wasReconstructed, false, xrefReconstructedCallback);
+    xref = new XRef(str.get(), getStartXRef(), getMainXRefEntriesOffset(), &wasReconstructed, false, xrefReconstructedCallback);
     if (!xref->isOk()) {
         if (wasReconstructed) {
             delete xref;
             startXRefPos = -1;
-            xref = new XRef(str, getStartXRef(true), getMainXRefEntriesOffset(true), &wasReconstructed, false, xrefReconstructedCallback);
+            xref = new XRef(str.get(), getStartXRef(true), getMainXRefEntriesOffset(true), &wasReconstructed, false, xrefReconstructedCallback);
         }
         if (!xref->isOk()) {
             error(errSyntaxError, -1, "Couldn't read xref table");
@@ -279,7 +275,7 @@ bool PDFDoc::setup(const std::optional<GooString> &ownerPassword, const std::opt
             // try one more time to construct the Catalog, maybe the problem is damaged XRef
             delete catalog;
             delete xref;
-            xref = new XRef(str, 0, 0, nullptr, true, xrefReconstructedCallback);
+            xref = new XRef(str.get(), 0, 0, nullptr, true, xrefReconstructedCallback);
             catalog = new Catalog(this);
         }
 
@@ -305,7 +301,6 @@ PDFDoc::~PDFDoc()
     delete xref;
     delete hints;
     delete linearization;
-    delete str;
 }
 
 // Check for a %%EOF at the end of this stream
@@ -594,7 +589,7 @@ std::vector<FormFieldSignature *> PDFDoc::getSignatureFields()
                 FormWidget *fw = pw->getWidget(i);
                 if (fw->getType() == formSignature) {
                     assert(fw->getField()->getType() == formSignature);
-                    FormFieldSignature *ffs = static_cast<FormFieldSignature *>(fw->getField());
+                    auto *ffs = static_cast<FormFieldSignature *>(fw->getField());
                     if (std::ranges::find(res, ffs) == res.end()) {
                         res.push_back(ffs);
                     }
@@ -655,7 +650,7 @@ void PDFDoc::processLinks(OutputDev *out, int page)
 Linearization *PDFDoc::getLinearization()
 {
     if (!linearization) {
-        linearization = new Linearization(str);
+        linearization = new Linearization(str.get());
         linearizationState = 0;
     }
     return linearization;
@@ -673,7 +668,7 @@ bool PDFDoc::checkLinearization()
         return false;
     }
     if (!hints) {
-        hints = new Hints(str, linearization, getXRef(), secHdlr);
+        hints = new Hints(str.get(), linearization, getXRef(), secHdlr);
     }
     if (!hints->isOk()) {
         linearizationState = 2;
@@ -709,18 +704,16 @@ bool PDFDoc::isLinearized(bool tryingToReconstruct)
 {
     if ((str->getLength()) && (getLinearization()->getLength() == str->getLength())) {
         return true;
-    } else {
-        if (tryingToReconstruct) {
-            return getLinearization()->getLength() > 0;
-        } else {
-            return false;
-        }
     }
+    if (tryingToReconstruct) {
+        return getLinearization()->getLength() > 0;
+    }
+    return false;
 }
 
 void PDFDoc::setDocInfoStringEntry(const char *key, std::unique_ptr<GooString> value)
 {
-    bool removeEntry = !value || value->getLength() == 0 || (value->toStr() == unicodeByteOrderMark);
+    bool removeEntry = !value || value->empty() || (value->toStr() == unicodeByteOrderMark);
 
     Object infoObj = getDocInfo();
     if (infoObj.isNull() && removeEntry) {
@@ -731,7 +724,7 @@ void PDFDoc::setDocInfoStringEntry(const char *key, std::unique_ptr<GooString> v
     Ref infoObjRef;
     infoObj = xref->createDocInfoIfNeeded(&infoObjRef);
     if (removeEntry) {
-        infoObj.dictSet(key, Object(objNull));
+        infoObj.dictSet(key, Object::null());
     } else {
         infoObj.dictSet(key, Object(std::move(value)));
     }
@@ -751,12 +744,12 @@ std::unique_ptr<GooString> PDFDoc::getDocInfoStringEntry(const char *key)
         return {};
     }
 
-    const Object entryObj = infoObj.dictLookup(key);
+    Object entryObj = infoObj.dictLookup(key);
     if (!entryObj.isString()) {
         return {};
     }
 
-    return entryObj.getString()->copy();
+    return entryObj.takeString();
 }
 
 static bool get_id(const GooString *encodedidstring, GooString *id)
@@ -765,7 +758,7 @@ static bool get_id(const GooString *encodedidstring, GooString *id)
     char pdfid[pdfIdLength + 1];
     int n;
 
-    if (encodedidstring->getLength() != pdfIdLength / 2) {
+    if (encodedidstring->size() != pdfIdLength / 2) {
         return false;
     }
 
@@ -775,7 +768,7 @@ static bool get_id(const GooString *encodedidstring, GooString *id)
         return false;
     }
 
-    id->Set(pdfid, pdfIdLength);
+    id->assign(pdfid, pdfIdLength);
     return true;
 }
 
@@ -817,13 +810,13 @@ bool PDFDoc::getID(GooString *permanent_id, GooString *update_id) const
 Hints *PDFDoc::getHints()
 {
     if (!hints && isLinearized()) {
-        hints = new Hints(str, getLinearization(), getXRef(), secHdlr);
+        hints = new Hints(str.get(), getLinearization(), getXRef(), secHdlr);
     }
 
     return hints;
 }
 
-int PDFDoc::savePageAs(const GooString &name, int pageNo)
+int PDFDoc::savePageAs(const std::string &name, int pageNo)
 {
     FILE *f;
 
@@ -855,7 +848,7 @@ int PDFDoc::savePageAs(const GooString &name, int pageNo)
     Object page = getXRef()->fetch(*refPage);
 
     if (!(f = openFile(name.c_str(), "wb"))) {
-        error(errIO, -1, "Couldn't open file '{0:t}'", &name);
+        error(errIO, -1, "Couldn't open file '{0:s}'", name.c_str());
         return errOpenFile;
     }
     // Calls fclose on f when the fileCloser is destroyed because it goes out of scope
@@ -994,14 +987,14 @@ int PDFDoc::savePageAs(const GooString &name, int pageNo)
     return errNone;
 }
 
-int PDFDoc::saveAs(const GooString &name, PDFWriteMode mode)
+int PDFDoc::saveAs(const std::string &name, PDFWriteMode mode)
 {
     FILE *f;
     OutStream *outStr;
     int res;
 
     if (!(f = openFile(name.c_str(), "wb"))) {
-        error(errIO, -1, "Couldn't open file '{0:t}'", &name);
+        error(errIO, -1, "Couldn't open file '{0:s}'", name.c_str());
         return errOpenFile;
     }
     outStr = new FileOutStream(f, 0);
@@ -1029,14 +1022,14 @@ int PDFDoc::saveAs(OutStream *outStr, PDFWriteMode mode)
     return errNone;
 }
 
-int PDFDoc::saveWithoutChangesAs(const GooString &name)
+int PDFDoc::saveWithoutChangesAs(const std::string &name)
 {
     FILE *f;
     OutStream *outStr;
     int res;
 
     if (!(f = openFile(name.c_str(), "wb"))) {
-        error(errIO, -1, "Couldn't open file '{0:t}'", &name);
+        error(errIO, -1, "Couldn't open file '{0:s}'", name.c_str());
         return errOpenFile;
     }
 
@@ -1056,7 +1049,7 @@ int PDFDoc::saveWithoutChangesAs(OutStream *outStr)
     }
 
     std::unique_ptr<BaseStream> copyStr { str->copy() };
-    if (!copyStr->reset()) {
+    if (!copyStr->rewind()) {
         return errFileIO;
     }
     while (copyStr->lookChar() != EOF) {
@@ -1076,7 +1069,7 @@ void PDFDoc::saveIncrementalUpdate(OutStream *outStr)
 {
     // copy the original file
     std::unique_ptr<BaseStream> copyStr { str->copy() };
-    if (!copyStr->reset()) {
+    if (!copyStr->rewind()) {
         // some err;
     }
     while (copyStr->lookChar() != EOF) {
@@ -1229,7 +1222,7 @@ std::string PDFDoc::sanitizedName(const std::string &name)
     return sanitizedName;
 }
 
-void PDFDoc::writeDictionary(Dict *dict, OutStream *outStr, XRef *xRef, unsigned int numOffset, unsigned char *fileKey, CryptAlgorithm encAlgorithm, int keyLength, Ref ref, std::set<Dict *> *alreadyWrittenDicts)
+void PDFDoc::writeDictionary(Dict *dict, OutStream *outStr, XRef *xRef, unsigned int numOffset, const unsigned char *fileKey, CryptAlgorithm encAlgorithm, int keyLength, Ref ref, std::set<Dict *> *alreadyWrittenDicts)
 {
     bool deleteSet = false;
     if (!alreadyWrittenDicts) {
@@ -1237,20 +1230,19 @@ void PDFDoc::writeDictionary(Dict *dict, OutStream *outStr, XRef *xRef, unsigned
         deleteSet = true;
     }
 
-    if (alreadyWrittenDicts->find(dict) != alreadyWrittenDicts->end()) {
+    const auto [_, inserted] = alreadyWrittenDicts->insert(dict);
+    if (!inserted) {
         error(errSyntaxWarning, -1, "PDFDoc::writeDictionary: Found recursive dicts");
         if (deleteSet) {
             delete alreadyWrittenDicts;
         }
         return;
-    } else {
-        alreadyWrittenDicts->insert(dict);
     }
 
     outStr->printf("<<");
     for (int i = 0; i < dict->getLength(); i++) {
-        GooString keyName(dict->getKey(i));
-        outStr->printf("/%s ", sanitizedName(keyName.toStr()).c_str());
+        std::string keyName(dict->getKey(i));
+        outStr->printf("/%s ", sanitizedName(keyName).c_str());
         Object obj1 = dict->getValNF(i).copy();
         writeObject(&obj1, outStr, xRef, numOffset, fileKey, encAlgorithm, keyLength, ref, alreadyWrittenDicts);
     }
@@ -1263,7 +1255,7 @@ void PDFDoc::writeDictionary(Dict *dict, OutStream *outStr, XRef *xRef, unsigned
 
 void PDFDoc::writeStream(Stream *str, OutStream *outStr)
 {
-    if (!str->reset()) {
+    if (!str->rewind()) {
         return;
     }
     outStr->printf("stream\r\n");
@@ -1289,8 +1281,8 @@ void PDFDoc::writeRawStream(Stream *str, OutStream *outStr)
     }
 
     outStr->printf("stream\r\n");
-    if (!str->unfilteredReset()) {
-        error(errSyntaxError, -1, "PDFDoc::writeRawStream, reset failed");
+    if (!str->unfilteredRewind()) {
+        error(errSyntaxError, -1, "PDFDoc::writeRawStream, rewind failed");
         return;
     }
     for (Goffset i = 0; i < length; i++) {
@@ -1301,7 +1293,7 @@ void PDFDoc::writeRawStream(Stream *str, OutStream *outStr)
         }
         outStr->printf("%c", c);
     }
-    (void)str->reset();
+    (void)str->rewind();
     outStr->printf("\r\nendstream\r\n");
 }
 
@@ -1310,14 +1302,14 @@ void PDFDoc::writeString(const GooString *s, OutStream *outStr, const unsigned c
     // Encrypt string if encryption is enabled
     std::unique_ptr<GooString> sEnc = nullptr;
     if (fileKey) {
-        EncryptStream *enc = new EncryptStream(new MemStream(s->c_str(), 0, s->getLength(), Object(objNull)), fileKey, encAlgorithm, keyLength, ref);
+        auto *enc = new EncryptStream(std::make_unique<MemStream>(s->c_str(), 0, s->size(), Object::null()), fileKey, encAlgorithm, keyLength, ref);
         sEnc = std::make_unique<GooString>();
         int c;
-        if (!enc->reset()) {
+        if (!enc->rewind()) {
             return;
         }
         while ((c = enc->getChar()) != EOF) {
-            sEnc->append((char)c);
+            sEnc->push_back((char)c);
         }
 
         delete enc;
@@ -1330,7 +1322,7 @@ void PDFDoc::writeString(const GooString *s, OutStream *outStr, const unsigned c
         const char *c = s->c_str();
         std::stringstream stream;
         stream << std::setfill('0') << std::hex;
-        for (int i = 0; i < s->getLength(); i++) {
+        for (size_t i = 0; i < s->size(); i++) {
             stream << std::setw(2) << (0xff & (unsigned int)*(c + i));
         }
         outStr->printf("<");
@@ -1339,7 +1331,7 @@ void PDFDoc::writeString(const GooString *s, OutStream *outStr, const unsigned c
     } else {
         const char *c = s->c_str();
         outStr->printf("(");
-        for (int i = 0; i < s->getLength(); i++) {
+        for (size_t i = 0; i < s->size(); i++) {
             char unescaped = *(c + i) & 0x000000ff;
             // escape if needed
             if (unescaped == '\r') {
@@ -1364,12 +1356,12 @@ Goffset PDFDoc::writeObjectHeader(Ref *ref, OutStream *outStr)
     return offset;
 }
 
-void PDFDoc::writeObject(Object *obj, OutStream *outStr, XRef *xRef, unsigned int numOffset, unsigned char *fileKey, CryptAlgorithm encAlgorithm, int keyLength, int objNum, int objGen, std::set<Dict *> *alreadyWrittenDicts)
+void PDFDoc::writeObject(Object *obj, OutStream *outStr, XRef *xRef, unsigned int numOffset, const unsigned char *fileKey, CryptAlgorithm encAlgorithm, int keyLength, int objNum, int objGen, std::set<Dict *> *alreadyWrittenDicts)
 {
-    writeObject(obj, outStr, xRef, numOffset, fileKey, encAlgorithm, keyLength, { objNum, objGen }, alreadyWrittenDicts);
+    writeObject(obj, outStr, xRef, numOffset, fileKey, encAlgorithm, keyLength, { .num = objNum, .gen = objGen }, alreadyWrittenDicts);
 }
 
-void PDFDoc::writeObject(Object *obj, OutStream *outStr, XRef *xRef, unsigned int numOffset, unsigned char *fileKey, CryptAlgorithm encAlgorithm, int keyLength, Ref ref, std::set<Dict *> *alreadyWrittenDicts)
+void PDFDoc::writeObject(Object *obj, OutStream *outStr, XRef *xRef, unsigned int numOffset, const unsigned char *fileKey, CryptAlgorithm encAlgorithm, int keyLength, Ref ref, std::set<Dict *> *alreadyWrittenDicts)
 {
     Array *array;
 
@@ -1395,15 +1387,15 @@ void PDFDoc::writeObject(Object *obj, OutStream *outStr, XRef *xRef, unsigned in
     case objHexString: {
         const GooString *s = obj->getHexString();
         outStr->printf("<");
-        for (int i = 0; i < s->getLength(); i++) {
+        for (size_t i = 0; i < s->size(); i++) {
             outStr->printf("%02x", s->getChar(i) & 0xff);
         }
         outStr->printf("> ");
         break;
     }
     case objName: {
-        GooString name(obj->getName());
-        outStr->printf("/%s ", sanitizedName(name.toStr()).c_str());
+        std::string name(obj->getNameString());
+        outStr->printf("/%s ", sanitizedName(name).c_str());
         break;
     }
     case objNull:
@@ -1464,12 +1456,10 @@ void PDFDoc::writeObject(Object *obj, OutStream *outStr, XRef *xRef, unsigned in
                 removeFilter = false;
             }
             if (addEncryptstream) {
-                encStream = std::make_unique<EncryptStream>(stream, fileKey, encAlgorithm, keyLength, ref);
-                encStream->setAutoDelete(false);
-                stream = encStream.get();
+                encStream = std::make_unique<EncryptStream>(*stream, fileKey, encAlgorithm, keyLength, ref);
             }
 
-            if (!stream->reset()) {
+            if (!stream->rewind()) {
                 break;
             }
             // recalculate stream length
@@ -1480,7 +1470,7 @@ void PDFDoc::writeObject(Object *obj, OutStream *outStr, XRef *xRef, unsigned in
             stream->getDict()->set("Length", Object(tmp));
 
             // Remove Stream encoding
-            AutoFreeMemStream *internalStream = dynamic_cast<AutoFreeMemStream *>(stream);
+            auto *internalStream = dynamic_cast<AutoFreeMemStream *>(stream);
             if (internalStream && internalStream->isFilterRemovalForbidden()) {
                 removeFilter = false;
             }
@@ -1492,14 +1482,13 @@ void PDFDoc::writeObject(Object *obj, OutStream *outStr, XRef *xRef, unsigned in
             writeDictionary(stream->getDict(), outStr, xRef, numOffset, fileKey, encAlgorithm, keyLength, ref, alreadyWrittenDicts);
             writeStream(stream, outStr);
         } else if (fileKey != nullptr && stream->getKind() == strFile && static_cast<FileStream *>(stream)->getNeedsEncryptionOnSave()) {
-            EncryptStream *encStream = new EncryptStream(stream, fileKey, encAlgorithm, keyLength, ref);
-            encStream->setAutoDelete(false);
+            auto *encStream = new EncryptStream(*stream, fileKey, encAlgorithm, keyLength, ref);
             writeDictionary(encStream->getDict(), outStr, xRef, numOffset, fileKey, encAlgorithm, keyLength, ref, alreadyWrittenDicts);
             writeStream(encStream, outStr);
             delete encStream;
         } else {
             // raw stream copy
-            FilterStream *fs = dynamic_cast<FilterStream *>(stream);
+            auto *fs = dynamic_cast<FilterStream *>(stream);
             if (fs) {
                 BaseStream *bs = fs->getBaseStream();
                 if (bs) {
@@ -1570,7 +1559,7 @@ Object PDFDoc::createTrailerDict(int uxrefSize, bool incrUpdate, Goffset startxR
             for (int i = 0; i < docInfo.getDict()->getLength(); i++) {
                 Object obj2 = docInfo.getDict()->getVal(i);
                 if (obj2.isString()) {
-                    message.append(obj2.getString());
+                    message.append(obj2.getString()->toStr());
                 }
             }
         }
@@ -1587,7 +1576,7 @@ Object PDFDoc::createTrailerDict(int uxrefSize, bool incrUpdate, Goffset startxR
 
     // calculate md5 digest
     unsigned char digest[16];
-    md5((unsigned char *)message.c_str(), message.getLength(), digest);
+    md5((unsigned char *)message.c_str(), message.size(), digest);
 
     // create ID array
     // In case of encrypted files, the ID must not be changed because it's used to calculate the key
@@ -1599,7 +1588,7 @@ Object PDFDoc::createTrailerDict(int uxrefSize, bool incrUpdate, Goffset startxR
                 error(errSyntaxWarning, -1, "PDFDoc::createTrailerDict original file's ID entry isn't an array. Trying to continue");
             }
         } else {
-            Array *array = new Array(xRef);
+            auto *array = new Array(xRef);
             // Get the first part of the ID
             array->add(obj4.arrayGet(0));
             array->add(Object(std::make_unique<GooString>((const char *)digest, 16)));
@@ -1607,7 +1596,7 @@ Object PDFDoc::createTrailerDict(int uxrefSize, bool incrUpdate, Goffset startxR
         }
     } else {
         // new file => same values for the two identifiers
-        Array *array = new Array(xRef);
+        auto *array = new Array(xRef);
         array->add(Object(std::make_unique<GooString>((const char *)digest, 16)));
         array->add(Object(std::make_unique<GooString>((const char *)digest, 16)));
         trailerDict->set("ID", Object(array));
@@ -1633,7 +1622,7 @@ void PDFDoc::writeXRefTableTrailer(Object &&trailerDict, XRef *uxref, bool write
 {
     uxref->writeTableToFile(outStr, writeAllEntries);
     outStr->printf("trailer\r\n");
-    writeDictionary(trailerDict.getDict(), outStr, xRef, 0, nullptr, cryptRC4, 0, { 0, 0 }, nullptr);
+    writeDictionary(trailerDict.getDict(), outStr, xRef, 0, nullptr, cryptRC4, 0, { .num = 0, .gen = 0 }, nullptr);
     outStr->printf("\r\nstartxref\r\n");
     outStr->printf("%lli\r\n", uxrefOffset);
     outStr->printf("%%%%EOF\r\n");
@@ -1647,9 +1636,9 @@ void PDFDoc::writeXRefStreamTrailer(Object &&trailerDict, XRef *uxref, Ref *uxre
     uxref->writeStreamToBuffer(&stmData, trailerDict.getDict(), xRef);
 
     // Create XRef stream object and write it
-    MemStream *mStream = new MemStream(stmData.c_str(), 0, stmData.getLength(), std::move(trailerDict));
+    auto mStream = std::make_unique<MemStream>(stmData.c_str(), 0, stmData.size(), std::move(trailerDict));
     writeObjectHeader(uxrefStreamRef, outStr);
-    Object obj1(static_cast<Stream *>(mStream));
+    Object obj1(std::move(mStream));
     writeObject(&obj1, outStr, xRef, 0, nullptr, cryptRC4, 0, 0, 0);
     writeObjectFooter(outStr);
 
@@ -1664,7 +1653,7 @@ void PDFDoc::writeXRefTableTrailer(Goffset uxrefOffset, XRef *uxref, bool writeA
     // file size (doesn't include the trailer)
     unsigned int fileSize = 0;
     int c;
-    if (!str->reset()) {
+    if (!str->rewind()) {
         return;
     }
     while ((c = str->getChar()) != EOF) {
@@ -1692,14 +1681,13 @@ bool PDFDoc::markDictionary(Dict *dict, XRef *xRef, XRef *countRef, unsigned int
         deleteSet = true;
     }
 
-    if (alreadyMarkedDicts->find(dict) != alreadyMarkedDicts->end()) {
+    const auto [_, inserted] = alreadyMarkedDicts->insert(dict);
+    if (!inserted) {
         error(errSyntaxWarning, -1, "PDFDoc::markDictionary: Found recursive dicts");
         if (deleteSet) {
             delete alreadyMarkedDicts;
         }
         return true;
-    } else {
-        alreadyMarkedDicts->insert(dict);
     }
 
     for (int i = 0; i < dict->getLength(); i++) {
@@ -1788,7 +1776,7 @@ bool PDFDoc::markObject(Object *obj, XRef *xRef, XRef *countRef, unsigned int nu
     return true;
 }
 
-bool PDFDoc::replacePageDict(int pageNo, int rotate, const PDFRectangle *mediaBox, const PDFRectangle *cropBox)
+bool PDFDoc::replacePageDict(int pageNo, int rotate, const PDFRectangle *mediaBox, const PDFRectangle *cropBox) const
 {
     Ref *refPage = getCatalog()->getPageRef(pageNo);
     Object page = getXRef()->fetch(*refPage);
@@ -1803,7 +1791,7 @@ bool PDFDoc::replacePageDict(int pageNo, int rotate, const PDFRectangle *mediaBo
     pageDict->remove("BleedBox");
     pageDict->remove("TrimBox");
     pageDict->remove("Rotate");
-    Array *mediaBoxArray = new Array(getXRef());
+    auto *mediaBoxArray = new Array(getXRef());
     mediaBoxArray->add(Object(mediaBox->x1));
     mediaBoxArray->add(Object(mediaBox->y1));
     mediaBoxArray->add(Object(mediaBox->x2));
@@ -1812,7 +1800,7 @@ bool PDFDoc::replacePageDict(int pageNo, int rotate, const PDFRectangle *mediaBo
     Object trimBoxObject = mediaBoxObject.copy();
     pageDict->add("MediaBox", std::move(mediaBoxObject));
     if (cropBox != nullptr) {
-        Array *cropBoxArray = new Array(getXRef());
+        auto *cropBoxArray = new Array(getXRef());
         cropBoxArray->add(Object(cropBox->x1));
         cropBoxArray->add(Object(cropBox->y1));
         cropBoxArray->add(Object(cropBox->x2));
@@ -1857,6 +1845,15 @@ bool PDFDoc::markAnnotations(Object *annotsObj, XRef *xRef, XRef *countRef, unsi
             if (obj1.isDict()) {
                 Dict *dict = obj1.getDict();
                 Object type = dict->lookup("Type");
+                if (type.isNull()) {
+                    Object subType = dict->lookup("SubType");
+                    // Type is optional, subtype is required
+                    // If neither of them exists, something is probably
+                    // weird here, so let us just skip this entry
+                    if (subType.isNull()) {
+                        continue;
+                    }
+                }
                 if (type.isName() && strcmp(type.getName(), "Annot") == 0) {
                     const Object &obj2 = dict->lookupNF("P");
                     if (obj2.isRef()) {
@@ -2011,7 +2008,7 @@ Outline *PDFDoc::getOutline()
 std::unique_ptr<PDFDoc> PDFDoc::ErrorPDFDoc(int errorCode, std::unique_ptr<GooString> &&fileNameA)
 {
     // We cannot call std::make_unique here because the PDFDoc constructor is private
-    PDFDoc *doc = new PDFDoc();
+    auto *doc = new PDFDoc();
     doc->errCode = errorCode;
     doc->fileName = std::move(fileNameA);
 
@@ -2155,7 +2152,7 @@ std::unique_ptr<Page> PDFDoc::parsePage(int page)
     }
     Dict *pageDict = obj.getDict();
 
-    return std::make_unique<Page>(this, page, std::move(obj), pageRef, std::make_unique<PageAttrs>(nullptr, pageDict), catalog->getForm());
+    return std::make_unique<Page>(this, page, std::move(obj), pageRef, std::make_unique<PageAttrs>(nullptr, pageDict));
 }
 
 Page *PDFDoc::getPage(int page)
@@ -2174,9 +2171,8 @@ Page *PDFDoc::getPage(int page)
         }
         if (pageCache[page - 1]) {
             return pageCache[page - 1].get();
-        } else {
-            error(errSyntaxWarning, -1, "Failed parsing page {0:d} using hint tables", page);
         }
+        error(errSyntaxWarning, -1, "Failed parsing page {0:d} using hint tables", page);
     }
 
     return catalog->getPage(page);
@@ -2189,19 +2185,19 @@ bool PDFDoc::hasJavascript()
     return jsInfo.containsJS();
 }
 
-std::optional<PDFDoc::SignatureData> PDFDoc::createSignature(::Page *destPage, std::unique_ptr<GooString> &&partialFieldName, const PDFRectangle &rect, const GooString &signatureText, const GooString &signatureTextLeft, double fontSize,
-                                                             double leftFontSize, std::unique_ptr<AnnotColor> &&fontColor, double borderWidth, std::unique_ptr<AnnotColor> &&borderColor, std::unique_ptr<AnnotColor> &&backgroundColor,
-                                                             const std::string &imagePath)
+std::variant<PDFDoc::SignatureData, CryptoSign::SigningErrorMessage> PDFDoc::createSignature(::Page *destPage, std::unique_ptr<GooString> &&partialFieldName, const PDFRectangle &rect, const GooString &signatureText,
+                                                                                             const GooString &signatureTextLeft, double fontSize, double leftFontSize, std::unique_ptr<AnnotColor> &&fontColor, double borderWidth,
+                                                                                             std::unique_ptr<AnnotColor> &&borderColor, std::unique_ptr<AnnotColor> &&backgroundColor, const std::string &imagePath)
 {
     if (destPage == nullptr) {
-        return std::nullopt;
+        return CryptoSign::SigningErrorMessage { .type = CryptoSign::SigningError::InternalError, .message = ERROR_IN_CODE_LOCATION };
     }
 
     Ref imageResourceRef = Ref::INVALID();
     if (!imagePath.empty()) {
         imageResourceRef = ImageEmbeddingUtils::embed(xref, imagePath);
         if (imageResourceRef == Ref::INVALID()) {
-            return std::nullopt;
+            return CryptoSign::SigningErrorMessage { .type = CryptoSign::SigningError::GenericError, .message = ERROR_IN_CODE_LOCATION };
         }
     }
 
@@ -2212,20 +2208,20 @@ std::optional<PDFDoc::SignatureData> PDFDoc::createSignature(::Page *destPage, s
     annotObj.dictSet("Subtype", Object(objName, "Widget"));
     annotObj.dictSet("FT", Object(objName, "Sig"));
     annotObj.dictSet("T", Object(std::move(partialFieldName)));
-    Array *rectArray = new Array(getXRef());
+    auto *rectArray = new Array(getXRef());
     rectArray->add(Object(rect.x1));
     rectArray->add(Object(rect.y1));
     rectArray->add(Object(rect.x2));
     rectArray->add(Object(rect.y2));
     annotObj.dictSet("Rect", Object(rectArray));
 
-    if (signatureText.getLength() || signatureTextLeft.getLength()) {
+    if (!signatureText.empty() || !signatureTextLeft.empty()) {
         const std::string pdfFontName = form->findPdfFontNameToUseForSigning();
         if (pdfFontName.empty()) {
-            return std::nullopt;
+            return CryptoSign::SigningErrorMessage { .type = CryptoSign::SigningError::GenericError, .message = ERROR_IN_CODE_LOCATION };
         }
 
-        const DefaultAppearance da { { objName, pdfFontName.c_str() }, fontSize, std::move(fontColor) };
+        const DefaultAppearance da { pdfFontName, fontSize, std::move(fontColor) };
         const std::string daStr = da.toAppearanceString();
         annotObj.dictSet("DA", Object(std::make_unique<GooString>(daStr)));
 
@@ -2244,7 +2240,7 @@ std::optional<PDFDoc::SignatureData> PDFDoc::createSignature(::Page *destPage, s
     field->setImageResource(imageResourceRef);
 
     Object refObj(ref);
-    AnnotWidget *signatureAnnot = new AnnotWidget(this, field->getObj(), &refObj, field.get());
+    auto signatureAnnot = std::make_shared<AnnotWidget>(this, field->getObj(), &refObj, field.get());
     signatureAnnot->setFlags(signatureAnnot->getFlags() | Annot::flagPrint | /*Annot::flagLocked | TODO */ Annot::flagNoRotate);
     Dict dummy(getXRef());
     auto appearCharacs = std::make_unique<AnnotAppearanceCharacs>(&dummy);
@@ -2256,32 +2252,31 @@ std::optional<PDFDoc::SignatureData> PDFDoc::createSignature(::Page *destPage, s
     border->setWidth(borderWidth);
     signatureAnnot->setBorder(std::move(border));
 
-    signatureAnnot->generateFieldAppearance();
-    signatureAnnot->updateAppearanceStream();
-
     FormWidget *formWidget = field->getWidget(field->getNumWidgets() - 1);
     formWidget->setWidgetAnnotation(signatureAnnot);
 
-    return SignatureData { { ref.num, ref.gen }, signatureAnnot, formWidget, std::move(field) };
+    return SignatureData { .ref = { .num = ref.num, .gen = ref.gen }, .annotWidget = signatureAnnot, .formWidget = formWidget, .field = std::move(field) };
 }
 
-std::optional<CryptoSign::SigningError> PDFDoc::sign(const std::string &saveFilename, const std::string &certNickname, const std::string &password, std::unique_ptr<GooString> &&partialFieldName, int page, const PDFRectangle &rect,
-                                                     const GooString &signatureText, const GooString &signatureTextLeft, double fontSize, double leftFontSize, std::unique_ptr<AnnotColor> &&fontColor, double borderWidth,
-                                                     std::unique_ptr<AnnotColor> &&borderColor, std::unique_ptr<AnnotColor> &&backgroundColor, const GooString *reason, const GooString *location, const std::string &imagePath,
-                                                     const std::optional<GooString> &ownerPassword, const std::optional<GooString> &userPassword)
+std::optional<CryptoSign::SigningErrorMessage> PDFDoc::sign(const std::string &saveFilename, const std::string &certNickname, const std::string &password, std::unique_ptr<GooString> &&partialFieldName, int page, const PDFRectangle &rect,
+                                                            const GooString &signatureText, const GooString &signatureTextLeft, double fontSize, double leftFontSize, std::unique_ptr<AnnotColor> &&fontColor, double borderWidth,
+                                                            std::unique_ptr<AnnotColor> &&borderColor, std::unique_ptr<AnnotColor> &&backgroundColor, const GooString *reason, const GooString *location, const std::string &imagePath,
+                                                            const std::optional<GooString> &ownerPassword, const std::optional<GooString> &userPassword)
 {
     ::Page *destPage = getPage(page);
     if (destPage == nullptr) {
-        return CryptoSign::SigningError::InternalError;
+        return CryptoSign::SigningErrorMessage { .type = CryptoSign::SigningError::InternalError, .message = ERROR_IN_CODE_LOCATION };
     }
 
-    std::optional<SignatureData> sig =
+    std::variant<SignatureData, CryptoSign::SigningErrorMessage> result =
             createSignature(destPage, std::move(partialFieldName), rect, signatureText, signatureTextLeft, fontSize, leftFontSize, std::move(fontColor), borderWidth, std::move(borderColor), std::move(backgroundColor), imagePath);
 
-    if (!sig) {
-        return CryptoSign::SigningError::GenericError; /*This should probably be expanded with error handling from createSignature*/
+    if (std::holds_alternative<CryptoSign::SigningErrorMessage>(result)) {
+        return std::get<CryptoSign::SigningErrorMessage>(result);
     }
 
+    auto *sig = std::get_if<SignatureData>(&result);
+
     sig->annotWidget->setFlags(sig->annotWidget->getFlags() | Annot::flagLocked);
 
     // say that there a now signatures and that we should append only
@@ -2289,7 +2284,7 @@ std::optional<CryptoSign::SigningError> PDFDoc::sign(const std::string &saveFile
 
     destPage->addAnnot(sig->annotWidget);
 
-    FormWidgetSignature *fws = dynamic_cast<FormWidgetSignature *>(sig->formWidget);
+    auto *fws = dynamic_cast<FormWidgetSignature *>(sig->formWidget);
     if (fws) {
         const auto res = fws->signDocument(saveFilename, certNickname, password, reason, location, ownerPassword, userPassword);
 
@@ -2306,5 +2301,5 @@ std::optional<CryptoSign::SigningError> PDFDoc::sign(const std::string &saveFile
         return res;
     }
 
-    return CryptoSign::SigningError::InternalError;
+    return CryptoSign::SigningErrorMessage { .type = CryptoSign::SigningError::InternalError, .message = ERROR_IN_CODE_LOCATION };
 }
