@@ -31,10 +31,12 @@
 // Copyright (C) 2015 Philipp Reinkemeier <philipp.reinkemeier@offis.de>
 // Copyright (C) 2018, 2019 Adam Reichold <adam.reichold@t-online.de>
 // Copyright (C) 2020 Oliver Sander <oliver.sander@tu-dresden.de>
-// Copyright (C) 2020, 2021 Nelson Benítez León <nbenitezl@gmail.com>
+// Copyright (C) 2020, 2021, 2025 Nelson Benítez León <nbenitezl@gmail.com>
 // Copyright (C) 2020 Philipp Knechtges <philipp-dev@knechtges.com>
 // Copyright (C) 2024 Pablo Correa Gómez <ablocorrea@hotmail.com>
-// Copyright (C) 2024, 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2024-2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2025 Stefan Brüns <stefan.bruens@rwth-aachen.de>
+// Copyright (C) 2025 Arnav V <arnav0872@gmail.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -43,7 +45,6 @@
 
 #include <config.h>
 
-#include <cstddef>
 #include <climits>
 #include "GlobalParams.h"
 #include "Object.h"
@@ -61,34 +62,48 @@
 #include "Error.h"
 #include "Page.h"
 #include "Catalog.h"
+#include "goo/gmem.h"
 
 //------------------------------------------------------------------------
 // PDFRectangle
 //------------------------------------------------------------------------
 
-void PDFRectangle::clipTo(PDFRectangle *rect)
-{
-    if (x1 < rect->x1) {
-        x1 = rect->x1;
-    } else if (x1 > rect->x2) {
-        x1 = rect->x2;
-    }
-    if (x2 < rect->x1) {
-        x2 = rect->x1;
-    } else if (x2 > rect->x2) {
-        x2 = rect->x2;
-    }
-    if (y1 < rect->y1) {
-        y1 = rect->y1;
-    } else if (y1 > rect->y2) {
-        y1 = rect->y2;
-    }
-    if (y2 < rect->y1) {
-        y2 = rect->y1;
-    } else if (y2 > rect->y2) {
-        y2 = rect->y2;
-    }
-}
+namespace {
+namespace testing {
+static_assert(PDFRectangle {} == PDFRectangle {});
+static_assert(PDFRectangle { 0, 0, 1, 1 } == PDFRectangle { 0, 0, 1, 1 });
+static_assert(PDFRectangle { 0, 0, 1, 1 }.isValid());
+static_assert(!PDFRectangle { 0, 0, 0, 0 }.isValid());
+static_assert(PDFRectangle { 0, 0, 2, 2 }.contains(1, 1));
+static_assert(!PDFRectangle { 0, 0, 1, 2 }.contains(2, 1));
+
+constexpr PDFRectangle r1 { 0, 0, 5, 5 };
+constexpr PDFRectangle r2 { 2, 2, 4, 4 };
+constexpr PDFRectangle r3 { 0, 3, 3, 3 };
+constexpr PDFRectangle r4 { 2, 3, 3, 3 };
+static_assert(r1.isValid());
+static_assert([]() {
+    auto r = r1;
+    r.clipTo(r1);
+    return r == r1;
+}());
+static_assert([]() {
+    auto r = r1;
+    r.clipTo(r2);
+    return r == r2;
+}());
+static_assert([]() {
+    auto r = r2;
+    r.clipTo(r1);
+    return r == r2;
+}());
+static_assert([]() {
+    auto r = r2;
+    r.clipTo(r3);
+    return r == r4;
+}());
+} // namespace testing
+} // namespace
 
 //------------------------------------------------------------------------
 // PageAttrs
@@ -184,10 +199,10 @@ PageAttrs::~PageAttrs() = default;
 
 void PageAttrs::clipBoxes()
 {
-    cropBox.clipTo(&mediaBox);
-    bleedBox.clipTo(&mediaBox);
-    trimBox.clipTo(&mediaBox);
-    artBox.clipTo(&mediaBox);
+    cropBox.clipTo(mediaBox);
+    bleedBox.clipTo(mediaBox);
+    trimBox.clipTo(mediaBox);
+    artBox.clipTo(mediaBox);
 }
 
 bool PageAttrs::readBox(Dict *dict, const char *key, PDFRectangle *box)
@@ -252,7 +267,7 @@ bool PageAttrs::readBox(Dict *dict, const char *key, PDFRectangle *box)
 
 #define pageLocker() const std::scoped_lock locker(mutex)
 
-Page::Page(PDFDoc *docA, int numA, Object &&pageDict, Ref pageRefA, std::unique_ptr<PageAttrs> attrsA, Form *form) : pageRef(pageRefA), attrs(std::move(attrsA))
+Page::Page(PDFDoc *docA, int numA, Object &&pageDict, Ref pageRefA, std::unique_ptr<PageAttrs> attrsA) : pageRef(pageRefA), attrs(std::move(attrsA))
 {
     ok = true;
     doc = docA;
@@ -294,8 +309,24 @@ Page::Page(PDFDoc *docA, int numA, Object &&pageDict, Ref pageRefA, std::unique_
     annotsObj = pageObj.dictLookupNF("Annots").copy();
     if (!(annotsObj.isRef() || annotsObj.isArray() || annotsObj.isNull())) {
         error(errSyntaxError, -1, "Page annotations object (page {0:d}) is wrong type ({1:s})", num, annotsObj.getTypeName());
+        annotsObj.setToNull();
+    }
+
+    if (annotsObj.isArray() && annotsObj.arrayGetLength() > 10000) {
+        error(errSyntaxError, -1, "Page annotations object (page {0:d}) is likely malformed. Too big: ({1:d})", num, annotsObj.arrayGetLength());
         goto err2;
     }
+    if (annotsObj.isRef()) {
+        auto resolvedObj = getAnnotsObject();
+        if (resolvedObj.isArray() && resolvedObj.arrayGetLength() > 10000) {
+            error(errSyntaxError, -1, "Page annotations object (page {0:d}) is likely malformed. Too big: ({1:d})", num, resolvedObj.arrayGetLength());
+            goto err2;
+        }
+        if (!resolvedObj.isArray() && !resolvedObj.isNull()) {
+            error(errSyntaxError, -1, "Page annotations object (page {0:d}) is wrong type ({1:s})", num, resolvedObj.getTypeName());
+            annotsObj.setToNull();
+        }
+    }
 
     // contents
     contents = pageObj.dictLookupNF("Contents").copy();
@@ -327,10 +358,7 @@ err1:
     ok = false;
 }
 
-Page::~Page()
-{
-    delete annots;
-}
+Page::~Page() = default;
 
 Dict *Page::getResourceDict()
 {
@@ -369,11 +397,11 @@ void Page::replaceXRef(XRef *xrefA)
 }
 
 /* Loads standalone fields into Page, should be called once per page only */
-void Page::loadStandaloneFields(Annots *annotations, Form *form)
+void Page::loadStandaloneFields(Form *form)
 {
     /* Look for standalone annots, identified by being: 1) of type Widget
      * 2) not referenced from the Catalog's Form Field array */
-    for (Annot *annot : annots->getAnnots()) {
+    for (const std::shared_ptr<Annot> &annot : annots->getAnnots()) {
 
         if (annot->getType() != Annot::typeWidget || !annot->getHasRef()) {
             continue;
@@ -389,13 +417,14 @@ void Page::loadStandaloneFields(Annots *annotations, Form *form)
 
         if (field && field->getNumWidgets() == 1) {
 
-            static_cast<AnnotWidget *>(annot)->setField(field.get());
+            auto aw = std::static_pointer_cast<AnnotWidget>(annot);
+            aw->setField(field.get());
 
             field->setStandAlone(true);
             FormWidget *formWidget = field->getWidget(0);
 
             if (!formWidget->getWidgetAnnotation()) {
-                formWidget->createWidgetAnnotation();
+                formWidget->setWidgetAnnotation(aw);
             }
 
             standaloneFields.push_back(std::move(field));
@@ -407,15 +436,15 @@ Annots *Page::getAnnots(XRef *xrefA)
 {
     if (!annots) {
         Object obj = getAnnotsObject(xrefA);
-        annots = new Annots(doc, num, &obj);
+        annots = std::make_unique<Annots>(doc, num, &obj);
         // Load standalone fields once for the page
-        loadStandaloneFields(annots, doc->getCatalog()->getForm());
+        loadStandaloneFields(doc->getCatalog()->getForm());
     }
 
-    return annots;
+    return annots.get();
 }
 
-bool Page::addAnnot(Annot *annot)
+bool Page::addAnnot(const std::shared_ptr<Annot> &annot)
 {
     if (unlikely(xref->getEntry(pageRef.num)->type == xrefEntryFree)) {
         // something very wrong happened if we're here
@@ -436,7 +465,7 @@ bool Page::addAnnot(Annot *annot)
         // page doesn't have annots array,
         // we have to create it
 
-        Array *annotsArray = new Array(xref);
+        auto *annotsArray = new Array(xref);
         annotsArray->add(Object(annotRef));
 
         annotsRef = xref->addIndirectObject(Object(annotsArray));
@@ -458,14 +487,14 @@ bool Page::addAnnot(Annot *annot)
     // Popup annots are already handled by markup annots,
     // so add to the list only Popup annots without a
     // markup annotation associated.
-    if (annot->getType() != Annot::typePopup || !static_cast<AnnotPopup *>(annot)->hasParent()) {
+    if (annot->getType() != Annot::typePopup || !static_cast<AnnotPopup *>(annot.get())->hasParent()) {
         annots->appendAnnot(annot);
     }
     annot->setPage(num, true);
 
-    AnnotMarkup *annotMarkup = dynamic_cast<AnnotMarkup *>(annot);
+    auto *annotMarkup = dynamic_cast<AnnotMarkup *>(annot.get());
     if (annotMarkup) {
-        AnnotPopup *annotPopup = annotMarkup->getPopup();
+        std::shared_ptr<AnnotPopup> annotPopup = annotMarkup->getPopup();
         if (annotPopup) {
             addAnnot(annotPopup);
         }
@@ -474,7 +503,7 @@ bool Page::addAnnot(Annot *annot)
     return true;
 }
 
-void Page::removeAnnot(Annot *annot)
+void Page::removeAnnot(const std::shared_ptr<Annot> &annot)
 {
     Ref annotRef = annot->getRef();
 
@@ -594,8 +623,8 @@ void Page::displaySlice(OutputDev *out, double hDPI, double vDPI, int rotate, bo
         if (globalParams->getPrintCommands()) {
             printf("***** Annotations\n");
         }
-        for (Annot *annot : annots->getAnnots()) {
-            if ((annotDisplayDecideCbk && (*annotDisplayDecideCbk)(annot, annotDisplayDecideCbkData)) || !annotDisplayDecideCbk) {
+        for (const std::shared_ptr<Annot> &annot : annots->getAnnots()) {
+            if ((annotDisplayDecideCbk && (*annotDisplayDecideCbk)(annot.get(), annotDisplayDecideCbkData)) || !annotDisplayDecideCbk) {
                 annot->draw(gfx.get(), printing);
             }
         }
@@ -682,10 +711,10 @@ bool Page::loadThumb(unsigned char **data_out, int *width_out, int *height_out,
 
     if (data_out) {
         ImageStream imgstr { str, width, colorMap.getNumPixelComps(), colorMap.getBits() };
-        if (!imgstr.reset()) {
+        if (!imgstr.rewind()) {
             return false;
         }
-        unsigned char *pixbufdata = (unsigned char *)gmalloc(pixbufdatasize);
+        auto *pixbufdata = (unsigned char *)gmalloc(pixbufdatasize);
         unsigned char *p = pixbufdata;
         for (int row = 0; row < height; ++row) {
             for (int col = 0; col < width; ++col) {
@@ -716,7 +745,7 @@ bool Page::loadThumb(unsigned char **data_out, int *width_out, int *height_out,
     return true;
 }
 
-void Page::makeBox(double hDPI, double vDPI, int rotate, bool useMediaBox, bool upsideDown, double sliceX, double sliceY, double sliceW, double sliceH, PDFRectangle *box, bool *crop)
+void Page::makeBox(double hDPI, double vDPI, int rotate, bool useMediaBox, bool upsideDown, double sliceX, double sliceY, double sliceW, double sliceH, PDFRectangle *box, bool *crop) const
 {
     const PDFRectangle *mediaBox, *cropBox, *baseBox;
     double kx, ky;
@@ -779,12 +808,12 @@ void Page::makeBox(double hDPI, double vDPI, int rotate, bool useMediaBox, bool
 void Page::processLinks(OutputDev *out)
 {
     std::unique_ptr<Links> links = getLinks();
-    for (AnnotLink *link : links->getLinks()) {
-        out->processLink(link);
+    for (const std::shared_ptr<AnnotLink> &link : links->getLinks()) {
+        out->processLink(link.get());
     }
 }
 
-void Page::getDefaultCTM(double *ctm, double hDPI, double vDPI, int rotate, bool useMediaBox, bool upsideDown)
+void Page::getDefaultCTM(double *ctm, double hDPI, double vDPI, int rotate, bool useMediaBox, bool upsideDown) const
 {
     GfxState *state;
     int i;
