@@ -13,6 +13,7 @@
 // Copyright 2021 Georgiy Sgibnev <georgiy@sgibnev.com>. Work sponsored by lab50.net.
 // Copyright 2021 André Guerreiro <aguerreiro1985@gmail.com>
 // Copyright 2021 Marek Kasik <mkasik@redhat.com>
+// Copyright 2023-2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 //========================================================================
 
@@ -24,6 +25,7 @@
 
 #include "poppler_private_export.h"
 #include "goo/GooString.h"
+#include "HashAlgorithm.h"
 
 enum SignatureValidationStatus
 {
@@ -53,7 +55,6 @@ class POPPLER_PRIVATE_EXPORT SignatureInfo
 {
 public:
     SignatureInfo();
-    SignatureInfo(SignatureValidationStatus, CertificateValidationStatus);
     ~SignatureInfo();
 
     SignatureInfo(const SignatureInfo &) = delete;
@@ -61,39 +62,36 @@ public:
 
     /* GETTERS */
     SignatureValidationStatus getSignatureValStatus() const;
-    CertificateValidationStatus getCertificateValStatus() const;
-    const char *getSignerName() const;
-    const char *getSubjectDN() const;
+    std::string getSignerName() const;
+    std::string getSubjectDN() const;
     const GooString &getLocation() const;
     const GooString &getReason() const;
-    int getHashAlgorithm() const; // Returns a NSS3 HASH_HashType or -1 if compiled without NSS3
+    HashAlgorithm getHashAlgorithm() const; // Returns the used HashAlgorithm, and unknown if compiled without signature support
     time_t getSigningTime() const;
     bool isSubfilterSupported() const { return sig_subfilter_supported; }
     const X509CertificateInfo *getCertificateInfo() const;
 
     /* SETTERS */
-    void setSignatureValStatus(enum SignatureValidationStatus);
-    void setCertificateValStatus(enum CertificateValidationStatus);
-    void setSignerName(const char *);
-    void setSubjectDN(const char *);
-    void setLocation(const GooString *);
-    void setReason(const GooString *);
-    void setHashAlgorithm(int);
-    void setSigningTime(time_t);
+    void setSignatureValStatus(enum SignatureValidationStatus sig_val_status);
+    void setSignerName(const std::string &signerName);
+    void setSubjectDN(const std::string &subjectDN);
+    void setLocation(std::unique_ptr<GooString> &&loc);
+    void setReason(std::unique_ptr<GooString> &&signingReason);
+    void setHashAlgorithm(HashAlgorithm type);
+    void setSigningTime(time_t signingTime);
     void setSubFilterSupport(bool isSupported) { sig_subfilter_supported = isSupported; }
-    void setCertificateInfo(std::unique_ptr<X509CertificateInfo>);
+    void setCertificateInfo(std::unique_ptr<X509CertificateInfo> certInfo);
 
 private:
-    SignatureValidationStatus sig_status;
-    CertificateValidationStatus cert_status;
+    SignatureValidationStatus sig_status = SIGNATURE_NOT_VERIFIED;
     std::unique_ptr<X509CertificateInfo> cert_info;
-    char *signer_name;
-    char *subject_dn;
+    std::string signer_name;
+    std::string subject_dn;
     GooString location;
     GooString reason;
-    int hash_type;
-    time_t signing_time;
-    bool sig_subfilter_supported;
+    HashAlgorithm hash_type = HashAlgorithm::Unknown;
+    time_t signing_time = 0;
+    bool sig_subfilter_supported = false;
 };
 
 #endif
