@@ -15,7 +15,7 @@
 //
 // Copyright (C) 2005 Jeff Muizelaar <jeff@infidigm.net>
 // Copyright (C) 2008 Julien Rebetez <julien@fhtagn.net>
-// Copyright (C) 2008, 2010, 2011, 2016-2022, 2024, 2025 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2008, 2010, 2011, 2016-2022, 2024-2026 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2009 Carlos Garcia Campos <carlosgc@gnome.org>
 // Copyright (C) 2009 Stefan Thomas <thomas@eload24.com>
 // Copyright (C) 2010 Hib Eris <hib@hiberis.nl>
@@ -33,9 +33,10 @@
 // Copyright (C) 2021 Hubert Figuiere <hub@figuiere.net>
 // Copyright (C) 2021 Christian Persch <chpe@src.gnome.org>
 // Copyright (C) 2021 Georgiy Sgibnev <georgiy@sgibnev.com>. Work sponsored by lab50.net.
-// Copyright (C) 2024, 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2024-2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 // Copyright (C) 2024 Fernando Herrera <fherrera@onirica.com>
 // Copyright (C) 2024, 2025 Nelson Benítez León <nbenitezl@gmail.com>
+// Copyright (C) 2025 Arnav V <arnav0872@gmail.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -54,6 +55,7 @@
 #include "poppler-config.h"
 #include "poppler_private_export.h"
 #include "Object.h"
+#include "goo/GooCheckedOps.h"
 
 class GooFile;
 class BaseStream;
@@ -101,11 +103,11 @@ enum CryptAlgorithm
 
 //------------------------------------------------------------------------
 
-typedef struct _ByteRange
+struct ByteRange
 {
     size_t offset;
     unsigned int length;
-} ByteRange;
+};
 
 //------------------------------------------------------------------------
 // Stream (base class)
@@ -126,34 +128,33 @@ public:
     // Get kind of stream.
     virtual StreamKind getKind() const = 0;
 
-    // Reset stream to beginning. Returns 'false' if stream was found to be invalid, 'true' otherwise.
-    [[nodiscard]] virtual bool reset() = 0;
+    // Rewind stream to beginning. Returns 'false' if stream was found to be invalid, 'true' otherwise.
+    [[nodiscard]] virtual bool rewind() = 0;
 
     // Close down the stream.
     virtual void close();
 
-    inline int doGetChars(int nChars, unsigned char *buffer)
+    int doGetChars(int nChars, unsigned char *buffer)
     {
         if (hasGetChars()) {
             return getChars(nChars, buffer);
-        } else {
-            for (int i = 0; i < nChars; ++i) {
-                const int c = getChar();
-                if (likely(c != EOF)) {
-                    buffer[i] = c;
-                } else {
-                    return i;
-                }
-            }
-            return nChars;
         }
+        for (int i = 0; i < nChars; ++i) {
+            const int c = getChar();
+            if (likely(c != EOF)) {
+                buffer[i] = c;
+            } else {
+                return i;
+            }
+        }
+        return nChars;
     }
 
-    inline void fillString(std::string &s)
+    void fillString(std::string &s)
     {
         unsigned char readBuf[4096];
         int readChars;
-        if (!reset()) {
+        if (!rewind()) {
             s.clear();
             return;
         }
@@ -162,9 +163,9 @@ public:
         }
     }
 
-    inline void fillGooString(GooString *s) { fillString(s->toNonConstStr()); }
+    void fillGooString(GooString *s) { fillString(s->toNonConstStr()); }
 
-    inline std::vector<unsigned char> toUnsignedChars(int initialSize = 4096, int sizeIncrement = 4096)
+    std::vector<unsigned char> toUnsignedChars(int initialSize = 4096, int sizeIncrement = 4096)
     {
         std::vector<unsigned char> buf(initialSize);
 
@@ -173,7 +174,7 @@ public:
         int length = 0;
         int charsToRead = initialSize;
         bool continueReading = true;
-        if (!reset()) {
+        if (!rewind()) {
             return {};
         }
         while (continueReading && (readChars = doGetChars(charsToRead, buf.data() + length)) != 0) {
@@ -216,10 +217,10 @@ public:
     // Get next char directly from stream source, without filtering it
     virtual int getUnfilteredChar() = 0;
 
-    // Resets the stream without reading anything (even not the headers)
+    // Rewinds the stream without reading anything (even not the headers)
     // WARNING: Reading the stream with something else than getUnfilteredChar
-    // may lead to unexcepted behaviour until you call reset ()
-    [[nodiscard]] virtual bool unfilteredReset() = 0;
+    // may lead to unexcepted behaviour until you call rewind ()
+    [[nodiscard]] virtual bool unfilteredRewind() = 0;
 
     // Get next line from stream.
     virtual char *getLine(char *buf, int size);
@@ -227,7 +228,7 @@ public:
     // Discard the next <n> bytes from stream.  Returns the number of
     // bytes discarded, which will be less than <n> only if EOF is
     // reached.
-    virtual unsigned int discardChars(unsigned int n);
+    [[nodiscard]] virtual unsigned int discardChars(unsigned int n);
 
     // Get current position in file.
     virtual Goffset getPos() = 0;
@@ -263,9 +264,9 @@ public:
     // Return the next stream in the "stack".
     virtual Stream *getNextStream() const { return nullptr; }
 
-    // Add filters to this stream according to the parameters in <dict>.
+    // Add filters to the stream according to the parameters in <dict>.
     // Returns the new stream.
-    Stream *addFilters(Dict *dict, int recursion = 0);
+    static std::unique_ptr<Stream> addFilters(std::unique_ptr<Stream> stream, Dict *dict, int recursion = 0);
 
     // Returns true if this stream includes a crypt filter.
     bool isEncrypted() const;
@@ -280,7 +281,7 @@ private:
     virtual bool hasGetChars() { return false; }
     virtual int getChars(int nChars, unsigned char *buffer);
 
-    Stream *makeFilter(const char *name, Stream *str, Object *params, int recursion = 0, Dict *dict = nullptr);
+    static std::unique_ptr<Stream> makeFilter(const char *name, std::unique_ptr<Stream> str, Object *params, int recursion = 0, Dict *dict = nullptr);
 
     std::atomic_int ref; // reference count
 };
@@ -352,7 +353,7 @@ class POPPLER_PRIVATE_EXPORT BaseStream : public Stream
 public:
     BaseStream(Object &&dictA, Goffset lengthA);
     ~BaseStream() override;
-    virtual BaseStream *copy() = 0;
+    virtual std::unique_ptr<BaseStream> copy() = 0;
     virtual std::unique_ptr<Stream> makeSubStream(Goffset start, bool limited, Goffset length, Object &&dict) = 0;
     void setPos(Goffset pos, int dir = 0) override = 0;
     bool isBinary(bool last = true) const override { return last; }
@@ -391,7 +392,7 @@ public:
     BaseSeekInputStream(Goffset startA, bool limitedA, Goffset lengthA, Object &&dictA);
     ~BaseSeekInputStream() override;
     StreamKind getKind() const override { return strWeird; }
-    [[nodiscard]] bool reset() override;
+    [[nodiscard]] bool rewind() override;
     void close() override;
     int getChar() override { return (bufPtr >= bufEnd && !fillBuf()) ? EOF : (*bufPtr++ & 0xff); }
     int lookChar() override { return (bufPtr >= bufEnd && !fillBuf()) ? EOF : (*bufPtr & 0xff); }
@@ -401,7 +402,7 @@ public:
     void moveStart(Goffset delta) override;
 
     int getUnfilteredChar() override { return getChar(); }
-    [[nodiscard]] bool unfilteredReset() override { return reset(); }
+    [[nodiscard]] bool unfilteredRewind() override { return rewind(); }
 
 protected:
     Goffset start;
@@ -422,8 +423,8 @@ private:
     char *bufPtr;
     char *bufEnd;
     Goffset bufPos;
-    Goffset savePos;
-    bool saved;
+    Goffset savePos = 0;
+    bool saved = false;
 };
 
 //------------------------------------------------------------------------
@@ -447,12 +448,22 @@ public:
     Stream *getNextStream() const override { return str; }
 
     int getUnfilteredChar() override { return str->getUnfilteredChar(); }
-    [[nodiscard]] bool unfilteredReset() override { return str->unfilteredReset(); }
+    [[nodiscard]] bool unfilteredRewind() override { return str->unfilteredRewind(); }
 
 protected:
     Stream *str;
 };
 
+class OwnedFilterStream : public FilterStream
+{
+public:
+    explicit OwnedFilterStream(std::unique_ptr<Stream> strA);
+    ~OwnedFilterStream() override;
+
+private:
+    std::unique_ptr<Stream> ownedStream;
+};
+
 //------------------------------------------------------------------------
 // ImageStream
 //------------------------------------------------------------------------
@@ -470,10 +481,10 @@ public:
     ImageStream(const ImageStream &) = delete;
     ImageStream &operator=(const ImageStream &other) = delete;
 
-    // Reset the stream.
-    [[nodiscard]] bool reset();
+    // Rewind the stream.
+    [[nodiscard]] bool rewind();
 
-    // Close the stream previously reset
+    // Close the stream previously rewind
     void close();
 
     // Gets the next pixel from the stream.  <pix> should be able to hold
@@ -515,7 +526,7 @@ public:
     StreamPredictor(const StreamPredictor &) = delete;
     StreamPredictor &operator=(const StreamPredictor &) = delete;
 
-    bool isOk() { return ok; }
+    bool isOk() const { return ok; }
 
     int lookChar();
     int getChar();
@@ -548,10 +559,10 @@ class POPPLER_PRIVATE_EXPORT FileStream : public BaseStream
 public:
     FileStream(GooFile *fileA, Goffset startA, bool limitedA, Goffset lengthA, Object &&dictA);
     ~FileStream() override;
-    BaseStream *copy() override;
+    std::unique_ptr<BaseStream> copy() override;
     std::unique_ptr<Stream> makeSubStream(Goffset startA, bool limitedA, Goffset lengthA, Object &&dictA) override;
     StreamKind getKind() const override { return strFile; }
-    [[nodiscard]] bool reset() override;
+    [[nodiscard]] bool rewind() override;
     void close() override;
     int getChar() override { return (bufPtr >= bufEnd && !fillBuf()) ? EOF : (*bufPtr++ & 0xff); }
     int lookChar() override { return (bufPtr >= bufEnd && !fillBuf()) ? EOF : (*bufPtr & 0xff); }
@@ -561,7 +572,7 @@ public:
     void moveStart(Goffset delta) override;
 
     int getUnfilteredChar() override { return getChar(); }
-    [[nodiscard]] bool unfilteredReset() override { return reset(); }
+    [[nodiscard]] bool unfilteredRewind() override { return rewind(); }
 
     bool getNeedsEncryptionOnSave() const { return needsEncryptionOnSave; }
     void setNeedsEncryptionOnSave(bool needsEncryptionOnSaveA) { needsEncryptionOnSave = needsEncryptionOnSaveA; }
@@ -617,10 +628,10 @@ class POPPLER_PRIVATE_EXPORT CachedFileStream : public BaseStream
 public:
     CachedFileStream(std::shared_ptr<CachedFile> ccA, Goffset startA, bool limitedA, Goffset lengthA, Object &&dictA);
     ~CachedFileStream() override;
-    BaseStream *copy() override;
+    std::unique_ptr<BaseStream> copy() override;
     std::unique_ptr<Stream> makeSubStream(Goffset startA, bool limitedA, Goffset lengthA, Object &&dictA) override;
     StreamKind getKind() const override { return strCachedFile; }
-    [[nodiscard]] bool reset() override;
+    [[nodiscard]] bool rewind() override;
     void close() override;
     int getChar() override { return (bufPtr >= bufEnd && !fillBuf()) ? EOF : (*bufPtr++ & 0xff); }
     int lookChar() override { return (bufPtr >= bufEnd && !fillBuf()) ? EOF : (*bufPtr & 0xff); }
@@ -630,7 +641,7 @@ public:
     void moveStart(Goffset delta) override;
 
     int getUnfilteredChar() override { return getChar(); }
-    [[nodiscard]] bool unfilteredReset() override { return reset(); }
+    [[nodiscard]] bool unfilteredRewind() override { return rewind(); }
 
 private:
     bool fillBuf();
@@ -663,7 +674,7 @@ public:
         bufPtr = buf + start;
     }
 
-    BaseStream *copy() override { return new BaseMemStream(buf, start, length, dict.copy()); }
+    std::unique_ptr<BaseStream> copy() override { return std::make_unique<BaseMemStream>(buf, start, length, dict.copy()); }
 
     std::unique_ptr<Stream> makeSubStream(Goffset startA, bool limited, Goffset lengthA, Object &&dictA) override
     {
@@ -679,7 +690,7 @@ public:
 
     StreamKind getKind() const override { return strWeird; }
 
-    [[nodiscard]] bool reset() override
+    [[nodiscard]] bool rewind() override
     {
         bufPtr = buf + start;
         return true;
@@ -721,7 +732,7 @@ public:
 
     int getUnfilteredChar() override { return getChar(); }
 
-    bool unfilteredReset() override { return reset(); }
+    bool unfilteredRewind() override { return rewind(); }
 
 protected:
     T *buf;
@@ -785,6 +796,16 @@ public:
 // EmbedStream is deleted, reads from the base stream will proceed where
 // the BaseStream left off.  Note that this is very different behavior
 // that creating a new FileStream (using makeSubStream).
+//
+// When an EmbedStream has been created with reusable set to true, it keeps a copy of
+// what is read in memory. This allows rewinding it (which is generally not possible).
+// After rewind whatever was recorded will be returned. When reaching the end of recorded
+// data and returning EOF once, the stream will go back to reading from its underlying stream.
+// Thw fact that an extra EOF is added when reaching the end of recorded data makes this
+// mostly only useful if you have read the full stream and want to go back to the beginning
+// to read it again.
+//
+// EmbedStream decreases it's length every time a character is read
 //------------------------------------------------------------------------
 
 class POPPLER_PRIVATE_EXPORT EmbedStream : public BaseStream
@@ -792,10 +813,10 @@ class POPPLER_PRIVATE_EXPORT EmbedStream : public BaseStream
 public:
     EmbedStream(Stream *strA, Object &&dictA, bool limitedA, Goffset lengthA, bool reusableA = false);
     ~EmbedStream() override;
-    BaseStream *copy() override;
+    std::unique_ptr<BaseStream> copy() override;
     std::unique_ptr<Stream> makeSubStream(Goffset start, bool limitedA, Goffset lengthA, Object &&dictA) override;
     StreamKind getKind() const override { return str->getKind(); }
-    [[nodiscard]] bool reset() override;
+    [[nodiscard]] bool rewind() override;
     int getChar() override;
     int lookChar() override;
     Goffset getPos() override;
@@ -804,38 +825,34 @@ public:
     void moveStart(Goffset delta) override;
 
     int getUnfilteredChar() override { return str->getUnfilteredChar(); }
-    [[nodiscard]] bool unfilteredReset() override { return str->unfilteredReset(); }
-
-    void rewind();
-    void restore();
+    [[nodiscard]] bool unfilteredRewind() override { return str->unfilteredRewind(); }
 
 private:
     bool hasGetChars() override { return true; }
     int getChars(int nChars, unsigned char *buffer) override;
 
     Stream *str;
-    bool limited;
-    bool reusable;
-    bool record;
+    const bool limited;
+    const bool reusable;
     bool replay;
     unsigned char *bufData;
     long bufMax;
     long bufLen;
     long bufPos;
-    Goffset start;
+    const Goffset initialLength;
 };
 
 //------------------------------------------------------------------------
 // ASCIIHexStream
 //------------------------------------------------------------------------
 
-class ASCIIHexStream : public FilterStream
+class ASCIIHexStream : public OwnedFilterStream
 {
 public:
-    explicit ASCIIHexStream(Stream *strA);
+    explicit ASCIIHexStream(std::unique_ptr<Stream> strA);
     ~ASCIIHexStream() override;
     StreamKind getKind() const override { return strASCIIHex; }
-    [[nodiscard]] bool reset() override;
+    [[nodiscard]] bool rewind() override;
     int getChar() override
     {
         int c = lookChar();
@@ -855,13 +872,13 @@ private:
 // ASCII85Stream
 //------------------------------------------------------------------------
 
-class ASCII85Stream : public FilterStream
+class ASCII85Stream : public OwnedFilterStream
 {
 public:
-    explicit ASCII85Stream(Stream *strA);
+    explicit ASCII85Stream(std::unique_ptr<Stream> strA);
     ~ASCII85Stream() override;
     StreamKind getKind() const override { return strASCII85; }
-    [[nodiscard]] bool reset() override;
+    [[nodiscard]] bool rewind() override;
     int getChar() override
     {
         int ch = lookChar();
@@ -883,13 +900,13 @@ private:
 // LZWStream
 //------------------------------------------------------------------------
 
-class LZWStream : public FilterStream
+class LZWStream : public OwnedFilterStream
 {
 public:
-    LZWStream(Stream *strA, int predictor, int columns, int colors, int bits, int earlyA);
+    LZWStream(std::unique_ptr<Stream> strA, int predictor, int columns, int colors, int bits, int earlyA);
     ~LZWStream() override;
     StreamKind getKind() const override { return strLZW; }
-    [[nodiscard]] bool reset() override;
+    [[nodiscard]] bool rewind() override;
     int getChar() override;
     int lookChar() override;
     int getRawChar() override;
@@ -901,7 +918,7 @@ private:
     bool hasGetChars() override { return true; }
     int getChars(int nChars, unsigned char *buffer) override;
 
-    inline int doGetRawChar()
+    int doGetRawChar()
     {
         if (eof) {
             return EOF;
@@ -943,13 +960,13 @@ private:
 // RunLengthStream
 //------------------------------------------------------------------------
 
-class RunLengthStream : public FilterStream
+class RunLengthStream : public OwnedFilterStream
 {
 public:
-    explicit RunLengthStream(Stream *strA);
+    explicit RunLengthStream(std::unique_ptr<Stream> strA);
     ~RunLengthStream() override;
     StreamKind getKind() const override { return strRunLength; }
-    [[nodiscard]] bool reset() override;
+    [[nodiscard]] bool rewind() override;
     int getChar() override { return (bufPtr >= bufEnd && !fillBuf()) ? EOF : (*bufPtr++ & 0xff); }
     int lookChar() override { return (bufPtr >= bufEnd && !fillBuf()) ? EOF : (*bufPtr & 0xff); }
     std::optional<std::string> getPSFilter(int psLevel, const char *indent) override;
@@ -973,13 +990,13 @@ private:
 
 struct CCITTCodeTable;
 
-class CCITTFaxStream : public FilterStream
+class CCITTFaxStream : public OwnedFilterStream
 {
 public:
-    CCITTFaxStream(Stream *strA, int encodingA, bool endOfLineA, bool byteAlignA, int columnsA, int rowsA, bool endOfBlockA, bool blackA, int damagedRowsBeforeErrorA);
+    CCITTFaxStream(std::unique_ptr<Stream> strA, int encodingA, bool endOfLineA, bool byteAlignA, int columnsA, int rowsA, bool endOfBlockA, bool blackA, int damagedRowsBeforeErrorA);
     ~CCITTFaxStream() override;
     StreamKind getKind() const override { return strCCITTFax; }
-    [[nodiscard]] bool reset() override;
+    [[nodiscard]] bool rewind() override;
     int getChar() override
     {
         int c = lookChar();
@@ -990,18 +1007,18 @@ public:
     std::optional<std::string> getPSFilter(int psLevel, const char *indent) override;
     bool isBinary(bool last = true) const override;
 
-    [[nodiscard]] bool unfilteredReset() override;
+    [[nodiscard]] bool unfilteredRewind() override;
 
-    int getEncoding() { return encoding; }
-    bool getEndOfLine() { return endOfLine; }
-    bool getEncodedByteAlign() { return byteAlign; }
-    bool getEndOfBlock() { return endOfBlock; }
-    int getColumns() { return columns; }
-    bool getBlackIs1() { return black; }
-    int getDamagedRowsBeforeError() { return damagedRowsBeforeError; }
+    int getEncoding() const { return encoding; }
+    bool getEndOfLine() const { return endOfLine; }
+    bool getEncodedByteAlign() const { return byteAlign; }
+    bool getEndOfBlock() const { return endOfBlock; }
+    int getColumns() const { return columns; }
+    bool getBlackIs1() const { return black; }
+    int getDamagedRowsBeforeError() const { return damagedRowsBeforeError; }
 
 private:
-    [[nodiscard]] bool ccittReset(bool unfiltered);
+    [[nodiscard]] bool ccittRewind(bool unfiltered);
     int encoding; // 'K' parameter
     bool endOfLine; // 'EndOfLine' parameter
     bool byteAlign; // 'EncodedByteAlign' parameter
@@ -1036,7 +1053,7 @@ private:
     }
 };
 
-#ifndef ENABLE_LIBJPEG
+#if !ENABLE_LIBJPEG
 //------------------------------------------------------------------------
 // DCTStream
 //------------------------------------------------------------------------
@@ -1070,23 +1087,23 @@ struct DCTHuffTable
     unsigned char sym[256]; // symbols
 };
 
-class DCTStream : public FilterStream
+class DCTStream : public OwnedFilterStream
 {
 public:
-    DCTStream(Stream *strA, int colorXformA, Dict *dict, int recursion);
+    DCTStream(std::unique_ptr<Stream> strA, int colorXformA, Dict *dict, int recursion);
     ~DCTStream() override;
     StreamKind getKind() const override { return strDCT; }
-    [[nodiscard]] bool reset() override;
+    [[nodiscard]] bool rewind() override;
     void close() override;
     int getChar() override;
     int lookChar() override;
     std::optional<std::string> getPSFilter(int psLevel, const char *indent) override;
     bool isBinary(bool last = true) const override;
 
-    [[nodiscard]] bool unfilteredReset() override;
+    [[nodiscard]] bool unfilteredRewind() override;
 
 private:
-    [[nodiscard]] bool dctReset(bool unfiltered);
+    [[nodiscard]] bool dctRewind(bool unfiltered);
     bool progressive; // set if in progressive mode
     bool interleaved; // set if in interleaved mode
     int width, height; // image size
@@ -1142,7 +1159,7 @@ private:
 
 #endif
 
-#ifndef ENABLE_ZLIB_UNCOMPRESS
+#if !ENABLE_ZLIB_UNCOMPRESS
 //------------------------------------------------------------------------
 // FlateStream
 //------------------------------------------------------------------------
@@ -1174,24 +1191,24 @@ struct FlateDecode
     int first; // first length/distance
 };
 
-class FlateStream : public FilterStream
+class FlateStream : public OwnedFilterStream
 {
 public:
-    FlateStream(Stream *strA, int predictor, int columns, int colors, int bits);
+    FlateStream(std::unique_ptr<Stream> strA, int predictor, int columns, int colors, int bits);
     ~FlateStream() override;
     StreamKind getKind() const override { return strFlate; }
-    [[nodiscard]] bool reset() override;
+    [[nodiscard]] bool rewind() override;
     int getChar() override;
     int lookChar() override;
     int getRawChar() override;
     void getRawChars(int nChars, int *buffer) override;
     std::optional<std::string> getPSFilter(int psLevel, const char *indent) override;
     bool isBinary(bool last = true) const override;
-    [[nodiscard]] bool unfilteredReset() override;
+    [[nodiscard]] bool unfilteredRewind() override;
 
 private:
-    [[nodiscard]] bool flateReset(bool unfiltered);
-    inline int doGetRawChar()
+    [[nodiscard]] bool flateRewind(bool unfiltered);
+    int doGetRawChar()
     {
         int c;
 
@@ -1240,7 +1257,7 @@ private:
     bool startBlock();
     void loadFixedCodes();
     bool readDynamicCodes();
-    FlateCode *compHuffmanCodes(const int *lengths, int n, int *maxLen);
+    static FlateCode *compHuffmanCodes(const int *lengths, int n, int *maxLen);
     int getHuffmanCodeWord(FlateHuffmanTab *tab);
     int getCodeWord(int bits);
 };
@@ -1250,13 +1267,13 @@ private:
 // EOFStream
 //------------------------------------------------------------------------
 
-class EOFStream : public FilterStream
+class EOFStream : public OwnedFilterStream
 {
 public:
-    explicit EOFStream(Stream *strA);
+    explicit EOFStream(std::unique_ptr<Stream> strA);
     ~EOFStream() override;
     StreamKind getKind() const override { return strWeird; }
-    [[nodiscard]] bool reset() override { return true; }
+    [[nodiscard]] bool rewind() override { return true; }
     int getChar() override { return EOF; }
     int lookChar() override { return EOF; }
     std::optional<std::string> getPSFilter(int /*psLevel*/, const char * /*indent*/) override { return {}; }
@@ -1267,16 +1284,16 @@ public:
 // BufStream
 //------------------------------------------------------------------------
 
-class BufStream : public FilterStream
+class BufStream : public OwnedFilterStream
 {
 public:
-    BufStream(Stream *strA, int bufSizeA);
+    BufStream(std::unique_ptr<Stream> strA, int bufSizeA);
     ~BufStream() override;
     StreamKind getKind() const override { return strWeird; }
-    [[nodiscard]] bool reset() override;
+    [[nodiscard]] bool rewind() override;
     int getChar() override;
     int lookChar() override;
-    std::optional<std::string> getPSFilter(int psLevel, const char *indent) override { return {}; }
+    std::optional<std::string> getPSFilter(int /*psLevel*/, const char * /*indent*/) override { return {}; }
     bool isBinary(bool last = true) const override;
 
     int lookChar(int idx);
@@ -1296,7 +1313,7 @@ public:
     FixedLengthEncoder(Stream *strA, int lengthA);
     ~FixedLengthEncoder() override;
     StreamKind getKind() const override { return strWeird; }
-    [[nodiscard]] bool reset() override;
+    [[nodiscard]] bool rewind() override;
     int getChar() override;
     int lookChar() override;
     std::optional<std::string> getPSFilter(int /*psLevel*/, const char * /*indent*/) override { return {}; }
@@ -1318,7 +1335,7 @@ public:
     explicit ASCIIHexEncoder(Stream *strA);
     ~ASCIIHexEncoder() override;
     StreamKind getKind() const override { return strWeird; }
-    [[nodiscard]] bool reset() override;
+    [[nodiscard]] bool rewind() override;
     int getChar() override { return (bufPtr >= bufEnd && !fillBuf()) ? EOF : (*bufPtr++ & 0xff); }
     int lookChar() override { return (bufPtr >= bufEnd && !fillBuf()) ? EOF : (*bufPtr & 0xff); }
     std::optional<std::string> getPSFilter(int /*psLevel*/, const char * /*indent*/) override { return {}; }
@@ -1345,7 +1362,7 @@ public:
     explicit ASCII85Encoder(Stream *strA);
     ~ASCII85Encoder() override;
     StreamKind getKind() const override { return strWeird; }
-    [[nodiscard]] bool reset() override;
+    [[nodiscard]] bool rewind() override;
     int getChar() override { return (bufPtr >= bufEnd && !fillBuf()) ? EOF : (*bufPtr++ & 0xff); }
     int lookChar() override { return (bufPtr >= bufEnd && !fillBuf()) ? EOF : (*bufPtr & 0xff); }
     std::optional<std::string> getPSFilter(int /*psLevel*/, const char * /*indent*/) override { return {}; }
@@ -1372,7 +1389,7 @@ public:
     explicit RunLengthEncoder(Stream *strA);
     ~RunLengthEncoder() override;
     StreamKind getKind() const override { return strWeird; }
-    [[nodiscard]] bool reset() override;
+    [[nodiscard]] bool rewind() override;
     int getChar() override { return (bufPtr >= bufEnd && !fillBuf()) ? EOF : (*bufPtr++ & 0xff); }
     int lookChar() override { return (bufPtr >= bufEnd && !fillBuf()) ? EOF : (*bufPtr & 0xff); }
     std::optional<std::string> getPSFilter(int /*psLevel*/, const char * /*indent*/) override { return {}; }
@@ -1406,11 +1423,11 @@ public:
     explicit LZWEncoder(Stream *strA);
     ~LZWEncoder() override;
     StreamKind getKind() const override { return strWeird; }
-    [[nodiscard]] bool reset() override;
+    [[nodiscard]] bool rewind() override;
     int getChar() override;
     int lookChar() override;
-    std::optional<std::string> getPSFilter(int psLevel, const char *indent) override { return {}; }
-    bool isBinary(bool last = true) const override { return true; }
+    std::optional<std::string> getPSFilter(int /*psLevel*/, const char * /*indent*/) override { return {}; }
+    bool isBinary(bool /*last*/ = true) const override { return true; }
     bool isEncoder() const override { return true; }
 
 private:
@@ -1436,7 +1453,7 @@ public:
     explicit CMYKGrayEncoder(Stream *strA);
     ~CMYKGrayEncoder() override;
     StreamKind getKind() const override { return strWeird; }
-    [[nodiscard]] bool reset() override;
+    [[nodiscard]] bool rewind() override;
     int getChar() override { return (bufPtr >= bufEnd && !fillBuf()) ? EOF : (*bufPtr++ & 0xff); }
     int lookChar() override { return (bufPtr >= bufEnd && !fillBuf()) ? EOF : (*bufPtr & 0xff); }
     std::optional<std::string> getPSFilter(int /*psLevel*/, const char * /*indent*/) override { return {}; }
@@ -1462,7 +1479,7 @@ public:
     explicit RGBGrayEncoder(Stream *strA);
     ~RGBGrayEncoder() override;
     StreamKind getKind() const override { return strWeird; }
-    [[nodiscard]] bool reset() override;
+    [[nodiscard]] bool rewind() override;
     int getChar() override { return (bufPtr >= bufEnd && !fillBuf()) ? EOF : (*bufPtr++ & 0xff); }
     int lookChar() override { return (bufPtr >= bufEnd && !fillBuf()) ? EOF : (*bufPtr & 0xff); }
     std::optional<std::string> getPSFilter(int /*psLevel*/, const char * /*indent*/) override { return {}; }
@@ -1491,7 +1508,7 @@ public:
     explicit SplashBitmapCMYKEncoder(SplashBitmap *bitmapA);
     ~SplashBitmapCMYKEncoder() override;
     StreamKind getKind() const override { return strWeird; }
-    [[nodiscard]] bool reset() override;
+    [[nodiscard]] bool rewind() override;
     int getChar() override;
     int lookChar() override;
     std::optional<std::string> getPSFilter(int /*psLevel*/, const char * /*indent*/) override { return {}; }
@@ -1502,7 +1519,7 @@ public:
     bool isEncoder() const override { return false; }
 
     int getUnfilteredChar() override { return getChar(); }
-    [[nodiscard]] bool unfilteredReset() override { return reset(); }
+    [[nodiscard]] bool unfilteredRewind() override { return rewind(); }
 
     BaseStream *getBaseStream() override { return nullptr; }
     Stream *getUndecodedStream() override { return this; }
@@ -1529,10 +1546,10 @@ private:
 // Object Stream accessors.
 //------------------------------------------------------------------------
 
-inline bool Object::streamReset()
+inline bool Object::streamRewind()
 {
     OBJECT_TYPE_CHECK(objStream);
-    return stream->reset();
+    return stream->rewind();
 }
 
 inline void Object::streamClose()
