@@ -11,14 +11,13 @@
 // Copyright 2018, 2021, 2023 Adrian Johnson <ajohnson@redneon.com>
 // Copyright 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright 2018 Adam Reichold <adam.reichold@t-online.de>
-// Copyright 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright 2025, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 //========================================================================
 
 #include "StructElement.h"
 #include "StructTreeRoot.h"
 #include "GlobalParams.h"
-#include "UnicodeMap.h"
 #include "PDFDoc.h"
 #include "Dict.h"
 
@@ -110,7 +109,7 @@ static bool isTableScopeName(Object *value)
 
 static bool isRGBColor(Object *value)
 {
-    if (!(value->isArray() && value->arrayGetLength() == 3)) {
+    if (!value->isArray() || value->arrayGetLength() != 3) {
         return false;
     }
 
@@ -180,7 +179,7 @@ ARRAY_CHECKER(isNumberOrArrayN, isNumber, 0, true, false)
 ARRAY_CHECKER(isTableHeaders, isTextString, 0, false, false)
 
 // Type of functions used to do type-checking on attribute values
-typedef bool (*AttributeCheckFunc)(Object *);
+using AttributeCheckFunc = bool (*)(Object *);
 
 // Maps attributes to their names and whether the attribute can be inherited.
 struct AttributeMapEntry
@@ -336,9 +335,9 @@ static const struct OwnerMapEntry
     // XXX: Those are sorted in the owner priority resolution order. If the
     //      same attribute is defined with two owners, the order in the table
     //      can be used to know which one has more priority.
-    { Attribute::XML_1_00, "XML-1.00" },     { Attribute::HTML_3_20, "HTML-3.20" }, { Attribute::HTML_4_01, "HTML-4.01" }, { Attribute::OEB_1_00, "OEB-1.00" },
-    { Attribute::RTF_1_05, "RTF-1.05" },     { Attribute::CSS_1_00, "CSS-1.00" },   { Attribute::CSS_2_00, "CSS-2.00" },   { Attribute::Layout, "Layout" },
-    { Attribute::PrintField, "PrintField" }, { Attribute::Table, "Table" },         { Attribute::List, "List" },           { Attribute::UserProperties, "UserProperties" },
+    { .owner = Attribute::XML_1_00, .name = "XML-1.00" },     { .owner = Attribute::HTML_3_20, .name = "HTML-3.20" }, { .owner = Attribute::HTML_4_01, .name = "HTML-4.01" }, { .owner = Attribute::OEB_1_00, .name = "OEB-1.00" },
+    { .owner = Attribute::RTF_1_05, .name = "RTF-1.05" },     { .owner = Attribute::CSS_1_00, .name = "CSS-1.00" },   { .owner = Attribute::CSS_2_00, .name = "CSS-2.00" },   { .owner = Attribute::Layout, .name = "Layout" },
+    { .owner = Attribute::PrintField, .name = "PrintField" }, { .owner = Attribute::Table, .name = "Table" },         { .owner = Attribute::List, .name = "List" },           { .owner = Attribute::UserProperties, .name = "UserProperties" },
 };
 
 static bool ownerHasMorePriority(Attribute::Owner a, Attribute::Owner b)
@@ -375,55 +374,55 @@ static const struct TypeMapEntry
     ElementType elementType;
     const AttributeMapEntry **attributes;
 } typeMap[] = {
-    { StructElement::Document, "Document", elementTypeGrouping, attributeMapShared },
-    { StructElement::Part, "Part", elementTypeGrouping, attributeMapShared },
-    { StructElement::Art, "Art", elementTypeGrouping, attributeMapColumns },
-    { StructElement::Sect, "Sect", elementTypeGrouping, attributeMapColumns },
-    { StructElement::Div, "Div", elementTypeGrouping, attributeMapColumns },
-    { StructElement::BlockQuote, "BlockQuote", elementTypeGrouping, attributeMapInline },
-    { StructElement::Caption, "Caption", elementTypeGrouping, attributeMapInline },
-    { StructElement::NonStruct, "NonStruct", elementTypeGrouping, attributeMapInline },
-    { StructElement::Index, "Index", elementTypeGrouping, attributeMapInline },
-    { StructElement::Private, "Private", elementTypeGrouping, attributeMapInline },
-    { StructElement::Span, "Span", elementTypeInline, attributeMapInline },
-    { StructElement::Quote, "Quote", elementTypeInline, attributeMapInline },
-    { StructElement::Note, "Note", elementTypeInline, attributeMapInline },
-    { StructElement::Reference, "Reference", elementTypeInline, attributeMapInline },
-    { StructElement::BibEntry, "BibEntry", elementTypeInline, attributeMapInline },
-    { StructElement::Code, "Code", elementTypeInline, attributeMapInline },
-    { StructElement::Link, "Link", elementTypeInline, attributeMapInline },
-    { StructElement::Annot, "Annot", elementTypeInline, attributeMapInline },
-    { StructElement::Ruby, "Ruby", elementTypeInline, attributeMapRubyText },
-    { StructElement::RB, "RB", elementTypeUndefined, attributeMapRubyText },
-    { StructElement::RT, "RT", elementTypeUndefined, attributeMapRubyText },
-    { StructElement::RP, "RP", elementTypeUndefined, attributeMapShared },
-    { StructElement::Warichu, "Warichu", elementTypeInline, attributeMapRubyText },
-    { StructElement::WT, "WT", elementTypeUndefined, attributeMapShared },
-    { StructElement::WP, "WP", elementTypeUndefined, attributeMapShared },
-    { StructElement::P, "P", elementTypeBlock, attributeMapBlock },
-    { StructElement::H, "H", elementTypeBlock, attributeMapBlock },
-    { StructElement::H1, "H1", elementTypeBlock, attributeMapBlock },
-    { StructElement::H2, "H2", elementTypeBlock, attributeMapBlock },
-    { StructElement::H3, "H3", elementTypeBlock, attributeMapBlock },
-    { StructElement::H4, "H4", elementTypeBlock, attributeMapBlock },
-    { StructElement::H5, "H5", elementTypeBlock, attributeMapBlock },
-    { StructElement::H6, "H6", elementTypeBlock, attributeMapBlock },
-    { StructElement::L, "L", elementTypeBlock, attributeMapList },
-    { StructElement::LI, "LI", elementTypeBlock, attributeMapBlock },
-    { StructElement::Lbl, "Lbl", elementTypeBlock, attributeMapBlock },
-    { StructElement::LBody, "LBody", elementTypeBlock, attributeMapBlock },
-    { StructElement::Table, "Table", elementTypeBlock, attributeMapTable },
-    { StructElement::TR, "TR", elementTypeUndefined, attributeMapShared },
-    { StructElement::TH, "TH", elementTypeUndefined, attributeMapTableCell },
-    { StructElement::TD, "TD", elementTypeUndefined, attributeMapTableCell },
-    { StructElement::THead, "THead", elementTypeUndefined, attributeMapShared },
-    { StructElement::TFoot, "TFoot", elementTypeUndefined, attributeMapShared },
-    { StructElement::TBody, "TBody", elementTypeUndefined, attributeMapShared },
-    { StructElement::Figure, "Figure", elementTypeUndefined, attributeMapIllustration },
-    { StructElement::Formula, "Formula", elementTypeUndefined, attributeMapIllustration },
-    { StructElement::Form, "Form", elementTypeUndefined, attributeMapIllustration },
-    { StructElement::TOC, "TOC", elementTypeGrouping, attributeMapShared },
-    { StructElement::TOCI, "TOCI", elementTypeGrouping, attributeMapShared },
+    { .type = StructElement::Document, .name = "Document", .elementType = elementTypeGrouping, .attributes = attributeMapShared },
+    { .type = StructElement::Part, .name = "Part", .elementType = elementTypeGrouping, .attributes = attributeMapShared },
+    { .type = StructElement::Art, .name = "Art", .elementType = elementTypeGrouping, .attributes = attributeMapColumns },
+    { .type = StructElement::Sect, .name = "Sect", .elementType = elementTypeGrouping, .attributes = attributeMapColumns },
+    { .type = StructElement::Div, .name = "Div", .elementType = elementTypeGrouping, .attributes = attributeMapColumns },
+    { .type = StructElement::BlockQuote, .name = "BlockQuote", .elementType = elementTypeGrouping, .attributes = attributeMapInline },
+    { .type = StructElement::Caption, .name = "Caption", .elementType = elementTypeGrouping, .attributes = attributeMapInline },
+    { .type = StructElement::NonStruct, .name = "NonStruct", .elementType = elementTypeGrouping, .attributes = attributeMapInline },
+    { .type = StructElement::Index, .name = "Index", .elementType = elementTypeGrouping, .attributes = attributeMapInline },
+    { .type = StructElement::Private, .name = "Private", .elementType = elementTypeGrouping, .attributes = attributeMapInline },
+    { .type = StructElement::Span, .name = "Span", .elementType = elementTypeInline, .attributes = attributeMapInline },
+    { .type = StructElement::Quote, .name = "Quote", .elementType = elementTypeInline, .attributes = attributeMapInline },
+    { .type = StructElement::Note, .name = "Note", .elementType = elementTypeInline, .attributes = attributeMapInline },
+    { .type = StructElement::Reference, .name = "Reference", .elementType = elementTypeInline, .attributes = attributeMapInline },
+    { .type = StructElement::BibEntry, .name = "BibEntry", .elementType = elementTypeInline, .attributes = attributeMapInline },
+    { .type = StructElement::Code, .name = "Code", .elementType = elementTypeInline, .attributes = attributeMapInline },
+    { .type = StructElement::Link, .name = "Link", .elementType = elementTypeInline, .attributes = attributeMapInline },
+    { .type = StructElement::Annot, .name = "Annot", .elementType = elementTypeInline, .attributes = attributeMapInline },
+    { .type = StructElement::Ruby, .name = "Ruby", .elementType = elementTypeInline, .attributes = attributeMapRubyText },
+    { .type = StructElement::RB, .name = "RB", .elementType = elementTypeUndefined, .attributes = attributeMapRubyText },
+    { .type = StructElement::RT, .name = "RT", .elementType = elementTypeUndefined, .attributes = attributeMapRubyText },
+    { .type = StructElement::RP, .name = "RP", .elementType = elementTypeUndefined, .attributes = attributeMapShared },
+    { .type = StructElement::Warichu, .name = "Warichu", .elementType = elementTypeInline, .attributes = attributeMapRubyText },
+    { .type = StructElement::WT, .name = "WT", .elementType = elementTypeUndefined, .attributes = attributeMapShared },
+    { .type = StructElement::WP, .name = "WP", .elementType = elementTypeUndefined, .attributes = attributeMapShared },
+    { .type = StructElement::P, .name = "P", .elementType = elementTypeBlock, .attributes = attributeMapBlock },
+    { .type = StructElement::H, .name = "H", .elementType = elementTypeBlock, .attributes = attributeMapBlock },
+    { .type = StructElement::H1, .name = "H1", .elementType = elementTypeBlock, .attributes = attributeMapBlock },
+    { .type = StructElement::H2, .name = "H2", .elementType = elementTypeBlock, .attributes = attributeMapBlock },
+    { .type = StructElement::H3, .name = "H3", .elementType = elementTypeBlock, .attributes = attributeMapBlock },
+    { .type = StructElement::H4, .name = "H4", .elementType = elementTypeBlock, .attributes = attributeMapBlock },
+    { .type = StructElement::H5, .name = "H5", .elementType = elementTypeBlock, .attributes = attributeMapBlock },
+    { .type = StructElement::H6, .name = "H6", .elementType = elementTypeBlock, .attributes = attributeMapBlock },
+    { .type = StructElement::L, .name = "L", .elementType = elementTypeBlock, .attributes = attributeMapList },
+    { .type = StructElement::LI, .name = "LI", .elementType = elementTypeBlock, .attributes = attributeMapBlock },
+    { .type = StructElement::Lbl, .name = "Lbl", .elementType = elementTypeBlock, .attributes = attributeMapBlock },
+    { .type = StructElement::LBody, .name = "LBody", .elementType = elementTypeBlock, .attributes = attributeMapBlock },
+    { .type = StructElement::Table, .name = "Table", .elementType = elementTypeBlock, .attributes = attributeMapTable },
+    { .type = StructElement::TR, .name = "TR", .elementType = elementTypeUndefined, .attributes = attributeMapShared },
+    { .type = StructElement::TH, .name = "TH", .elementType = elementTypeUndefined, .attributes = attributeMapTableCell },
+    { .type = StructElement::TD, .name = "TD", .elementType = elementTypeUndefined, .attributes = attributeMapTableCell },
+    { .type = StructElement::THead, .name = "THead", .elementType = elementTypeUndefined, .attributes = attributeMapShared },
+    { .type = StructElement::TFoot, .name = "TFoot", .elementType = elementTypeUndefined, .attributes = attributeMapShared },
+    { .type = StructElement::TBody, .name = "TBody", .elementType = elementTypeUndefined, .attributes = attributeMapShared },
+    { .type = StructElement::Figure, .name = "Figure", .elementType = elementTypeUndefined, .attributes = attributeMapIllustration },
+    { .type = StructElement::Formula, .name = "Formula", .elementType = elementTypeUndefined, .attributes = attributeMapIllustration },
+    { .type = StructElement::Form, .name = "Form", .elementType = elementTypeUndefined, .attributes = attributeMapIllustration },
+    { .type = StructElement::TOC, .name = "TOC", .elementType = elementTypeGrouping, .attributes = attributeMapShared },
+    { .type = StructElement::TOCI, .name = "TOCI", .elementType = elementTypeGrouping, .attributes = attributeMapShared },
 };
 
 //------------------------------------------------------------------------
@@ -590,11 +589,7 @@ Object *Attribute::getDefaultValue(Attribute::Type type)
 void Attribute::setFormattedValue(const GooString *formattedA)
 {
     if (formattedA) {
-        if (formatted) {
-            formatted->Set(formattedA);
-        } else {
-            formatted = formattedA->copy();
-        }
+        formatted = formattedA->copy();
     } else {
         formatted = {};
     }
@@ -644,9 +639,9 @@ Attribute *Attribute::parseUserProperty(Dict *property)
 
     obj = property->lookup("N");
     if (obj.isString()) {
-        name.Set(obj.getString());
+        name.assign(obj.getString()->toStr());
     } else if (obj.isName()) {
-        name.Set(obj.getName());
+        name.assign(obj.getNameString());
     } else {
         error(errSyntaxError, -1, "N object is wrong type ({0:s})", obj.getTypeName());
         return nullptr;
@@ -658,7 +653,7 @@ Attribute *Attribute::parseUserProperty(Dict *property)
         return nullptr;
     }
 
-    Attribute *attribute = new Attribute(std::move(name), &value);
+    auto *attribute = new Attribute(std::move(name), &value);
     obj = property->lookup("F");
     if (obj.isString()) {
         attribute->setFormattedValue(obj.getString());
@@ -680,7 +675,7 @@ Attribute *Attribute::parseUserProperty(Dict *property)
 // StructElement
 //------------------------------------------------------------------------
 
-StructElement::StructData::StructData() : altText(nullptr), actualText(nullptr), id(nullptr), title(nullptr), expandedAbbr(nullptr), language(nullptr), revision(0) { }
+StructElement::StructData::StructData() : altText(nullptr), actualText(nullptr), id(nullptr), title(nullptr), expandedAbbr(nullptr), language(nullptr) { }
 
 StructElement::StructData::~StructData()
 {
@@ -835,7 +830,7 @@ GooString *StructElement::appendSubTreeText(GooString *string, bool recursive) c
         }
 
         for (const TextSpan &span : spans) {
-            string->append(span.getText());
+            string->append(span.getText()->toStr());
         }
 
         return string;
@@ -1010,7 +1005,7 @@ void StructElement::parse(Dict *element)
                 const int revision = iobj.getInt();
                 // Set revision numbers for the elements previously created.
                 for (unsigned j = attrIndex; j < getNumAttributes(); j++) {
-                    getAttribute(j)->setRevision(revision);
+                    getNonConstAttribute(j)->setRevision(revision);
                 }
             } else {
                 error(errSyntaxWarning, -1, "A item is wrong type ({0:s})", iobj.getTypeName());
@@ -1038,7 +1033,7 @@ void StructElement::parse(Dict *element)
                         // Set revision numbers for the elements previously created.
                         const int revision = iobj.getInt();
                         for (unsigned j = attrIndex; j < getNumAttributes(); j++) {
-                            getAttribute(j)->setRevision(revision);
+                            getNonConstAttribute(j)->setRevision(revision);
                         }
                     } else {
                         error(errSyntaxWarning, -1, "C item is wrong type ({0:s})", iobj.getTypeName());
@@ -1193,7 +1188,7 @@ void StructElement::parseAttributes(Dict *attributes, bool keepExisting)
                     if (t != Attribute::Unknown) {
                         Object value = attributes->getVal(i);
                         bool typeCheckOk = true;
-                        Attribute *attribute = new Attribute(t, &value);
+                        auto *attribute = new Attribute(t, &value);
 
                         if (attribute->isOk() && (typeCheckOk = attribute->checkType(this))) {
                             appendAttribute(attribute);
