@@ -6,9 +6,10 @@
 //
 // Copyright 2013, 2014 Igalia S.L.
 // Copyright 2014 Luigi Scarso <luigi.scarso@gmail.com>
-// Copyright 2014, 2018, 2019, 2021, 2023 Albert Astals Cid <aacid@kde.org>
+// Copyright 2014, 2018, 2019, 2021, 2023-2025 Albert Astals Cid <aacid@kde.org>
 // Copyright 2018 Adam Reichold <adam.reichold@t-online.de>
-// Copyright 2021 Adrian Johnson <ajohnson@redneon.com>
+// Copyright 2021, 2023 Adrian Johnson <ajohnson@redneon.com>
+// Copyright 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 //========================================================================
 
@@ -20,7 +21,6 @@
 #include "Object.h"
 #include "poppler_private_export.h"
 #include <vector>
-#include <set>
 
 class GooString;
 class Dict;
@@ -128,8 +128,7 @@ public:
     const Object *getValue() const { return &value; }
     static Object *getDefaultValue(Type type);
 
-    // The caller gets the ownership of the return GooString and is responsible of deleting it
-    std::unique_ptr<GooString> getName() const { return std::make_unique<GooString>(type == UserProperty ? name.c_str() : getTypeName()); }
+    const char *getName() const { return (type == UserProperty ? name.c_str() : getTypeName()); }
 
     // The revision is optional, and defaults to zero.
     unsigned int getRevision() const { return revision; }
@@ -142,7 +141,7 @@ public:
     // The formatted value may be in the PDF, or be left undefined (nullptr).
     // In the later case the user agent should provide a default representation.
     const char *getFormattedValue() const { return formatted ? formatted->c_str() : nullptr; }
-    void setFormattedValue(const char *formattedA);
+    void setFormattedValue(const GooString *formattedA);
 
     ~Attribute();
 
@@ -153,7 +152,7 @@ private:
     GooString name;
     Object value;
     bool hidden;
-    GooString *formatted;
+    std::unique_ptr<GooString> formatted;
 
     bool checkType(StructElement *element = nullptr);
     static Type getTypeForName(const char *name, StructElement *element = nullptr);
@@ -237,39 +236,41 @@ public:
     bool isInline() const;
     bool isGrouping() const;
 
-    inline bool isContent() const { return (type == MCID) || isObjectRef(); }
-    inline bool isObjectRef() const { return (type == OBJR && c->ref != Ref::INVALID()); }
+    bool isContent() const { return (type == MCID) || isObjectRef(); }
+    bool isObjectRef() const { return (type == OBJR && c->ref != Ref::INVALID()); }
 
     int getMCID() const { return c->mcid; }
     Ref getObjectRef() const { return c->ref; }
-    Ref getParentRef() { return isContent() ? parent->getParentRef() : s->parentRef; }
+    Ref getParentRef() const { return isContent() ? parent->getParentRef() : s->parentRef; }
+    StructElement *getParent() const { return parent; } // returns NULL if parent is StructTreeRoot
     bool hasPageRef() const;
     bool getPageRef(Ref &ref) const;
+    bool hasStmRef() const { return stmRef.isRef(); }
+    bool getStmRef(Ref &ref) const;
     StructTreeRoot *getStructTreeRoot() { return treeRoot; }
 
     // Optional element identifier.
-    const GooString *getID() const { return isContent() ? nullptr : s->id; }
-    GooString *getID() { return isContent() ? nullptr : s->id; }
+    const GooString *getID() const { return isContent() ? nullptr : s->id.get(); }
 
     // Optional ISO language name, e.g. en_US
     GooString *getLanguage()
     {
         if (!isContent() && s->language) {
-            return s->language;
+            return s->language.get();
         }
         return parent ? parent->getLanguage() : nullptr;
     }
     const GooString *getLanguage() const
     {
         if (!isContent() && s->language) {
-            return s->language;
+            return s->language.get();
         }
         return parent ? parent->getLanguage() : nullptr;
     }
 
     // Optional revision number, defaults to zero.
     unsigned int getRevision() const { return isContent() ? 0 : s->revision; }
-    void setRevision(unsigned int revision)
+    void setRevision(unsigned int revision) const
     {
         if (isContent()) {
             s->revision = revision;
@@ -277,18 +278,15 @@ public:
     }
 
     // Optional element title, in human-readable form.
-    const GooString *getTitle() const { return isContent() ? nullptr : s->title; }
-    GooString *getTitle() { return isContent() ? nullptr : s->title; }
+    const GooString *getTitle() const { return isContent() ? nullptr : s->title.get(); }
 
     // Optional element expanded abbreviation text.
-    const GooString *getExpandedAbbr() const { return isContent() ? nullptr : s->expandedAbbr; }
-    GooString *getExpandedAbbr() { return isContent() ? nullptr : s->expandedAbbr; }
+    const GooString *getExpandedAbbr() const { return isContent() ? nullptr : s->expandedAbbr.get(); }
 
     unsigned getNumChildren() const { return isContent() ? 0 : s->elements.size(); }
     const StructElement *getChild(int i) const { return isContent() ? nullptr : s->elements.at(i); }
-    StructElement *getChild(int i) { return isContent() ? nullptr : s->elements.at(i); }
 
-    void appendChild(StructElement *element)
+    void appendChild(StructElement *element) const
     {
         if (!isContent() && element && element->isOk()) {
             s->elements.push_back(element);
@@ -297,9 +295,9 @@ public:
 
     unsigned getNumAttributes() const { return isContent() ? 0 : s->attributes.size(); }
     const Attribute *getAttribute(int i) const { return isContent() ? nullptr : s->attributes.at(i); }
-    Attribute *getAttribute(int i) { return isContent() ? nullptr : s->attributes.at(i); }
+    Attribute *getNonConstAttribute(int i) const { return isContent() ? nullptr : s->attributes.at(i); }
 
-    void appendAttribute(Attribute *attribute)
+    void appendAttribute(Attribute *attribute) const
     {
         if (!isContent() && attribute) {
             s->attributes.push_back(attribute);
@@ -308,11 +306,9 @@ public:
 
     const Attribute *findAttribute(Attribute::Type attributeType, bool inherit = false, Attribute::Owner owner = Attribute::UnknownOwner) const;
 
-    const GooString *getAltText() const { return isContent() ? nullptr : s->altText; }
-    GooString *getAltText() { return isContent() ? nullptr : s->altText; }
+    const GooString *getAltText() const { return isContent() ? nullptr : s->altText.get(); }
 
-    const GooString *getActualText() const { return isContent() ? nullptr : s->actualText; }
-    GooString *getActualText() { return isContent() ? nullptr : s->actualText; }
+    const GooString *getActualText() const { return isContent() ? nullptr : s->actualText.get(); }
 
     // Content text referenced by the element:
     //
@@ -329,7 +325,7 @@ public:
     //
     GooString *getText(bool recursive = true) const { return appendSubTreeText(nullptr, recursive); }
 
-    const TextSpanArray getTextSpans() const
+    TextSpanArray getTextSpans() const
     {
         if (!isContent()) {
             return TextSpanArray();
@@ -344,19 +340,19 @@ private:
     GooString *appendSubTreeText(GooString *string, bool recursive) const;
     const TextSpanArray &getTextSpansInternal(MarkedContentOutputDev &mcdev) const;
 
-    typedef std::vector<Attribute *> AttrPtrArray;
-    typedef std::vector<StructElement *> ElemPtrArray;
+    using AttrPtrArray = std::vector<Attribute *>;
+    using ElemPtrArray = std::vector<StructElement *>;
 
     struct StructData
     {
         Ref parentRef;
-        GooString *altText;
-        GooString *actualText;
-        GooString *id;
-        GooString *title;
-        GooString *expandedAbbr;
-        GooString *language;
-        unsigned int revision;
+        std::unique_ptr<GooString> altText;
+        std::unique_ptr<GooString> actualText;
+        std::unique_ptr<GooString> id;
+        std::unique_ptr<GooString> title;
+        std::unique_ptr<GooString> expandedAbbr;
+        std::unique_ptr<GooString> language;
+        unsigned int revision = 0;
         ElemPtrArray elements;
         AttrPtrArray attributes;
 
@@ -393,7 +389,7 @@ private:
 
     StructElement(Dict *elementDict, StructTreeRoot *treeRootA, StructElement *parentA, RefRecursionChecker &seen);
     StructElement(int mcid, StructTreeRoot *treeRootA, StructElement *parentA);
-    StructElement(const Ref ref, StructTreeRoot *treeRootA, StructElement *parentA);
+    StructElement(Ref ref, StructTreeRoot *treeRootA, StructElement *parentA);
 
     void parse(Dict *elementDict);
     StructElement *parseChild(const Object *ref, Object *childObj, RefRecursionChecker &seen);
