@@ -15,7 +15,7 @@
 //
 // Copyright (C) 2005 Dan Sheridan <dan.sheridan@postman.org.uk>
 // Copyright (C) 2005 Brad Hards <bradh@frogmouth.net>
-// Copyright (C) 2006, 2008, 2010, 2012-2014, 2016-2025 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2006, 2008, 2010, 2012-2014, 2016-2026 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2007-2008 Julien Rebetez <julienr@svn.gnome.org>
 // Copyright (C) 2007 Carlos Garcia Campos <carlosgc@gnome.org>
 // Copyright (C) 2009, 2010 Ilya Gorenbein <igorenbein@finjan.com>
@@ -32,11 +32,13 @@
 // Copyright (C) 2010 William Bader <william@newspapersystems.com>
 // Copyright (C) 2021 Mahmoud Khalil <mahmoudkhalil11@gmail.com>
 // Copyright (C) 2021 Georgiy Sgibnev <georgiy@sgibnev.com>. Work sponsored by lab50.net.
-// Copyright (C) 2023, 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2023, 2025, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 // Copyright (C) 2023 Ilaï Deutel <idtl@google.com>
 // Copyright (C) 2023 Even Rouault <even.rouault@spatialys.com>
 // Copyright (C) 2024 Nelson Benítez León <nbenitezl@gmail.com>
 // Copyright (C) 2024 Vincent Lefevre <vincent@vinc17.net>
+// Copyright (C) 2025 Arnav V <arnav0872@gmail.com>
+// Copyright (C) 2026 Ojas Maheshwari <workonlyojas@gmail.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -44,15 +46,12 @@
 //========================================================================
 
 #include <config.h>
-#include "poppler-config.h"
 
 #include <cstdlib>
 #include <cstddef>
 #include <cstring>
-#include <cmath>
 #include <cctype>
 #include <climits>
-#include <cfloat>
 #include <limits>
 #include "goo/gfile.h"
 #include "goo/gmem.h"
@@ -70,15 +69,15 @@
 // Note that the PDF spec uses 1 base (eg bit 3 is 1<<2)
 //------------------------------------------------------------------------
 
-#define permPrint (1 << 2) // bit 3
-#define permChange (1 << 3) // bit 4
-#define permCopy (1 << 4) // bit 5
-#define permNotes (1 << 5) // bit 6
-#define permFillForm (1 << 8) // bit 9
-#define permAccessibility (1 << 9) // bit 10
-#define permAssemble (1 << 10) // bit 11
-#define permHighResPrint (1 << 11) // bit 12
-#define defPermFlags 0xfffc
+constexpr int permPrint = 1 << 2; // bit 3
+constexpr int permChange = 1 << 3; // bit 4
+constexpr int permCopy = 1 << 4; // bit 5
+constexpr int permNotes = 1 << 5; // bit 6
+constexpr int permFillForm = 1 << 8; // bit 9
+constexpr int permAccessibility = 1 << 9; // bit 10
+constexpr int permAssemble = 1 << 10; // bit 11
+constexpr int permHighResPrint = 1 << 11; // bit 12
+constexpr int defPermFlags = 0xfffc;
 
 //------------------------------------------------------------------------
 // ObjectStream
@@ -91,7 +90,7 @@ public:
     // generation 0.
     ObjectStream(XRef *xref, int objStrNumA, int recursion = 0);
 
-    bool isOk() { return ok; }
+    bool isOk() const { return ok; }
 
     ~ObjectStream();
 
@@ -99,7 +98,7 @@ public:
     ObjectStream &operator=(const ObjectStream &) = delete;
 
     // Return the object number of this object stream.
-    int getObjStrNum() { return objStrNum; }
+    int getObjStrNum() const { return objStrNum; }
 
     // Get the <objIdx>th object from this stream, which should be
     // object number <objNum>, generation 0.
@@ -161,7 +160,7 @@ ObjectStream::ObjectStream(XRef *xref, int objStrNumA, int recursion)
         error(errSyntaxError, -1, "Too many objects in an object stream");
         return;
     }
-    if (!objStr.streamReset()) {
+    if (!objStr.streamRewind()) {
         return;
     }
     objs = new Object[nObjects];
@@ -192,7 +191,7 @@ ObjectStream::ObjectStream(XRef *xref, int objStrNumA, int recursion)
         }
     }
     {
-        auto str = parser->getStream();
+        auto *str = parser->getStream();
         while (str && str->getChar() != EOF) {
             ;
         }
@@ -216,7 +215,7 @@ ObjectStream::ObjectStream(XRef *xref, int objStrNumA, int recursion)
         }
         parser = new Parser(xref, std::move(strPtr), false);
         objs[i] = parser->getObj();
-        auto str = parser->getStream();
+        auto *str = parser->getStream();
         while (str && str->getChar() != EOF) {
             ;
         }
@@ -247,7 +246,7 @@ Object ObjectStream::getObject(int objIdx, int objNum)
 
 #define xrefLocker() const std::scoped_lock locker(mutex)
 
-XRef::XRef() : objStrs { 5 }
+XRef::XRef()
 {
     ok = true;
     errCode = errNone;
@@ -265,7 +264,6 @@ XRef::XRef() : objStrs { 5 }
     ownerPasswordOk = false;
     rootNum = -1;
     rootGen = -1;
-    strOwner = false;
     xrefReconstructed = false;
     encAlgorithm = cryptNone;
     keyLength = 0;
@@ -294,57 +292,57 @@ XRef::XRef(BaseStream *strA, Goffset pos, Goffset mainXRefEntriesOffsetA, bool *
     if (reconstruct && !(ok = constructXRef(wasReconstructed))) {
         errCode = errDamaged;
         return;
+    }
+    // if there was a problem with the 'startxref' position, try to
+    // reconstruct the xref table
+    if (prevXRefOffset == 0) {
+        if (!(ok = constructXRef(wasReconstructed))) {
+            errCode = errDamaged;
+            return;
+        }
+
+        // read the xref table
     } else {
-        // if there was a problem with the 'startxref' position, try to
-        // reconstruct the xref table
-        if (prevXRefOffset == 0) {
-            if (!(ok = constructXRef(wasReconstructed))) {
-                errCode = errDamaged;
-                return;
-            }
+        std::vector<Goffset> followedXRefStm;
+        readXRef(&prevXRefOffset, &followedXRefStm, nullptr);
 
-            // read the xref table
-        } else {
-            std::vector<Goffset> followedXRefStm;
-            readXRef(&prevXRefOffset, &followedXRefStm, nullptr);
-
-            // if there was a problem with the xref table,
-            // try to reconstruct it
-            if (!ok) {
-                if (!(ok = constructXRef(wasReconstructed))) {
-                    errCode = errDamaged;
-                    return;
-                }
-            }
-        }
-
-        // set size to (at least) the size specified in trailer dict
-        obj = trailerDict.dictLookupNF("Size").copy();
-        if (!obj.isInt()) {
-            error(errSyntaxWarning, -1, "No valid XRef size in trailer");
-        } else {
-            if (obj.getInt() > size) {
-                if (resize(obj.getInt()) != obj.getInt()) {
-                    if (!(ok = constructXRef(wasReconstructed))) {
-                        errCode = errDamaged;
-                        return;
-                    }
-                }
-            }
-        }
-
-        // get the root dictionary (catalog) object
-        obj = trailerDict.dictLookupNF("Root").copy();
-        if (obj.isRef()) {
-            rootNum = obj.getRefNum();
-            rootGen = obj.getRefGen();
-        } else {
+        // if there was a problem with the xref table,
+        // try to reconstruct it
+        if (!ok) {
             if (!(ok = constructXRef(wasReconstructed))) {
                 errCode = errDamaged;
                 return;
             }
         }
     }
+
+    // set size to (at least) the size specified in trailer dict
+    obj = trailerDict.dictLookupNF("Size").copy();
+    if (!obj.isInt()) {
+        error(errSyntaxWarning, -1, "No valid XRef size in trailer");
+    } else {
+        if (obj.getInt() > size) {
+            if (resize(obj.getInt()) != obj.getInt()) {
+                if (!(ok = constructXRef(wasReconstructed))) {
+                    errCode = errDamaged;
+                    return;
+                }
+            }
+        }
+    }
+
+    // get the root dictionary (catalog) object
+    obj = trailerDict.dictLookupNF("Root").copy();
+    if (obj.isRef()) {
+        rootNum = obj.getRefNum();
+        rootGen = obj.getRefGen();
+    } else {
+        if (!(ok = constructXRef(wasReconstructed))) {
+            errCode = errDamaged;
+            return;
+        }
+    }
+
     // now set the trailer dictionary's xref pointer so we can fetch
     // indirect objects from it
     trailerDict.getDict()->setXRef(this);
@@ -364,16 +362,13 @@ XRef::~XRef()
     if (streamEnds) {
         gfree(streamEnds);
     }
-    if (strOwner) {
-        delete str;
-    }
 }
 
 XRef *XRef::copy() const
 {
     XRef *xref = new XRef();
-    xref->str = str->copy();
-    xref->strOwner = true;
+    xref->strOwner = str->copy();
+    xref->str = xref->strOwner.get();
     xref->encrypted = encrypted;
     xref->permFlags = permFlags;
     xref->ownerPasswordOk = ownerPasswordOk;
@@ -687,7 +682,7 @@ bool XRef::readXRefTable(Parser *parser, Goffset *pos, std::vector<Goffset> *fol
         } else {
             pos2 = obj2.getInt64();
         }
-        for (size_t i = 0; ok == true && i < followedXRefStm->size(); ++i) {
+        for (size_t i = 0; ok && i < followedXRefStm->size(); ++i) {
             if (followedXRefStm->at(i) == pos2) {
                 ok = false;
             }
@@ -752,11 +747,13 @@ bool XRef::readXRefStream(Stream *xrefStr, Goffset *pos)
             return false;
         }
     }
-    if (w[0] > (int)sizeof(int) || w[1] > (int)sizeof(long long) || w[2] > (int)sizeof(long long)) {
+    constexpr int intNBytes = sizeof(int);
+    constexpr int longLongNBytes = sizeof(long long);
+    if (w[0] > intNBytes || w[1] > longLongNBytes || w[2] > longLongNBytes) {
         return false;
     }
 
-    if (!xrefStr->reset()) {
+    if (!xrefStr->rewind()) {
         return false;
     }
 
@@ -918,7 +915,7 @@ bool XRef::constructXRef(bool *wasReconstructed, bool needCatalogDict)
         xrefReconstructedCb();
     }
 
-    if (!str->reset()) {
+    if (!str->rewind()) {
         return false;
     }
     while (true) {
@@ -1137,15 +1134,14 @@ bool XRef::okToPrintHighRes(bool ignoreOwnerPW) const
     if (encrypted) {
         if (2 == encRevision) {
             return (okToPrint(ignoreOwnerPW));
-        } else if (encRevision >= 3) {
-            return (okToPrint(ignoreOwnerPW) && (permFlags & permHighResPrint));
-        } else {
-            // something weird - unknown security handler version
-            return false;
         }
-    } else {
-        return true;
+        if (encRevision >= 3) {
+            return (okToPrint(ignoreOwnerPW) && (permFlags & permHighResPrint));
+        }
+        // something weird - unknown security handler version
+        return false;
     }
+    return true;
 }
 
 bool XRef::okToChange(bool ignoreOwnerPW) const
@@ -1203,7 +1199,7 @@ Object XRef::fetch(int num, int gen, int recursion, Goffset *endPos)
 
     xrefLocker();
 
-    const Ref ref = { num, gen };
+    const Ref ref = { .num = num, .gen = gen };
 
     if (!refsBeingFetched.insert(ref)) {
         return Object::null();
@@ -1228,7 +1224,11 @@ Object XRef::fetch(int num, int gen, int recursion, Goffset *endPos)
         if (e->gen != gen || e->offset < 0) {
             goto err;
         }
-        Parser parser { this, str->makeSubStream(start + e->offset, false, 0, Object::null()), true };
+        Goffset subStreamOffset;
+        if (checkedAdd(start, e->offset, &subStreamOffset)) {
+            goto err;
+        }
+        Parser parser { this, str->makeSubStream(subStreamOffset, false, 0, Object::null()), true };
         obj1 = parser.getObj(recursion);
         obj2 = parser.getObj(recursion);
         obj3 = parser.getObj(recursion);
@@ -1270,8 +1270,10 @@ Object XRef::fetch(int num, int gen, int recursion, Goffset *endPos)
             goto err;
         }
 
-        ObjectStream *objStr = objStrs.lookup(e->offset);
-        if (!objStr) {
+        ObjectStream *objStr = nullptr;
+        if (const auto it = objStrs.find(e->offset); it != objStrs.end()) {
+            objStr = it->second.get();
+        } else {
             objStr = new ObjectStream(this, static_cast<int>(e->offset), recursion + 1);
             if (!objStr->isOk()) {
                 delete objStr;
@@ -1280,7 +1282,7 @@ Object XRef::fetch(int num, int gen, int recursion, Goffset *endPos)
             } else {
                 // XRef could be reconstructed in constructor of ObjectStream:
                 e = getEntry(num);
-                objStrs.put(e->offset, objStr);
+                objStrs.emplace(e->offset, std::unique_ptr<ObjectStream>(objStr));
             }
         }
         if (endPos) {
@@ -1413,9 +1415,8 @@ int XRef::getNumEntry(Goffset offset)
             }
         }
         return res;
-    } else {
-        return -1;
     }
+    return -1;
 }
 
 void XRef::add(Ref ref, Goffset offs, bool used)
@@ -1520,7 +1521,7 @@ void XRef::removeIndirectObject(Ref r)
     if (e->type == xrefEntryFree) {
         return;
     }
-    e->obj.~Object();
+    e->obj = Object();
     e->type = xrefEntryFree;
     if (likely(e->gen < 65535)) {
         e->gen++;
@@ -1648,18 +1649,18 @@ XRef::XRefPreScanWriter::XRefPreScanWriter()
     hasOffsetsBeyond4GB = false;
 }
 
-void XRef::XRefPreScanWriter::startSection(int first, int count) { }
+void XRef::XRefPreScanWriter::startSection(int /*first*/, int /*count*/) { }
 
-void XRef::XRefPreScanWriter::writeEntry(Goffset offset, int gen, XRefEntryType type)
+void XRef::XRefPreScanWriter::writeEntry(Goffset offset, int /*gen*/, XRefEntryType /*type*/)
 {
-    if (offset >= 0x100000000ll) {
+    if (offset >= 0x100000000LL) {
         hasOffsetsBeyond4GB = true;
     }
 }
 
 void XRef::writeStreamToBuffer(GooString *stmBuf, Dict *xrefDict, XRef *xref)
 {
-    Array *index = new Array(xref);
+    auto *index = new Array(xref);
     stmBuf->clear();
 
     // First pass: determine whether all offsets fit in 4 bytes or not
@@ -1673,7 +1674,7 @@ void XRef::writeStreamToBuffer(GooString *stmBuf, Dict *xrefDict, XRef *xref)
 
     xrefDict->set("Type", Object(objName, "XRef"));
     xrefDict->set("Index", Object(index));
-    Array *wArray = new Array(xref);
+    auto *wArray = new Array(xref);
     wArray->add(Object(1));
     wArray->add(Object(offsetSize));
     wArray->add(Object(2));
