@@ -14,7 +14,7 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2005 Brad Hards <bradh@frogmouth.net>
-// Copyright (C) 2006, 2008, 2010-2013, 2017-2022, 2024 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2006, 2008, 2010-2013, 2017-2022, 2024, 2025, Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2007-2008 Julien Rebetez <julienr@svn.gnome.org>
 // Copyright (C) 2007 Carlos Garcia Campos <carlosgc@gnome.org>
 // Copyright (C) 2010 Ilya Gorenbein <igorenbein@finjan.com>
@@ -27,7 +27,8 @@
 // Copyright (C) 2018 Marek Kasik <mkasik@redhat.com>
 // Copyright (C) 2021 Mahmoud Khalil <mahmoudkhalil11@gmail.com>
 // Copyright (C) 2021 Georgiy Sgibnev <georgiy@sgibnev.com>. Work sponsored by lab50.net.
-// Copyright (C) 2023, 2024 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2023-2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2026 Ojas Maheshwari <workonlyojas@gmail.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -39,7 +40,6 @@
 
 #include <functional>
 
-#include "poppler-config.h"
 #include "poppler_private_export.h"
 #include "Object.h"
 #include "Stream.h"
@@ -81,13 +81,13 @@ struct XRefEntry
         DontRewrite // Entry must not be written back in case of full rewrite
     };
 
-    inline bool getFlag(Flag flag) const
+    bool getFlag(Flag flag) const
     {
         const int mask = (1 << (int)flag);
         return (flags & mask) != 0;
     }
 
-    inline void setFlag(Flag flag, bool value)
+    void setFlag(Flag flag, bool value)
     {
         const int mask = (1 << (int)flag);
         if (value) {
@@ -161,7 +161,7 @@ public:
     Object getCatalog();
 
     // Fetch an indirect reference.
-    Object fetch(const Ref ref, int recursion = 0);
+    Object fetch(Ref ref, int recursion = 0);
     // If endPos is not null, returns file position after parsing the object. This will
     // be a few bytes after the end of the object due to the parser reading ahead.
     // Returns -1 if object is in compressed stream.
@@ -185,7 +185,7 @@ public:
     // Return the catalog object reference.
     int getRootNum() const { return rootNum; }
     int getRootGen() const { return rootGen; }
-    Ref getRoot() const { return { rootNum, rootGen }; }
+    Ref getRoot() const { return { .num = rootNum, .gen = rootGen }; }
 
     // Get end position for a stream in a damaged file.
     // Returns false if unknown or file is not damaged.
@@ -223,8 +223,7 @@ public:
     // For stream compression, if the data is already compressed
     // don't compress again. If it is not compressed, use compress (Flate / zlib)
     // Returns ref to a new object.
-    Ref addStreamObject(Dict *dict, char *buffer, const Goffset bufferSize, StreamCompression compression);
-    Ref addStreamObject(Dict *dict, uint8_t *buffer, const Goffset bufferSize, StreamCompression compression);
+    Ref addStreamObject(Dict *dict, std::vector<char> buffer, StreamCompression compression);
 
     // Output XRef table to stream
     void writeTableToFile(OutStream *outStr, bool writeAllEntries);
@@ -251,7 +250,7 @@ private:
     Goffset *streamEnds; // 'endstream' positions - only used in
                          //   damaged files
     int streamEndsLen; // number of valid entries in streamEnds
-    PopplerCache<Goffset, ObjectStream> objStrs; // cached object streams
+    std::unordered_map<Goffset, std::unique_ptr<ObjectStream>> objStrs; // object streams map
     bool encrypted; // true if file is encrypted
     int encRevision;
     int encVersion; // encryption algorithm
@@ -265,7 +264,7 @@ private:
     bool xRefStream; // true if last XRef section is a stream
     Goffset mainXRefOffset; // position of the main XRef table/stream
     bool scannedSpecialFlags; // true if scanSpecialFlags has been called
-    bool strOwner; // true if str is owned by the instance
+    std::unique_ptr<BaseStream> strOwner; // ownership if any of str (can be null if others own the stream)
     mutable std::recursive_mutex mutex;
     std::function<void()> xrefReconstructedCb;
 
