@@ -47,7 +47,7 @@ void ThumbnailsDock::fillInfo()
         const Poppler::Page *page = document()->page(i);
         const QImage image = page ? page->thumbnail() : QImage();
         if (!image.isNull()) {
-            QListWidgetItem *item = new QListWidgetItem();
+            auto *item = new QListWidgetItem();
             item->setText(QString::number(i + 1));
             item->setData(Qt::DecorationRole, QPixmap::fromImage(image));
             item->setData(PageRole, i);
