@@ -79,9 +79,8 @@ public:
         Node *n = static_cast<Node *>(child.internalPointer());
         if (n->m_parent == nullptr) {
             return QModelIndex();
-        } else {
-            return createIndex(n->m_parent->m_row, 0, n->m_parent);
         }
+        return createIndex(n->m_parent->m_row, 0, n->m_parent);
     }
 
     int rowCount(const QModelIndex &parent) const override
@@ -131,7 +130,7 @@ TocDock::~TocDock() = default;
 
 void TocDock::expandItemModels(const QModelIndex &parent)
 {
-    TocModel *model = static_cast<TocModel *>(m_tree->model());
+    auto *model = static_cast<TocModel *>(m_tree->model());
     for (int i = 0; i < model->rowCount(parent); ++i) {
         QModelIndex index = model->index(i, 0, parent);
         Node *n = static_cast<Node *>(index.internalPointer());
@@ -146,13 +145,13 @@ void TocDock::fillInfo()
 {
     auto outline = document()->outline();
     if (!outline.isEmpty()) {
-        TocModel *model = new TocModel(std::move(outline), this);
+        auto *model = new TocModel(std::move(outline), this);
         m_tree->setModel(model);
 
         expandItemModels(QModelIndex());
     } else {
-        QStandardItemModel *model = new QStandardItemModel(this);
-        QStandardItem *item = new QStandardItem(tr("No TOC"));
+        auto *model = new QStandardItemModel(this);
+        auto *item = new QStandardItem(tr("No TOC"));
         item->setFlags(item->flags() & ~Qt::ItemIsEnabled);
         model->appendRow(item);
         m_tree->setModel(model);
