@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2008, Pino Toscano <pino@kde.org>
  * Copyright (C) 2021, Mahmoud Khalil <mahmoudkhalil11@gmail.com>
+ * Copyright (C) 2021, Albert Astals Cid <aacid@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,7 +38,7 @@ class PdfViewer : public QMainWindow
     friend class DocumentObserver;
 
 public:
-    PdfViewer(QWidget *parent = nullptr);
+    explicit PdfViewer(QWidget *parent = nullptr);
     ~PdfViewer() override;
 
     QSize sizeHint() const override;
@@ -45,7 +46,7 @@ public:
     void loadDocument(const QString &file);
     void closeDocument();
 
-private Q_SLOTS:
+private:
     void slotOpenFile();
     void slotSaveCopy();
     void slotAbout();
@@ -54,12 +55,11 @@ private Q_SLOTS:
     void slotToggleGfxAA(bool value);
     void slotRenderBackend(QAction *act);
 
-private:
     void setPage(int page);
     int page() const;
     void xrefReconstructedHandler(Poppler::Document *doc);
 
-    int m_currentPage;
+    int m_currentPage = 0;
     bool xrefReconstructed;
 
     QAction *m_fileOpenAct;
@@ -70,7 +70,7 @@ private:
 
     QList<DocumentObserver *> m_observers;
 
-    Poppler::Document *m_doc;
+    Poppler::Document *m_doc = nullptr;
 };
 
 #endif
