@@ -4,6 +4,8 @@
  * Copyright (C) 2012, 2013 Fabio D'Urso <fabiodurso@hotmail.it>
  * Copyright (C) 2012, 2014, 2018, 2019, Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2020, Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by Technische Universität Dresden
+ * Copyright (C) 2021, Mahmoud Ahmed Khalil <mahmoudkhalil11@gmail.com>
+ * Copyright (C) 2024, 2025, g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,6 +32,7 @@
 #include "poppler-annotation.h"
 
 #include <Object.h>
+#include <AnnotStampImageHelper.h>
 
 class Annot;
 class AnnotPath;
@@ -40,6 +43,7 @@ namespace Poppler {
 class DocumentData;
 
 PDFRectangle boundaryToPdfRectangle(::Page *pdfPage, const QRectF &r, int flags);
+void getRawDataFromQImage(const QImage &qimg, int bitsPerPixel, QByteArray *data, QByteArray *sMaskData);
 
 class AnnotationPrivate : public QSharedData
 {
@@ -54,7 +58,7 @@ public:
 
     /* Returns an Annotation of the right subclass whose d_ptr points to
      * this AnnotationPrivate */
-    virtual Annotation *makeAlias() = 0;
+    virtual std::unique_ptr<Annotation> makeAlias() = 0;
 
     /* properties: contents related */
     QString author;
@@ -64,7 +68,7 @@ public:
     QDateTime creationDate; // before or equal to modifyDate
 
     /* properties: look/interaction related */
-    int flags;
+    int flags = 0;
     QRectF boundary;
 
     /* style and popup */
@@ -72,29 +76,29 @@ public:
     Annotation::Popup popup;
 
     /* revisions */
-    Annotation::RevScope revisionScope;
-    Annotation::RevType revisionType;
-    QList<Annotation *> revisions;
+    Annotation::RevScope revisionScope = Annotation::Root;
+    Annotation::RevType revisionType = Annotation::None;
+    std::vector<std::unique_ptr<Annotation>> revisions;
 
     /* After this call, the Annotation object will behave like a wrapper for
      * the specified Annot object. All cached values are discarded */
-    void tieToNativeAnnot(Annot *ann, ::Page *page, DocumentData *doc);
+    void tieToNativeAnnot(std::shared_ptr<Annot> ann, ::Page *page, DocumentData *doc);
 
     /* Creates a new Annot object on the specified page, flushes current
      * values to that object and ties this Annotation to that object */
-    virtual Annot *createNativeAnnot(::Page *destPage, DocumentData *doc) = 0;
+    virtual std::shared_ptr<Annot> createNativeAnnot(::Page *destPage, DocumentData *doc) = 0;
 
     /* Inited to 0 (i.e. untied annotation) */
-    Annot *pdfAnnot;
-    ::Page *pdfPage;
-    DocumentData *parentDoc;
+    std::shared_ptr<Annot> pdfAnnot;
+    ::Page *pdfPage = nullptr;
+    DocumentData *parentDoc = nullptr;
 
     /* The following helpers only work if pdfPage is set */
     void flushBaseAnnotationProperties();
     void fillTransformationMTX(double MTX[6]) const;
     QRectF fromPdfRectangle(const PDFRectangle &r) const;
     PDFRectangle boundaryToPdfRectangle(const QRectF &r, int flags) const;
-    AnnotPath *toAnnotPath(const QLinkedList<QPointF> &l) const;
+    std::unique_ptr<AnnotPath> toAnnotPath(const QLinkedList<QPointF> &l) const;
 
     /* Scan page for annotations, parentId=0 searches for root annotations, subtypes empty means all subtypes */
     static QList<Annotation *> findAnnotations(::Page *pdfPage, DocumentData *doc, const QSet<Annotation::SubType> &subtypes, int parentId = -1);
@@ -108,6 +112,16 @@ public:
     Ref pdfObjectReference() const;
 
     Link *additionalAction(Annotation::AdditionalActionType type) const;
+
+    Object annotationAppearance;
+};
+
+class AnnotationAppearancePrivate
+{
+public:
+    explicit AnnotationAppearancePrivate(Annot *annot);
+
+    Object appearance;
 };
 
 }
