@@ -1,7 +1,7 @@
 /* poppler-document.cc: qt interface to poppler
  * Copyright (C) 2005, Net Integration Technologies, Inc.
  * Copyright (C) 2005, 2008, Brad Hards <bradh@frogmouth.net>
- * Copyright (C) 2005-2010, 2012, 2013, 2015, 2017-2022, 2024, 2025, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2005-2010, 2012, 2013, 2015, 2017-2022, 2024-2026, Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2006-2010, Pino Toscano <pino@kde.org>
  * Copyright (C) 2010, 2011 Hib Eris <hib@hiberis.nl>
  * Copyright (C) 2012 Koji Otani <sho@bbr.jp>
@@ -23,6 +23,7 @@
  * Copyright (C) 2024 Pratham Gandhi <ppg.1382@gmail.com>
  * Copyright (C) 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
  * Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+ * Copyright (C) 2025 Arnav V <arnav0872@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -64,7 +65,7 @@
 #include "poppler-page-private.h"
 #include "poppler-outline-private.h"
 
-#if defined(USE_CMS)
+#if USE_CMS
 #    include <lcms2.h>
 #endif
 
@@ -72,20 +73,20 @@ namespace Poppler {
 
 Document *Document::load(const QString &filePath, const QByteArray &ownerPassword, const QByteArray &userPassword)
 {
-    DocumentData *doc = new DocumentData(filePath, GooString(ownerPassword.data()), GooString(userPassword.data()));
+    auto *doc = new DocumentData(filePath, GooString(ownerPassword.data()), GooString(userPassword.data()));
     return DocumentData::checkDocument(doc);
 }
 
 Document *Document::load(QIODevice *device, const QByteArray &ownerPassword, const QByteArray &userPassword)
 {
-    DocumentData *doc = new DocumentData(device, GooString(ownerPassword.data()), GooString(userPassword.data()));
+    auto *doc = new DocumentData(device, GooString(ownerPassword.data()), GooString(userPassword.data()));
     return DocumentData::checkDocument(doc);
 }
 
 Document *Document::loadFromData(const QByteArray &fileContents, const QByteArray &ownerPassword, const QByteArray &userPassword)
 {
     // create stream
-    DocumentData *doc = new DocumentData(fileContents, GooString(ownerPassword.data()), GooString(userPassword.data()));
+    auto *doc = new DocumentData(fileContents, GooString(ownerPassword.data()), GooString(userPassword.data()));
     return DocumentData::checkDocument(doc);
 }
 
@@ -101,9 +102,9 @@ Document *DocumentData::checkDocument(DocumentData *doc)
             pdoc->m_doc->fillMembers();
         }
         return pdoc;
-    } else {
-        delete doc;
     }
+    delete doc;
+
     return nullptr;
 }
 
@@ -248,7 +249,7 @@ QByteArray Document::fontData(const FontInfo &fi) const
 
         Object refObj(fi.m_data->embRef);
         Object strObj = refObj.fetch(xref);
-        if (strObj.isStream() && strObj.streamReset()) {
+        if (strObj.isStream() && strObj.streamRewind()) {
             int c;
             while ((c = strObj.streamGetChar()) != EOF) {
                 result.append((char)c);
@@ -568,7 +569,7 @@ void Document::getPdfVersion(int *major, int *minor) const
 
 Document::PdfVersion Document::getPdfVersion() const
 {
-    return PdfVersion { m_doc->doc->getPDFMajorVersion(), m_doc->doc->getPDFMinorVersion() };
+    return PdfVersion { .major = m_doc->doc->getPDFMajorVersion(), .minor = m_doc->doc->getPDFMinorVersion() };
 }
 
 Page *Document::page(const QString &label) const
@@ -603,7 +604,7 @@ QDomDocument *Document::toc() const
         return nullptr;
     }
 
-    QDomDocument *toc = new QDomDocument();
+    auto *toc = new QDomDocument();
     m_doc->addTocChildren(toc, toc, items);
 
     return toc;
@@ -615,8 +616,8 @@ QVector<OutlineItem> Document::outline() const
 
     if (::Outline *outline = m_doc->doc->getOutline()) {
         if (const std::vector<::OutlineItem *> *items = outline->getItems()) {
-            for (void *item : *items) {
-                result.push_back(OutlineItem { new OutlineItemData { static_cast<::OutlineItem *>(item), m_doc } });
+            for (::OutlineItem *item : *items) {
+                result.push_back(OutlineItem { new OutlineItemData { item, m_doc } });
             }
         }
     }
@@ -628,7 +629,7 @@ LinkDestination *Document::linkDestination(const QString &name)
 {
     const std::unique_ptr<GooString> namedDest = QStringToGooString(name);
     LinkDestinationData ldd(nullptr, namedDest.get(), m_doc, false);
-    LinkDestination *ld = new LinkDestination(ldd);
+    auto *ld = new LinkDestination(ldd);
     return ld;
 }
 
@@ -639,7 +640,7 @@ void Document::setPaperColor(const QColor &color)
 
 void Document::setColorDisplayProfile(void *outputProfileA)
 {
-#if defined(USE_CMS)
+#if USE_CMS
     if (m_doc->m_sRGBProfile && m_doc->m_sRGBProfile.get() == outputProfileA) {
         // Catch the special case that the user passes the sRGB profile
         m_doc->m_displayProfile = m_doc->m_sRGBProfile;
@@ -657,7 +658,7 @@ void Document::setColorDisplayProfile(void *outputProfileA)
 
 void Document::setColorDisplayProfileName(const QString &name)
 {
-#if defined(USE_CMS)
+#if USE_CMS
     void *rawprofile = cmsOpenProfileFromFile(name.toLocal8Bit().constData(), "r");
     m_doc->m_displayProfile = make_GfxLCMSProfilePtr(rawprofile);
 #else
@@ -667,7 +668,7 @@ void Document::setColorDisplayProfileName(const QString &name)
 
 void *Document::colorRgbProfile() const
 {
-#if defined(USE_CMS)
+#if USE_CMS
     if (!m_doc->m_sRGBProfile) {
         m_doc->m_sRGBProfile = make_GfxLCMSProfilePtr(cmsCreate_sRGBProfile());
     }
@@ -679,7 +680,7 @@ void *Document::colorRgbProfile() const
 
 void *Document::colorDisplayProfile() const
 {
-#if defined(USE_CMS)
+#if USE_CMS
     return m_doc->m_displayProfile.get();
 #else
     return nullptr;
@@ -949,7 +950,7 @@ QDateTime convertDate(char *dateString)
 
 bool isCmsAvailable()
 {
-#if defined(USE_CMS)
+#if USE_CMS
     return true;
 #else
     return false;
