@@ -32,6 +32,7 @@
 #include <poppler-media.h>
 
 #include <QtCore/QStringList>
+#include <utility>
 
 #include "poppler-annotation-private.h"
 
@@ -143,10 +144,10 @@ public:
     bool sync : 1;
     bool repeat : 1;
     bool mix : 1;
-    SoundObject *sound;
+    SoundObject *sound = nullptr;
 };
 
-LinkSoundPrivate::LinkSoundPrivate(const QRectF &area) : LinkPrivate(area), sound(nullptr) { }
+LinkSoundPrivate::LinkSoundPrivate(const QRectF &area) : LinkPrivate(area) { }
 
 LinkSoundPrivate::~LinkSoundPrivate()
 {
@@ -156,17 +157,17 @@ LinkSoundPrivate::~LinkSoundPrivate()
 class LinkRenditionPrivate : public LinkPrivate
 {
 public:
-    explicit LinkRenditionPrivate(const QRectF &area, std::unique_ptr<::MediaRendition> &&rendition, ::LinkRendition::RenditionOperation operation, const QString &script, const Ref ref);
+    explicit LinkRenditionPrivate(const QRectF &area, std::unique_ptr<::MediaRendition> &&rendition, ::LinkRendition::RenditionOperation operation, QString script, Ref ref);
     ~LinkRenditionPrivate() override;
 
     std::unique_ptr<MediaRendition> rendition;
-    LinkRendition::RenditionAction action;
+    LinkRendition::RenditionAction action = LinkRendition::PlayRendition;
     QString script;
     Ref annotationReference;
 };
 
-LinkRenditionPrivate::LinkRenditionPrivate(const QRectF &area, std::unique_ptr<::MediaRendition> &&r, ::LinkRendition::RenditionOperation operation, const QString &javaScript, const Ref ref)
-    : LinkPrivate(area), rendition(r ? new MediaRendition(std::move(r)) : nullptr), action(LinkRendition::PlayRendition), script(javaScript), annotationReference(ref)
+LinkRenditionPrivate::LinkRenditionPrivate(const QRectF &area, std::unique_ptr<::MediaRendition> &&r, ::LinkRendition::RenditionOperation operation, QString javaScript, const Ref ref)
+    : LinkPrivate(area), rendition(r ? new MediaRendition(std::move(r)) : nullptr), script(std::move(javaScript)), annotationReference(ref)
 {
     switch (operation) {
     case ::LinkRendition::NoRendition:
@@ -204,7 +205,7 @@ LinkJavaScriptPrivate::~LinkJavaScriptPrivate() = default;
 class LinkMoviePrivate : public LinkPrivate
 {
 public:
-    LinkMoviePrivate(const QRectF &area, LinkMovie::Operation operation, const QString &title, const Ref reference);
+    LinkMoviePrivate(const QRectF &area, LinkMovie::Operation operation, QString title, Ref reference);
     ~LinkMoviePrivate() override;
 
     LinkMovie::Operation operation;
@@ -212,7 +213,7 @@ public:
     Ref annotationReference;
 };
 
-LinkMoviePrivate::LinkMoviePrivate(const QRectF &area, LinkMovie::Operation _operation, const QString &title, const Ref reference) : LinkPrivate(area), operation(_operation), annotationTitle(title), annotationReference(reference) { }
+LinkMoviePrivate::LinkMoviePrivate(const QRectF &area, LinkMovie::Operation _operation, QString title, const Ref reference) : LinkPrivate(area), operation(_operation), annotationTitle(std::move(title)), annotationReference(reference) { }
 
 LinkMoviePrivate::~LinkMoviePrivate() = default;
 
@@ -284,10 +285,10 @@ LinkDestination::LinkDestination(const LinkDestinationData &data) : d(new LinkDe
             cvtUserToDev(page, left, top, &leftAux, &topAux);
             cvtUserToDev(page, right, bottom, &rightAux, &bottomAux);
 
-            d->left = leftAux / (double)page->getCropWidth();
-            d->top = topAux / (double)page->getCropHeight();
-            d->right = rightAux / (double)page->getCropWidth();
-            d->bottom = bottomAux / (double)page->getCropHeight();
+            d->left = leftAux / page->getCropWidth();
+            d->top = topAux / page->getCropHeight();
+            d->right = rightAux / page->getCropWidth();
+            d->bottom = bottomAux / page->getCropHeight();
         } else {
             d->pageNum = 0;
         }
@@ -300,7 +301,7 @@ LinkDestination::LinkDestination(const LinkDestinationData &data) : d(new LinkDe
 
 LinkDestination::LinkDestination(const QString &description) : d(new LinkDestinationPrivate)
 {
-    const QStringList tokens = description.split(';');
+    const QStringList tokens = description.split(QChar::fromLatin1(';'));
     if (tokens.size() >= 10) {
         d->kind = static_cast<Kind>(tokens.at(0).toInt());
         d->pageNum = tokens.at(1).toInt();
@@ -315,9 +316,9 @@ LinkDestination::LinkDestination(const QString &description) : d(new LinkDestina
     }
 }
 
-LinkDestination::LinkDestination(const LinkDestination &other) : d(other.d) { }
+LinkDestination::LinkDestination(const LinkDestination &other) = default;
 
-LinkDestination::~LinkDestination() { }
+LinkDestination::~LinkDestination() = default;
 
 LinkDestination::Kind LinkDestination::kind() const
 {
@@ -371,16 +372,17 @@ bool LinkDestination::isChangeZoom() const
 
 QString LinkDestination::toString() const
 {
+    const QChar semicolon = QChar::fromLatin1(';');
     QString s = QString::number((qint8)d->kind);
-    s += ";" + QString::number(d->pageNum);
-    s += ";" + QString::number(d->left);
-    s += ";" + QString::number(d->bottom);
-    s += ";" + QString::number(d->right);
-    s += ";" + QString::number(d->top);
-    s += ";" + QString::number(d->zoom);
-    s += ";" + QString::number((qint8)d->changeLeft);
-    s += ";" + QString::number((qint8)d->changeTop);
-    s += ";" + QString::number((qint8)d->changeZoom);
+    s += semicolon + QString::number(d->pageNum);
+    s += semicolon + QString::number(d->left);
+    s += semicolon + QString::number(d->bottom);
+    s += semicolon + QString::number(d->right);
+    s += semicolon + QString::number(d->top);
+    s += semicolon + QString::number(d->zoom);
+    s += semicolon + QString::number((qint8)d->changeLeft);
+    s += semicolon + QString::number((qint8)d->changeTop);
+    s += semicolon + QString::number((qint8)d->changeZoom);
     return s;
 }
 
@@ -433,7 +435,7 @@ LinkGoto::LinkGoto(const QRectF &linkArea, QString extFileName, const LinkDestin
     d->extFileName = std::move(extFileName); // TODO remove when extFileName moves to be a const &
 }
 
-LinkGoto::~LinkGoto() { }
+LinkGoto::~LinkGoto() = default;
 
 bool LinkGoto::isExternal() const
 {
@@ -466,7 +468,7 @@ LinkExecute::LinkExecute(const QRectF &linkArea, const QString &file, const QStr
     d->parameters = params;
 }
 
-LinkExecute::~LinkExecute() { }
+LinkExecute::~LinkExecute() = default;
 
 QString LinkExecute::fileName() const
 {
@@ -491,7 +493,7 @@ LinkBrowse::LinkBrowse(const QRectF &linkArea, const QString &url) : Link(*new L
     d->url = url;
 }
 
-LinkBrowse::~LinkBrowse() { }
+LinkBrowse::~LinkBrowse() = default;
 
 QString LinkBrowse::url() const
 {
@@ -511,7 +513,7 @@ LinkAction::LinkAction(const QRectF &linkArea, ActionType actionType) : Link(*ne
     d->type = actionType;
 }
 
-LinkAction::~LinkAction() { }
+LinkAction::~LinkAction() = default;
 
 LinkAction::ActionType LinkAction::actionType() const
 {
@@ -535,7 +537,7 @@ LinkSound::LinkSound(const QRectF &linkArea, double volume, bool sync, bool repe
     d->sound = sound;
 }
 
-LinkSound::~LinkSound() { }
+LinkSound::~LinkSound() = default;
 
 Link::LinkType LinkSound::linkType() const
 {
@@ -583,7 +585,7 @@ LinkRendition::LinkRendition(const QRectF &linkArea, std::unique_ptr<::MediaRend
 {
 }
 
-LinkRendition::~LinkRendition() { }
+LinkRendition::~LinkRendition() = default;
 
 Link::LinkType LinkRendition::linkType() const
 {
@@ -611,11 +613,7 @@ QString LinkRendition::script() const
 bool LinkRendition::isReferencedAnnotation(const ScreenAnnotation *annotation) const
 {
     Q_D(const LinkRendition);
-    if (d->annotationReference != Ref::INVALID() && d->annotationReference == annotation->d_ptr->pdfObjectReference()) {
-        return true;
-    }
-
-    return false;
+    return d->annotationReference != Ref::INVALID() && d->annotationReference == annotation->d_ptr->pdfObjectReference();
 }
 
 // LinkJavaScript
@@ -625,7 +623,7 @@ LinkJavaScript::LinkJavaScript(const QRectF &linkArea, const QString &js) : Link
     d->js = js;
 }
 
-LinkJavaScript::~LinkJavaScript() { }
+LinkJavaScript::~LinkJavaScript() = default;
 
 Link::LinkType LinkJavaScript::linkType() const
 {
@@ -644,7 +642,7 @@ LinkMovie::LinkMovie(const QRectF &linkArea, Operation operation, const QString
 {
 }
 
-LinkMovie::~LinkMovie() { }
+LinkMovie::~LinkMovie() = default;
 
 Link::LinkType LinkMovie::linkType() const
 {
@@ -662,7 +660,8 @@ bool LinkMovie::isReferencedAnnotation(const MovieAnnotation *annotation) const
     Q_D(const LinkMovie);
     if (d->annotationReference != Ref::INVALID() && d->annotationReference == annotation->d_ptr->pdfObjectReference()) {
         return true;
-    } else if (!d->annotationTitle.isNull()) {
+    }
+    if (!d->annotationTitle.isNull()) {
         return (annotation->movieTitle() == d->annotationTitle);
     }
 
@@ -671,7 +670,7 @@ bool LinkMovie::isReferencedAnnotation(const MovieAnnotation *annotation) const
 
 LinkOCGState::LinkOCGState(LinkOCGStatePrivate *ocgp) : Link(*ocgp) { }
 
-LinkOCGState::~LinkOCGState() { }
+LinkOCGState::~LinkOCGState() = default;
 
 Link::LinkType LinkOCGState::linkType() const
 {
@@ -681,7 +680,7 @@ Link::LinkType LinkOCGState::linkType() const
 // LinkHide
 LinkHide::LinkHide(LinkHidePrivate *lhidep) : Link(*lhidep) { }
 
-LinkHide::~LinkHide() { }
+LinkHide::~LinkHide() = default;
 
 Link::LinkType LinkHide::linkType() const
 {
@@ -703,7 +702,7 @@ bool LinkHide::isShowAction() const
 // LinkResetForm
 LinkResetForm::LinkResetForm(LinkResetFormPrivate *lrfp) : Link(*lrfp) { }
 
-LinkResetForm::~LinkResetForm() { }
+LinkResetForm::~LinkResetForm() = default;
 
 Link::LinkType LinkResetForm::linkType() const
 {
@@ -729,7 +728,7 @@ static_assert(static_cast<int>(LinkSubmitForm::EmbedFormFlag) == static_cast<int
 
 LinkSubmitForm::LinkSubmitForm(LinkSubmitFormPrivate *lsfp) : Link(*lsfp) { }
 
-LinkSubmitForm::~LinkSubmitForm() { }
+LinkSubmitForm::~LinkSubmitForm() = default;
 
 Link::LinkType LinkSubmitForm::linkType() const
 {
