@@ -3,7 +3,7 @@
  * Copyright (C) 2007, Brad Hards <bradh@kde.org>
  * Copyright (C) 2008, 2014, Pino Toscano <pino@kde.org>
  * Copyright (C) 2008, Carlos Garcia Campos <carlosgc@gnome.org>
- * Copyright (C) 2015-2019, 2022, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2015-2019, 2022, 2025, Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2017, Hubert Figuière <hub@figuiere.net>
  * Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
  * Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
@@ -159,7 +159,7 @@ OptContentModelPrivate::OptContentModelPrivate(OptContentModel *qq, const OCGs *
     const auto &ocgs = optContent->getOCGs();
 
     for (const auto &ocg : ocgs) {
-        OptContentItem *node = new OptContentItem(ocg.second.get());
+        auto *node = new OptContentItem(ocg.second.get());
         m_optContentItems.insert(QString::number(ocg.first.num), node);
     }
 
@@ -205,7 +205,7 @@ void OptContentModelPrivate::parseOrderArray(OptContentItem *parentNode, const A
             parseOrderArray(lastItem, orderItem.getArray());
         } else if (orderItem.isString()) {
             const GooString *label = orderItem.getString();
-            OptContentItem *header = new OptContentItem(UnicodeParsedString(label));
+            auto *header = new OptContentItem(UnicodeParsedString(label));
             m_headerOptContentItems.append(header);
             addChild(parentNode, header);
             parentNode = header;
@@ -229,7 +229,7 @@ void OptContentModelPrivate::parseRBGroupsArray(const Array *rBGroupArray)
             return;
         }
         Array *rbarray = rbObj.getArray();
-        RadioButtonGroup *rbg = new RadioButtonGroup(this, rbarray);
+        auto *rbg = new RadioButtonGroup(this, rbarray);
         m_rbgroups.append(rbg);
     }
 }
@@ -292,12 +292,11 @@ int OptContentModel::rowCount(const QModelIndex &parent) const
     OptContentItem *parentNode = d->nodeFromIndex(parent);
     if (!parentNode) {
         return 0;
-    } else {
-        return parentNode->childList().count();
     }
+    return parentNode->childList().count();
 }
 
-int OptContentModel::columnCount(const QModelIndex &parent) const
+int OptContentModel::columnCount(const QModelIndex & /*parent*/) const
 {
     return 1;
 }
@@ -353,7 +352,7 @@ bool OptContentModel::setData(const QModelIndex &index, const QVariant &value, i
             }
             std::stable_sort(indexes.begin(), indexes.end()); // NOLINT(modernize-use-ranges) QModelIndexList doesn't support ranges requirements
             Q_FOREACH (const QModelIndex &changedIndex, indexes) {
-                emit dataChanged(changedIndex, changedIndex);
+                Q_EMIT dataChanged(changedIndex, changedIndex);
             }
             return true;
         }
@@ -414,7 +413,7 @@ void OptContentModel::applyLink(LinkOCGState *link)
         }
         std::stable_sort(indexes.begin(), indexes.end()); // NOLINT(modernize-use-ranges) Qt5 QModelIndexList doesn't support ranges requirements
         Q_FOREACH (const QModelIndex &changedIndex, indexes) {
-            emit dataChanged(changedIndex, changedIndex);
+            Q_EMIT dataChanged(changedIndex, changedIndex);
         }
     }
 }
@@ -433,8 +432,7 @@ OptContentItem *OptContentModelPrivate::nodeFromIndex(const QModelIndex &index,
 {
     if (index.isValid()) {
         return static_cast<OptContentItem *>(index.internalPointer());
-    } else {
-        return canBeNull ? nullptr : m_rootNode;
     }
+    return canBeNull ? nullptr : m_rootNode;
 }
 }
