@@ -28,7 +28,7 @@
  * Copyright (C) 2021 Hubert Figuiere <hub@figuiere.net>
  * Copyright (C) 2021 Thomas Huxhorn <thomas.huxhorn@web.de>
  * Copyright (C) 2023 Kevin Ottens <kevin.ottens@enioka.com>. Work sponsored by De Bortoli Wines
- * Copyright (C) 2024, 2025 Stefan Brüns <stefan.bruens@rwth-aachen.de>
+ * Copyright (C) 2024-2026 Stefan Brüns <stefan.bruens@rwth-aachen.de>
  * Copyright (C) 2024 Pratham Gandhi <ppg.1382@gmail.com>
  * Copyright (C) 2024, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
  *
@@ -116,8 +116,8 @@ public:
 class Qt5SplashOutputDev : public SplashOutputDev, public OutputDevCallbackHelper
 {
 public:
-    Qt5SplashOutputDev(SplashColorMode colorModeA, int bitmapRowPadA, bool reverseVideoA, bool ignorePaperColorA, SplashColorPtr paperColorA, bool bitmapTopDownA, SplashThinLineMode thinLineMode, bool overprintPreviewA)
-        : SplashOutputDev(colorModeA, bitmapRowPadA, reverseVideoA, paperColorA, bitmapTopDownA, thinLineMode, overprintPreviewA), ignorePaperColor(ignorePaperColorA)
+    Qt5SplashOutputDev(SplashColorMode colorModeA, int bitmapRowPadA, bool ignorePaperColorA, SplashColorPtr paperColorA, bool bitmapTopDownA, SplashThinLineMode thinLineMode, bool overprintPreviewA)
+        : SplashOutputDev(colorModeA, bitmapRowPadA, paperColorA, bitmapTopDownA, thinLineMode, overprintPreviewA), ignorePaperColor(ignorePaperColorA)
     {
     }
 
@@ -166,9 +166,8 @@ public:
                     gfree(data);
                 }
                 return i;
-            } else {
-                return QImage(data, bw, bh, brs, format).copy();
             }
+            return QImage(data, bw, bh, brs, format).copy();
         }
 
         return QImage();
@@ -199,7 +198,7 @@ private:
 
 QImageDumpingQPainterOutputDev::~QImageDumpingQPainterOutputDev() = default;
 
-Link *PageData::convertLinkActionToLink(::LinkAction *a, const QRectF &linkArea)
+Link *PageData::convertLinkActionToLink(::LinkAction *a, const QRectF &linkArea) const
 {
     return convertLinkActionToLink(a, parentDoc, linkArea);
 }
@@ -213,14 +212,14 @@ Link *PageData::convertLinkActionToLink(::LinkAction *a, DocumentData *parentDoc
     Link *popplerLink = nullptr;
     switch (a->getKind()) {
     case actionGoTo: {
-        LinkGoTo *g = (LinkGoTo *)a;
+        auto *g = (LinkGoTo *)a;
         const LinkDestinationData ldd(g->getDest(), g->getNamedDest(), parentDoc, false);
         // create link: no ext file, namedDest, object pointer
         popplerLink = new LinkGoto(linkArea, QString(), LinkDestination(ldd));
     } break;
 
     case actionGoToR: {
-        LinkGoToR *g = (LinkGoToR *)a;
+        auto *g = (LinkGoToR *)a;
         // copy link file
         const QString fileName = UnicodeParsedString(g->getFileName());
         const LinkDestinationData ldd(g->getDest(), g->getNamedDest(), parentDoc, !fileName.isEmpty());
@@ -229,7 +228,7 @@ Link *PageData::convertLinkActionToLink(::LinkAction *a, DocumentData *parentDoc
     } break;
 
     case actionLaunch: {
-        LinkLaunch *e = (LinkLaunch *)a;
+        auto *e = (LinkLaunch *)a;
         const GooString *p = e->getParams();
         popplerLink = new LinkExecute(linkArea, UnicodeParsedString(e->getFileName()), p ? QString::fromStdString(p->toStr()) : QString {});
     } break;
@@ -275,17 +274,17 @@ Link *PageData::convertLinkActionToLink(::LinkAction *a, DocumentData *parentDoc
     } break;
 
     case actionSound: {
-        ::LinkSound *ls = (::LinkSound *)a;
+        auto *ls = (::LinkSound *)a;
         popplerLink = new LinkSound(linkArea, ls->getVolume(), ls->getSynchronous(), ls->getRepeat(), ls->getMix(), new SoundObject(ls->getSound()));
     } break;
 
     case actionJavaScript: {
-        ::LinkJavaScript *ljs = (::LinkJavaScript *)a;
+        auto *ljs = (::LinkJavaScript *)a;
         popplerLink = new LinkJavaScript(linkArea, UnicodeParsedString(ljs->getScript()));
     } break;
 
     case actionMovie: {
-        ::LinkMovie *lm = (::LinkMovie *)a;
+        auto *lm = (::LinkMovie *)a;
 
         const QString title = (lm->hasAnnotTitle() ? UnicodeParsedString(lm->getAnnotTitle()) : QString());
 
@@ -314,7 +313,7 @@ Link *PageData::convertLinkActionToLink(::LinkAction *a, DocumentData *parentDoc
     } break;
 
     case actionRendition: {
-        ::LinkRendition *lrn = (::LinkRendition *)a;
+        auto *lrn = (::LinkRendition *)a;
 
         Ref reference = Ref::INVALID();
         if (lrn->hasScreenAnnot()) {
@@ -325,31 +324,31 @@ Link *PageData::convertLinkActionToLink(::LinkAction *a, DocumentData *parentDoc
     } break;
 
     case actionOCGState: {
-        ::LinkOCGState *plocg = (::LinkOCGState *)a;
+        auto *plocg = (::LinkOCGState *)a;
 
-        LinkOCGStatePrivate *locgp = new LinkOCGStatePrivate(linkArea, plocg->getStateList(), plocg->getPreserveRB());
+        auto *locgp = new LinkOCGStatePrivate(linkArea, plocg->getStateList(), plocg->getPreserveRB());
         popplerLink = new LinkOCGState(locgp);
     } break;
 
     case actionHide: {
-        ::LinkHide *lh = (::LinkHide *)a;
+        auto *lh = (::LinkHide *)a;
 
-        LinkHidePrivate *lhp = new LinkHidePrivate(linkArea, lh->hasTargetName() ? UnicodeParsedString(lh->getTargetName()) : QString(), lh->isShowAction());
+        auto *lhp = new LinkHidePrivate(linkArea, lh->hasTargetName() ? UnicodeParsedString(lh->getTargetName()) : QString(), lh->isShowAction());
         popplerLink = new LinkHide(lhp);
     } break;
 
     case actionResetForm: {
-        ::LinkResetForm *lrf = (::LinkResetForm *)a;
+        auto *lrf = (::LinkResetForm *)a;
         std::vector<std::string> stdStringFields = lrf->getFields();
         QStringList qStringFields;
         for (const std::string &str : stdStringFields) {
             qStringFields << QString::fromStdString(str);
         }
-        LinkResetFormPrivate *lrfp = new LinkResetFormPrivate(linkArea, qStringFields, lrf->getExclude());
+        auto *lrfp = new LinkResetFormPrivate(linkArea, qStringFields, lrf->getExclude());
         popplerLink = new LinkResetForm(lrfp);
     } break;
     case actionSubmitForm: {
-        ::LinkSubmitForm *lsf = (::LinkSubmitForm *)a;
+        auto *lsf = (::LinkSubmitForm *)a;
         const std::vector<std::string> &stdStringFields = lsf->getFields();
         QVector<int> fieldIds;
         fieldIds.reserve(stdStringFields.size());
@@ -367,8 +366,8 @@ Link *PageData::convertLinkActionToLink(::LinkAction *a, DocumentData *parentDoc
             }
         }
         QString qStringUrl = QString::fromStdString(lsf->getUrl());
-        LinkSubmitForm::SubmitFormFlags qFlags = static_cast<LinkSubmitForm::SubmitFormFlags>(lsf->getFlags());
-        LinkSubmitFormPrivate *lsfp = new LinkSubmitFormPrivate(linkArea, fieldIds, qStringUrl, qFlags);
+        auto qFlags = static_cast<LinkSubmitForm::SubmitFormFlags>(lsf->getFlags());
+        auto *lsfp = new LinkSubmitFormPrivate(linkArea, fieldIds, qStringUrl, qFlags);
         popplerLink = new LinkSubmitForm(lsfp);
     } break;
 
@@ -387,7 +386,7 @@ Link *PageData::convertLinkActionToLink(::LinkAction *a, DocumentData *parentDoc
     return popplerLink;
 }
 
-inline TextPage *PageData::prepareTextSearch(const QString &text, Page::Rotation rotate, QVector<Unicode> *u)
+inline std::unique_ptr<TextPage> PageData::prepareTextSearch(const QString &text, Page::Rotation rotate, QVector<Unicode> *u) const
 {
     *u = text.toUcs4();
 
@@ -396,7 +395,7 @@ inline TextPage *PageData::prepareTextSearch(const QString &text, Page::Rotation
     // fetch ourselves a textpage
     TextOutputDev td(nullptr, true, 0, false, false);
     parentDoc->doc->displayPage(&td, index + 1, 72, 72, rotation, false, true, false, nullptr, nullptr, nullptr, nullptr, true);
-    TextPage *textPage = td.takeText();
+    std::unique_ptr<TextPage> textPage = td.takeText();
 
     return textPage;
 }
@@ -406,9 +405,11 @@ inline bool PageData::performSingleTextSearch(TextPage *textPage, QVector<Unicod
 {
     if (direction == Page::FromTop) {
         return textPage->findText(u.data(), u.size(), true, true, false, false, sCase, sDiacritics, sAcrossLines, false, sWords, &sLeft, &sTop, &sRight, &sBottom, nullptr, nullptr);
-    } else if (direction == Page::NextResult) {
+    }
+    if (direction == Page::NextResult) {
         return textPage->findText(u.data(), u.size(), false, true, true, false, sCase, sDiacritics, sAcrossLines, false, sWords, &sLeft, &sTop, &sRight, &sBottom, nullptr, nullptr);
-    } else if (direction == Page::PreviousResult) {
+    }
+    if (direction == Page::PreviousResult) {
         return textPage->findText(u.data(), u.size(), false, true, true, false, sCase, sDiacritics, sAcrossLines, true, sWords, &sLeft, &sTop, &sRight, &sBottom, nullptr, nullptr);
     }
 
@@ -475,12 +476,12 @@ static auto annotDisplayDecideCbk = [](Annot *annot, void * /*user_data*/) {
 static bool (*nullAnnotCallBack)(Annot *annot, void *user_data) = nullptr;
 
 static auto shouldAbortRenderInternalCallback = [](void *user_data) {
-    OutputDevCallbackHelper *helper = reinterpret_cast<OutputDevCallbackHelper *>(user_data);
+    auto *helper = reinterpret_cast<OutputDevCallbackHelper *>(user_data);
     return helper->shouldAbortRenderCallback(helper->payload);
 };
 
 static auto shouldAbortExtractionInternalCallback = [](void *user_data) {
-    TextExtractionAbortHelper *helper = reinterpret_cast<TextExtractionAbortHelper *>(user_data);
+    auto *helper = reinterpret_cast<TextExtractionAbortHelper *>(user_data);
     return helper->shouldAbortExtractionCallback(helper->payload);
 };
 
@@ -502,7 +503,7 @@ static bool renderToQPainter(QImageDumpingQPainterOutputDev *qpainter_output, QP
     }
     painter->translate(x == -1 ? 0 : -x, y == -1 ? 0 : -y);
 
-    qpainter_output->startDoc(page->parentDoc->doc);
+    qpainter_output->startDoc(page->parentDoc->doc.get());
 
     const bool hideAnnotations = page->parentDoc->m_hints & Document::HideAnnotations;
 
@@ -546,7 +547,7 @@ QImage Page::renderToImage(double xres, double yres, int xPos, int yPos, int w,
     switch (m_page->parentDoc->m_backend) {
     case Poppler::Document::SplashBackend: {
         SplashColor bgColor;
-        const bool overprintPreview = m_page->parentDoc->m_hints & Document::OverprintPreview ? true : false;
+        const bool overprintPreview = (m_page->parentDoc->m_hints & Document::OverprintPreview) != 0;
         if (overprintPreview) {
             unsigned char c, m, y, k;
 
@@ -585,19 +586,19 @@ QImage Page::renderToImage(double xres, double yres, int xPos, int yPos, int w,
 
         const bool ignorePaperColor = m_page->parentDoc->m_hints & Document::IgnorePaperColor;
 
-        Qt5SplashOutputDev splash_output(colorMode, 4, false, ignorePaperColor, ignorePaperColor ? nullptr : bgColor, true, thinLineMode, overprintPreview);
+        Qt5SplashOutputDev splash_output(colorMode, 4, ignorePaperColor, ignorePaperColor ? nullptr : bgColor, true, thinLineMode, overprintPreview);
 
         splash_output.setCallbacks(partialUpdateCallback, shouldDoPartialUpdateCallback, shouldAbortRenderCallback, payload);
 
-        splash_output.setFontAntialias(m_page->parentDoc->m_hints & Document::TextAntialiasing ? true : false);
-        splash_output.setVectorAntialias(m_page->parentDoc->m_hints & Document::Antialiasing ? true : false);
-        splash_output.setFreeTypeHinting(m_page->parentDoc->m_hints & Document::TextHinting ? true : false, m_page->parentDoc->m_hints & Document::TextSlightHinting ? true : false);
+        splash_output.setFontAntialias((m_page->parentDoc->m_hints & Document::TextAntialiasing) != 0);
+        splash_output.setVectorAntialias((m_page->parentDoc->m_hints & Document::Antialiasing) != 0);
+        splash_output.setFreeTypeHinting((m_page->parentDoc->m_hints & Document::TextHinting) != 0, (m_page->parentDoc->m_hints & Document::TextSlightHinting) != 0);
 
 #if USE_CMS
         splash_output.setDisplayProfile(m_page->parentDoc->m_displayProfile);
 #endif
 
-        splash_output.startDoc(m_page->parentDoc->doc);
+        splash_output.startDoc(m_page->parentDoc->doc.get());
 
         const bool hideAnnotations = m_page->parentDoc->m_hints & Document::HideAnnotations;
 
@@ -688,12 +689,7 @@ QString Page::text(const QRectF &r, TextLayout textLayout) const
     output_dev = new TextOutputDev(nullptr, physLayout, 0, rawOrder, false);
     m_page->parentDoc->doc->displayPageSlice(output_dev, m_page->index + 1, 72, 72, 0, false, true, false, -1, -1, -1, -1, nullptr, nullptr, nullptr, nullptr, true);
     if (r.isNull()) {
-        const PDFRectangle *rect = m_page->page->getCropBox();
-        if (orientation() == Orientation::Portrait || orientation() == Orientation::UpsideDown) {
-            s = output_dev->getText(*rect);
-        } else {
-            s = output_dev->getText(PDFRectangle { rect->y1, rect->x1, rect->y2, rect->x2 });
-        }
+        s = output_dev->getText(std::nullopt);
     } else {
         if (textLayout == ReadingOrder) {
             qWarning() << "ReadingOrder is not supported with non null rect";
@@ -715,62 +711,54 @@ QString Page::text(const QRectF &r) const
 
 bool Page::search(const QString &text, double &sLeft, double &sTop, double &sRight, double &sBottom, SearchDirection direction, SearchMode caseSensitive, Rotation rotate) const
 {
-    const bool sCase = caseSensitive == Page::CaseSensitive ? true : false;
+    const bool sCase = caseSensitive == Page::CaseSensitive;
 
     QVector<Unicode> u;
-    TextPage *textPage = m_page->prepareTextSearch(text, rotate, &u);
+    std::unique_ptr<TextPage> textPage = m_page->prepareTextSearch(text, rotate, &u);
 
-    const bool found = m_page->performSingleTextSearch(textPage, u, sLeft, sTop, sRight, sBottom, direction, sCase, false, false, false);
-
-    textPage->decRefCnt();
+    const bool found = Poppler::PageData::performSingleTextSearch(textPage.get(), u, sLeft, sTop, sRight, sBottom, direction, sCase, false, false, false);
 
     return found;
 }
 
 bool Page::search(const QString &text, double &sLeft, double &sTop, double &sRight, double &sBottom, SearchDirection direction, SearchFlags flags, Rotation rotate) const
 {
-    const bool sCase = flags.testFlag(IgnoreCase) ? false : true;
-    const bool sWords = flags.testFlag(WholeWords) ? true : false;
-    const bool sDiacritics = flags.testFlag(IgnoreDiacritics) ? true : false;
-    const bool sAcrossLines = flags.testFlag(AcrossLines) ? true : false;
+    const bool sCase = !flags.testFlag(IgnoreCase);
+    const bool sWords = flags.testFlag(WholeWords);
+    const bool sDiacritics = flags.testFlag(IgnoreDiacritics);
+    const bool sAcrossLines = flags.testFlag(AcrossLines);
 
     QVector<Unicode> u;
-    TextPage *textPage = m_page->prepareTextSearch(text, rotate, &u);
+    std::unique_ptr<TextPage> textPage = m_page->prepareTextSearch(text, rotate, &u);
 
-    const bool found = m_page->performSingleTextSearch(textPage, u, sLeft, sTop, sRight, sBottom, direction, sCase, sWords, sDiacritics, sAcrossLines);
-
-    textPage->decRefCnt();
+    const bool found = Poppler::PageData::performSingleTextSearch(textPage.get(), u, sLeft, sTop, sRight, sBottom, direction, sCase, sWords, sDiacritics, sAcrossLines);
 
     return found;
 }
 
 QList<QRectF> Page::search(const QString &text, SearchMode caseSensitive, Rotation rotate) const
 {
-    const bool sCase = caseSensitive == Page::CaseSensitive ? true : false;
+    const bool sCase = caseSensitive == Page::CaseSensitive;
 
     QVector<Unicode> u;
-    TextPage *textPage = m_page->prepareTextSearch(text, rotate, &u);
+    std::unique_ptr<TextPage> textPage = m_page->prepareTextSearch(text, rotate, &u);
 
-    const QList<QRectF> results = m_page->performMultipleTextSearch(textPage, u, sCase, false, false, false);
-
-    textPage->decRefCnt();
+    const QList<QRectF> results = Poppler::PageData::performMultipleTextSearch(textPage.get(), u, sCase, false, false, false);
 
     return results;
 }
 
 QList<QRectF> Page::search(const QString &text, SearchFlags flags, Rotation rotate) const
 {
-    const bool sCase = flags.testFlag(IgnoreCase) ? false : true;
-    const bool sWords = flags.testFlag(WholeWords) ? true : false;
-    const bool sDiacritics = flags.testFlag(IgnoreDiacritics) ? true : false;
-    const bool sAcrossLines = flags.testFlag(AcrossLines) ? true : false;
+    const bool sCase = !flags.testFlag(IgnoreCase);
+    const bool sWords = flags.testFlag(WholeWords);
+    const bool sDiacritics = flags.testFlag(IgnoreDiacritics);
+    const bool sAcrossLines = flags.testFlag(AcrossLines);
 
     QVector<Unicode> u;
-    TextPage *textPage = m_page->prepareTextSearch(text, rotate, &u);
+    std::unique_ptr<TextPage> textPage = m_page->prepareTextSearch(text, rotate, &u);
 
-    const QList<QRectF> results = m_page->performMultipleTextSearch(textPage, u, sCase, sWords, sDiacritics, sAcrossLines);
-
-    textPage->decRefCnt();
+    const QList<QRectF> results = Poppler::PageData::performMultipleTextSearch(textPage.get(), u, sCase, sWords, sDiacritics, sAcrossLines);
 
     return results;
 }
@@ -808,8 +796,8 @@ QList<TextBox *> Page::textList(Rotation rotate, ShouldAbortQueryFunc shouldAbor
         double xMin, yMin, xMax, yMax;
         word->getBBox(&xMin, &yMin, &xMax, &yMax);
 
-        TextBox *text_box = new TextBox(string, QRectF(xMin, yMin, xMax - xMin, yMax - yMin));
-        text_box->m_data->hasSpaceAfter = word->hasSpaceAfter() == true;
+        auto *text_box = new TextBox(string, QRectF(xMin, yMin, xMax - xMin, yMax - yMin));
+        text_box->m_data->hasSpaceAfter = word->hasSpaceAfter();
         text_box->m_data->charBBoxes.reserve(word->getLength());
         for (int j = 0; j < word->getLength(); ++j) {
             word->getCharBBox(j, &xMin, &yMin, &xMax, &yMax);
@@ -867,9 +855,8 @@ QSizeF Page::pageSizeF() const
     Page::Orientation orient = orientation();
     if ((Page::Landscape == orient) || (Page::Seascape == orient)) {
         return QSizeF(m_page->page->getCropHeight(), m_page->page->getCropWidth());
-    } else {
-        return QSizeF(m_page->page->getCropWidth(), m_page->page->getCropHeight());
     }
+    return QSizeF(m_page->page->getCropWidth(), m_page->page->getCropHeight());
 }
 
 QSize Page::pageSize() const
