@@ -8,7 +8,7 @@
  * Copyright (C) 2021, Georgiy Sgibnev <georgiy@sgibnev.com>. Work sponsored by lab50.net.
  * Copyright (C) 2022, Martin <martinbts@gmx.net>
  * Copyright (C) 2022, Felix Jung <fxjung@posteo.de>
- * Copyright (C) 2024, 2025, g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+ * Copyright (C) 2024-2026, g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -91,7 +91,7 @@ bool PDFConverter::convert()
     }
 
     bool deleteFile = false;
-    if (QFile *file = qobject_cast<QFile *>(dev)) {
+    if (auto *file = qobject_cast<QFile *>(dev)) {
         deleteFile = !file->exists();
     }
 
@@ -132,7 +132,7 @@ bool PDFConverter::sign(const NewSignatureData &data)
         return false;
     }
 
-    ::PDFDoc *doc = d->document->doc;
+    ::PDFDoc *doc = d->document->doc.get();
     ::Page *destPage = doc->getPage(data.page() + 1);
     std::unique_ptr<GooString> gSignatureText = std::unique_ptr<GooString>(QStringToUnicodeGooString(data.signatureText()));
     std::unique_ptr<GooString> gSignatureLeftText = std::unique_ptr<GooString>(QStringToUnicodeGooString(data.signatureLeftText()));
@@ -169,11 +169,10 @@ bool PDFConverter::sign(const NewSignatureData &data)
             break;
         }
         return false;
-    } else {
-        d->lastSigningErrorDetails = {};
-        d->lastSigningResult = SigningSuccess;
-        return true;
     }
+    d->lastSigningErrorDetails = {};
+    d->lastSigningResult = SigningSuccess;
+    return true;
 }
 
 ErrorString PDFConverter::lastSigningErrorDetails() const
