@@ -11,11 +11,11 @@ class TestInternalOutline : public QObject
 public:
     explicit TestInternalOutline(QObject *parent = nullptr) : QObject(parent) { }
 private Q_SLOTS:
-    void testCreateOutline();
-    void testSetOutline();
-    void testInsertChild();
-    void testRemoveChild();
-    void testSetTitleAndSetPageDest();
+    static void testCreateOutline();
+    static void testSetOutline();
+    static void testInsertChild();
+    static void testRemoveChild();
+    static void testSetTitleAndSetPageDest();
 };
 
 void TestInternalOutline::testCreateOutline()
@@ -32,7 +32,7 @@ void TestInternalOutline::testCreateOutline()
     // ensure the file has no existing outline
     Outline *outline = doc->getOutline();
     QVERIFY(outline != nullptr);
-    auto *outlineItems = outline->getItems();
+    const auto *outlineItems = outline->getItems();
     QVERIFY(outlineItems == nullptr);
 
     // create an empty outline and save the file
@@ -79,7 +79,7 @@ void TestInternalOutline::testSetOutline()
     // ensure the file has no existing outline
     Outline *outline = doc->getOutline();
     QVERIFY(outline != nullptr);
-    auto *outlineItems = outline->getItems();
+    const auto *outlineItems = outline->getItems();
     QVERIFY(outlineItems == nullptr);
 
     // create an outline and save the file
@@ -169,7 +169,7 @@ void TestInternalOutline::testInsertChild()
     // ensure the file has no existing outline
     Outline *outline = doc->getOutline();
     QVERIFY(outline != nullptr);
-    auto *outlineItems = outline->getItems();
+    const auto *outlineItems = outline->getItems();
     QVERIFY(outlineItems == nullptr);
 
     // create an outline and save the file
@@ -271,7 +271,7 @@ void TestInternalOutline::testRemoveChild()
     // ensure the file has no existing outline
     Outline *outline = doc->getOutline();
     QVERIFY(outline != nullptr);
-    auto *outlineItems = outline->getItems();
+    const auto *outlineItems = outline->getItems();
     QVERIFY(outlineItems == nullptr);
 
     // create an outline and save the file
@@ -365,7 +365,7 @@ void TestInternalOutline::testSetTitleAndSetPageDest()
     // ensure the file has no existing outline
     Outline *outline = doc->getOutline();
     QVERIFY(outline != nullptr);
-    auto *outlineItems = outline->getItems();
+    const auto *outlineItems = outline->getItems();
     QVERIFY(outlineItems == nullptr);
 
     // create an outline and save the file
@@ -398,7 +398,7 @@ void TestInternalOutline::testSetTitleAndSetPageDest()
     {
         const LinkAction *action = item->getAction();
         QVERIFY(action->getKind() == actionGoTo);
-        const LinkGoTo *gotoAction = dynamic_cast<const LinkGoTo *>(action);
+        const auto *gotoAction = dynamic_cast<const LinkGoTo *>(action);
         const LinkDest *dest = gotoAction->getDest();
         QVERIFY(dest->isPageRef() == false);
         QCOMPARE(dest->getPageNum(), 3);
@@ -426,7 +426,7 @@ void TestInternalOutline::testSetTitleAndSetPageDest()
         item = outline->getItems()->at(2);
         const LinkAction *action = item->getAction();
         QVERIFY(action->getKind() == actionGoTo);
-        const LinkGoTo *gotoAction = dynamic_cast<const LinkGoTo *>(action);
+        const auto *gotoAction = dynamic_cast<const LinkGoTo *>(action);
         const LinkDest *dest = gotoAction->getDest();
         QVERIFY(dest->isPageRef() == false);
         QCOMPARE(dest->getPageNum(), 1);
