@@ -11,13 +11,13 @@ class TestPageLabelInfo : public QObject
     Q_OBJECT
 public:
     explicit TestPageLabelInfo(QObject *parent = nullptr) : QObject(parent) { }
-private slots:
-    void testFromDecimal();
-    void testFromDecimalUnicode();
-    void testToRoman();
-    void testFromRoman();
-    void testToLatin();
-    void testFromLatin();
+private Q_SLOTS:
+    static void testFromDecimal();
+    static void testFromDecimalUnicode();
+    static void testToRoman();
+    static void testFromRoman();
+    static void testToLatin();
+    static void testFromLatin();
 };
 
 void TestPageLabelInfo::testFromDecimal()
