@@ -1,4 +1,4 @@
-#include <QtTest/QtTest>
+#include <QtTest/QTest>
 
 #include <poppler-qt5.h>
 
@@ -7,16 +7,16 @@ class TestPageLayout : public QObject
     Q_OBJECT
 public:
     explicit TestPageLayout(QObject *parent = nullptr) : QObject(parent) { }
-private slots:
-    void checkNone();
-    void checkSingle();
-    void checkFacing();
+private Q_SLOTS:
+    static void checkNone();
+    static void checkSingle();
+    static void checkFacing();
 };
 
 void TestPageLayout::checkNone()
 {
     Poppler::Document *doc;
-    doc = Poppler::Document::load(TESTDATADIR "/unittestcases/UseNone.pdf");
+    doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/UseNone.pdf"));
     QVERIFY(doc);
 
     QCOMPARE(doc->pageLayout(), Poppler::Document::NoLayout);
@@ -27,7 +27,7 @@ void TestPageLayout::checkNone()
 void TestPageLayout::checkSingle()
 {
     Poppler::Document *doc;
-    doc = Poppler::Document::load(TESTDATADIR "/unittestcases/FullScreen.pdf");
+    doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/FullScreen.pdf"));
     QVERIFY(doc);
 
     QCOMPARE(doc->pageLayout(), Poppler::Document::SinglePage);
@@ -38,7 +38,7 @@ void TestPageLayout::checkSingle()
 void TestPageLayout::checkFacing()
 {
     Poppler::Document *doc;
-    doc = Poppler::Document::load(TESTDATADIR "/unittestcases/doublepage.pdf");
+    doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/doublepage.pdf"));
     QVERIFY(doc);
 
     QCOMPARE(doc->pageLayout(), Poppler::Document::TwoPageRight);
