@@ -7,14 +7,14 @@ class TestPermissions : public QObject
     Q_OBJECT
 public:
     explicit TestPermissions(QObject *parent = nullptr) : QObject(parent) { }
-private slots:
-    void permissions1();
+private Q_SLOTS:
+    static void permissions1();
 };
 
 void TestPermissions::permissions1()
 {
     Poppler::Document *doc;
-    doc = Poppler::Document::load(TESTDATADIR "/unittestcases/orientation.pdf");
+    doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/orientation.pdf"));
     QVERIFY(doc);
 
     // we are allowed to print
