@@ -12,9 +12,9 @@ class TestStrokeOpacity : public QObject
     Q_OBJECT
 public:
     explicit TestStrokeOpacity(QObject *parent = nullptr) : QObject(parent) { }
-private slots:
-    void checkStrokeOpacity_data();
-    void checkStrokeOpacity();
+private Q_SLOTS:
+    static void checkStrokeOpacity_data();
+    static void checkStrokeOpacity();
 };
 
 void TestStrokeOpacity::checkStrokeOpacity_data()
@@ -29,7 +29,7 @@ void TestStrokeOpacity::checkStrokeOpacity()
 {
     QFETCH(int, backendType);
 
-    auto doc = std::unique_ptr<Poppler::Document>(Poppler::Document::load(TESTDATADIR "/unittestcases/stroke-alpha-pattern.pdf"));
+    auto doc = std::unique_ptr<Poppler::Document>(Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/stroke-alpha-pattern.pdf")));
     QVERIFY(doc != nullptr);
 
     doc->setRenderBackend((Poppler::Document::RenderBackend)backendType);
