@@ -15,11 +15,11 @@ class TestUTFConversion : public QObject
     Q_OBJECT
 public:
     explicit TestUTFConversion(QObject *parent = nullptr) : QObject(parent) { }
-private slots:
-    void testUTF_data();
-    void testUTF();
-    void testUnicodeToAscii7();
-    void testUnicodeLittleEndian();
+private Q_SLOTS:
+    static void testUTF_data();
+    static void testUTF();
+    static void testUnicodeToAscii7();
+    static void testUnicodeLittleEndian();
 };
 
 static bool compare(const Unicode *a, const char *b, int len)
@@ -81,7 +81,7 @@ void TestUTFConversion::testUTF()
 
     std::string gsUtf16_a(utf8ToUtf16WithBom(str));
     std::unique_ptr<GooString> gsUtf16_b(Poppler::QStringToUnicodeGooString(s));
-    QCOMPARE(gsUtf16_b->cmp(gsUtf16_a), 0);
+    QCOMPARE(gsUtf16_b->compare(gsUtf16_a), 0);
 
     // UTF-16 to UTF-8
 
