@@ -11,12 +11,12 @@ class PDFDisplay : public QWidget // picture display widget
 {
     Q_OBJECT
 public:
-    PDFDisplay(Poppler::Document *d, QWidget *parent = nullptr);
+    explicit PDFDisplay(Poppler::Document *d, QWidget *parent = nullptr);
     ~PDFDisplay() override;
 
 protected:
-    void paintEvent(QPaintEvent *) override;
-    void keyPressEvent(QKeyEvent *) override;
+    void paintEvent(QPaintEvent *event) override;
+    void keyPressEvent(QKeyEvent *e) override;
 
 private:
     void display();
@@ -52,7 +52,7 @@ PDFDisplay::~PDFDisplay()
     delete doc;
 }
 
-void PDFDisplay::paintEvent(QPaintEvent *e)
+void PDFDisplay::paintEvent(QPaintEvent * /*e*/)
 {
     QPainter paint(this); // paint widget
     if (!image.isNull()) {
@@ -88,7 +88,7 @@ int main(int argc, char **argv)
         exit(1);
     }
 
-    Poppler::Document *doc = Poppler::Document::load(argv[2], argv[1]);
+    Poppler::Document *doc = Poppler::Document::load(QString::fromLocal8Bit(argv[2]), argv[1]);
     if (!doc) {
         qWarning() << "doc not loaded";
         exit(1);
@@ -114,7 +114,7 @@ int main(int argc, char **argv)
     qDebug() << "OK to add notes: " << doc->okToAddNotes();
     qDebug() << "      Page mode: " << doc->pageMode();
     QStringList fontNameList;
-    foreach (const Poppler::FontInfo &font, doc->fonts())
+    Q_FOREACH (const Poppler::FontInfo &font, doc->fonts())
         fontNameList += font.name();
     qDebug() << "          Fonts: " << fontNameList.join(QStringLiteral(", "));
 
@@ -125,7 +125,7 @@ int main(int argc, char **argv)
     test.setWindowTitle(QStringLiteral("Poppler-Qt5 Test"));
     test.show(); // show it
 
-    return a.exec(); // start event loop
+    return QApplication::exec(); // start event loop
 }
 
 #include "test-password-qt5.moc"
