@@ -3,6 +3,8 @@
  * Copyright (C) 2008, 2019, 2020, Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2009, Shawn Rutledge <shawn.t.rutledge@gmail.com>
  * Copyright (C) 2013, Fabio D'Urso <fabiodurso@hotmail.it>
+ * Copyright (C) 2020, 2021, Oliver Sander <oliver.sander@tu-dresden.de>
+ * Copyright (C) 2021, Mahmoud Khalil <mahmoudkhalil11@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,7 +46,9 @@
 #include <QMenuBar>
 #include <QMessageBox>
 
-PdfViewer::PdfViewer(QWidget *parent) : QMainWindow(parent), m_currentPage(0), m_doc(nullptr)
+#include <functional>
+
+PdfViewer::PdfViewer(QWidget *parent) : QMainWindow(parent), m_doc(nullptr)
 {
     setWindowTitle(tr("Poppler-Qt6 Demo"));
 
@@ -77,7 +81,7 @@ PdfViewer::PdfViewer(QWidget *parent) : QMainWindow(parent), m_currentPage(0), m
     act->setChecked(true);
     act->setData(QVariant::fromValue(0));
     m_settingsRenderBackendGrp->addAction(act);
-    act = settingsRenderMenu->addAction(tr("Arthur"));
+    act = settingsRenderMenu->addAction(tr("QPainter"));
     act->setCheckable(true);
     act->setData(QVariant::fromValue(1));
     m_settingsRenderBackendGrp->addAction(act);
@@ -87,57 +91,57 @@ PdfViewer::PdfViewer(QWidget *parent) : QMainWindow(parent), m_currentPage(0), m
     act = helpMenu->addAction(tr("&About"), this, &PdfViewer::slotAbout);
     act = helpMenu->addAction(tr("About &Qt"), this, &PdfViewer::slotAboutQt);
 
-    NavigationToolBar *navbar = new NavigationToolBar(this);
+    auto *navbar = new NavigationToolBar(this);
     addToolBar(navbar);
     m_observers.append(navbar);
 
-    PageView *view = new PageView(this);
+    auto *view = new PageView(this);
     setCentralWidget(view);
     m_observers.append(view);
 
-    InfoDock *infoDock = new InfoDock(this);
+    auto *infoDock = new InfoDock(this);
     addDockWidget(Qt::LeftDockWidgetArea, infoDock);
     infoDock->hide();
     viewMenu->addAction(infoDock->toggleViewAction());
     m_observers.append(infoDock);
 
-    TocDock *tocDock = new TocDock(this);
+    auto *tocDock = new TocDock(this);
     addDockWidget(Qt::LeftDockWidgetArea, tocDock);
     tocDock->hide();
     viewMenu->addAction(tocDock->toggleViewAction());
     m_observers.append(tocDock);
 
-    FontsDock *fontsDock = new FontsDock(this);
+    auto *fontsDock = new FontsDock(this);
     addDockWidget(Qt::LeftDockWidgetArea, fontsDock);
     fontsDock->hide();
     viewMenu->addAction(fontsDock->toggleViewAction());
     m_observers.append(fontsDock);
 
-    PermissionsDock *permissionsDock = new PermissionsDock(this);
+    auto *permissionsDock = new PermissionsDock(this);
     addDockWidget(Qt::LeftDockWidgetArea, permissionsDock);
     permissionsDock->hide();
     viewMenu->addAction(permissionsDock->toggleViewAction());
     m_observers.append(permissionsDock);
 
-    ThumbnailsDock *thumbnailsDock = new ThumbnailsDock(this);
+    auto *thumbnailsDock = new ThumbnailsDock(this);
     addDockWidget(Qt::LeftDockWidgetArea, thumbnailsDock);
     thumbnailsDock->hide();
     viewMenu->addAction(thumbnailsDock->toggleViewAction());
     m_observers.append(thumbnailsDock);
 
-    EmbeddedFilesDock *embfilesDock = new EmbeddedFilesDock(this);
+    auto *embfilesDock = new EmbeddedFilesDock(this);
     addDockWidget(Qt::BottomDockWidgetArea, embfilesDock);
     embfilesDock->hide();
     viewMenu->addAction(embfilesDock->toggleViewAction());
     m_observers.append(embfilesDock);
 
-    MetadataDock *metadataDock = new MetadataDock(this);
+    auto *metadataDock = new MetadataDock(this);
     addDockWidget(Qt::BottomDockWidgetArea, metadataDock);
     metadataDock->hide();
     viewMenu->addAction(metadataDock->toggleViewAction());
     m_observers.append(metadataDock);
 
-    OptContentDock *optContentDock = new OptContentDock(this);
+    auto *optContentDock = new OptContentDock(this);
     addDockWidget(Qt::LeftDockWidgetArea, optContentDock);
     optContentDock->hide();
     viewMenu->addAction(optContentDock->toggleViewAction());
@@ -167,7 +171,9 @@ QSize PdfViewer::sizeHint() const
 
 void PdfViewer::loadDocument(const QString &file)
 {
-    Poppler::Document *newdoc = Poppler::Document::load(file);
+    // resetting xrefReconstructed each time we load new document
+    xrefReconstructed = false;
+    std::unique_ptr<Poppler::Document> newdoc = Poppler::Document::load(file);
     if (!newdoc) {
         QMessageBox msgbox(QMessageBox::Critical, tr("Open Error"), tr("Cannot open:\n") + file, QMessageBox::Ok, this);
         msgbox.exec();
@@ -178,7 +184,6 @@ void PdfViewer::loadDocument(const QString &file)
         bool ok = true;
         QString password = QInputDialog::getText(this, tr("Document Password"), tr("Please insert the password of the document:"), QLineEdit::Password, QString(), &ok);
         if (!ok) {
-            delete newdoc;
             return;
         }
         newdoc->unlock(password.toLatin1(), password.toLatin1());
@@ -186,11 +191,18 @@ void PdfViewer::loadDocument(const QString &file)
 
     closeDocument();
 
-    m_doc = newdoc;
+    m_doc = std::move(newdoc);
 
     m_doc->setRenderHint(Poppler::Document::TextAntialiasing, m_settingsTextAAAct->isChecked());
     m_doc->setRenderHint(Poppler::Document::Antialiasing, m_settingsGfxAAAct->isChecked());
     m_doc->setRenderBackend((Poppler::Document::RenderBackend)m_settingsRenderBackendGrp->checkedAction()->data().toInt());
+    if (m_doc->xrefWasReconstructed()) {
+        xrefReconstructedHandler();
+    } else {
+        std::function<void()> cb = [this]() { xrefReconstructedHandler(); };
+
+        m_doc->setXRefReconstructedCallback(cb);
+    }
 
     Q_FOREACH (DocumentObserver *obs, m_observers) {
         obs->documentLoaded();
@@ -211,12 +223,21 @@ void PdfViewer::closeDocument()
     }
 
     m_currentPage = 0;
-    delete m_doc;
     m_doc = nullptr;
 
     m_fileSaveCopyAct->setEnabled(false);
 }
 
+void PdfViewer::xrefReconstructedHandler()
+{
+    if (!xrefReconstructed) {
+        QMessageBox msgbox(QMessageBox::Critical, tr("File may be corrupted"), tr("The PDF may be broken but we're still showing something, contents may not be correct"), QMessageBox::Ok, this);
+        msgbox.exec();
+
+        xrefReconstructed = true;
+    }
+}
+
 void PdfViewer::slotOpenFile()
 {
     QString fileName = QFileDialog::getOpenFileName(this, tr("Open PDF Document"), QDir::homePath(), tr("PDF Documents (*.pdf)"));
@@ -238,13 +259,12 @@ void PdfViewer::slotSaveCopy()
         return;
     }
 
-    Poppler::PDFConverter *converter = m_doc->pdfConverter();
+    std::unique_ptr<Poppler::PDFConverter> converter = m_doc->pdfConverter();
     converter->setOutputFileName(fileName);
     converter->setPDFOptions(converter->pdfOptions() & ~Poppler::PDFConverter::WithChanges);
     if (!converter->convert()) {
         QMessageBox msgbox(QMessageBox::Critical, tr("Save Error"), tr("Cannot export to:\n%1").arg(fileName), QMessageBox::Ok, this);
     }
-    delete converter;
 }
 
 void PdfViewer::slotAbout()
