@@ -14,7 +14,7 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2005 Brad Hards <bradh@frogmouth.net>
-// // Copyright (C) 2005-2009, 2011, 2012, 2014, 2015, 2018, 2019, 2021, 2022, 2024, 2025 Albert Astals Cid <aacid@kde.org>
+// // Copyright (C) 2005-2009, 2011, 2012, 2014, 2015, 2018, 2019, 2021, 2022, 2024-2026 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2008, 2010 Pino Toscano <pino@kde.org>
 // Copyright (C) 2009, 2011 Carlos Garcia Campos <carlosgc@gnome.org>
 // Copyright (C) 2009 Petr Gajdos <pgajdos@novell.com>
@@ -144,7 +144,7 @@ const QPicture &QPainterOutputDevType3Font::getGlyph(int gid) const
 // QPainterOutputDev
 //------------------------------------------------------------------------
 
-QPainterOutputDev::QPainterOutputDev(QPainter *painter) : m_lastTransparencyGroupPicture(nullptr), m_hintingPreference(QFont::PreferDefaultHinting)
+QPainterOutputDev::QPainterOutputDev(QPainter *painter)
 {
     m_painter.push(painter);
     m_currentBrush = QBrush(Qt::SolidPattern);
@@ -175,7 +175,7 @@ void QPainterOutputDev::startDoc(PDFDoc *doc)
     m_codeToGID = nullptr;
 }
 
-void QPainterOutputDev::startPage(int /*pageNum*/, GfxState * /*state*/, XRef *) { }
+void QPainterOutputDev::startPage(int /*pageNum*/, GfxState * /*state*/, XRef * /*xref*/) { }
 
 void QPainterOutputDev::endPage() { }
 
@@ -213,7 +213,7 @@ void QPainterOutputDev::updateAll(GfxState *state)
 }
 
 // Set CTM (Current Transformation Matrix) to a fixed matrix
-void QPainterOutputDev::setDefaultCTM(const double *ctm)
+void QPainterOutputDev::setDefaultCTM(const std::array<double, 6> &ctm)
 {
     m_painter.top()->setTransform(QTransform(ctm[0], ctm[1], ctm[2], ctm[3], ctm[4], ctm[5]));
 }
@@ -877,7 +877,7 @@ void QPainterOutputDev::drawChar(GfxState *state, double x, double y, double /*d
         m_painter.top()->setTransform(fontMatrix, true);
 
         // Apply the text matrix on top
-        const double *textMat = state->getTextMat();
+        const std::array<double, 6> &textMat = state->getTextMat();
 
         QTransform textTransform(textMat[0] * state->getHorizScaling(), textMat[1] * state->getHorizScaling(), textMat[2], textMat[3], 0, 0);
 
@@ -924,7 +924,7 @@ void QPainterOutputDev::drawChar(GfxState *state, double x, double y, double /*d
         // reflect the page at glyphPosition.y().
 
         // Make the glyph position the coordinate origin -- that's our center of scaling
-        const double *textMat = state->getTextMat();
+        const std::array<double, 6> &textMat = state->getTextMat();
 
         m_painter.top()->translate(QPointF(glyphPosition.x(), glyphPosition.y()));
 
@@ -975,7 +975,7 @@ void QPainterOutputDev::drawImageMask(GfxState * /*state*/, Object * /*ref*/, St
 
     // TODO: Would using QImage::Format_Mono be more efficient here?
     QImage image(width, height, QImage::Format_ARGB32);
-    unsigned int *data = reinterpret_cast<unsigned int *>(image.bits());
+    auto *data = reinterpret_cast<unsigned int *>(image.bits());
     int stride = image.bytesPerLine() / 4;
 
     QRgb fillColor = m_currentBrush.color().rgb();
@@ -1084,7 +1084,7 @@ void QPainterOutputDev::drawSoftMaskedImage(GfxState *state, Object *ref, Stream
     }
 
     QImage image(width, height, QImage::Format_ARGB32);
-    unsigned int *data = reinterpret_cast<unsigned int *>(image.bits());
+    auto *data = reinterpret_cast<unsigned int *>(image.bits());
     int stride = image.bytesPerLine() / 4;
 
     std::vector<unsigned char> maskLine(maskWidth);
