@@ -1,6 +1,6 @@
 /* poppler-media.cc: qt interface to poppler
  * Copyright (C) 2012 Guillermo A. Amaral B. <gamaral@kde.org>
- * Copyright (C) 2013, 2018, 2021, 2024 Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2013, 2018, 2021, 2024, 2026 Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
  * Copyright (C) 2025 Arnav V <arnav0872@gmail.com>
  *
@@ -27,7 +27,7 @@
 
 #include <QtCore/QBuffer>
 
-#define BUFFER_MAX 4096
+constexpr int BUFFER_MAX = 4096;
 
 namespace Poppler {
 
@@ -112,11 +112,12 @@ bool MediaRendition::autoPlay() const
     Q_D(const MediaRendition);
     if (d->rendition->getBEParameters()) {
         return d->rendition->getBEParameters()->autoPlay;
-    } else if (d->rendition->getMHParameters()) {
-        return d->rendition->getMHParameters()->autoPlay;
-    } else {
-        qDebug("No BE or MH parameters to reference!");
     }
+    if (d->rendition->getMHParameters()) {
+        return d->rendition->getMHParameters()->autoPlay;
+    }
+    qDebug("No BE or MH parameters to reference!");
+
     return false;
 }
 
@@ -125,11 +126,12 @@ bool MediaRendition::showControls() const
     Q_D(const MediaRendition);
     if (d->rendition->getBEParameters()) {
         return d->rendition->getBEParameters()->showControls;
-    } else if (d->rendition->getMHParameters()) {
-        return d->rendition->getMHParameters()->showControls;
-    } else {
-        qDebug("No BE or MH parameters to reference!");
     }
+    if (d->rendition->getMHParameters()) {
+        return d->rendition->getMHParameters()->showControls;
+    }
+    qDebug("No BE or MH parameters to reference!");
+
     return false;
 }
 
@@ -138,12 +140,13 @@ float MediaRendition::repeatCount() const
     Q_D(const MediaRendition);
     if (d->rendition->getBEParameters()) {
         return d->rendition->getBEParameters()->repeatCount;
-    } else if (d->rendition->getMHParameters()) {
-        return d->rendition->getMHParameters()->repeatCount;
-    } else {
-        qDebug("No BE or MH parameters to reference!");
     }
-    return 1.f;
+    if (d->rendition->getMHParameters()) {
+        return d->rendition->getMHParameters()->repeatCount;
+    }
+    qDebug("No BE or MH parameters to reference!");
+
+    return 1.F;
 }
 
 QSize MediaRendition::size() const
