@@ -1,7 +1,7 @@
 /* poppler-page.cc: qt interface to poppler
  * Copyright (C) 2005, Net Integration Technologies, Inc.
  * Copyright (C) 2005, Brad Hards <bradh@frogmouth.net>
- * Copyright (C) 2005-2022, 2024, 2025, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2005-2022, 2024-2026, Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2005, Stefan Kebekus <stefan.kebekus@math.uni-koeln.de>
  * Copyright (C) 2006-2011, Pino Toscano <pino@kde.org>
  * Copyright (C) 2008 Carlos Garcia Campos <carlosgc@gnome.org>
@@ -27,9 +27,9 @@
  * Copyright (C) 2021 Hubert Figuiere <hub@figuiere.net>
  * Copyright (C) 2021 Thomas Huxhorn <thomas.huxhorn@web.de>
  * Copyright (C) 2023 Kevin Ottens <kevin.ottens@enioka.com>. Work sponsored by De Bortoli Wines
- * Copyright (C) 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
+ * Copyright (C) 2024-2026 Stefan Brüns <stefan.bruens@rwth-aachen.de>
  * Copyright (C) 2024 Pratham Gandhi <ppg.1382@gmail.com>
- * Copyright (C) 2024 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+ * Copyright (C) 2024, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -68,6 +68,7 @@
 #include <QPainterOutputDev.h>
 #include <Rendition.h>
 #include <SplashOutputDev.h>
+#include <goo/gmem.h>
 #include <splash/SplashBitmap.h>
 
 #include "poppler-private.h"
@@ -114,8 +115,8 @@ public:
 class Qt6SplashOutputDev : public SplashOutputDev, public OutputDevCallbackHelper
 {
 public:
-    Qt6SplashOutputDev(SplashColorMode colorModeA, int bitmapRowPadA, bool reverseVideoA, bool ignorePaperColorA, SplashColorPtr paperColorA, bool bitmapTopDownA, SplashThinLineMode thinLineMode, bool overprintPreviewA)
-        : SplashOutputDev(colorModeA, bitmapRowPadA, reverseVideoA, paperColorA, bitmapTopDownA, thinLineMode, overprintPreviewA), ignorePaperColor(ignorePaperColorA)
+    Qt6SplashOutputDev(SplashColorMode colorModeA, int bitmapRowPadA, bool ignorePaperColorA, SplashColorPtr paperColorA, bool bitmapTopDownA, SplashThinLineMode thinLineMode, bool overprintPreviewA)
+        : SplashOutputDev(colorModeA, bitmapRowPadA, paperColorA, bitmapTopDownA, thinLineMode, overprintPreviewA), ignorePaperColor(ignorePaperColorA)
     {
     }
 
@@ -164,9 +165,8 @@ public:
                     gfree(data);
                 }
                 return i;
-            } else {
-                return QImage(data, bw, bh, brs, format).copy();
             }
+            return QImage(data, bw, bh, brs, format).copy();
         }
 
         return QImage();
@@ -197,7 +197,7 @@ private:
 
 QImageDumpingQPainterOutputDev::~QImageDumpingQPainterOutputDev() = default;
 
-std::unique_ptr<Link> PageData::convertLinkActionToLink(::LinkAction *a, const QRectF &linkArea)
+std::unique_ptr<Link> PageData::convertLinkActionToLink(::LinkAction *a, const QRectF &linkArea) const
 {
     return convertLinkActionToLink(a, parentDoc, linkArea);
 }
@@ -211,14 +211,14 @@ std::unique_ptr<Link> PageData::convertLinkActionToLink(::LinkAction *a, Documen
     std::unique_ptr<Link> popplerLink;
     switch (a->getKind()) {
     case actionGoTo: {
-        LinkGoTo *g = (LinkGoTo *)a;
+        auto *g = (LinkGoTo *)a;
         const LinkDestinationData ldd(g->getDest(), g->getNamedDest(), parentDoc, false);
         // create link: no ext file, namedDest, object pointer
         popplerLink = std::make_unique<LinkGoto>(linkArea, QString(), LinkDestination(ldd));
     } break;
 
     case actionGoToR: {
-        LinkGoToR *g = (LinkGoToR *)a;
+        auto *g = (LinkGoToR *)a;
         // copy link file
         const QString fileName = UnicodeParsedString(g->getFileName());
         const LinkDestinationData ldd(g->getDest(), g->getNamedDest(), parentDoc, !fileName.isEmpty());
@@ -227,7 +227,7 @@ std::unique_ptr<Link> PageData::convertLinkActionToLink(::LinkAction *a, Documen
     } break;
 
     case actionLaunch: {
-        LinkLaunch *e = (LinkLaunch *)a;
+        auto *e = (LinkLaunch *)a;
         const GooString *p = e->getParams();
         popplerLink = std::make_unique<LinkExecute>(linkArea, UnicodeParsedString(e->getFileName()), p ? QString::fromStdString(p->toStr()) : QString {});
     } break;
@@ -273,17 +273,17 @@ std::unique_ptr<Link> PageData::convertLinkActionToLink(::LinkAction *a, Documen
     } break;
 
     case actionSound: {
-        ::LinkSound *ls = (::LinkSound *)a;
+        auto *ls = (::LinkSound *)a;
         popplerLink = std::make_unique<LinkSound>(linkArea, ls->getVolume(), ls->getSynchronous(), ls->getRepeat(), ls->getMix(), new SoundObject(ls->getSound()));
     } break;
 
     case actionJavaScript: {
-        ::LinkJavaScript *ljs = (::LinkJavaScript *)a;
+        auto *ljs = (::LinkJavaScript *)a;
         popplerLink = std::make_unique<LinkJavaScript>(linkArea, UnicodeParsedString(ljs->getScript()));
     } break;
 
     case actionMovie: {
-        ::LinkMovie *lm = (::LinkMovie *)a;
+        auto *lm = (::LinkMovie *)a;
 
         const QString title = (lm->hasAnnotTitle() ? UnicodeParsedString(lm->getAnnotTitle()) : QString());
 
@@ -312,7 +312,7 @@ std::unique_ptr<Link> PageData::convertLinkActionToLink(::LinkAction *a, Documen
     } break;
 
     case actionRendition: {
-        ::LinkRendition *lrn = (::LinkRendition *)a;
+        auto *lrn = (::LinkRendition *)a;
 
         Ref reference = Ref::INVALID();
         if (lrn->hasScreenAnnot()) {
@@ -323,32 +323,32 @@ std::unique_ptr<Link> PageData::convertLinkActionToLink(::LinkAction *a, Documen
     } break;
 
     case actionOCGState: {
-        ::LinkOCGState *plocg = (::LinkOCGState *)a;
+        auto *plocg = (::LinkOCGState *)a;
 
-        LinkOCGStatePrivate *locgp = new LinkOCGStatePrivate(linkArea, plocg->getStateList(), plocg->getPreserveRB());
+        auto *locgp = new LinkOCGStatePrivate(linkArea, plocg->getStateList(), plocg->getPreserveRB());
         popplerLink = std::make_unique<LinkOCGState>(locgp);
     } break;
 
     case actionHide: {
-        ::LinkHide *lh = (::LinkHide *)a;
+        auto *lh = (::LinkHide *)a;
 
-        LinkHidePrivate *lhp = new LinkHidePrivate(linkArea, lh->hasTargetName() ? UnicodeParsedString(lh->getTargetName()) : QString(), lh->isShowAction());
+        auto *lhp = new LinkHidePrivate(linkArea, lh->hasTargetName() ? UnicodeParsedString(lh->getTargetName()) : QString(), lh->isShowAction());
         popplerLink = std::make_unique<LinkHide>(lhp);
     } break;
 
     case actionResetForm: {
-        ::LinkResetForm *lrf = (::LinkResetForm *)a;
+        auto *lrf = (::LinkResetForm *)a;
         std::vector<std::string> stdStringFields = lrf->getFields();
         QStringList qStringFields;
         for (const std::string &str : stdStringFields) {
             qStringFields << QString::fromStdString(str);
         }
-        LinkResetFormPrivate *lrfp = new LinkResetFormPrivate(linkArea, qStringFields, lrf->getExclude());
+        auto *lrfp = new LinkResetFormPrivate(linkArea, qStringFields, lrf->getExclude());
         popplerLink = std::make_unique<LinkResetForm>(lrfp);
     } break;
 
     case actionSubmitForm: {
-        ::LinkSubmitForm *lsf = (::LinkSubmitForm *)a;
+        auto *lsf = (::LinkSubmitForm *)a;
         const std::vector<std::string> &stdStringFields = lsf->getFields();
         QVector<int> fieldIds;
         fieldIds.reserve(stdStringFields.size());
@@ -366,8 +366,8 @@ std::unique_ptr<Link> PageData::convertLinkActionToLink(::LinkAction *a, Documen
             }
         }
         QString qStringUrl = QString::fromStdString(lsf->getUrl());
-        LinkSubmitForm::SubmitFormFlags qFlags = static_cast<LinkSubmitForm::SubmitFormFlags>(lsf->getFlags());
-        LinkSubmitFormPrivate *lsfp = new LinkSubmitFormPrivate(linkArea, fieldIds, qStringUrl, qFlags);
+        auto qFlags = static_cast<LinkSubmitForm::SubmitFormFlags>(lsf->getFlags());
+        auto *lsfp = new LinkSubmitFormPrivate(linkArea, fieldIds, qStringUrl, qFlags);
         popplerLink = std::make_unique<LinkSubmitForm>(lsfp);
     } break;
 
@@ -386,7 +386,7 @@ std::unique_ptr<Link> PageData::convertLinkActionToLink(::LinkAction *a, Documen
     return popplerLink;
 }
 
-inline TextPage *PageData::prepareTextSearch(const QString &text, Page::Rotation rotate, QVector<Unicode> *u)
+inline std::unique_ptr<TextPage> PageData::prepareTextSearch(const QString &text, Page::Rotation rotate, QVector<Unicode> *u) const
 {
     *u = text.toUcs4();
 
@@ -395,7 +395,7 @@ inline TextPage *PageData::prepareTextSearch(const QString &text, Page::Rotation
     // fetch ourselves a textpage
     TextOutputDev td(nullptr, true, 0, false, false);
     parentDoc->doc->displayPage(&td, index + 1, 72, 72, rotation, false, true, false, nullptr, nullptr, nullptr, nullptr, true);
-    TextPage *textPage = td.takeText();
+    std::unique_ptr<TextPage> textPage = td.takeText();
 
     return textPage;
 }
@@ -405,9 +405,11 @@ inline bool PageData::performSingleTextSearch(TextPage *textPage, QVector<Unicod
 {
     if (direction == Page::FromTop) {
         return textPage->findText(u.data(), u.size(), true, true, false, false, sCase, sDiacritics, sAcrossLines, false, sWords, &sLeft, &sTop, &sRight, &sBottom, nullptr, nullptr);
-    } else if (direction == Page::NextResult) {
+    }
+    if (direction == Page::NextResult) {
         return textPage->findText(u.data(), u.size(), false, true, true, false, sCase, sDiacritics, sAcrossLines, false, sWords, &sLeft, &sTop, &sRight, &sBottom, nullptr, nullptr);
-    } else if (direction == Page::PreviousResult) {
+    }
+    if (direction == Page::PreviousResult) {
         return textPage->findText(u.data(), u.size(), false, true, true, false, sCase, sDiacritics, sAcrossLines, true, sWords, &sLeft, &sTop, &sRight, &sBottom, nullptr, nullptr);
     }
 
@@ -464,7 +466,7 @@ Page::~Page()
 }
 
 // Callback that filters out everything but form fields
-static auto annotDisplayDecideCbk = [](Annot *annot, void *user_data) {
+static auto annotDisplayDecideCbk = [](Annot *annot, void * /*user_data*/) {
     // Hide everything but forms
     return (annot->getType() == Annot::typeWidget);
 };
@@ -474,12 +476,12 @@ static auto annotDisplayDecideCbk = [](Annot *annot, void *user_data) {
 static bool (*nullAnnotCallBack)(Annot *annot, void *user_data) = nullptr;
 
 static auto shouldAbortRenderInternalCallback = [](void *user_data) {
-    OutputDevCallbackHelper *helper = reinterpret_cast<OutputDevCallbackHelper *>(user_data);
+    auto *helper = reinterpret_cast<OutputDevCallbackHelper *>(user_data);
     return helper->shouldAbortRenderCallback(helper->payload);
 };
 
 static auto shouldAbortExtractionInternalCallback = [](void *user_data) {
-    TextExtractionAbortHelper *helper = reinterpret_cast<TextExtractionAbortHelper *>(user_data);
+    auto *helper = reinterpret_cast<TextExtractionAbortHelper *>(user_data);
     return helper->shouldAbortExtractionCallback(helper->payload);
 };
 
@@ -501,7 +503,7 @@ static bool renderToQPainter(QImageDumpingQPainterOutputDev *qpainter_output, QP
     }
     painter->translate(x == -1 ? 0 : -x, y == -1 ? 0 : -y);
 
-    qpainter_output->startDoc(page->parentDoc->doc);
+    qpainter_output->startDoc(page->parentDoc->doc.get());
 
     const bool hideAnnotations = page->parentDoc->m_hints & Document::HideAnnotations;
 
@@ -545,7 +547,7 @@ QImage Page::renderToImage(double xres, double yres, int xPos, int yPos, int w,
     switch (m_page->parentDoc->m_backend) {
     case Poppler::Document::SplashBackend: {
         SplashColor bgColor;
-        const bool overprintPreview = m_page->parentDoc->m_hints & Document::OverprintPreview ? true : false;
+        const bool overprintPreview = (m_page->parentDoc->m_hints & Document::OverprintPreview) != 0;
         if (overprintPreview) {
             unsigned char c, m, y, k;
 
@@ -584,19 +586,19 @@ QImage Page::renderToImage(double xres, double yres, int xPos, int yPos, int w,
 
         const bool ignorePaperColor = m_page->parentDoc->m_hints & Document::IgnorePaperColor;
 
-        Qt6SplashOutputDev splash_output(colorMode, 4, false, ignorePaperColor, ignorePaperColor ? nullptr : bgColor, true, thinLineMode, overprintPreview);
+        Qt6SplashOutputDev splash_output(colorMode, 4, ignorePaperColor, ignorePaperColor ? nullptr : bgColor, true, thinLineMode, overprintPreview);
 
         splash_output.setCallbacks(partialUpdateCallback, shouldDoPartialUpdateCallback, shouldAbortRenderCallback, payload);
 
-        splash_output.setFontAntialias(m_page->parentDoc->m_hints & Document::TextAntialiasing ? true : false);
-        splash_output.setVectorAntialias(m_page->parentDoc->m_hints & Document::Antialiasing ? true : false);
-        splash_output.setFreeTypeHinting(m_page->parentDoc->m_hints & Document::TextHinting ? true : false, m_page->parentDoc->m_hints & Document::TextSlightHinting ? true : false);
+        splash_output.setFontAntialias((m_page->parentDoc->m_hints & Document::TextAntialiasing) != 0);
+        splash_output.setVectorAntialias((m_page->parentDoc->m_hints & Document::Antialiasing) != 0);
+        splash_output.setFreeTypeHinting((m_page->parentDoc->m_hints & Document::TextHinting) != 0, (m_page->parentDoc->m_hints & Document::TextSlightHinting) != 0);
 
-#ifdef USE_CMS
+#if USE_CMS
         splash_output.setDisplayProfile(m_page->parentDoc->m_displayProfile);
 #endif
 
-        splash_output.startDoc(m_page->parentDoc->doc);
+        splash_output.startDoc(m_page->parentDoc->doc.get());
 
         const bool hideAnnotations = m_page->parentDoc->m_hints & Document::HideAnnotations;
 
@@ -620,7 +622,7 @@ QImage Page::renderToImage(double xres, double yres, int xPos, int yPos, int w,
 
         qpainter_output.setHintingPreference(QFontHintingFromPopplerHinting(m_page->parentDoc->m_hints));
 
-#ifdef USE_CMS
+#if USE_CMS
         qpainter_output.setDisplayProfile(m_page->parentDoc->m_displayProfile);
 #endif
 
@@ -683,17 +685,17 @@ QString Page::text(const QRectF &r, TextLayout textLayout) const
     QString result;
 
     const bool rawOrder = textLayout == RawOrderLayout;
-    output_dev = new TextOutputDev(nullptr, false, 0, rawOrder, false);
+    const bool physLayout = textLayout == PhysicalLayout;
+    output_dev = new TextOutputDev(nullptr, physLayout, 0, rawOrder, false);
     m_page->parentDoc->doc->displayPageSlice(output_dev, m_page->index + 1, 72, 72, 0, false, true, false, -1, -1, -1, -1, nullptr, nullptr, nullptr, nullptr, true);
     if (r.isNull()) {
-        const PDFRectangle *rect = m_page->page->getCropBox();
-        if (orientation() == Orientation::Portrait || orientation() == Orientation::UpsideDown) {
-            s = output_dev->getText(rect->x1, rect->y1, rect->x2, rect->y2);
-        } else {
-            s = output_dev->getText(rect->y1, rect->x1, rect->y2, rect->x2);
-        }
+        s = output_dev->getText(std::nullopt);
     } else {
-        s = output_dev->getText(r.left(), r.top(), r.right(), r.bottom());
+        if (textLayout == ReadingOrder) {
+            qWarning() << "ReadingOrder is not supported with non null rect";
+            return {};
+        }
+        s = output_dev->getText(PDFRectangle { r.left(), r.top(), r.right(), r.bottom() });
     }
 
     result = QString::fromStdString(s.toStr());
@@ -709,34 +711,30 @@ QString Page::text(const QRectF &r) const
 
 bool Page::search(const QString &text, double &sLeft, double &sTop, double &sRight, double &sBottom, SearchDirection direction, SearchFlags flags, Rotation rotate) const
 {
-    const bool sCase = flags.testFlag(IgnoreCase) ? false : true;
-    const bool sWords = flags.testFlag(WholeWords) ? true : false;
-    const bool sDiacritics = flags.testFlag(IgnoreDiacritics) ? true : false;
-    const bool sAcrossLines = flags.testFlag(AcrossLines) ? true : false;
+    const bool sCase = !flags.testFlag(IgnoreCase);
+    const bool sWords = flags.testFlag(WholeWords);
+    const bool sDiacritics = flags.testFlag(IgnoreDiacritics);
+    const bool sAcrossLines = flags.testFlag(AcrossLines);
 
     QVector<Unicode> u;
-    TextPage *textPage = m_page->prepareTextSearch(text, rotate, &u);
+    std::unique_ptr<TextPage> textPage = m_page->prepareTextSearch(text, rotate, &u);
 
-    const bool found = m_page->performSingleTextSearch(textPage, u, sLeft, sTop, sRight, sBottom, direction, sCase, sWords, sDiacritics, sAcrossLines);
-
-    textPage->decRefCnt();
+    const bool found = Poppler::PageData::performSingleTextSearch(textPage.get(), u, sLeft, sTop, sRight, sBottom, direction, sCase, sWords, sDiacritics, sAcrossLines);
 
     return found;
 }
 
 QList<QRectF> Page::search(const QString &text, SearchFlags flags, Rotation rotate) const
 {
-    const bool sCase = flags.testFlag(IgnoreCase) ? false : true;
-    const bool sWords = flags.testFlag(WholeWords) ? true : false;
-    const bool sDiacritics = flags.testFlag(IgnoreDiacritics) ? true : false;
-    const bool sAcrossLines = flags.testFlag(AcrossLines) ? true : false;
+    const bool sCase = !flags.testFlag(IgnoreCase);
+    const bool sWords = flags.testFlag(WholeWords);
+    const bool sDiacritics = flags.testFlag(IgnoreDiacritics);
+    const bool sAcrossLines = flags.testFlag(AcrossLines);
 
     QVector<Unicode> u;
-    TextPage *textPage = m_page->prepareTextSearch(text, rotate, &u);
+    std::unique_ptr<TextPage> textPage = m_page->prepareTextSearch(text, rotate, &u);
 
-    QList<QRectF> results = m_page->performMultipleTextSearch(textPage, u, sCase, sWords, sDiacritics, sAcrossLines);
-
-    textPage->decRefCnt();
+    QList<QRectF> results = Poppler::PageData::performMultipleTextSearch(textPage.get(), u, sCase, sWords, sDiacritics, sAcrossLines);
 
     return results;
 }
@@ -769,14 +767,13 @@ std::vector<std::unique_ptr<TextBox>> Page::textList(Rotation rotate, ShouldAbor
     const std::vector<TextWord *> &words = word_list->getWords();
     output_list.reserve(words.size());
     for (const TextWord *word : words) {
-        GooString *gooWord = word->getText();
-        QString string = QString::fromUtf8(gooWord->c_str());
-        delete gooWord;
+        const std::unique_ptr<std::string> wordText = word->getText();
+        const QString string = QString::fromUtf8(wordText->c_str());
         double xMin, yMin, xMax, yMax;
         word->getBBox(&xMin, &yMin, &xMax, &yMax);
 
         auto text_box = std::make_unique<TextBox>(string, QRectF(xMin, yMin, xMax - xMin, yMax - yMin));
-        text_box->m_data->hasSpaceAfter = word->hasSpaceAfter() == true;
+        text_box->m_data->hasSpaceAfter = word->hasSpaceAfter();
         text_box->m_data->charBBoxes.reserve(word->getLength());
         for (int j = 0; j < word->getLength(); ++j) {
             word->getCharBBox(j, &xMin, &yMin, &xMax, &yMax);
@@ -832,9 +829,8 @@ QSizeF Page::pageSizeF() const
     Page::Orientation orient = orientation();
     if ((Page::Landscape == orient) || (Page::Seascape == orient)) {
         return QSizeF(m_page->page->getCropHeight(), m_page->page->getCropWidth());
-    } else {
-        return QSizeF(m_page->page->getCropWidth(), m_page->page->getCropHeight());
     }
+    return QSizeF(m_page->page->getCropWidth(), m_page->page->getCropHeight());
 }
 
 QSize Page::pageSize() const
