@@ -21,7 +21,7 @@
  * Copyright (C) 2021 Mahmoud Khalil <mahmoudkhalil11@gmail.com>
  * Copyright (C) 2021 Hubert Figuiere <hub@figuiere.net>
  * Copyright (C) 2021 Georgiy Sgibnev <georgiy@sgibnev.com>. Work sponsored by lab50.net.
- * Copyright (C) 2024, 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+ * Copyright (C) 2024-2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
  * Inspired on code by
  * Copyright (C) 2004 by Albert Astals Cid <tsdgeos@terra.es>
  * Copyright (C) 2004 by Enrico Ros <eros.kde@email.it>
@@ -112,27 +112,27 @@ public:
         m_filePath = filePath;
 
 #ifdef _WIN32
-        doc = new PDFDoc((wchar_t *)filePath.utf16(), filePath.length(), ownerPassword, userPassword, std::bind(&DocumentData::noitfyXRefReconstructed, this));
+        doc = std::make_unique<PDFDoc>((wchar_t *)filePath.utf16(), filePath.length(), ownerPassword, userPassword, [this] { notifyXRefReconstructed(); });
 #else
-        doc = new PDFDoc(std::make_unique<GooString>(QFile::encodeName(filePath).constData()), ownerPassword, userPassword, std::bind(&DocumentData::noitfyXRefReconstructed, this));
+        doc = std::make_unique<PDFDoc>(std::make_unique<GooString>(QFile::encodeName(filePath).constData()), ownerPassword, userPassword, [this] { notifyXRefReconstructed(); });
 #endif
     }
 
     DocumentData(QIODevice *device, const std::optional<GooString> &ownerPassword, const std::optional<GooString> &userPassword) : GlobalParamsIniter(qt6ErrorFunction)
     {
         m_device = device;
-        QIODeviceInStream *str = new QIODeviceInStream(device, 0, false, device->size(), Object::null());
+        auto str = std::make_unique<QIODeviceInStream>(device, 0, false, device->size(), Object::null());
         init();
-        doc = new PDFDoc(str, ownerPassword, userPassword, std::bind(&DocumentData::noitfyXRefReconstructed, this));
+        doc = std::make_unique<PDFDoc>(std::move(str), ownerPassword, userPassword, [this] { notifyXRefReconstructed(); });
     }
 
     DocumentData(const QByteArray &data, const std::optional<GooString> &ownerPassword, const std::optional<GooString> &userPassword) : GlobalParamsIniter(qt6ErrorFunction)
     {
         m_device = nullptr;
         fileContents = data;
-        MemStream *str = new MemStream((char *)fileContents.data(), 0, fileContents.length(), Object::null());
+        auto str = std::make_unique<MemStream>(fileContents.data(), 0, fileContents.length(), Object::null());
         init();
-        doc = new PDFDoc(str, ownerPassword, userPassword, std::bind(&DocumentData::noitfyXRefReconstructed, this));
+        doc = std::make_unique<PDFDoc>(std::move(str), ownerPassword, userPassword, [this] { notifyXRefReconstructed(); });
     }
 
     void init();
@@ -161,11 +161,11 @@ public:
      * where we'll set xrefReconstructed flag and notify users of the
      * reconstruction event
      */
-    void noitfyXRefReconstructed();
+    void notifyXRefReconstructed();
 
     static std::unique_ptr<Document> checkDocument(DocumentData *doc);
 
-    PDFDoc *doc;
+    std::unique_ptr<PDFDoc> doc;
     QString m_filePath;
     QIODevice *m_device;
     QByteArray fileContents;
@@ -175,7 +175,7 @@ public:
     QPointer<OptContentModel> m_optContentModel;
     QColor paperColor;
     int m_hints;
-#ifdef USE_CMS
+#if USE_CMS
     GfxLCMSProfilePtr m_sRGBProfile;
     GfxLCMSProfilePtr m_displayProfile;
 #endif
@@ -229,7 +229,7 @@ public:
 class FontIteratorData
 {
 public:
-    FontIteratorData(int startPage, DocumentData *dd) : fontInfoScanner(dd->doc, startPage), totalPages(dd->doc->getNumPages()), currentPage(qMax(startPage, 0) - 1) { }
+    FontIteratorData(int startPage, DocumentData *dd) : fontInfoScanner(dd->doc.get(), startPage), totalPages(dd->doc->getNumPages()), currentPage(qMax(startPage, 0) - 1) { }
 
     ~FontIteratorData() = default;
 
@@ -241,15 +241,34 @@ public:
 class TextBoxData
 {
 public:
-    TextBoxData() : nextWord(nullptr), hasSpaceAfter(false) { }
+    TextBoxData() = default;
 
     QString text;
     QRectF bBox;
-    TextBox *nextWord;
+    TextBox *nextWord = nullptr;
     QVector<QRectF> charBBoxes; // the boundingRect of each character
-    bool hasSpaceAfter;
+    bool hasSpaceAfter = false;
 };
 
+inline Poppler::ErrorStringType fromPopplerCore(::ErrorStringType type)
+{
+    switch (type) {
+    case ::ErrorStringType::ErrorCodeString:
+        return Poppler::ErrorStringType::ErrorCodeString;
+    case ::ErrorStringType::UserString:
+        return Poppler::ErrorStringType::UserString;
+    }
+    return Poppler::ErrorStringType::ErrorCodeString;
+}
+
+inline Poppler::ErrorString fromPopplerCore(const ::ErrorString &str)
+{
+    Poppler::ErrorString res;
+    res.type = fromPopplerCore(str.type);
+    res.data = QString::fromStdString(str.text);
+    return res;
+}
+
 class FormFieldData
 {
 public:
@@ -260,6 +279,7 @@ public:
     ::FormWidget *fm;
     QRectF box;
     static POPPLER_QT6_EXPORT ::FormWidget *getFormWidget(const FormField *f);
+    Poppler::ErrorString lastSigningErrorDetails;
 };
 
 class FormFieldIcon;
