@@ -1,7 +1,9 @@
 /* poppler-qiodevicestream-private.h: Qt6 interface to poppler
  * Copyright (C) 2008, Pino Toscano <pino@kde.org>
  * Copyright (C) 2013 Adrian Johnson <ajohnson@redneon.com>
- * Copyright (C) 2021 Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2021, 2025 Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2021, Even Rouault <even.rouault@spatialys.com>
+ * Copyright (C) 2024, g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +23,6 @@
 #ifndef POPPLER_QIODEVICESTREAM_PRIVATE_H
 #define POPPLER_QIODEVICESTREAM_PRIVATE_H
 
-#include "Object.h"
 #include "Stream.h"
 
 class QIODevice;
@@ -37,7 +38,8 @@ public:
     void close() override;
     Goffset getPos() override;
     void put(char c) override;
-    void printf(const char *format, ...) override;
+    size_t write(std::span<const unsigned char> data) override;
+    void printf(const char *format, ...) override GCC_PRINTF_FORMAT(2, 3);
 
 private:
     QIODevice *m_device;
