@@ -10,16 +10,16 @@ class TestActualText : public QObject
 public:
     explicit TestActualText(QObject *parent = nullptr) : QObject(parent) { }
 
-    void checkActualText(Poppler::Document &doc, const QRectF &area, const QString &text);
+    static void checkActualText(Poppler::Document &doc, const QRectF &area, const QString &text);
 
-private slots:
-    void checkActualText1();
-    void checkActualText2();
-    void checkActualText2_data();
-    void checkAllOrientations();
-    void checkAllOrientations_data();
-    void checkFakeboldText();
-    void checkFakeboldText_data();
+private Q_SLOTS:
+    static void checkActualText1();
+    static void checkActualText2();
+    static void checkActualText2_data();
+    static void checkAllOrientations();
+    static void checkAllOrientations_data();
+    static void checkFakeboldText();
+    static void checkFakeboldText_data();
 };
 
 void TestActualText::checkActualText(Poppler::Document &doc, const QRectF &area, const QString &text)
@@ -32,7 +32,7 @@ void TestActualText::checkActualText(Poppler::Document &doc, const QRectF &area,
 
 void TestActualText::checkActualText1()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/WithActualText.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/WithActualText.pdf"));
     QVERIFY(doc);
 
     checkActualText(*doc, QRectF {}, QStringLiteral("The slow brown fox jumps over the black dog."));
@@ -43,7 +43,7 @@ void TestActualText::checkActualText2()
     QFETCH(QRectF, area);
     QFETCH(QString, text);
 
-    QFile file(TESTDATADIR "/unittestcases/WithActualText.pdf");
+    QFile file(QStringLiteral(TESTDATADIR "/unittestcases/WithActualText.pdf"));
     QVERIFY(file.open(QIODevice::ReadOnly));
 
     std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(&file);
@@ -79,7 +79,7 @@ void TestActualText::checkAllOrientations()
     QFETCH(QRectF, area);
     QFETCH(QString, text);
 
-    QString path { TESTDATADIR "/unittestcases/orientation.pdf" };
+    QString path { QStringLiteral(TESTDATADIR "/unittestcases/orientation.pdf") };
     std::unique_ptr<Poppler::Document> doc { Poppler::Document::load(path) };
     QVERIFY(doc);
 
@@ -126,7 +126,7 @@ void TestActualText::checkFakeboldText()
     QFETCH(QRectF, area);
     QFETCH(QString, text);
 
-    QString path { TESTDATADIR "/unittestcases/fakebold.pdf" };
+    QString path { QStringLiteral(TESTDATADIR "/unittestcases/fakebold.pdf") };
     std::unique_ptr<Poppler::Document> doc { Poppler::Document::load(path) };
     QVERIFY(doc);
 
