@@ -17,16 +17,16 @@ class TestAnnotations : public QObject
 public:
     explicit TestAnnotations(QObject *parent = nullptr) : QObject(parent) { }
 
-    void saveAndCheck(const std::unique_ptr<Poppler::Document> &doc, const std::function<void(Poppler::Annotation *a)> &checkFunction);
+    static void saveAndCheck(const std::unique_ptr<Poppler::Document> &doc, const std::function<void(Poppler::Annotation *a)> &checkFunction);
 
 private Q_SLOTS:
-    void checkQColorPrecision();
-    void checkFontSizeAndColor();
-    void checkHighlightFromAndToQuads();
-    void checkUTF16LEAnnot();
-    void checkModificationCreationDate();
-    void checkNonMarkupAnnotations();
-    void checkDefaultAppearance();
+    static void checkQColorPrecision();
+    static void checkFontSizeAndColor();
+    static void checkHighlightFromAndToQuads();
+    static void checkUTF16LEAnnot();
+    static void checkModificationCreationDate();
+    static void checkNonMarkupAnnotations();
+    static void checkDefaultAppearance();
 };
 
 /* Is .5f sufficient for 16 bit color channel roundtrip trough save and load on all architectures? */
@@ -92,7 +92,7 @@ void TestAnnotations::checkFontSizeAndColor()
         auto &&annot = annots.cbegin();
         for (const auto &color : testColors) {
             QCOMPARE((*annot)->subType(), Poppler::Annotation::AText);
-            auto textAnnot = static_cast<Poppler::TextAnnotation *>(annot->get());
+            auto *textAnnot = static_cast<Poppler::TextAnnotation *>(annot->get());
             QCOMPARE(textAnnot->contents(), contents);
             QCOMPARE(textAnnot->textFont().pointSize(), testFont.pointSize());
             QCOMPARE(static_cast<int>(textAnnot->textColor().spec()), static_cast<int>(color.spec()));
@@ -122,7 +122,8 @@ void TestAnnotations::checkHighlightFromAndToQuads()
     auto ha = std::make_unique<Poppler::HighlightAnnotation>();
     page->addAnnotation(ha.get());
 
-    const QList<Poppler::HighlightAnnotation::Quad> quads = { { { { 0, 0.1 }, { 0.2, 0.3 }, { 0.4, 0.5 }, { 0.6, 0.7 } }, false, false, 0 }, { { { 0.8, 0.9 }, { 0.1, 0.2 }, { 0.3, 0.4 }, { 0.5, 0.6 } }, true, false, 0.4 } };
+    const QList<Poppler::HighlightAnnotation::Quad> quads = { { .points = { { 0, 0.1 }, { 0.2, 0.3 }, { 0.4, 0.5 }, { 0.6, 0.7 } }, .capStart = false, .capEnd = false, .feather = 0 },
+                                                              { .points = { { 0.8, 0.9 }, { 0.1, 0.2 }, { 0.3, 0.4 }, { 0.5, 0.6 } }, .capStart = true, .capEnd = false, .feather = 0.4 } };
     ha->setHighlightQuads(quads);
     QCOMPARE(ha->highlightQuads(), quads);
 }
@@ -226,8 +227,8 @@ void TestAnnotations::checkDefaultAppearance()
         GooString daString { "/Helv 10 Tf 0.1 0.2 0.3 rg" };
         const DefaultAppearance da { &daString };
         QCOMPARE(da.getFontPtSize(), 10.);
-        QVERIFY(da.getFontName().isName());
-        QCOMPARE(da.getFontName().getName(), "Helv");
+        QVERIFY(!da.getFontName().empty());
+        QCOMPARE(da.getFontName(), "Helv");
         const AnnotColor *color = da.getFontColor();
         QVERIFY(color);
         QCOMPARE(color->getSpace(), AnnotColor::colorRGB);
@@ -240,8 +241,8 @@ void TestAnnotations::checkDefaultAppearance()
         /* roundtrip through parse/generate/parse shall preserve values */
         const DefaultAppearance da { roundtripString.get() };
         QCOMPARE(da.getFontPtSize(), 10.);
-        QVERIFY(da.getFontName().isName());
-        QCOMPARE(da.getFontName().getName(), "Helv");
+        QVERIFY(!da.getFontName().empty());
+        QCOMPARE(da.getFontName(), "Helv");
         const AnnotColor *color = da.getFontColor();
         QVERIFY(color);
         QCOMPARE(color->getSpace(), AnnotColor::colorRGB);
@@ -253,7 +254,7 @@ void TestAnnotations::checkDefaultAppearance()
         /* parsing bad DA strings must not cause crash */
         GooString daString { "/ % Tf 1 2 rg" };
         const DefaultAppearance da { &daString };
-        QVERIFY(!da.getFontName().isName());
+        QVERIFY(da.getFontName().empty());
     }
 }
 
