@@ -8,7 +8,7 @@ class EndOfLines : public QObject
 public:
     explicit EndOfLines(QObject *parent = nullptr) : QObject(parent) { }
 private Q_SLOTS:
-    void checkEndOfLines();
+    static void checkEndOfLines();
 };
 
 void EndOfLines::checkEndOfLines()
@@ -22,7 +22,7 @@ void EndOfLines::checkEndOfLines()
 
     auto text = page->text(QRect {});
 
-    QCOMPARE(text, QStringLiteral("Hello World!\nHello World!\nHello World!\n"));
+    QCOMPARE(text, QStringLiteral("Hello World!\n\nHello World!\n\nHello World!"));
 }
 
 QTEST_GUILESS_MAIN(EndOfLines)
