@@ -1,4 +1,4 @@
-#include <QtTest/QtTest>
+#include <QtTest/QTest>
 
 #include <poppler-qt6.h>
 
@@ -8,12 +8,12 @@ class TestLinks : public QObject
 {
     Q_OBJECT
 public:
-    TestLinks(QObject *parent = nullptr) : QObject(parent) { }
-private slots:
-    void checkDocumentWithNoDests();
-    void checkDests_xr01();
-    void checkDests_xr02();
-    void checkDocumentURILink();
+    explicit TestLinks(QObject *parent = nullptr) : QObject(parent) { }
+private Q_SLOTS:
+    static void checkDocumentWithNoDests();
+    static void checkDests_xr01();
+    static void checkDests_xr02();
+    static void checkDocumentURILink();
 };
 
 static bool isDestinationValid_pageNumber(const Poppler::LinkDestination *dest, const Poppler::Document *doc)
@@ -28,7 +28,7 @@ static bool isDestinationValid_name(const Poppler::LinkDestination *dest)
 
 void TestLinks::checkDocumentWithNoDests()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/WithAttachments.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/WithAttachments.pdf"));
     QVERIFY(doc);
 
     std::unique_ptr<Poppler::LinkDestination> dest = doc->linkDestination(QStringLiteral("no.dests.in.this.document"));
@@ -38,7 +38,7 @@ void TestLinks::checkDocumentWithNoDests()
 
 void TestLinks::checkDests_xr01()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/xr01.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/xr01.pdf"));
     QVERIFY(doc);
 
     std::unique_ptr<Poppler::Page> page = doc->page(0);
@@ -49,7 +49,7 @@ void TestLinks::checkDests_xr01()
 
     {
         QCOMPARE(links.at(0)->linkType(), Poppler::Link::Goto);
-        Poppler::LinkGoto *link = static_cast<Poppler::LinkGoto *>(links.at(0).get());
+        auto *link = static_cast<Poppler::LinkGoto *>(links.at(0).get());
         const Poppler::LinkDestination dest = link->destination();
         QVERIFY(!isDestinationValid_pageNumber(&dest, doc.get()));
         QVERIFY(isDestinationValid_name(&dest));
@@ -58,7 +58,7 @@ void TestLinks::checkDests_xr01()
 
     {
         QCOMPARE(links.at(1)->linkType(), Poppler::Link::Goto);
-        Poppler::LinkGoto *link = static_cast<Poppler::LinkGoto *>(links.at(1).get());
+        auto *link = static_cast<Poppler::LinkGoto *>(links.at(1).get());
         const Poppler::LinkDestination dest = link->destination();
         QVERIFY(!isDestinationValid_pageNumber(&dest, doc.get()));
         QVERIFY(isDestinationValid_name(&dest));
@@ -68,7 +68,7 @@ void TestLinks::checkDests_xr01()
 
 void TestLinks::checkDests_xr02()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/xr02.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/xr02.pdf"));
     QVERIFY(doc);
 
     std::unique_ptr<Poppler::LinkDestination> dest = doc->linkDestination(QStringLiteral("section.1"));
@@ -80,11 +80,15 @@ void TestLinks::checkDests_xr02()
     dest = doc->linkDestination(QStringLiteral("section.3"));
     QVERIFY(!isDestinationValid_pageNumber(dest.get(), doc.get()));
     QVERIFY(isDestinationValid_name(dest.get()));
+    // Better check that a link that should be in the middle of the sorted names does not give one of the neighboring ones
+    dest = doc->linkDestination(QStringLiteral("section.15"));
+    QVERIFY(!isDestinationValid_pageNumber(dest.get(), doc.get()));
+    QVERIFY(isDestinationValid_name(dest.get()));
 }
 
 void TestLinks::checkDocumentURILink()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/checkbox_issue_159.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/checkbox_issue_159.pdf"));
     QVERIFY(doc);
 
     std::unique_ptr<Poppler::Page> page = doc->page(0);
@@ -94,7 +98,7 @@ void TestLinks::checkDocumentURILink()
     QCOMPARE(links.size(), 1);
 
     QCOMPARE(links.at(0)->linkType(), Poppler::Link::Browse);
-    Poppler::LinkBrowse *link = static_cast<Poppler::LinkBrowse *>(links.at(0).get());
+    auto *link = static_cast<Poppler::LinkBrowse *>(links.at(0).get());
     QCOMPARE(link->url(), QLatin1String("http://www.tcpdf.org"));
 }
 
