@@ -1,4 +1,5 @@
 #include <QtTest/QTest>
+#include <QtCore/QTimeZone>
 
 #include <poppler-qt6.h>
 
@@ -7,23 +8,23 @@ class TestMetaData : public QObject
     Q_OBJECT
 public:
     explicit TestMetaData(QObject *parent = nullptr) : QObject(parent) { }
-private slots:
-    void checkStrings_data();
-    void checkStrings();
-    void checkStrings2_data();
-    void checkStrings2();
-    void checkStringKeys();
-    void checkLinearised();
-    void checkNumPages();
-    void checkDate();
-    void checkPageSize();
-    void checkPortraitOrientation();
-    void checkLandscapeOrientation();
-    void checkUpsideDownOrientation();
-    void checkSeascapeOrientation();
-    void checkVersion();
-    void checkPdfId();
-    void checkNoPdfId();
+private Q_SLOTS:
+    static void checkStrings_data();
+    static void checkStrings();
+    static void checkStrings2_data();
+    static void checkStrings2();
+    static void checkStringKeys();
+    static void checkLinearised();
+    static void checkNumPages();
+    static void checkDate();
+    static void checkPageSize();
+    static void checkPortraitOrientation();
+    static void checkLandscapeOrientation();
+    static void checkUpsideDownOrientation();
+    static void checkSeascapeOrientation();
+    static void checkVersion();
+    static void checkPdfId();
+    static void checkNoPdfId();
 };
 
 void TestMetaData::checkStrings_data()
@@ -47,7 +48,7 @@ void TestMetaData::checkStrings_data()
 
 void TestMetaData::checkStrings()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/doublepage.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/doublepage.pdf"));
     QVERIFY(doc);
 
     QFETCH(QString, key);
@@ -78,7 +79,7 @@ void TestMetaData::checkStrings2_data()
 
 void TestMetaData::checkStrings2()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/truetype.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/truetype.pdf"));
     QVERIFY(doc);
 
     QFETCH(QString, key);
@@ -88,7 +89,7 @@ void TestMetaData::checkStrings2()
 
 void TestMetaData::checkStringKeys()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/truetype.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/truetype.pdf"));
     QVERIFY(doc);
 
     QStringList keyList;
@@ -102,19 +103,19 @@ void TestMetaData::checkStringKeys()
 
 void TestMetaData::checkLinearised()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/orientation.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/orientation.pdf"));
     QVERIFY(doc);
 
     QVERIFY(doc->isLinearized());
 
-    doc = Poppler::Document::load(TESTDATADIR "/unittestcases/truetype.pdf");
+    doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/truetype.pdf"));
     QVERIFY(doc);
     QCOMPARE(doc->isLinearized(), false);
 }
 
 void TestMetaData::checkPortraitOrientation()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/orientation.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/orientation.pdf"));
     QVERIFY(doc);
 
     std::unique_ptr<Poppler::Page> page = doc->page(0);
@@ -123,26 +124,26 @@ void TestMetaData::checkPortraitOrientation()
 
 void TestMetaData::checkNumPages()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/doublepage.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/doublepage.pdf"));
     QVERIFY(doc);
     QCOMPARE(doc->numPages(), 2);
 
-    doc = Poppler::Document::load(TESTDATADIR "/unittestcases/truetype.pdf");
+    doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/truetype.pdf"));
     QVERIFY(doc);
     QCOMPARE(doc->numPages(), 1);
 }
 
 void TestMetaData::checkDate()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/truetype.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/truetype.pdf"));
     QVERIFY(doc);
-    QCOMPARE(doc->date(QStringLiteral("ModDate")), QDateTime(QDate(2005, 12, 5), QTime(9, 44, 46), Qt::UTC));
-    QCOMPARE(doc->date(QStringLiteral("CreationDate")), QDateTime(QDate(2005, 8, 13), QTime(1, 12, 11), Qt::UTC));
+    QCOMPARE(doc->date(QStringLiteral("ModDate")), QDateTime(QDate(2005, 12, 5), QTime(9, 44, 46), QTimeZone::utc()));
+    QCOMPARE(doc->date(QStringLiteral("CreationDate")), QDateTime(QDate(2005, 8, 13), QTime(1, 12, 11), QTimeZone::utc()));
 }
 
 void TestMetaData::checkPageSize()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/truetype.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/truetype.pdf"));
     QVERIFY(doc);
     std::unique_ptr<Poppler::Page> page = doc->page(0);
     QCOMPARE(page->pageSize(), QSize(595, 842));
@@ -151,7 +152,7 @@ void TestMetaData::checkPageSize()
 
 void TestMetaData::checkLandscapeOrientation()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/orientation.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/orientation.pdf"));
     QVERIFY(doc);
 
     std::unique_ptr<Poppler::Page> page = doc->page(1);
@@ -160,7 +161,7 @@ void TestMetaData::checkLandscapeOrientation()
 
 void TestMetaData::checkUpsideDownOrientation()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/orientation.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/orientation.pdf"));
     QVERIFY(doc);
 
     std::unique_ptr<Poppler::Page> page = doc->page(2);
@@ -169,7 +170,7 @@ void TestMetaData::checkUpsideDownOrientation()
 
 void TestMetaData::checkSeascapeOrientation()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/orientation.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/orientation.pdf"));
     QVERIFY(doc);
 
     std::unique_ptr<Poppler::Page> page = doc->page(3);
@@ -178,7 +179,7 @@ void TestMetaData::checkSeascapeOrientation()
 
 void TestMetaData::checkVersion()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/doublepage.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/doublepage.pdf"));
     QVERIFY(doc);
 
     auto pdfVersion = doc->getPdfVersion();
@@ -188,7 +189,7 @@ void TestMetaData::checkVersion()
 
 void TestMetaData::checkPdfId()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/A6EmbeddedFiles.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/A6EmbeddedFiles.pdf"));
     QVERIFY(doc);
 
     const QByteArray referencePermanentId("00C9D5B6D8FB11D7A902003065D630AA");
@@ -222,7 +223,7 @@ void TestMetaData::checkPdfId()
 
 void TestMetaData::checkNoPdfId()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/WithActualText.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/WithActualText.pdf"));
     QVERIFY(doc);
 
     QVERIFY(!doc->getPdfId(nullptr, nullptr));
