@@ -7,15 +7,15 @@ class TestPageLayout : public QObject
     Q_OBJECT
 public:
     explicit TestPageLayout(QObject *parent = nullptr) : QObject(parent) { }
-private slots:
-    void checkNone();
-    void checkSingle();
-    void checkFacing();
+private Q_SLOTS:
+    static void checkNone();
+    static void checkSingle();
+    static void checkFacing();
 };
 
 void TestPageLayout::checkNone()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/UseNone.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/UseNone.pdf"));
     QVERIFY(doc);
 
     QCOMPARE(doc->pageLayout(), Poppler::Document::NoLayout);
@@ -23,7 +23,7 @@ void TestPageLayout::checkNone()
 
 void TestPageLayout::checkSingle()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/FullScreen.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/FullScreen.pdf"));
     QVERIFY(doc);
 
     QCOMPARE(doc->pageLayout(), Poppler::Document::SinglePage);
@@ -31,7 +31,7 @@ void TestPageLayout::checkSingle()
 
 void TestPageLayout::checkFacing()
 {
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(TESTDATADIR "/unittestcases/doublepage.pdf");
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/doublepage.pdf"));
     QVERIFY(doc);
 
     QCOMPARE(doc->pageLayout(), Poppler::Document::TwoPageRight);
