@@ -38,13 +38,13 @@ public:
 
 private Q_SLOTS:
     void init();
-    void initTestCase_data();
+    static void initTestCase_data();
     void initTestCase() { }
-    void cleanupTestCase();
-    void testSignatureCount();
-    void testSignatureSizes();
-    void testSignerInfo(); // names and stuff
-    void testSignedRanges();
+    static void cleanupTestCase();
+    void testSignatureCount() const;
+    void testSignatureSizes() const;
+    void testSignerInfo() const; // names and stuff
+    void testSignedRanges() const;
 };
 
 std::unique_ptr<QTemporaryDir> TestSignatureBasics::tmpdir;
@@ -74,7 +74,7 @@ void TestSignatureBasics::initTestCase_data()
 #endif
     QTest::addColumn<std::string>("filename");
 
-    for (auto document : { TESTDATADIR "/unittestcases/pdf-signature-sample-2sigs.pdf", TESTDATADIR "/unittestcases/pdf-signature-sample-2sigs-randompadded.pdf" }) {
+    for (const auto *document : { TESTDATADIR "/unittestcases/pdf-signature-sample-2sigs.pdf", TESTDATADIR "/unittestcases/pdf-signature-sample-2sigs-randompadded.pdf" }) {
 #if ENABLE_SIGNATURES
 
 #    if ENABLE_NSS3
@@ -102,7 +102,7 @@ void TestSignatureBasics::cleanupTestCase()
     globalParams.reset();
 }
 
-void TestSignatureBasics::testSignatureCount()
+void TestSignatureBasics::testSignatureCount() const
 {
     QVERIFY(doc);
     auto signatureFields = doc->getSignatureFields();
@@ -114,7 +114,7 @@ void TestSignatureBasics::testSignatureCount()
     QVERIFY(signatureFields[3]->getSignature().empty());
 }
 
-void TestSignatureBasics::testSignatureSizes()
+void TestSignatureBasics::testSignatureSizes() const
 {
     auto signatureFields = doc->getSignatureFields();
     // These are not the actual signature lengths, but rather
@@ -126,12 +126,12 @@ void TestSignatureBasics::testSignatureSizes()
     QCOMPARE(signatureFields[1]->getSignature().size(), 10196); // Signature data size is 2340
 }
 
-void TestSignatureBasics::testSignerInfo()
+void TestSignatureBasics::testSignerInfo() const
 {
     auto signatureFields = doc->getSignatureFields();
     QCOMPARE(signatureFields[0]->getCreateWidget()->getField()->getFullyQualifiedName()->toStr(), std::string { "P2.AnA_Signature0_B_" });
     QCOMPARE(signatureFields[0]->getSignatureType(), CryptoSign::SignatureType::ETSI_CAdES_detached);
-    auto siginfo0 = signatureFields[0]->validateSignatureAsync(false, false, -1 /* now */, false, false, {});
+    auto *siginfo0 = signatureFields[0]->validateSignatureAsync(false, false, -1 /* now */, false, false, {});
     signatureFields[0]->validateSignatureResult();
 #if ENABLE_SIGNATURES
     QCOMPARE(siginfo0->getSignerName(), std::string { "Koch, Werner" });
@@ -145,7 +145,7 @@ void TestSignatureBasics::testSignerInfo()
 
     QCOMPARE(signatureFields[1]->getCreateWidget()->getField()->getFullyQualifiedName()->toStr(), std::string { "P2.AnA_Signature1_B_" });
     QCOMPARE(signatureFields[1]->getSignatureType(), CryptoSign::SignatureType::ETSI_CAdES_detached);
-    auto siginfo1 = signatureFields[1]->validateSignatureAsync(false, false, -1 /* now */, false, false, {});
+    auto *siginfo1 = signatureFields[1]->validateSignatureAsync(false, false, -1 /* now */, false, false, {});
     signatureFields[1]->validateSignatureResult();
 #if ENABLE_SIGNATURES
     QCOMPARE(siginfo1->getSignerName(), std::string { "Koch, Werner" });
@@ -169,7 +169,7 @@ void TestSignatureBasics::testSignerInfo()
     QCOMPARE(signatureFields[3]->getSignatureType(), CryptoSign::SignatureType::unsigned_signature_field);
 }
 
-void TestSignatureBasics::testSignedRanges()
+void TestSignatureBasics::testSignedRanges() const
 {
     auto signatureFields = doc->getSignatureFields();
 
