@@ -42,16 +42,16 @@ public:
     QVector<GooString *> m_gooStrings;
 
 private Q_SLOTS:
-    void initTestCase();
-    void cleanupTestCase();
-    void check_unicodeToQString_data();
-    void check_unicodeToQString();
+    static void initTestCase();
+    void cleanupTestCase() const;
+    static void check_unicodeToQString_data();
+    static void check_unicodeToQString();
     void check_UnicodeParsedString_data();
-    void check_UnicodeParsedString();
-    void check_QStringToUnicodeGooString_data();
-    void check_QStringToUnicodeGooString();
+    static void check_UnicodeParsedString();
+    static void check_QStringToUnicodeGooString_data();
+    static void check_QStringToUnicodeGooString();
     void check_QStringToGooString_data();
-    void check_QStringToGooString();
+    static void check_QStringToGooString();
 };
 
 void TestStrings::initTestCase()
@@ -62,7 +62,7 @@ void TestStrings::initTestCase()
     globalParams = std::make_unique<GlobalParams>();
 }
 
-void TestStrings::cleanupTestCase()
+void TestStrings::cleanupTestCase() const
 {
     qDeleteAll(m_gooStrings);
 
@@ -77,40 +77,40 @@ void TestStrings::check_unicodeToQString_data()
 
     {
         const int l = 1;
-        Unicode *u = new Unicode[l];
+        auto *u = new Unicode[l];
         u[0] = int('a');
         QTest::newRow("a") << u << l << QStringLiteral("a");
     }
     {
         const int l = 1;
-        Unicode *u = new Unicode[l];
+        auto *u = new Unicode[l];
         u[0] = 0x0161;
         QTest::newRow("\u0161") << u << l << QStringLiteral("\u0161");
     }
     {
         const int l = 2;
-        Unicode *u = new Unicode[l];
+        auto *u = new Unicode[l];
         u[0] = int('a');
         u[1] = int('b');
         QTest::newRow("ab") << u << l << QStringLiteral("ab");
     }
     {
         const int l = 2;
-        Unicode *u = new Unicode[l];
+        auto *u = new Unicode[l];
         u[0] = int('a');
         u[1] = 0x0161;
         QTest::newRow("a\u0161") << u << l << QStringLiteral("a\u0161");
     }
     {
         const int l = 2;
-        Unicode *u = new Unicode[l];
+        auto *u = new Unicode[l];
         u[0] = 0x5c01;
         u[1] = 0x9762;
         QTest::newRow("\xe5\xb0\x81\xe9\x9d\xa2") << u << l << QStringLiteral("封面");
     }
     {
         const int l = 3;
-        Unicode *u = new Unicode[l];
+        auto *u = new Unicode[l];
         u[0] = 0x5c01;
         u[1] = 0x9762;
         u[2] = 0x0;
@@ -118,7 +118,7 @@ void TestStrings::check_unicodeToQString_data()
     }
     {
         const int l = 4;
-        Unicode *u = new Unicode[l];
+        auto *u = new Unicode[l];
         u[0] = 0x5c01;
         u[1] = 0x9762;
         u[2] = 0x0;
@@ -223,14 +223,14 @@ void TestStrings::check_QStringToGooString()
 
 GooString *TestStrings::newGooString(const char *s)
 {
-    GooString *goo = new GooString(s);
+    auto *goo = new GooString(s);
     m_gooStrings.append(goo);
     return goo;
 }
 
 GooString *TestStrings::newGooString(const char *s, int l)
 {
-    GooString *goo = new GooString(s, l);
+    auto *goo = new GooString(s, l);
     m_gooStrings.append(goo);
     return goo;
 }
