@@ -223,7 +223,7 @@ int main(int argc, char **argv)
                 std::cout << "\t\t\tVisible: " << form->isVisible() << std::endl;
                 switch (form->type()) {
                 case Poppler::FormField::FormButton: {
-                    const Poppler::FormFieldButton *buttonForm = static_cast<const Poppler::FormFieldButton *>(form.get());
+                    const auto *buttonForm = static_cast<const Poppler::FormFieldButton *>(form.get());
                     std::cout << "\t\t\tButtonType: " << buttonForm->buttonType() << std::endl;
                     std::cout << "\t\t\tCaption: " << buttonForm->caption() << std::endl;
                     std::cout << "\t\t\tState: " << buttonForm->state() << std::endl;
@@ -231,7 +231,7 @@ int main(int argc, char **argv)
                 } break;
 
                 case Poppler::FormField::FormText: {
-                    const Poppler::FormFieldText *textForm = static_cast<const Poppler::FormFieldText *>(form.get());
+                    const auto *textForm = static_cast<const Poppler::FormFieldText *>(form.get());
                     std::cout << "\t\t\tTextType: " << textForm->textType() << std::endl;
                     std::cout << "\t\t\tText: " << textForm->text() << std::endl;
                     std::cout << "\t\t\tIsPassword: " << textForm->isPassword() << std::endl;
@@ -242,7 +242,7 @@ int main(int argc, char **argv)
                 } break;
 
                 case Poppler::FormField::FormChoice: {
-                    const Poppler::FormFieldChoice *choiceForm = static_cast<const Poppler::FormFieldChoice *>(form.get());
+                    const auto *choiceForm = static_cast<const Poppler::FormFieldChoice *>(form.get());
                     std::cout << "\t\t\tChoiceType: " << choiceForm->choiceType() << std::endl;
                     std::cout << "\t\t\tChoices: " << choiceForm->choices() << std::endl;
                     std::cout << "\t\t\tIsEditable: " << choiceForm->isEditable() << std::endl;
@@ -254,12 +254,12 @@ int main(int argc, char **argv)
                 } break;
 
                 case Poppler::FormField::FormSignature: {
-                    const Poppler::FormFieldSignature *signatureForm = static_cast<const Poppler::FormFieldSignature *>(form.get());
+                    const auto *signatureForm = static_cast<const Poppler::FormFieldSignature *>(form.get());
                     const Poppler::SignatureValidationInfo svi = signatureForm->validateAsync(Poppler::FormFieldSignature::ValidateVerifyCertificate).first;
                     const Poppler::SignatureValidationInfo::CertificateStatus certStatus = signatureForm->validateResult();
                     std::cout << "\t\t\tSignatureStatus: " << svi.signatureStatus() << std::endl;
                     std::cout << "\t\t\tCertificateStatus: " << certStatus << std::endl;
-                    if (svi.signerName().isEmpty() == false) {
+                    if (!svi.signerName().isEmpty()) {
                         std::cout << "\t\t\tSignerName: " << svi.signerName() << std::endl;
                     } else {
                         std::cout << "\t\t\tSignerName: "
