@@ -72,7 +72,7 @@ SillyThread::SillyThread(Poppler::Document *document, QObject *parent) : QThread
 
 void SillyThread::run()
 {
-    forever {
+    Q_FOREVER {
         for (std::unique_ptr<Poppler::Page> &page : m_pages) {
             QImage image = page->renderToImage();
 
@@ -89,9 +89,9 @@ CrazyThread::CrazyThread(Poppler::Document *document, QMutex *annotationMutex, Q
 
 void CrazyThread::run()
 {
-    typedef std::unique_ptr<Poppler::Page> PagePointer;
+    using PagePointer = std::unique_ptr<Poppler::Page>;
 
-    forever {
+    Q_FOREVER {
         if (QRandomGenerator::global()->bounded(2) == 0) {
             qDebug() << "search...";
 
@@ -253,7 +253,7 @@ int main(int argc, char **argv)
             (new SillyThread(document.get()))->start();
         }
 
-        QMutex *annotationMutex = new QMutex();
+        auto *annotationMutex = new QMutex();
 
         for (int i = 0; i < crazyCount; ++i) {
             (new CrazyThread(document.get(), annotationMutex))->start();
