@@ -13,7 +13,7 @@
 //
 // Copyright (C) 2007 Ilmari Heikkinen <ilmari.heikkinen@gmail.com>
 // Copyright (C) 2009 Shen Liang <shenzhuxi@gmail.com>
-// Copyright (C) 2009, 2012, 2018, 2021 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2009, 2012, 2018, 2021, 2022, 2024-2026 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2009 Stefan Thomas <thomas@eload24.com>
 // Copyright (C) 2010, 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2010 Harry Roberts <harry.roberts@midnight-labs.org>
@@ -33,12 +33,16 @@
 #ifndef SPLASHBITMAP_H
 #define SPLASHBITMAP_H
 
+#include "SplashErrorCodes.h"
 #include "SplashTypes.h"
-#include "poppler/GfxState.h"
 #include "poppler_private_export.h"
 #include <cstdio>
+#include <memory>
+#include <string>
+#include <vector>
 
 class ImgWriter;
+class GfxSeparationColorSpace;
 
 //------------------------------------------------------------------------
 // SplashBitmap
@@ -51,7 +55,7 @@ public:
     // color mode <modeA>.  Rows will be padded out to a multiple of
     // <rowPad> bytes.  If <topDown> is false, the bitmap will be stored
     // upside-down, i.e., with the last row first in memory.
-    SplashBitmap(int widthA, int heightA, int rowPad, SplashColorMode modeA, bool alphaA, bool topDown = true, const std::vector<GfxSeparationColorSpace *> *separationList = nullptr);
+    SplashBitmap(int widthA, int heightA, int rowPad, SplashColorMode modeA, bool alphaA, bool topDown = true, const std::vector<std::unique_ptr<GfxSeparationColorSpace>> *separationList = nullptr);
     static SplashBitmap *copy(const SplashBitmap *src);
 
     ~SplashBitmap();
@@ -67,10 +71,10 @@ public:
     SplashColorMode getMode() const { return mode; }
     SplashColorPtr getDataPtr() { return data; }
     unsigned char *getAlphaPtr() { return alpha; }
-    std::vector<GfxSeparationColorSpace *> *getSeparationList() { return separationList; }
+    std::vector<std::unique_ptr<GfxSeparationColorSpace>> *getSeparationList() { return separationList; }
     SplashColorConstPtr getDataPtr() const { return data; }
     const unsigned char *getAlphaPtr() const { return alpha; }
-    const std::vector<GfxSeparationColorSpace *> *getSeparationList() const { return separationList; }
+    const std::vector<std::unique_ptr<GfxSeparationColorSpace>> *getSeparationList() const { return separationList; }
 
     SplashError writePNMFile(char *fileName);
     SplashError writePNMFile(FILE *f);
@@ -80,13 +84,13 @@ public:
     {
         int jpegQuality = -1;
         bool jpegProgressive = false;
-        GooString tiffCompression;
+        std::string tiffCompression;
         bool jpegOptimize = false;
     };
 
-    SplashError writeImgFile(SplashImageFileFormat format, const char *fileName, int hDPI, int vDPI, WriteImgParams *params = nullptr);
-    SplashError writeImgFile(SplashImageFileFormat format, FILE *f, int hDPI, int vDPI, WriteImgParams *params = nullptr);
-    SplashError writeImgFile(ImgWriter *writer, FILE *f, int hDPI, int vDPI, SplashColorMode imageWriterFormat);
+    SplashError writeImgFile(SplashImageFileFormat format, const char *fileName, double hDPI, double vDPI, WriteImgParams *params = nullptr);
+    SplashError writeImgFile(SplashImageFileFormat format, FILE *f, double hDPI, double vDPI, WriteImgParams *params = nullptr);
+    SplashError writeImgFile(ImgWriter *writer, FILE *f, double hDPI, double vDPI, SplashColorMode imageWriterFormat);
 
     enum ConversionMode
     {
@@ -97,7 +101,7 @@ public:
 
     bool convertToXBGR(ConversionMode conversionMode = conversionOpaque);
 
-    void getPixel(int x, int y, SplashColorPtr pixel);
+    void getPixel(int x, int y, SplashColorPtr pixel) const;
     void getRGBLine(int y, SplashColorPtr line);
     void getXBGRLine(int y, SplashColorPtr line, ConversionMode conversionMode = conversionOpaque);
     void getCMYKLine(int y, SplashColorPtr line);
@@ -117,11 +121,11 @@ private:
     SplashColorPtr data; // pointer to row zero of the color data
     unsigned char *alpha; // pointer to row zero of the alpha data
                           //   (always top-down)
-    std::vector<GfxSeparationColorSpace *> *separationList; // list of spot colorants and their mapping functions
+    std::vector<std::unique_ptr<GfxSeparationColorSpace>> *separationList; // list of spot colorants and their mapping functions
 
     friend class Splash;
 
-    void setJpegParams(ImgWriter *writer, WriteImgParams *params);
+    static void setJpegParams(ImgWriter *writer, WriteImgParams *params);
 };
 
 #endif
