@@ -11,7 +11,7 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2005, 2007-2011, 2014, 2018, 2020, 2025 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2007-2011, 2014, 2018, 2020, 2025, 2026 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2006 Kristian Høgsberg <krh@bitplanet.net>
 // Copyright (C) 2009 Petr Gajdos <pgajdos@novell.com>
 // Copyright (C) 2010 Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
@@ -19,7 +19,7 @@
 // Copyright (C) 2012 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2018 Oliver Sander <oliver.sander@tu-dresden.de>
-// Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2025, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -53,8 +53,8 @@ static int glyphPathCubicTo(const FT_Vector *ctrl1, const FT_Vector *ctrl2, cons
 // SplashFTFont
 //------------------------------------------------------------------------
 
-SplashFTFont::SplashFTFont(SplashFTFontFile *fontFileA, const std::array<SplashCoord, 4> &matA, const std::array<SplashCoord, 4> &textMatA)
-    : SplashFont(fontFileA, matA, textMatA, fontFileA->engine->aa), textScale(0), enableFreeTypeHinting(fontFileA->engine->enableFreeTypeHinting), enableSlightHinting(fontFileA->engine->enableSlightHinting), isOk(false)
+SplashFTFont::SplashFTFont(const std::shared_ptr<SplashFTFontFile> &fontFileA, const std::array<SplashCoord, 4> &matA, const std::array<SplashCoord, 4> &textMatA)
+    : SplashFont(fontFileA, matA, textMatA, fontFileA->engine->aa), enableFreeTypeHinting(fontFileA->engine->enableFreeTypeHinting), enableSlightHinting(fontFileA->engine->enableSlightHinting)
 {
     FT_Face face;
     int div;
@@ -150,7 +150,7 @@ SplashFTFont::SplashFTFont(SplashFTFontFile *fontFileA, const std::array<SplashC
 
 SplashFTFont::~SplashFTFont() = default;
 
-bool SplashFTFont::getGlyph(int c, int xFrac, int /*yFrac*/, SplashGlyphBitmap *bitmap, int x0, int y0, SplashClip *clip, SplashClipResult *clipRes)
+bool SplashFTFont::getGlyph(int c, int xFrac, int /*yFrac*/, SplashGlyphBitmap *bitmap, int x0, int y0, const SplashClip &clip, SplashClipResult *clipRes)
 {
     return SplashFont::getGlyph(c, xFrac, 0, bitmap, x0, y0, clip, clipRes);
 }
@@ -185,7 +185,7 @@ static FT_Int32 getFTLoadFlags(bool type1, bool trueType, bool aa, bool enableFr
     return ret;
 }
 
-bool SplashFTFont::makeGlyph(int c, int xFrac, int /*yFrac*/, SplashGlyphBitmap *bitmap, int x0, int y0, SplashClip *clip, SplashClipResult *clipRes)
+bool SplashFTFont::makeGlyph(int c, int xFrac, int /*yFrac*/, SplashGlyphBitmap *bitmap, int x0, int y0, const SplashClip &clip, SplashClipResult *clipRes)
 {
     SplashFTFontFile *ff;
     FT_Vector offset;
@@ -199,7 +199,7 @@ bool SplashFTFont::makeGlyph(int c, int xFrac, int /*yFrac*/, SplashGlyphBitmap
         return false;
     }
 
-    ff = (SplashFTFontFile *)fontFile;
+    ff = (SplashFTFontFile *)fontFile.get();
 
     ff->face->size = sizeObj;
     offset.x = (FT_Pos)(int)((SplashCoord)xFrac * splashFontFractionMul * 64);
@@ -207,7 +207,7 @@ bool SplashFTFont::makeGlyph(int c, int xFrac, int /*yFrac*/, SplashGlyphBitmap
     FT_Set_Transform(ff->face, &matrix, &offset);
     slot = ff->face->glyph;
 
-    if (c < int(ff->codeToGID.size()) && c >= 0) {
+    if (c >= 0 && size_t(c) < ff->codeToGID.size()) {
         gid = (FT_UInt)ff->codeToGID[c];
     } else {
         gid = (FT_UInt)c;
@@ -226,7 +226,14 @@ bool SplashFTFont::makeGlyph(int c, int xFrac, int /*yFrac*/, SplashGlyphBitmap
     bitmap->w = ((cbox.xMax - cbox.xMin) / 64) + 4;
     bitmap->h = ((cbox.yMax - cbox.yMin) / 64) + 4;
 
-    *clipRes = clip->testRect(x0 - bitmap->x, y0 - bitmap->y, x0 - bitmap->x + bitmap->w, y0 - bitmap->y + bitmap->h);
+    int rectXMin, rectYMin;
+    if (checkedSubtraction(x0, bitmap->x, &rectXMin)) {
+        return false;
+    }
+    if (checkedSubtraction(y0, bitmap->y, &rectYMin)) {
+        return false;
+    }
+    *clipRes = clip.testRect(rectXMin, rectYMin, rectXMin + bitmap->w, rectYMin + bitmap->h);
     if (*clipRes == splashClipAllOutside) {
         bitmap->freeData = false;
         return true;
@@ -271,7 +278,7 @@ double SplashFTFont::getGlyphAdvance(int c)
     FT_UInt gid;
     FT_Matrix identityMatrix;
 
-    ff = (SplashFTFontFile *)fontFile;
+    ff = (SplashFTFontFile *)fontFile.get();
 
     // init the matrix
     identityMatrix.xx = 65536; // 1 in 16.16 format
@@ -286,7 +293,7 @@ double SplashFTFont::getGlyphAdvance(int c)
     ff->face->size = sizeObj;
     FT_Set_Transform(ff->face, &identityMatrix, &offset);
 
-    if (c < int(ff->codeToGID.size())) {
+    if (c >= 0 && size_t(c) < ff->codeToGID.size()) {
         gid = (FT_UInt)ff->codeToGID[c];
     } else {
         gid = (FT_UInt)c;
@@ -334,11 +341,11 @@ SplashPath *SplashFTFont::getGlyphPath(int c)
         return nullptr;
     }
 
-    ff = (SplashFTFontFile *)fontFile;
+    ff = (SplashFTFontFile *)fontFile.get();
     ff->face->size = sizeObj;
     FT_Set_Transform(ff->face, &textMatrix, nullptr);
     slot = ff->face->glyph;
-    if (c < int(ff->codeToGID.size()) && c >= 0) {
+    if (c >= 0 && size_t(c) < ff->codeToGID.size()) {
         gid = ff->codeToGID[c];
     } else {
         gid = (FT_UInt)c;
@@ -365,7 +372,7 @@ SplashPath *SplashFTFont::getGlyphPath(int c)
 
 static int glyphPathMoveTo(const FT_Vector *pt, void *path)
 {
-    SplashFTFontPath *p = (SplashFTFontPath *)path;
+    auto *p = (SplashFTFontPath *)path;
 
     if (p->needClose) {
         p->path->close();
@@ -377,7 +384,7 @@ static int glyphPathMoveTo(const FT_Vector *pt, void *path)
 
 static int glyphPathLineTo(const FT_Vector *pt, void *path)
 {
-    SplashFTFontPath *p = (SplashFTFontPath *)path;
+    auto *p = (SplashFTFontPath *)path;
 
     p->path->lineTo((SplashCoord)pt->x * p->textScale / 64.0, (SplashCoord)pt->y * p->textScale / 64.0);
     p->needClose = true;
@@ -386,7 +393,7 @@ static int glyphPathLineTo(const FT_Vector *pt, void *path)
 
 static int glyphPathConicTo(const FT_Vector *ctrl, const FT_Vector *pt, void *path)
 {
-    SplashFTFontPath *p = (SplashFTFontPath *)path;
+    auto *p = (SplashFTFontPath *)path;
     SplashCoord x0, y0, x1, y1, x2, y2, x3, y3, xc, yc;
 
     if (!p->path->getCurPt(&x0, &y0)) {
@@ -425,7 +432,7 @@ static int glyphPathConicTo(const FT_Vector *ctrl, const FT_Vector *pt, void *pa
 
 static int glyphPathCubicTo(const FT_Vector *ctrl1, const FT_Vector *ctrl2, const FT_Vector *pt, void *path)
 {
-    SplashFTFontPath *p = (SplashFTFontPath *)path;
+    auto *p = (SplashFTFontPath *)path;
 
     p->path->curveTo((SplashCoord)ctrl1->x * p->textScale / 64.0, (SplashCoord)ctrl1->y * p->textScale / 64.0, (SplashCoord)ctrl2->x * p->textScale / 64.0, (SplashCoord)ctrl2->y * p->textScale / 64.0,
                      (SplashCoord)pt->x * p->textScale / 64.0, (SplashCoord)pt->y * p->textScale / 64.0);
