@@ -12,10 +12,10 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2006 Takashi Iwai <tiwai@suse.de>
-// Copyright (C) 2008, 2022 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2008, 2022, 2025, 2026 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2019 Christian Persch <chpe@src.gnome.org>
 // Copyright (C) 2022 Oliver Sander <oliver.sander@tu-dresden.de>
-// Copyright (C) 2024, 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2024-2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -24,10 +24,6 @@
 
 #include <config.h>
 
-#include <cstdio>
-#ifdef HAVE_UNISTD_H
-#    include <unistd.h>
-#endif
 #include "SplashFontFile.h"
 #include "SplashFontFileID.h"
 
@@ -35,62 +31,17 @@
 // SplashFontFile
 //------------------------------------------------------------------------
 
-SplashFontFile::SplashFontFile(std::unique_ptr<SplashFontFileID> idA, SplashFontSrc *srcA)
+SplashFontFile::SplashFontFile(std::unique_ptr<SplashFontFileID> idA, std::unique_ptr<SplashFontSrc> srcA) : src(std::move(srcA))
 {
     id = std::move(idA);
-    src = srcA;
-    src->ref();
-    refCnt = 0;
     doAdjustMatrix = false;
 }
 
-SplashFontFile::~SplashFontFile()
-{
-    src->unref();
-}
-
-void SplashFontFile::incRefCnt()
-{
-    ++refCnt;
-}
-
-void SplashFontFile::decRefCnt()
-{
-    if (!--refCnt) {
-        delete this;
-    }
-}
+SplashFontFile::~SplashFontFile() = default;
 
 //
 
-SplashFontSrc::SplashFontSrc()
-{
-    isFile = false;
-    refcnt = 1;
-}
+SplashFontSrc::SplashFontSrc(const std::string &file) : m_data(file) { }
+SplashFontSrc::SplashFontSrc(std::vector<unsigned char> &&data) : m_data(std::move(data)) { }
 
 SplashFontSrc::~SplashFontSrc() = default;
-
-void SplashFontSrc::ref()
-{
-    refcnt++;
-}
-
-void SplashFontSrc::unref()
-{
-    if (!--refcnt) {
-        delete this;
-    }
-}
-
-void SplashFontSrc::setFile(const std::string &file)
-{
-    isFile = true;
-    fileName = file;
-}
-
-void SplashFontSrc::setBuf(std::vector<unsigned char> &&bufA)
-{
-    isFile = false;
-    buf = std::move(bufA);
-}
