@@ -32,7 +32,7 @@ struct SplashXPathAdjust;
 
 //------------------------------------------------------------------------
 
-#define splashMaxCurveSplits (1 << 10)
+static constexpr int splashMaxCurveSplits = 1 << 10;
 
 //------------------------------------------------------------------------
 // SplashXPathSeg
@@ -75,8 +75,8 @@ public:
     void aaScale();
 
 protected:
-    void transform(const std::array<SplashCoord, 6> &matrix, SplashCoord xi, SplashCoord yi, SplashCoord *xo, SplashCoord *yo);
-    void strokeAdjust(SplashXPathAdjust *adjust, SplashCoord *xp, SplashCoord *yp);
+    static void transform(const std::array<SplashCoord, 6> &matrix, SplashCoord xi, SplashCoord yi, SplashCoord *xo, SplashCoord *yo);
+    static void strokeAdjust(SplashXPathAdjust *adjust, SplashCoord *xp, SplashCoord *yp);
     void grow(int nSegs);
     void addCurve(SplashCoord x0, SplashCoord y0, SplashCoord x1, SplashCoord y1, SplashCoord x2, SplashCoord y2, SplashCoord x3, SplashCoord y3, SplashCoord flatness);
     void addSegment(SplashCoord x0, SplashCoord y0, SplashCoord x1, SplashCoord y1);
