@@ -11,7 +11,7 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2008, 2010, 2014, 2018, 2019, 2021, 2022, 2024, 2025 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2008, 2010, 2014, 2018, 2019, 2021, 2022, 2024-2026 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2010 Paweł Wiejacha <pawel.wiejacha@gmail.com>
 // Copyright (C) 2013, 2014, 2021 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2018, 2025 Stefan Brüns <stefan.bruens@rwth-aachen.de>
@@ -40,7 +40,7 @@
 //------------------------------------------------------------------------
 
 SplashXPathScanner::SplashXPathScanner(const SplashXPath &xPath, bool eoA, int clipYMin, int clipYMax) //
-    : eo(eoA), xMin(1), yMin(1), xMax(0), yMax(0)
+    : eo(eoA)
 {
     // compute the bbox
     if (xPath.length == 0) {
@@ -107,6 +107,11 @@ SplashXPathScanner::SplashXPathScanner(const SplashXPath &xPath, bool eoA, int c
         yMax = clipYMax;
     }
 
+    if (yMin > yMax) {
+        // This means the splashFloors overflowed/underflowed
+        return;
+    }
+
     computeIntersections(xPath);
 }
 
@@ -193,8 +198,7 @@ bool SplashXPathScanIterator::getNextSpan(int *x0, int *x1)
     return true;
 }
 
-SplashXPathScanIterator::SplashXPathScanIterator(const SplashXPathScanner &scanner, int y)
-    : line((y < scanner.yMin || y > scanner.yMax) ? scanner.allIntersections[0] : scanner.allIntersections[y - scanner.yMin]), interIdx(0), interCount(0), eo(scanner.eo)
+SplashXPathScanIterator::SplashXPathScanIterator(const SplashXPathScanner &scanner, int y) : line((y < scanner.yMin || y > scanner.yMax) ? scanner.allIntersections[0] : scanner.allIntersections[y - scanner.yMin]), eo(scanner.eo)
 {
     if (y < scanner.yMin || y > scanner.yMax) {
         // set index to line end
@@ -441,7 +445,7 @@ void SplashXPathScanner::clipAALine(SplashBitmap *aaBuf, const int *x0, const in
                 if (xx < xx0) {
                     SplashColorPtr p = aaBuf->getDataPtr() + yy * aaBuf->getRowSize() + (xx >> 3);
                     if (xx & 7) {
-                        unsigned char mask = (unsigned char)(0xff00 >> (xx & 7));
+                        auto mask = (unsigned char)(0xff00 >> (xx & 7));
                         if ((xx & ~7) == (xx0 & ~7)) {
                             mask |= 0xff >> (xx0 & 7);
                         }
@@ -468,7 +472,7 @@ void SplashXPathScanner::clipAALine(SplashBitmap *aaBuf, const int *x0, const in
         if (xx < xx0 && xx >= 0) {
             SplashColorPtr p = aaBuf->getDataPtr() + yy * aaBuf->getRowSize() + (xx >> 3);
             if (xx & 7) {
-                unsigned char mask = (unsigned char)(0xff00 >> (xx & 7));
+                auto mask = (unsigned char)(0xff00 >> (xx & 7));
                 if ((xx & ~7) == (xx0 & ~7)) {
                     mask &= 0xff >> (xx0 & 7);
                 }
