@@ -72,19 +72,19 @@ public:
     void redraw(int srcX, int srcY, cairo_t *cr, int width, int height);
 
 private:
-    int incrementalUpdate;
+    int incrementalUpdate = 1;
     void (*redrawCbk)(void *data);
     void *redrawCbkData;
 };
 
-typedef struct
+struct View
 {
     PopplerDocument *doc;
     GtkWidget *drawing_area;
     GtkWidget *spin_button;
     cairo_surface_t *surface;
     GDKSplashOutputDev *out;
-} View;
+};
 
 //------------------------------------------------------------------------
 // Constants and macros
@@ -96,7 +96,7 @@ typedef struct
 // GDKSplashOutputDev
 //------------------------------------------------------------------------
 
-GDKSplashOutputDev::GDKSplashOutputDev(GdkScreen * /*screen*/, void (*redrawCbkA)(void *data), void *redrawCbkDataA, SplashColor sc) : SplashOutputDev(splashModeRGB8, 4, false, sc), incrementalUpdate(1)
+GDKSplashOutputDev::GDKSplashOutputDev(GdkScreen * /*screen*/, void (*redrawCbkA)(void *data), void *redrawCbkDataA, SplashColor sc) : SplashOutputDev(splashModeRGB8, 4, sc)
 {
     redrawCbk = redrawCbkA;
     redrawCbkData = redrawCbkDataA;
@@ -311,7 +311,7 @@ static View *view_new(PopplerDocument *doc)
         SplashColor sc = { 255, 255, 255 };
 
         view->out = new GDKSplashOutputDev(gtk_widget_get_screen(window), redraw_callback, (void *)view, sc);
-        view->out->startDoc(view->doc->doc);
+        view->out->startDoc(view->doc->doc.get());
     }
 
     g_signal_connect(view->drawing_area, "draw", G_CALLBACK(drawing_area_draw), view);
