@@ -1,6 +1,6 @@
 /* Copyright Krzysztof Kowalczyk 2006-2007
    Copyright Hib Eris <hib@hiberis.nl> 2008, 2013
-   Copyright 2018, 2020, 2022, 2025 Albert Astals Cid <aacid@kde.org> 2018
+   Copyright 2018, 2020, 2022, 2025, 2026 Albert Astals Cid <aacid@kde.org> 2018
    Copyright 2019 Oliver Sander <oliver.sander@tu-dresden.de>
    Copyright 2020 Adam Reichold <adam.reichold@t-online.de>
    Copyright 2024 Vincent Lefevre <vincent@vinc17.net>
@@ -56,7 +56,7 @@
 
 #define dimof(X) (sizeof(X) / sizeof((X)[0]))
 
-#define INVALID_PAGE_NO (-1)
+constexpr int INVALID_PAGE_NO = -1;
 
 class PdfEnginePoppler
 {
@@ -72,7 +72,7 @@ public:
     void setFileName(const char *fileName)
     {
         assert(!_fileName);
-        _fileName = (char *)strdup(fileName);
+        _fileName = strdup(fileName);
     }
 
     int pageCount() const { return _pageCount; }
@@ -83,18 +83,18 @@ public:
     SplashOutputDev *outputDevice();
 
 private:
-    char *_fileName;
-    int _pageCount;
+    char *_fileName = nullptr;
+    int _pageCount = INVALID_PAGE_NO;
 
-    PDFDoc *_pdfDoc;
-    SplashOutputDev *_outputDev;
+    PDFDoc *_pdfDoc = nullptr;
+    SplashOutputDev *_outputDev = nullptr;
 };
 
-typedef struct StrList
+struct StrList
 {
     struct StrList *next;
     char *str;
-} StrList;
+};
 
 /* List of all command-line arguments that are not switches.
    We assume those are:
@@ -105,13 +105,13 @@ typedef struct StrList
 static StrList *gArgsListRoot = nullptr;
 
 /* Names of all command-line switches we recognize */
-#define TIMINGS_ARG "-timings"
-#define RESOLUTION_ARG "-resolution"
-#define RECURSIVE_ARG "-recursive"
-#define OUT_ARG "-out"
-#define LOAD_ONLY_ARG "-loadonly"
-#define PAGE_ARG "-page"
-#define TEXT_ARG "-text"
+constexpr const char *TIMINGS_ARG = "-timings";
+constexpr const char *RESOLUTION_ARG = "-resolution";
+constexpr const char *RECURSIVE_ARG = "-recursive";
+constexpr const char *OUT_ARG = "-out";
+constexpr const char *LOAD_ONLY_ARG = "-loadonly";
+constexpr const char *PAGE_ARG = "-page";
+constexpr const char *TEXT_ARG = "-text";
 
 /* Should we record timings? True if -timings command-line argument was given. */
 static bool gfTimings = false;
@@ -138,13 +138,10 @@ static FILE *gErrFile = nullptr;
    Controlled by -recursive command-line argument */
 static bool gfRecursive = false;
 
-/* 1 second (1000 milliseconds) */
-#define SLOW_PREVIEW_TIME 1000
-
 /* If true, we only dump the text, not render */
 static bool gfTextOnly = false;
 
-#define PAGE_NO_NOT_GIVEN (-1)
+constexpr int PAGE_NO_NOT_GIVEN = -1;
 
 /* If equals PAGE_NO_NOT_GIVEN, we're in default mode where we render all pages.
    If different, will only render this page */
@@ -153,17 +150,7 @@ static int gPageNo = PAGE_NO_NOT_GIVEN;
    profiling load time */
 static bool gfLoadOnly = false;
 
-#define PDF_FILE_DPI 72
-
-#define MAX_FILENAME_SIZE 1024
-
-/* DOS is 0xd 0xa */
-#define DOS_NEWLINE "\x0d\x0a"
-/* Mac is single 0xd */
-#define MAC_NEWLINE "\x0d"
-/* Unix is single 0xa (10) */
-#define UNIX_NEWLINE "\x0a"
-#define UNIX_NEWLINE_C 0xa
+constexpr int PDF_FILE_DPI = 72;
 
 static void memzero(void *data, size_t len)
 {
@@ -324,7 +311,7 @@ static void SplashColorsInit()
     splashColorSet(SPLASH_COL_WHITE_PTR, 0xff, 0xff, 0xff);
 }
 
-PdfEnginePoppler::PdfEnginePoppler() : _fileName(nullptr), _pageCount(INVALID_PAGE_NO), _pdfDoc(nullptr), _outputDev(nullptr) { }
+PdfEnginePoppler::PdfEnginePoppler() = default;
 
 PdfEnginePoppler::~PdfEnginePoppler()
 {
@@ -349,7 +336,7 @@ SplashOutputDev *PdfEnginePoppler::outputDevice()
 {
     if (!_outputDev) {
         bool bitmapTopDown = true;
-        _outputDev = new SplashOutputDev(gSplashColorMode, 4, false, gBgColor, bitmapTopDown);
+        _outputDev = new SplashOutputDev(gSplashColorMode, 4, gBgColor, bitmapTopDown);
         if (_outputDev) {
             _outputDev->startDoc(_pdfDoc);
         }
@@ -455,7 +442,7 @@ static void StrList_Destroy(StrList **root)
     *root = nullptr;
 }
 
-static void my_error(ErrorCategory, Goffset /*pos*/, const char * /*msg*/)
+static void my_error(ErrorCategory /*category*/, Goffset /*pos*/, const char * /*msg*/)
 {
 #if 0
     char        buf[4096], *p = buf;
@@ -548,7 +535,7 @@ static void RenderPdfAsText(const char *fileName)
 
     LogInfo("started: %s\n", fileName);
 
-    TextOutputDev *textOut = new TextOutputDev(nullptr, true, 0, false, false);
+    auto *textOut = new TextOutputDev(nullptr, true, 0, false, false);
     if (!textOut->isOk()) {
         delete textOut;
         return;
@@ -798,10 +785,7 @@ static void ParseCommandLine(int argc, char **argv)
 
 static bool IsPdfFileName(char *path)
 {
-    if (str_endswith(path, ".pdf")) {
-        return true;
-    }
-    return false;
+    return str_endswith(path, ".pdf");
 }
 
 /* Render 'cmdLineArg', which can be:
