@@ -18,7 +18,7 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2010 OSSD CDAC Mumbai by Leena Chourey (leenac@cdacmumbai.in) and Onkar Potdar (onkar@cdacmumbai.in)
-// Copyright (C) 2010, 2012, 2017, 2018, 2020 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2010, 2012, 2017, 2018, 2020, 2026 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2011 Steven Murdoch <Steven.Murdoch@cl.cam.ac.uk>
 // Copyright (C) 2011 Joshua Richardson <jric@chegg.com>
 // Copyright (C) 2012 Igor Slepchin <igor.slepchin@gmail.com>
@@ -46,13 +46,13 @@ private:
     unsigned int g;
     unsigned int b;
     unsigned int opacity;
-    bool Ok(unsigned int xcol) { return xcol <= 255; }
-    std::unique_ptr<GooString> convtoX(unsigned int xcol) const;
+    static bool Ok(unsigned int xcol) { return xcol <= 255; }
+    static std::string convtoX(unsigned int xcol);
 
 public:
     HtmlFontColor() : r(0), g(0), b(0), opacity(255) { }
     HtmlFontColor(GfxRGB rgb, double opacity);
-    std::unique_ptr<GooString> toString() const;
+    std::string toString() const;
     double getOpacity() const { return opacity / 255.0; }
     bool isEqual(HtmlFontColor col) const { return ((r == col.r) && (g == col.g) && (b == col.b) && (opacity == col.opacity)); }
 };
@@ -66,33 +66,31 @@ private:
     bool bold;
     bool rotOrSkewed;
     std::string familyName;
-    std::unique_ptr<GooString> FontName;
+    std::string FontName;
     HtmlFontColor color;
-    double rotSkewMat[4]; // only four values needed for rotation and skew
+    std::array<double, 4> rotSkewMat; // only four values needed for rotation and skew
 public:
     HtmlFont(const GfxFont &font, int _size, GfxRGB rgb, double opacity);
-    HtmlFont(const HtmlFont &x);
-    HtmlFont &operator=(const HtmlFont &x);
     HtmlFontColor getColor() const { return color; }
     ~HtmlFont();
-    std::unique_ptr<GooString> getFullName();
+    std::string getFullName() const;
     bool isItalic() const { return italic; }
     bool isBold() const { return bold; }
     bool isRotOrSkewed() const { return rotOrSkewed; }
     int getSize() const { return size; }
     int getLineSize() const { return lineSize; }
     void setLineSize(int _lineSize) { lineSize = _lineSize; }
-    void setRotMat(const double *const mat)
+    void setRotMat(const std::array<double, 4> &mat)
     {
         rotOrSkewed = true;
-        memcpy(rotSkewMat, mat, sizeof(rotSkewMat));
+        rotSkewMat = mat;
     }
-    const double *getRotMat() const { return rotSkewMat; }
-    std::unique_ptr<GooString> getFontName();
+    const std::array<double, 4> &getRotMat() const { return rotSkewMat; }
+    std::string getFontName() const;
     static std::unique_ptr<GooString> HtmlFilter(const Unicode *u, int uLen); // char* s);
     bool isEqual(const HtmlFont &x) const;
     bool isEqualIgnoreBold(const HtmlFont &x) const;
-    void print() const { printf("font: %s (%s) %d %s%s\n", FontName->c_str(), familyName.c_str(), size, bold ? "bold " : "", italic ? "italic " : ""); };
+    void print() const { printf("font: %s (%s) %d %s%s\n", FontName.c_str(), familyName.c_str(), size, bold ? "bold " : "", italic ? "italic " : ""); };
 };
 
 class HtmlFontAccu
