@@ -17,7 +17,7 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2005-2013, 2016-2022, 2024, 2025 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005-2013, 2016-2022, 2024-2026 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2008 Kjartan Maraas <kmaraas@gnome.org>
 // Copyright (C) 2008 Boris Toloknov <tlknv@yandex.ru>
 // Copyright (C) 2008 Haruyuki Kawabe <Haruyuki.Kawabe@unisys.co.jp>
@@ -47,7 +47,7 @@
 // Copyright (C) 2020 Eddie Kohler <ekohler@gmail.com>
 // Copyright (C) 2021 Christopher Hasse <hasse.christopher@gmail.com>
 // Copyright (C) 2022 Brian Rosenfield <brosenfi@yahoo.com>
-// Copyright (C) 2024, 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2024-2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 // Copyright (C) 2025 Arnav V <arnav0872@gmail.com>
 //
 // To see a description of the changes please see the Changelog file that
@@ -133,9 +133,14 @@ static GooString* Dirname(GooString* str){
 }
 #endif
 
-static std::string print_matrix(const double *mat)
+static std::string print_matrix(const std::array<double, 4> &mat)
 {
-    return GooString::format("[{0:g} {1:g} {2:g} {3:g} {4:g} {5:g}]", *mat, mat[1], mat[2], mat[3], mat[4], mat[5]);
+    return GooString::format("[{0:g} {1:g} {2:g} {3:g}]", mat[0], mat[1], mat[2], mat[3]);
+}
+
+static std::string print_matrix(const std::array<double, 6> &mat)
+{
+    return GooString::format("[{0:g} {1:g} {2:g} {3:g} {4:g} {5:g}]", mat[0], mat[1], mat[2], mat[3], mat[4], mat[5]);
 }
 
 static std::string print_uni_str(const Unicode *u, const unsigned uLen)
@@ -179,8 +184,8 @@ HtmlString::HtmlString(GfxState *state, double fontSize, HtmlFontAccu *_fonts) :
         state->getFillRGB(&rgb);
         HtmlFont hfont = HtmlFont(*font, std::lround(fontSize), rgb, state->getFillOpacity());
         if (isMatRotOrSkew(state->getTextMat())) {
-            double normalizedMatrix[4];
-            memcpy(normalizedMatrix, state->getTextMat(), sizeof(normalizedMatrix));
+            const std::array<double, 6> &textMatrix = state->getTextMat();
+            std::array<double, 4> normalizedMatrix = { textMatrix[0], textMatrix[1], textMatrix[2], textMatrix[3] };
             // browser rotates the opposite way
             // so flip the sign of the angle -> sin() components change sign
             if (debug) {
@@ -358,7 +363,7 @@ void HtmlPage::addChar(GfxState *state, double x, double y, double dx, double dy
     // if ((UnicodeMap::getDirection(u[0]) != curStr->dir) ||
     // XXX
     if (debug) {
-        const double *text_mat = state->getTextMat();
+        const std::array<double, 6> &text_mat = state->getTextMat();
         // rotation is (cos q, sin q, -sin q, cos q, 0, 0)
         // sin q is zero iff there is no rotation, or 180 deg. rotation;
         // for 180 rotation, cos q will be negative
@@ -633,7 +638,7 @@ void HtmlPage::coalesce()
             CloseTags(str1->htext.get(), finish_a, finish_italic, finish_bold);
             if (switch_links && hlink2 != nullptr) {
                 const std::unique_ptr<GooString> ls = hlink2->getLinkStart();
-                str1->htext->append(ls.get());
+                str1->htext->append(ls->toStr());
             }
             if ((!hfont1->isItalic() || finish_italic) && hfont2->isItalic()) {
                 str1->htext->append("<i>", 3);
@@ -642,7 +647,7 @@ void HtmlPage::coalesce()
                 str1->htext->append("<b>", 3);
             }
 
-            str1->htext->append(str2->htext.get());
+            str1->htext->append(str2->htext->toStr());
             // str1 now contains href for link of str2 (if it is defined)
             str1->link = str2->link;
             hfont1 = hfont2;
@@ -709,7 +714,7 @@ void HtmlPage::dumpAsXML(FILE *f, int page)
     }
 
     for (auto &ptr : imgList) {
-        auto img = static_cast<HtmlImage *>(ptr.get());
+        auto *img = static_cast<HtmlImage *>(ptr.get());
         if (!noRoundedCoordinates) {
             fprintf(f, R"(<image top="%d" left="%d" )", xoutRound(img->yMin), xoutRound(img->xMin));
             fprintf(f, R"(width="%d" height="%d" )", xoutRound(img->xMax - img->xMin), xoutRound(img->yMax - img->yMin));
@@ -910,7 +915,7 @@ void HtmlPage::dump(FILE *f, int pageNum, const std::vector<std::string> &backgr
         fprintf(f, "<a name=%d></a>", pageNum);
         // Loop over the list of image names on this page
         for (auto &ptr : imgList) {
-            auto img = static_cast<HtmlImage *>(ptr.get());
+            auto *img = static_cast<HtmlImage *>(ptr.get());
 
             // see printCSS() for class names
             const char *styles[4] = { "", " class=\"xflip\"", " class=\"yflip\"", " class=\"xyflip\"" };
@@ -988,9 +993,9 @@ HtmlMetaVar::~HtmlMetaVar() = default;
 std::unique_ptr<GooString> HtmlMetaVar::toString() const
 {
     auto result = std::make_unique<GooString>("<meta name=\"");
-    result->append(name.get());
+    result->append(name->toStr());
     result->append("\" content=\"");
-    result->append(content.get());
+    result->append(content->toStr());
     result->append("\"/>");
     return result;
 }
@@ -1335,7 +1340,7 @@ void HtmlOutputDev::drawPngImage(GfxState *state, Stream *str, int width, int he
             error(errInternal, -1, "Can't rewind image stream");
             return;
         }
-        unsigned char *row = (unsigned char *)gmalloc(3 * width); // 3 bytes/pixel: RGB
+        auto *row = (unsigned char *)gmalloc(3 * width); // 3 bytes/pixel: RGB
         unsigned char **row_pointer = &row;
 
         // Initialize the image stream
@@ -1389,7 +1394,7 @@ void HtmlOutputDev::drawPngImage(GfxState *state, Stream *str, int width, int he
             error(errInternal, -1, "failed to rewind stream");
             return;
         }
-        unsigned char *png_row = (unsigned char *)gmalloc(size);
+        auto *png_row = (unsigned char *)gmalloc(size);
 
         for (int ri = 0; ri < height; ++ri) {
             for (int i = 0; i < size; i++) {
@@ -1489,7 +1494,7 @@ std::unique_ptr<GooString> HtmlOutputDev::getLinkDest(AnnotLink *link)
     switch (link->getAction()->getKind()) {
     case actionGoTo: {
         int destPage = 1;
-        LinkGoTo *ha = (LinkGoTo *)link->getAction();
+        auto *ha = (LinkGoTo *)link->getAction();
         std::unique_ptr<LinkDest> dest;
         if (ha->getDest() != nullptr) {
             dest = std::make_unique<LinkDest>(*ha->getDest());
@@ -1529,12 +1534,11 @@ std::unique_ptr<GooString> HtmlOutputDev::getLinkDest(AnnotLink *link)
                 printf(" link to page %d ", destPage);
             }
             return file;
-        } else {
-            return std::make_unique<GooString>();
         }
+        return std::make_unique<GooString>();
     }
     case actionGoToR: {
-        LinkGoToR *ha = (LinkGoToR *)link->getAction();
+        auto *ha = (LinkGoToR *)link->getAction();
         LinkDest *dest = nullptr;
         int destPage = 1;
         std::unique_ptr<GooString> file = std::make_unique<GooString>();
@@ -1559,7 +1563,7 @@ std::unique_ptr<GooString> HtmlOutputDev::getLinkDest(AnnotLink *link)
                     file->erase(file->size() - 4, 4);
                     file->append(".html");
                 }
-                file->append('#');
+                file->push_back('#');
                 file->append(std::to_string(destPage));
             }
         }
@@ -1569,13 +1573,13 @@ std::unique_ptr<GooString> HtmlOutputDev::getLinkDest(AnnotLink *link)
         return file;
     }
     case actionURI: {
-        LinkURI *ha = (LinkURI *)link->getAction();
+        auto *ha = (LinkURI *)link->getAction();
         // printf("uri : %s\n",ha->getURI()->c_str());
         return std::make_unique<GooString>(ha->getURI());
     }
     case actionLaunch:
         if (printHtml) {
-            LinkLaunch *ha = (LinkLaunch *)link->getAction();
+            auto *ha = (LinkLaunch *)link->getAction();
             std::unique_ptr<GooString> file = std::make_unique<GooString>(ha->getFileName()->c_str());
             const char *p = file->c_str() + file->size() - 4;
             if (!strcmp(p, ".pdf") || !strcmp(p, ".PDF")) {
