@@ -15,8 +15,9 @@
  All changes made under the Poppler project to this file are licensed
  under GPL version 2 or later
 
- Copyright (C) 2008, 2009, 2018 Albert Astals Cid <aacid@kde.org>
+ Copyright (C) 2008, 2009, 2018, 2025 Albert Astals Cid <aacid@kde.org>
  Copyright (C) 2011, 2012 Adrian Johnson <ajohnson@redneon.com>
+ Copyright (C) 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 
  To see a description of the changes please see the Changelog file that
  came with your tarball or type make ChangeLog if you are building from git
@@ -24,7 +25,6 @@
 ========================================================================*/
 
 #include <cstdio>
-#include <cstddef>
 #include <cstring>
 #include <cstdlib>
 #include <cctype>
@@ -47,12 +47,15 @@ bool parseArgs(const ArgDesc *args, int *argc, char *argv[])
     while (i < *argc) {
         if (!strcmp(argv[i], "--")) {
             --*argc;
-            for (j = i; j < *argc; ++j)
+            for (j = i; j < *argc; ++j) {
                 argv[j] = argv[j + 1];
+            }
             break;
-        } else if ((arg = findArg(args, argv[i]))) {
-            if (!grabArg(arg, i, argc, argv))
+        }
+        if ((arg = findArg(args, argv[i]))) {
+            if (!grabArg(arg, i, argc, argv)) {
                 ok = false;
+            }
         } else {
             ++i;
         }
@@ -68,13 +71,15 @@ void printUsage(const char *program, const char *otherArgs, const ArgDesc *args)
 
     w = 0;
     for (arg = args; arg->arg; ++arg) {
-        if ((w1 = strlen(arg->arg)) > w)
+        if ((w1 = strlen(arg->arg)) > w) {
             w = w1;
+        }
     }
 
     fprintf(stderr, "Usage: %s [options]", program);
-    if (otherArgs)
+    if (otherArgs) {
         fprintf(stderr, " %s", otherArgs);
+    }
     fprintf(stderr, "\n");
 
     for (arg = args; arg->arg; ++arg) {
@@ -101,8 +106,9 @@ void printUsage(const char *program, const char *otherArgs, const ArgDesc *args)
             break;
         }
         fprintf(stderr, "%-*s", w1, typ);
-        if (arg->usage)
+        if (arg->usage) {
             fprintf(stderr, ": %s", arg->usage);
+        }
         fprintf(stderr, "\n");
     }
 }
@@ -112,8 +118,9 @@ static const ArgDesc *findArg(const ArgDesc *args, char *arg)
     const ArgDesc *p;
 
     for (p = args; p->arg; ++p) {
-        if (p->kind < argFlagDummy && !strcmp(p->arg, arg))
+        if (p->kind < argFlagDummy && !strcmp(p->arg, arg)) {
             return p;
+        }
     }
     return nullptr;
 }
@@ -161,7 +168,7 @@ static bool grabArg(const ArgDesc *arg, int i, int *argc, char *argv[])
         break;
     case argGooString:
         if (i + 1 < *argc) {
-            ((GooString *)arg->val)->Set(argv[i + 1]);
+            ((GooString *)arg->val)->assign(argv[i + 1]);
             n = 2;
         } else {
             ok = false;
@@ -175,52 +182,58 @@ static bool grabArg(const ArgDesc *arg, int i, int *argc, char *argv[])
     }
     if (n > 0) {
         *argc -= n;
-        for (j = i; j < *argc; ++j)
+        for (j = i; j < *argc; ++j) {
             argv[j] = argv[j + n];
+        }
     }
     return ok;
 }
 
 bool isInt(const char *s)
 {
-    if (*s == '-' || *s == '+')
+    if (*s == '-' || *s == '+') {
         ++s;
-    while (isdigit(*s))
+    }
+    while (isdigit(*s)) {
         ++s;
-    if (*s)
-        return false;
-    return true;
+    }
+    return *s == 0;
 }
 
 bool isFP(const char *s)
 {
     int n;
 
-    if (*s == '-' || *s == '+')
+    if (*s == '-' || *s == '+') {
         ++s;
+    }
     n = 0;
     while (isdigit(*s)) {
         ++s;
         ++n;
     }
-    if (*s == '.')
+    if (*s == '.') {
         ++s;
+    }
     while (isdigit(*s)) {
         ++s;
         ++n;
     }
     if (n > 0 && (*s == 'e' || *s == 'E')) {
         ++s;
-        if (*s == '-' || *s == '+')
+        if (*s == '-' || *s == '+') {
             ++s;
+        }
         n = 0;
-        if (!isdigit(*s))
+        if (!isdigit(*s)) {
             return false;
+        }
         do {
             ++s;
         } while (isdigit(*s));
     }
-    if (*s)
+    if (*s) {
         return false;
+    }
     return true;
 }
