@@ -18,7 +18,7 @@
 // Copyright (C) 2009 Michael K. Johnson <a1237@danlj.org>
 // Copyright (C) 2009 Shen Liang <shenzhuxi@gmail.com>
 // Copyright (C) 2009 Stefan Thomas <thomas@eload24.com>
-// Copyright (C) 2009-2011, 2015, 2018-2022, 2025 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2009-2011, 2015, 2018-2022, 2025, 2026 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2010, 2012, 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2010 Hib Eris <hib@hiberis.nl>
 // Copyright (C) 2010 Jonathan Liu <net147@gmail.com>
@@ -38,7 +38,7 @@
 // Copyright (C) 2021 Diogo Kollross <diogoko@gmail.com>
 // Copyright (C) 2021 Peter Williams <peter@newton.cx>
 // Copyright (C) 2022 James Cloos <cloos@jhcloos.com>
-// Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2025, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -226,10 +226,10 @@ static bool parseJpegOptions()
         const char *comma = strchr(nextOpt, ',');
         GooString opt;
         if (comma) {
-            opt.Set(nextOpt, static_cast<int>(comma - nextOpt));
+            opt.assign(nextOpt, static_cast<int>(comma - nextOpt));
             nextOpt = comma + 1;
         } else {
-            opt.Set(nextOpt);
+            opt.assign(nextOpt);
             nextOpt = nullptr;
         }
         // here opt is "<optN>=<valN> "
@@ -243,7 +243,7 @@ static bool parseJpegOptions()
         opt.erase(iequal, opt.size() - iequal);
         // here opt is "<optN>" and value is "<valN>"
 
-        if (opt.cmp("quality") == 0) {
+        if (opt.compare("quality") == 0) {
             if (!isInt(value.c_str())) {
                 fprintf(stderr, "Invalid jpeg quality\n");
                 return false;
@@ -253,19 +253,19 @@ static bool parseJpegOptions()
                 fprintf(stderr, "jpeg quality must be between 0 and 100\n");
                 return false;
             }
-        } else if (opt.cmp("progressive") == 0) {
+        } else if (opt.compare("progressive") == 0) {
             jpegProgressive = false;
-            if (value.cmp("y") == 0) {
+            if (value.compare("y") == 0) {
                 jpegProgressive = true;
-            } else if (value.cmp("n") != 0) {
+            } else if (value.compare("n") != 0) {
                 fprintf(stderr, "jpeg progressive option must be \"y\" or \"n\"\n");
                 return false;
             }
-        } else if (opt.cmp("optimize") == 0 || opt.cmp("optimise") == 0) {
+        } else if (opt.compare("optimize") == 0 || opt.compare("optimise") == 0) {
             jpegOptimize = false;
-            if (value.cmp("y") == 0) {
+            if (value.compare("y") == 0) {
                 jpegOptimize = true;
-            } else if (value.cmp("n") != 0) {
+            } else if (value.compare("n") != 0) {
                 fprintf(stderr, "jpeg optimize option must be \"y\" or \"n\"\n");
                 return false;
             }
@@ -313,7 +313,7 @@ static void savePageSlice(PDFDoc *doc, SplashOutputDev *splashOut, int pg, int x
         } else {
             e = bitmap->writePNMFile(ppmFile);
         }
-        if (e != splashOk) {
+        if (e != SplashError::NoError) {
             fprintf(stderr, "Could not write image to %s; exiting\n", ppmFile);
             exit(EXIT_FAILURE);
         }
@@ -435,9 +435,8 @@ int main(int argc, char *argv[])
         }
         if (printVersion || printHelp) {
             return 0;
-        } else {
-            return kOtherError;
         }
+        return kOtherError;
     }
     if (argc > 1) {
         fileName = new GooString(argv[1]);
@@ -495,7 +494,7 @@ int main(int argc, char *argv[])
     if (fileName == nullptr) {
         fileName = new GooString("fd://0");
     }
-    if (fileName->cmp("-") == 0) {
+    if (fileName->compare("-") == 0) {
         delete fileName;
         fileName = new GooString("fd://0");
     }
@@ -597,7 +596,7 @@ int main(int argc, char *argv[])
 
 #ifndef UTILS_USE_PTHREADS
 
-    splashOut = new SplashOutputDev(mono ? splashModeMono1 : gray ? splashModeMono8 : (jpegcmyk || overprint) ? splashModeDeviceN8 : splashModeRGB8, 4, false, paperColor, true, thinLineMode, splashOverprintPreview);
+    splashOut = new SplashOutputDev(mono ? splashModeMono1 : gray ? splashModeMono8 : (jpegcmyk || overprint) ? splashModeDeviceN8 : splashModeRGB8, 4, paperColor, true, thinLineMode, splashOverprintPreview);
 
     splashOut->setFontAntialias(fontAntialias);
     splashOut->setVectorAntialias(vectorAntialias);
