@@ -16,7 +16,7 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2006 Kristian Høgsberg <krh@redhat.com>
-// Copyright (C) 2007-2008, 2010, 2015, 2017, 2018, 2020-2022 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2007-2008, 2010, 2015, 2017, 2018, 2020-2022, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2009 Till Kamppeter <till.kamppeter@gmail.com>
 // Copyright (C) 2009 Sanjoy Mahajan <sanjoy@mit.edu>
 // Copyright (C) 2009, 2011, 2012, 2014-2016, 2020 William Bader <williambader@hotmail.com>
@@ -25,9 +25,10 @@
 // Copyright (C) 2013 Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
 // Copyright (C) 2014, 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
-// Copyright (C) 2019, 2021 Oliver Sander <oliver.sander@tu-dresden.de>
+// Copyright (C) 2019, 2021, 2023 Oliver Sander <oliver.sander@tu-dresden.de>
 // Copyright (C) 2020 Philipp Knechtges <philipp-dev@knechtges.com>
 // Copyright (C) 2021 Hubert Figuiere <hub@figuiere.net>
+// Copyright (C) 2025, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -38,17 +39,10 @@
 #include <poppler-config.h>
 #include <cstdio>
 #include <cstdlib>
-#include <cstddef>
 #include <cstring>
 #include "parseargs.h"
 #include "goo/GooString.h"
-#include "goo/gmem.h"
 #include "GlobalParams.h"
-#include "Object.h"
-#include "Stream.h"
-#include "Array.h"
-#include "Dict.h"
-#include "XRef.h"
 #include "Catalog.h"
 #include "Page.h"
 #include "PDFDoc.h"
@@ -58,7 +52,7 @@
 #include "Win32Console.h"
 #include "sanitychecks.h"
 
-#ifdef USE_CMS
+#if USE_CMS
 #    include <lcms2.h>
 #endif
 
@@ -95,9 +89,7 @@ static bool level3Sep = false;
 static bool origPageSizes = false;
 static bool doEPS = false;
 static bool doForm = false;
-#ifdef OPI_SUPPORT
 static bool doOPI = false;
-#endif
 static int splashResolution = 0;
 static bool psBinary = false;
 static bool noEmbedT1Fonts = false;
@@ -127,7 +119,7 @@ static bool overprint = false;
 static GooString processcolorformatname;
 static SplashColorMode processcolorformat;
 static bool processcolorformatspecified = false;
-#ifdef USE_CMS
+#if USE_CMS
 static GooString processcolorprofilename;
 static GfxLCMSProfilePtr processcolorprofile;
 static GooString defaultgrayprofilename;
@@ -149,9 +141,7 @@ static const ArgDesc argDesc[] = { { "-f", argInt, &firstPage, 0, "first page to
                                    { "-origpagesizes", argFlag, &origPageSizes, 0, "conserve original page sizes" },
                                    { "-eps", argFlag, &doEPS, 0, "generate Encapsulated PostScript (EPS)" },
                                    { "-form", argFlag, &doForm, 0, "generate a PostScript form" },
-#ifdef OPI_SUPPORT
                                    { "-opi", argFlag, &doOPI, 0, "generate OPI comments" },
-#endif
                                    { "-r", argInt, &splashResolution, 0, "resolution for rasterization, in DPI (default is 300)" },
                                    { "-binary", argFlag, &psBinary, 0, "write binary data in Level 1 PostScript" },
                                    { "-noembt1", argFlag, &noEmbedT1Fonts, 0, "don't embed Type 1 fonts" },
@@ -162,7 +152,7 @@ static const ArgDesc argDesc[] = { { "-f", argInt, &firstPage, 0, "first page to
                                    { "-aaRaster", argString, rasterAntialiasStr, sizeof(rasterAntialiasStr), "enable anti-aliasing on rasterization: yes, no" },
                                    { "-rasterize", argString, forceRasterizeStr, sizeof(forceRasterizeStr), "control rasterization: always, never, whenneeded" },
                                    { "-processcolorformat", argGooString, &processcolorformatname, 0, "color format that is used during rasterization and transparency reduction: MONO8, RGB8, CMYK8" },
-#ifdef USE_CMS
+#if USE_CMS
                                    { "-processcolorprofile", argGooString, &processcolorprofilename, 0, "ICC color profile to use as the process color profile during rasterization and transparency reduction" },
                                    { "-defaultgrayprofile", argGooString, &defaultgrayprofilename, 0, "ICC color profile to use as the DefaultGray color space" },
                                    { "-defaultrgbprofile", argGooString, &defaultrgbprofilename, 0, "ICC color profile to use as the DefaultRGB color space" },
@@ -194,7 +184,7 @@ int main(int argc, char *argv[])
 {
     std::unique_ptr<PDFDoc> doc;
     GooString *fileName;
-    GooString *psFileName;
+    std::string psFileName;
     PSLevel level;
     PSOutMode mode;
     std::optional<GooString> ownerPW, userPW;
@@ -203,7 +193,7 @@ int main(int argc, char *argv[])
     int exitCode;
     bool rasterAntialias = false;
     std::vector<int> pages;
-#ifdef USE_CMS
+#if USE_CMS
     cmsColorSpaceSignature profilecolorspace;
 #endif
 
@@ -289,7 +279,7 @@ int main(int argc, char *argv[])
         }
     }
 
-#ifdef USE_CMS
+#if USE_CMS
     if (!processcolorprofilename.toStr().empty()) {
         processcolorprofile = make_GfxLCMSProfilePtr(cmsOpenProfileFromFile(processcolorprofilename.c_str(), "r"));
         if (!processcolorprofile) {
@@ -340,7 +330,7 @@ int main(int argc, char *argv[])
         }
     }
 
-#ifdef USE_CMS
+#if USE_CMS
     if (!defaultgrayprofilename.toStr().empty()) {
         defaultgrayprofile = make_GfxLCMSProfilePtr(cmsOpenProfileFromFile(defaultgrayprofilename.c_str(), "r"));
         if (!checkICCProfile(defaultgrayprofile, defaultgrayprofilename.c_str(), LCMS_USED_AS_INPUT, cmsSigGrayData)) {
@@ -368,7 +358,7 @@ int main(int argc, char *argv[])
     if (userPassword[0] != '\001') {
         userPW = GooString(userPassword);
     }
-    if (fileName->cmp("-") == 0) {
+    if (fileName->compare("-") == 0) {
         delete fileName;
         fileName = new GooString("fd://0");
     }
@@ -391,18 +381,19 @@ int main(int argc, char *argv[])
 
     // construct PostScript file name
     if (argc == 3) {
-        psFileName = new GooString(argv[2]);
-    } else if (fileName->cmp("fd://0") == 0) {
+        psFileName = std::string(argv[2]);
+    } else if (fileName->compare("fd://0") == 0) {
         error(errCommandLine, -1, "You have to provide an output filename when reading from stdin.");
         goto err1;
     } else {
-        const char *p = fileName->c_str() + fileName->getLength() - 4;
+        const char *p = fileName->c_str() + fileName->size() - 4;
         if (!strcmp(p, ".pdf") || !strcmp(p, ".PDF")) {
-            psFileName = new GooString(fileName->c_str(), fileName->getLength() - 4);
+            psFileName = std::string(fileName->c_str(), fileName->size() - 4);
+
         } else {
-            psFileName = fileName->copy();
+            psFileName = fileName->toStr();
         }
-        psFileName->append(doEPS ? ".eps" : ".ps");
+        psFileName += (doEPS ? ".eps" : ".ps");
     }
 
     // get page range
@@ -414,13 +405,13 @@ int main(int argc, char *argv[])
     }
     if (lastPage < firstPage) {
         error(errCommandLine, -1, "Wrong page range given: the first page ({0:d}) can not be after the last page ({1:d}).", firstPage, lastPage);
-        goto err2;
+        goto err1;
     }
 
     // check for multi-page EPS or form
     if ((doEPS || doForm) && firstPage != lastPage) {
         error(errCommandLine, -1, "EPS and form files can only contain one page.");
-        goto err2;
+        goto err1;
     }
 
     for (int i = firstPage; i <= lastPage; ++i) {
@@ -428,7 +419,7 @@ int main(int argc, char *argv[])
     }
 
     // write PostScript file
-    psOut = new PSOutputDev(psFileName->c_str(), doc.get(), nullptr, pages, mode, paperWidth, paperHeight, noCrop, duplex, /*imgLLXA*/ 0, /*imgLLYA*/ 0,
+    psOut = new PSOutputDev(psFileName.c_str(), doc.get(), nullptr, pages, mode, paperWidth, paperHeight, noCrop, duplex, /*imgLLXA*/ 0, /*imgLLYA*/ 0,
                             /*imgURXA*/ 0, /*imgURYA*/ 0, psRasterizeWhenNeeded, /*manualCtrlA*/ false, /*customCodeCbkA*/ nullptr, /*customCodeCbkDataA*/ nullptr, level);
     if (noCenter) {
         psOut->setPSCenter(false);
@@ -469,7 +460,7 @@ int main(int argc, char *argv[])
     if (processcolorformatspecified) {
         psOut->setProcessColorFormat(processcolorformat);
     }
-#ifdef USE_CMS
+#if USE_CMS
     psOut->setDisplayProfile(processcolorprofile);
     psOut->setDefaultGrayProfile(defaultgrayprofile);
     psOut->setDefaultRGBProfile(defaultrgbprofile);
@@ -483,9 +474,7 @@ int main(int argc, char *argv[])
     psOut->setPreloadImagesForms(preload);
     psOut->setOptimizeColorSpace(optimizeColorSpace);
     psOut->setPassLevel1CustomColor(passLevel1CustomColor);
-#ifdef OPI_SUPPORT
     psOut->setGenerateOPI(doOPI);
-#endif
     psOut->setUseBinary(psBinary);
 
     psOut->setRasterAntialias(rasterAntialias);
@@ -496,15 +485,13 @@ int main(int argc, char *argv[])
     } else {
         delete psOut;
         exitCode = 2;
-        goto err2;
+        goto err1;
     }
     delete psOut;
 
     exitCode = 0;
 
     // clean up
-err2:
-    delete psFileName;
 err1:
     delete fileName;
 err0:
