@@ -7,15 +7,16 @@
 // Copyright (C) 2011-2015, 2017 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2012 Arseny Solokha <asolokha@gmx.com>
 // Copyright (C) 2012 Fabio D'Urso <fabiodurso@hotmail.it>
-// Copyright (C) 2012, 2014, 2017-2019, 2021, 2022 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2012, 2014, 2017-2019, 2021, 2022, 2024, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2013 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2013 Hib Eris <hib@hiberis.nl>
 // Copyright (C) 2015 Arthur Stavisky <vovodroid@gmail.com>
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 // Copyright (C) 2019 Marek Kasik <mkasik@redhat.com>
-// Copyright (C) 2019 Oliver Sander <oliver.sander@tu-dresden.de>
+// Copyright (C) 2019, 2023 Oliver Sander <oliver.sander@tu-dresden.de>
 // Copyright (C) 2022 crt <chluo@cse.cuhk.edu.hk>
+// Copyright (C) 2025, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 //========================================================================
 
@@ -37,7 +38,7 @@ static void doMergeNameTree(PDFDoc *doc, XRef *srcXRef, XRef *countRef, int oldR
     Object mergeNameArray = mergeNameTree->lookup("Names");
     Object srcNameArray = srcNameTree->lookup("Names");
     if (mergeNameArray.isArray() && srcNameArray.isArray()) {
-        Array *newNameArray = new Array(srcXRef);
+        auto *newNameArray = new Array(srcXRef);
         int j = 0;
         for (int i = 0; i < srcNameArray.arrayGetLength() - 1; i += 2) {
             const Object &key = srcNameArray.arrayGetNF(i);
@@ -47,11 +48,11 @@ static void doMergeNameTree(PDFDoc *doc, XRef *srcXRef, XRef *countRef, int oldR
                     const Object &mkey = mergeNameArray.arrayGetNF(j);
                     const Object &mvalue = mergeNameArray.arrayGetNF(j + 1);
                     if (mkey.isString() && mvalue.isRef()) {
-                        if (mkey.getString()->cmp(key.getString()) < 0) {
-                            newNameArray->add(Object(new GooString(mkey.getString()->c_str())));
-                            newNameArray->add(Object({ mvalue.getRef().num + numOffset, mvalue.getRef().gen }));
+                        if (mkey.getString()->compare(key.getString()->toStr()) < 0) {
+                            newNameArray->add(Object(mkey.getString()->copy()));
+                            newNameArray->add(Object(Ref { .num = mvalue.getRef().num + numOffset, .gen = mvalue.getRef().gen }));
                             j += 2;
-                        } else if (mkey.getString()->cmp(key.getString()) == 0) {
+                        } else if (mkey.getString()->compare(key.getString()->toStr()) == 0) {
                             j += 2;
                         } else {
                             break;
@@ -60,7 +61,7 @@ static void doMergeNameTree(PDFDoc *doc, XRef *srcXRef, XRef *countRef, int oldR
                         j += 2;
                     }
                 }
-                newNameArray->add(Object(new GooString(key.getString()->c_str())));
+                newNameArray->add(Object(key.getString()->copy()));
                 newNameArray->add(Object(value.getRef()));
             }
         }
@@ -68,21 +69,21 @@ static void doMergeNameTree(PDFDoc *doc, XRef *srcXRef, XRef *countRef, int oldR
             const Object &mkey = mergeNameArray.arrayGetNF(j);
             const Object &mvalue = mergeNameArray.arrayGetNF(j + 1);
             if (mkey.isString() && mvalue.isRef()) {
-                newNameArray->add(Object(new GooString(mkey.getString()->c_str())));
-                newNameArray->add(Object({ mvalue.getRef().num + numOffset, mvalue.getRef().gen }));
+                newNameArray->add(Object(mkey.getString()->copy()));
+                newNameArray->add(Object(Ref { .num = mvalue.getRef().num + numOffset, .gen = mvalue.getRef().gen }));
             }
             j += 2;
         }
         srcNameTree->set("Names", Object(newNameArray));
         doc->markPageObjects(mergeNameTree, srcXRef, countRef, numOffset, oldRefNum, newRefNum);
     } else if (srcNameArray.isNull() && mergeNameArray.isArray()) {
-        Array *newNameArray = new Array(srcXRef);
+        auto *newNameArray = new Array(srcXRef);
         for (int i = 0; i < mergeNameArray.arrayGetLength() - 1; i += 2) {
             const Object &key = mergeNameArray.arrayGetNF(i);
             const Object &value = mergeNameArray.arrayGetNF(i + 1);
             if (key.isString() && value.isRef()) {
-                newNameArray->add(Object(new GooString(key.getString()->c_str())));
-                newNameArray->add(Object({ value.getRef().num + numOffset, value.getRef().gen }));
+                newNameArray->add(Object(key.getString()->copy()));
+                newNameArray->add(Object(Ref { .num = value.getRef().num + numOffset, .gen = value.getRef().gen }));
             }
         }
         srcNameTree->add("Names", Object(newNameArray));
@@ -106,16 +107,21 @@ static void doMergeNameDict(PDFDoc *doc, XRef *srcXRef, XRef *countRef, int oldR
     }
 }
 
-static void doMergeFormDict(Dict *srcFormDict, Dict *mergeFormDict, int numOffset)
+static bool doMergeFormDict(Dict *srcFormDict, Dict *mergeFormDict, int numOffset)
 {
     Object srcFields = srcFormDict->lookup("Fields");
     Object mergeFields = mergeFormDict->lookup("Fields");
     if (srcFields.isArray() && mergeFields.isArray()) {
         for (int i = 0; i < mergeFields.arrayGetLength(); i++) {
             const Object &value = mergeFields.arrayGetNF(i);
-            srcFields.arrayAdd(Object({ value.getRef().num + numOffset, value.getRef().gen }));
+            if (!value.isRef()) {
+                error(errSyntaxError, -1, "Fields object is not a Ref.");
+                return false;
+            }
+            srcFields.arrayAdd(Object(Ref { .num = value.getRef().num + numOffset, .gen = value.getRef().gen }));
         }
     }
+    return true;
 }
 
 ///////////////////////////////////////////////////////////////////////////
@@ -132,9 +138,8 @@ int main(int argc, char *argv[])
     XRef *yRef, *countRef;
     FILE *f;
     OutStream *outStr;
-    int i;
-    int j, rootNum;
-    std::vector<PDFDoc *> docs;
+    int rootNum;
+    std::vector<std::unique_ptr<PDFDoc>> docs;
     int majorVersion = 0;
     int minorVersion = 0;
     char *fileName = argv[argc - 1];
@@ -154,10 +159,9 @@ int main(int argc, char *argv[])
     }
     globalParams = std::make_unique<GlobalParams>();
 
-    for (i = 1; i < argc - 1; i++) {
-        PDFDoc *doc = new PDFDoc(std::make_unique<GooString>(argv[i]));
+    for (int i = 1; i < argc - 1; i++) {
+        std::unique_ptr<PDFDoc> doc = std::make_unique<PDFDoc>(std::make_unique<GooString>(argv[i]));
         if (doc->isOk() && !doc->isEncrypted() && doc->getXRef()->getCatalog().isDict()) {
-            docs.push_back(doc);
             if (doc->getPDFMajorVersion() > majorVersion) {
                 majorVersion = doc->getPDFMajorVersion();
                 minorVersion = doc->getPDFMinorVersion();
@@ -166,11 +170,13 @@ int main(int argc, char *argv[])
                     minorVersion = doc->getPDFMinorVersion();
                 }
             }
+            docs.push_back(std::move(doc));
         } else if (doc->isOk()) {
             if (doc->isEncrypted()) {
                 error(errUnimplemented, -1, "Could not merge encrypted files ('{0:s}')", argv[i]);
                 return -1;
-            } else if (!doc->getXRef()->getCatalog().isDict()) {
+            }
+            if (!doc->getXRef()->getCatalog().isDict()) {
                 error(errSyntaxError, -1, "XRef's Catalog is not a dictionary ('{0:s}')", argv[i]);
                 return -1;
             }
@@ -196,7 +202,7 @@ int main(int argc, char *argv[])
     Object names;
     Object afObj;
     Object ocObj;
-    if (docs.size() >= 1) {
+    if (!docs.empty()) {
         Object catObj = docs[0]->getXRef()->getCatalog();
         if (!catObj.isDict()) {
             fclose(f);
@@ -222,12 +228,12 @@ int main(int argc, char *argv[])
             docs[0]->markPageObjects(names.getDict(), yRef, countRef, 0, refPage->num, refPage->num);
         }
         if (intents.isArray() && intents.arrayGetLength() > 0) {
-            for (i = 1; i < (int)docs.size(); i++) {
+            for (size_t i = 1; i < docs.size(); i++) {
                 Object pagecatObj = docs[i]->getXRef()->getCatalog();
                 Dict *pagecatDict = pagecatObj.getDict();
                 Object pageintents = pagecatDict->lookup("OutputIntents");
                 if (pageintents.isArray() && pageintents.arrayGetLength() > 0) {
-                    for (j = intents.arrayGetLength() - 1; j >= 0; j--) {
+                    for (int j = intents.arrayGetLength() - 1; j >= 0; j--) {
                         Object intent = intents.arrayGet(j, 0);
                         if (intent.isDict()) {
                             Object idf = intent.dictLookup("OutputConditionIdentifier");
@@ -240,7 +246,7 @@ int main(int argc, char *argv[])
                                         Object pgidf = pgintent.dictLookup("OutputConditionIdentifier");
                                         if (pgidf.isString()) {
                                             const GooString *gpgidf = pgidf.getString();
-                                            if (gpgidf->cmp(gidf) == 0) {
+                                            if (gpgidf->compare(gidf->toStr()) == 0) {
                                                 removeIntent = false;
                                                 break;
                                             }
@@ -266,7 +272,7 @@ int main(int argc, char *argv[])
             }
         }
         if (intents.isArray() && intents.arrayGetLength() > 0) {
-            for (j = intents.arrayGetLength() - 1; j >= 0; j--) {
+            for (int j = intents.arrayGetLength() - 1; j >= 0; j--) {
                 Object intent = intents.arrayGet(j, 0);
                 if (intent.isDict()) {
                     docs[0]->markPageObjects(intent.getDict(), yRef, countRef, numOffset, 0, 0);
@@ -277,8 +283,8 @@ int main(int argc, char *argv[])
         }
     }
 
-    for (i = 0; i < (int)docs.size(); i++) {
-        for (j = 1; j <= docs[i]->getNumPages(); j++) {
+    for (size_t i = 0; i < docs.size(); i++) {
+        for (int j = 1; j <= docs[i]->getNumPages(); j++) {
             if (!docs[i]->getCatalog()->getPage(j)) {
                 continue;
             }
@@ -287,7 +293,14 @@ int main(int argc, char *argv[])
             if (docs[i]->getCatalog()->getPage(j)->isCropped()) {
                 cropBox = docs[i]->getCatalog()->getPage(j)->getCropBox();
             }
-            docs[i]->replacePageDict(j, docs[i]->getCatalog()->getPage(j)->getRotate(), docs[i]->getCatalog()->getPage(j)->getMediaBox(), cropBox);
+            if (!docs[i]->replacePageDict(j, docs[i]->getCatalog()->getPage(j)->getRotate(), docs[i]->getCatalog()->getPage(j)->getMediaBox(), cropBox)) {
+                fclose(f);
+                delete yRef;
+                delete countRef;
+                delete outStr;
+                error(errSyntaxError, -1, "PDFDoc::replacePageDict failed.");
+                return -1;
+            }
             Ref *refPage = docs[i]->getCatalog()->getPageRef(j);
             Object page = docs[i]->getXRef()->fetch(*refPage);
             Dict *pageDict = page.getDict();
@@ -318,14 +331,20 @@ int main(int argc, char *argv[])
             if (!names.isDict()) {
                 names = Object(new Dict(yRef));
             }
-            doMergeNameDict(docs[i], yRef, countRef, 0, 0, names.getDict(), pageNames.getDict(), numOffset);
+            doMergeNameDict(docs[i].get(), yRef, countRef, 0, 0, names.getDict(), pageNames.getDict(), numOffset);
         }
         Object pageForm = pageCatDict->lookup("AcroForm");
         if (i > 0 && !pageForm.isNull() && pageForm.isDict()) {
             if (afObj.isNull()) {
                 afObj = pageCatDict->lookupNF("AcroForm").copy();
             } else if (afObj.isDict()) {
-                doMergeFormDict(afObj.getDict(), pageForm.getDict(), numOffset);
+                if (!doMergeFormDict(afObj.getDict(), pageForm.getDict(), numOffset)) {
+                    fclose(f);
+                    delete yRef;
+                    delete countRef;
+                    delete outStr;
+                    return -1;
+                }
             }
         }
         objectsCount += docs[i]->writePageObjects(outStr, yRef, numOffset, true);
@@ -339,7 +358,7 @@ int main(int argc, char *argv[])
     // insert OutputIntents
     if (intents.isArray() && intents.arrayGetLength() > 0) {
         outStr->printf(" /OutputIntents [");
-        for (j = 0; j < intents.arrayGetLength(); j++) {
+        for (int j = 0; j < intents.arrayGetLength(); j++) {
             Object intent = intents.arrayGet(j, 0);
             if (intent.isDict()) {
                 PDFDoc::writeObject(&intent, outStr, yRef, 0, nullptr, cryptRC4, 0, 0, 0);
@@ -368,18 +387,18 @@ int main(int argc, char *argv[])
     yRef->add(rootNum + 1, 0, outStr->getPos(), true);
     outStr->printf("%d 0 obj\n", rootNum + 1);
     outStr->printf("<< /Type /Pages /Kids [");
-    for (j = 0; j < (int)pages.size(); j++) {
-        outStr->printf(" %d 0 R", rootNum + j + 2);
+    for (size_t j = 0; j < pages.size(); j++) {
+        outStr->printf(" %zd 0 R", rootNum + j + 2);
     }
     outStr->printf(" ] /Count %zd >>\nendobj\n", pages.size());
     objectsCount++;
 
-    for (i = 0; i < (int)pages.size(); i++) {
+    for (size_t i = 0; i < pages.size(); i++) {
         yRef->add(rootNum + i + 2, 0, outStr->getPos(), true);
-        outStr->printf("%d 0 obj\n", rootNum + i + 2);
+        outStr->printf("%zu 0 obj\n", rootNum + i + 2);
         outStr->printf("<< ");
         Dict *pageDict = pages[i].getDict();
-        for (j = 0; j < pageDict->getLength(); j++) {
+        for (int j = 0; j < pageDict->getLength(); j++) {
             if (j > 0) {
                 outStr->printf(" ");
             }
@@ -409,8 +428,5 @@ int main(int argc, char *argv[])
     fclose(f);
     delete yRef;
     delete countRef;
-    for (i = 0; i < (int)docs.size(); i++) {
-        delete docs[i];
-    }
     return 0;
 }
